from .protocol import Symbol
import warnings


class _Deprecated:
    def __init__(self, oldname, symbol):
        self.oldname = oldname
        self.symbol = symbol

    def __get__(self, _obj, _objtype=None):
        warnings.warn(
            f"symbol {self.oldname} has been renamed to {self.symbol.name}",
            category=DeprecationWarning,
            stacklevel=2,
        )
        return self.symbol


class EuArm7Functions:

    _start_arm7 = Symbol(
        [0x0],
        [0x2380000],
        None,
        "_start_arm7",
        "The entrypoint for the ARM7 CPU.\n\nHandles mapping the ARM7 binary into the various memory areas that the program will be using.\n\nOnce the memory mapping has been completed, a constant containing the address to NitroSpMain is loaded into a register (r1), and a `bx` branch will jump to NitroSpMain.\n\nNo params.",
        None,
    )

    do_autoload_arm7 = Symbol([0x118], [0x2380118], None, "do_autoload_arm7", "", None)

    StartAutoloadDoneCallbackArm7 = Symbol(
        [0x188], [0x2380188], None, "StartAutoloadDoneCallbackArm7", "", None
    )

    NitroSpMain = Symbol(
        [0x1E8],
        [0x23801E8],
        None,
        "NitroSpMain",
        "This main function for the ARM7 subsystem. Contains the main event loop.\n\nNo params.",
        None,
    )

    HardwareInterrupt = Symbol(
        [0x3670],
        [0x2383670],
        None,
        "HardwareInterrupt",
        "Called whenever a hardware interrupt takes place.\n\nReturns immediately if the IME flag is 0 or if none of the devices that requested an interrupt has the corresponding Interrupt Enable flag set.\nIt searches for the first device that requested an interrupt, clears its Interrupt Request flag, then jumps to the start of the corresponding interrupt function. The return address is manually set to ReturnFromInterrupt.\nThis function does not return.\n\nNo params.",
        None,
    )

    ReturnFromInterrupt = Symbol(
        [0x36DC],
        [0x23836DC],
        None,
        "ReturnFromInterrupt",
        "The execution returns to this function after a hardware interrupt function is run.\n\nNo params.",
        None,
    )

    AudioInterrupt = Symbol(
        [0x3824],
        [0x2383824],
        None,
        "AudioInterrupt",
        "Called when handling a hardware interrupt from the audio system.\n\nIts parameter is used to index a list of function pointers. The game then jumps to the read pointer.\n\nr0: Index of the function to jump to",
        None,
    )

    ClearImeFlag = Symbol(
        [0x3AC0],
        [0x2383AC0],
        None,
        "ClearImeFlag",
        "Clears the Interrupt Master Enable flag, which disables all hardware interrupts.\n\nreturn: Previous IME value",
        None,
    )

    ClearIeFlag = Symbol(
        [0x3B10],
        [0x2383B10],
        None,
        "ClearIeFlag",
        "Clears the specified Interrupt Enable flag, which disables interrupts for the specified hardware component.\n\nr0: Flag to clear\nreturn: Previous value of the Interrupt Enable flags",
        None,
    )

    GetCurrentPlaybackTime = Symbol(
        [0x5404],
        [0x2385404],
        None,
        "GetCurrentPlaybackTime",
        "Returns the time that the current song has been playing for. Might have a more generic purpose.\n\nThe time is obtained using a couple of RAM counters and the hardware timers for additional precision.\nThe game uses this value to know when a given note should stop being played. It doesn't seem to be used to keep track of the\ncurrent time instant within the song.\n\nreturn: Playback time. Units unknown.",
        None,
    )

    ClearIrqFlag = Symbol(
        [0x5ED4],
        [0x2385ED4],
        None,
        "ClearIrqFlag",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nreturn: Old value of cpsr & 0x80 (0x80 if interrupts were disabled, 0x0 if they were already enabled)",
        None,
    )

    EnableIrqFlag = Symbol(
        [0x5EE8],
        [0x2385EE8],
        None,
        "EnableIrqFlag",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nreturn: Old value of cpsr & 0x80 (0x80 if interrupts were already disabled, 0x0 if they were enabled)",
        None,
    )

    SetIrqFlag = Symbol(
        [0x5EFC],
        [0x2385EFC],
        None,
        "SetIrqFlag",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nr0: Value to set the flag to (0x80 to set it, which disables interrupts; 0x0 to unset it, which enables interrupts)\nreturn: Old value of cpsr & 0x80 (0x80 if interrupts were disabled, 0x0 if they were enabled)",
        None,
    )

    EnableIrqFiqFlags = Symbol(
        [0x5F14],
        [0x2385F14],
        None,
        "EnableIrqFiqFlags",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nreturn: Old value of cpsr & 0xC0 (contains the previous values of the i and f flags)",
        None,
    )

    SetIrqFiqFlags = Symbol(
        [0x5F28],
        [0x2385F28],
        None,
        "SetIrqFiqFlags",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nr0: Value to set the flags to (0xC0 to set both flags, 0x80 to set the i flag and clear the f flag, 0x40 to set the f flag and clear the i flag and 0x0 to clear both flags)\nreturn: Old value of cpsr & 0xC0 (contains the previous values of the i and f flags)",
        None,
    )

    GetProcessorMode = Symbol(
        [0x5F40],
        [0x2385F40],
        None,
        "GetProcessorMode",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nreturn: cpsr & 0x1f (the cpsr mode bits M4-M0)",
        None,
    )

    _s32_div_f = Symbol(
        [0xEDB0],
        [0x238EDB0],
        None,
        "_s32_div_f",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nr0: dividend\nr1: divisor\nreturn: (quotient) | (remainder << 32)",
        None,
    )

    _u32_div_f = Symbol(
        [0xEFBC],
        [0x238EFBC],
        None,
        "_u32_div_f",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nr0: dividend\nr1: divisor\nreturn: (quotient) | (remainder << 32)",
        None,
    )

    _u32_div_not_0_f = Symbol(
        [0xEFC4],
        [0x238EFC4],
        None,
        "_u32_div_not_0_f",
        "Copy of the ARM9 function. See arm9.yml for more information.\n\nr0: dividend\nr1: divisor\nreturn: (quotient) | (remainder << 32)",
        None,
    )

    __divsi3 = _Deprecated("__divsi3", _s32_div_f)

    __udivsi3 = _Deprecated("__udivsi3", _u32_div_f)

    __udivsi3_no_zero_check = _Deprecated("__udivsi3_no_zero_check", _u32_div_not_0_f)


class EuArm7Data:

    pass


class EuArm7Section:
    name = "arm7"
    description = "The ARM7 binary.\n\nThis is the secondary binary that gets loaded when the game is launched.\n\nSpeaking generally, this is the program run by the Nintendo DS's secondary ARM7TDMI CPU, which handles the audio I/O, the touch screen, Wi-Fi functions, cryptography, and more.\n\nMemory map: (binary is initially loaded at 0x2380000)\n0x2380000-0x23801E8 => Contains _start_arm7 and two more methods, all related to memory mapping.\n0x23801E8-0x238F7F0 => Mapped to 0x37F8000, contains NitroSpMain and functions crucial to execution.\n0x238F7F0-0x23A7068 => Mapped to 0x27E0000, contains everything else that won't fit in the fast WRAM.\n\nNote that while the length for the main EU/NA/JP block is defined as 0x27080 above, after memory mappings, the block located at that address is only a 0x1E8 long ENTRY block, containing 3 functions solely used for the initial memory mapping. The memory following this block is reused and its purpose is undocumented at the moment."
    loadaddress = 0x2380000
    length = 0x27080
    functions = EuArm7Functions
    data = EuArm7Data


class EuArm9Functions:

    Svc_SoftReset = Symbol(
        [0x1A4], [0x20001A4], None, "Svc_SoftReset", "Software interrupt.", None
    )

    Svc_WaitByLoop = Symbol(
        [0x6B0], [0x20006B0], None, "Svc_WaitByLoop", "Software interrupt.", None
    )

    Svc_CpuSet = Symbol(
        [0x79E], [0x200079E], None, "Svc_CpuSet", "Software interrupt.", None
    )

    _start = Symbol(
        [0x800],
        [0x2000800],
        None,
        "_start",
        "The entrypoint for the ARM9 CPU. This is like the 'main' function for the ARM9 subsystem.\n\nOnce the entry function reaches the end, a constant containing the address to NitroMain is loaded into a register (r1), and a `bx` branch will jump to NitroMain.\n\nNo params.",
        None,
    )

    InitI_CpuClear32 = Symbol([0x954], [0x2000954], None, "InitI_CpuClear32", "", None)

    MIi_UncompressBackward = Symbol(
        [0x970],
        [0x2000970],
        None,
        "MIi_UncompressBackward",
        "Startup routine in the program's crt0 (https://en.wikipedia.org/wiki/Crt0).",
        None,
    )

    do_autoload = Symbol(
        [0xA1C],
        [0x2000A1C],
        None,
        "do_autoload",
        "Startup routine in the program's crt0 (https://en.wikipedia.org/wiki/Crt0).",
        None,
    )

    StartAutoloadDoneCallback = Symbol(
        [0xAAC],
        [0x2000AAC],
        None,
        "StartAutoloadDoneCallback",
        "Startup routine in the program's crt0 (https://en.wikipedia.org/wiki/Crt0).",
        None,
    )

    init_cp15 = Symbol([0xAB0], [0x2000AB0], None, "init_cp15", "", None)

    OSi_ReferSymbol = Symbol(
        [0xB9C],
        [0x2000B9C],
        None,
        "OSi_ReferSymbol",
        "Startup routine in the program's crt0 (https://en.wikipedia.org/wiki/Crt0).",
        None,
    )

    NitroMain = Symbol(
        [0xC6C],
        [0x2000C6C],
        None,
        "NitroMain",
        "Entrypoint into NitroSDK, the DS devkit library.",
        None,
    )

    InitMemAllocTable = Symbol(
        [0xDE0],
        [0x2000DE0],
        None,
        "InitMemAllocTable",
        "Initializes MEMORY_ALLOCATION_TABLE.\n\nSets up the default memory arena, sets the default memory allocator parameters (calls SetMemAllocatorParams(0, 0)), and does some other stuff.\n\nNo params.",
        None,
    )

    SetMemAllocatorParams = Symbol(
        [0xE70],
        [0x2000E70],
        None,
        "SetMemAllocatorParams",
        "Sets global parameters for the memory allocator.\n\nThis includes MEMORY_ALLOCATION_ARENA_GETTERS and some other stuff.\n\nDungeon mode uses the default arena getters. Ground mode uses its own arena getters that return custom arenas for some flag values, which are defined in overlay 11 and set (by calling this function) at the start of GroundMainLoop. Note that the sound memory arena is provided explicitly to MemLocateSet in the sound code, so doesn't go through this path.\n\nr0: GetAllocArena function pointer (GetAllocArenaDefault is used if null)\nr1: GetFreeArena function pointer (GetFreeArenaDefault is used if null)",
        None,
    )

    GetAllocArenaDefault = Symbol(
        [0xEC0],
        [0x2000EC0],
        None,
        "GetAllocArenaDefault",
        "The default function for retrieving the arena for memory allocations. This function always just returns the initial arena pointer.\n\nr0: initial memory arena pointer, or null\nr1: flags (see MemAlloc)\nreturn: memory arena pointer, or null",
        None,
    )

    GetFreeArenaDefault = Symbol(
        [0xEC4],
        [0x2000EC4],
        None,
        "GetFreeArenaDefault",
        "The default function for retrieving the arena for memory freeing. This function always just returns the initial arena pointer.\n\nr0: initial memory arena pointer, or null\nr1: pointer to free\nreturn: memory arena pointer, or null",
        None,
    )

    InitMemArena = Symbol(
        [0xEC8],
        [0x2000EC8],
        None,
        "InitMemArena",
        "Initializes a new memory arena with the given specifications, and records it in the global MEMORY_ALLOCATION_TABLE.\n\nr0: arena struct to be initialized\nr1: memory region to be owned by the arena, as {pointer, length}\nr2: pointer to block metadata array for the arena to use\nr3: maximum number of blocks that the arena can hold",
        None,
    )

    MemAllocFlagsToBlockType = Symbol(
        [0xF44],
        [0x2000F44],
        None,
        "MemAllocFlagsToBlockType",
        "Converts the internal alloc flags bitfield (struct mem_block field 0x4) to the block type bitfield (struct mem_block field 0x0).\n\nr0: internal alloc flags\nreturn: block type flags",
        None,
    )

    FindAvailableMemBlock = Symbol(
        [0xF88],
        [0x2000F88],
        None,
        "FindAvailableMemBlock",
        "Searches through the given memory arena for a block with enough free space.\n\nBlocks are searched in reverse order. For object allocations (i.e., not arenas), the block with the smallest amount of free space that still suffices is returned. For arena allocations, the first satisfactory block found is returned.\n\nr0: memory arena to search\nr1: internal alloc flags\nr2: amount of space needed, in bytes\nreturn: index of the located block in the arena's block array, or -1 if nothing is available",
        None,
    )

    SplitMemBlock = Symbol(
        [0x1070],
        [0x2001070],
        None,
        "SplitMemBlock",
        "Given a memory block at a given index, splits off another memory block of the specified size from the end.\n\nSince blocks are stored in an array on the memory arena struct, this is essentially an insertion operation, plus some processing on the block being split and its child.\n\nr0: memory arena\nr1: block index\nr2: internal alloc flags\nr3: number of bytes to split off\nstack[0]: user alloc flags (to assign to the new block)\nreturn: the newly split-off memory block",
        None,
    )

    MemAlloc = Symbol(
        [0x1170],
        [0x2001170],
        None,
        "MemAlloc",
        "Allocates some memory on the heap, returning a pointer to the starting address.\n\nMemory allocation is done with region-based memory management. See MEMORY_ALLOCATION_TABLE for more information.\n\nThis function is just a wrapper around MemLocateSet.\n\nr0: length in bytes\nr1: flags (see the comment on struct mem_block::user_flags)\nreturn: pointer",
        None,
    )

    MemFree = Symbol(
        [0x1188],
        [0x2001188],
        None,
        "MemFree",
        "Frees heap-allocated memory.\n\nThis function is just a wrapper around MemLocateUnset.\n\nr0: pointer",
        None,
    )

    MemArenaAlloc = Symbol(
        [0x119C],
        [0x200119C],
        None,
        "MemArenaAlloc",
        "Allocates some memory on the heap and creates a new global memory arena with it.\n\nThe actual allocation part works similarly to the normal MemAlloc.\n\nr0: desired parent memory arena, or null\nr1: length of the arena in bytes\nr2: maximum number of blocks that the arena can hold\nr3: flags (see MemAlloc)\nreturn: memory arena pointer",
        None,
    )

    CreateMemArena = Symbol(
        [0x1280],
        [0x2001280],
        None,
        "CreateMemArena",
        "Creates a new memory arena within a given block of memory.\n\nThis is essentially a wrapper around InitMemArena, accounting for the space needed by the arena metadata.\n\nr0: memory region in which to create the arena, as {pointer, length}\nr1: maximum number of blocks that the arena can hold\nreturn: memory arena pointer",
        None,
    )

    MemLocateSet = Symbol(
        [0x1390],
        [0x2001390],
        None,
        "MemLocateSet",
        "The implementation for MemAlloc.\n\nAt a high level, memory is allocated by choosing a memory arena, looking through blocks in the memory arena until a free one that's large enough is found, then splitting off a new memory block of the needed size.\n\nThis function is not fallible, i.e., it hangs the whole program on failure, so callers can assume it never fails.\n\nThe name for this function comes from the error message logged on failure, and it reflects what the function does: locate an available block of memory and set it up for the caller.\n\nr0: desired memory arena for allocation, or null (MemAlloc passes null)\nr1: length in bytes\nr2: flags (see MemAlloc)\nreturn: pointer to allocated memory",
        None,
    )

    MemLocateUnset = Symbol(
        [0x1638],
        [0x2001638],
        None,
        "MemLocateUnset",
        "The implementation for MemFree.\n\nAt a high level, memory is freed by locating the pointer in its memory arena (searching block-by-block) and emptying the block so it's available for future allocations, and merging it with neighboring blocks if they're available.\n\nr0: desired memory arena for freeing, or null (MemFree passes null)\nr1: pointer to free",
        None,
    )

    RoundUpDiv256 = Symbol(
        [0x1894],
        [0x2001894],
        None,
        "RoundUpDiv256",
        "Divide a number by 256 and round up to the nearest integer.\n\nr0: number\nreturn: number // 256",
        None,
    )

    UFixedPoint64CmpLt = Symbol(
        [0x1A30],
        [0x2001A30],
        None,
        "UFixedPoint64CmpLt",
        "Compares two unsigned 64-bit fixed-point numbers (16 fraction bits) x and y.\n\nr0: upper 32 bits of x\nr1: lower 32 bits of x\nr2: upper 32 bits of y\nr3: lower 32 bits of y\nreturn: x < y",
        None,
    )

    MultiplyByFixedPoint = Symbol(
        [0x1A54],
        [0x2001A54],
        None,
        "MultiplyByFixedPoint",
        "Multiply a signed integer x by a signed binary fixed-point multiplier (8 fraction bits).\n\nr0: x\nr1: multiplier\nreturn: x * multiplier",
        None,
    )

    UMultiplyByFixedPoint = Symbol(
        [0x1B0C],
        [0x2001B0C],
        None,
        "UMultiplyByFixedPoint",
        "Multiplies an unsigned integer x by an unsigned binary fixed-point multiplier (8 fraction bits).\n\nr0: x\nr1: multiplier\nreturn: x * multiplier",
        None,
    )

    IntToFixedPoint64 = Symbol(
        [0x1C80],
        [0x2001C80],
        None,
        "IntToFixedPoint64",
        "Converts a signed integer to a 64-bit fixed-point number (16 fraction bits).\n\nNote that this function appears to be bugged: it appears to try to sign-extend if the input is negative, but in a nonsensical way, checking the sign bit for a 16-bit signed integer, but then doing the sign extension as if the input were a 32-bit signed integer.\n\nr0: [output] 64-bit fixed-point number\nr1: 32-bit signed int",
        None,
    )

    FixedPoint64ToInt = Symbol(
        [0x1CB0],
        [0x2001CB0],
        None,
        "FixedPoint64ToInt",
        "Converts a 64-bit fixed-point number (16 fraction bits) to a signed integer.\n\nr0: 64-bit fixed-point number\nreturn: 32-bit signed",
        None,
    )

    FixedPoint32To64 = Symbol(
        [0x1CD4],
        [0x2001CD4],
        None,
        "FixedPoint32To64",
        "Converts a 32-bit fixed-point number (8 fraction bits) to a 64-bit fixed point number (16 fraction bits). Sign-extends as necessary.\n\nr0: [output] 64-bit fixed-point number\nr1: 32-bit signed fixed-point number",
        None,
    )

    NegateFixedPoint64 = Symbol(
        [0x1CF8],
        [0x2001CF8],
        None,
        "NegateFixedPoint64",
        "Negates a 64-bit fixed-point number (16 fraction bits) in-place.\n\nr0: 64-bit fixed-point number to negate",
        None,
    )

    FixedPoint64IsZero = Symbol(
        [0x1D28],
        [0x2001D28],
        None,
        "FixedPoint64IsZero",
        "Checks whether a 64-bit fixed-point number (16 fraction bits) is zero.\n\nr0: 64-bit fixed-point number\nreturn: bool",
        None,
    )

    FixedPoint64IsNegative = Symbol(
        [0x1D50],
        [0x2001D50],
        None,
        "FixedPoint64IsNegative",
        "Checks whether a 64-bit fixed-point number (16 fraction bits) is negative.\n\nr0: 64-bit fixed-point number\nreturn: bool",
        None,
    )

    FixedPoint64CmpLt = Symbol(
        [0x1D68],
        [0x2001D68],
        None,
        "FixedPoint64CmpLt",
        "Compares two signed 64-bit fixed-point numbers (16 fraction bits) x and y.\n\nr0: x\nr1: y\nreturn: x < y",
        None,
    )

    MultiplyFixedPoint64 = Symbol(
        [0x1DF4],
        [0x2001DF4],
        None,
        "MultiplyFixedPoint64",
        "Multiplies two signed 64-bit fixed-point numbers (16 fraction bits) x and y.\n\nr0: [output] product (x * y)\nr1: x\nr2: y",
        None,
    )

    DivideFixedPoint64 = Symbol(
        [0x1EC8],
        [0x2001EC8],
        None,
        "DivideFixedPoint64",
        "Divides two signed 64-bit fixed-point numbers (16 fraction bits).\n\nReturns the maximum positive value ((INT64_MAX >> 16) + (UINT16_MAX * 2^-16)) if the divisor is zero.\n\nr0: [output] quotient (dividend / divisor)\nr1: dividend\nr2: divisor",
        None,
    )

    UMultiplyFixedPoint64 = Symbol(
        [0x1FA0],
        [0x2001FA0],
        None,
        "UMultiplyFixedPoint64",
        "Multiplies two unsigned 64-bit fixed-point numbers (16 fraction bits) x and y.\n\nr0: [output] product (x * y)\nr1: x\nr2: y",
        None,
    )

    UDivideFixedPoint64 = Symbol(
        [0x2084],
        [0x2002084],
        None,
        "UDivideFixedPoint64",
        "Divides two unsigned 64-bit fixed-point numbers (16 fraction bits).\n\nReturns the maximum positive value for a signed fixed-point number ((INT64_MAX >> 16) + (UINT16_MAX * 2^-16)) if the divisor is zero.\n\nr0: [output] quotient (dividend / divisor)\nr1: dividend\nr2: divisor",
        None,
    )

    AddFixedPoint64 = Symbol(
        [0x21C8],
        [0x20021C8],
        None,
        "AddFixedPoint64",
        "Adds two 64-bit fixed-point numbers (16 fraction bits) x and y.\n\nr0: [output] sum (x + y)\nr1: x\nr2: y",
        None,
    )

    ClampedLn = Symbol(
        [0x21F4],
        [0x20021F4],
        None,
        "ClampedLn",
        "The natural log function over the domain of [1, 2047]. The input is clamped to this domain.\n\nr0: [output] ln(x)\nr1: x",
        None,
    )

    GetRngSeed = Symbol(
        [0x222C],
        [0x200222C],
        None,
        "GetRngSeed",
        "Get the current value of PRNG_SEQUENCE_NUM.",
        None,
    )

    SetRngSeed = Symbol(
        [0x223C],
        [0x200223C],
        None,
        "SetRngSeed",
        "Seed PRNG_SEQUENCE_NUM to a given value.\n\nr0: seed",
        None,
    )

    Rand16Bit = Symbol(
        [0x224C],
        [0x200224C],
        None,
        "Rand16Bit",
        "Computes a pseudorandom 16-bit integer using the general-purpose PRNG.\n\nNote that much of dungeon mode uses its own (slightly higher-quality) PRNG within overlay 29. See overlay29.yml for more information.\n\nRandom numbers are generated with a linear congruential generator (LCG), using a modulus of 2^16, a multiplier of 109, and an increment of 1021. I.e., the recurrence relation is `x = (109*x_prev + 1021) % 2^16`.\n\nThe LCG has a hard-coded seed of 13452 (0x348C), but can be seeded with a call to SetRngSeed.\n\nreturn: pseudorandom int on the interval [0, 65535]",
        None,
    )

    RandInt = Symbol(
        [0x2274],
        [0x2002274],
        None,
        "RandInt",
        "Compute a pseudorandom integer under a given maximum value using the general-purpose PRNG.\n\nThis function relies on a single call to Rand16Bit. Even though it takes a 32-bit integer as input, the number of unique outcomes is capped at 2^16.\n\nr0: high\nreturn: pseudorandom integer on the interval [0, high - 1]",
        None,
    )

    RandRange = Symbol(
        [0x228C],
        [0x200228C],
        None,
        "RandRange",
        "Compute a pseudorandom value between two integers using the general-purpose PRNG.\n\nThis function relies on a single call to Rand16Bit. Even though it takes 32-bit integers as input, the number of unique outcomes is capped at 2^16.\n\nr0: x\nr1: y\nreturn: pseudorandom integer on the interval [x, y - 1]",
        None,
    )

    Rand32Bit = Symbol(
        [0x22AC],
        [0x20022AC],
        None,
        "Rand32Bit",
        "Computes a random 32-bit integer using the general-purpose PRNG. The upper and lower 16 bits are each generated with a separate call to Rand16Bit (so this function advances the PRNG twice).\n\nreturn: pseudorandom int on the interval [0, 4294967295]",
        None,
    )

    RandIntSafe = Symbol(
        [0x22F8],
        [0x20022F8],
        None,
        "RandIntSafe",
        "Same as RandInt, except explicitly masking out the upper 16 bits of the output from Rand16Bit (which should be zero anyway).\n\nr0: high\nreturn: pseudorandom integer on the interval [0, high - 1]",
        None,
    )

    RandRangeSafe = Symbol(
        [0x2318],
        [0x2002318],
        None,
        "RandRangeSafe",
        "Like RandRange, except reordering the inputs as needed, and explicitly masking out the upper 16 bits of the output from Rand16Bit (which should be zero anyway).\n\nr0: x\nr1: y\nreturn: pseudorandom integer on the interval [min(x, y), max(x, y) - 1]",
        None,
    )

    WaitForever = Symbol(
        [0x2438],
        [0x2002438],
        None,
        "WaitForever",
        "Sets some program state and calls WaitForInterrupt in an infinite loop.\n\nThis is called on fatal errors to hang the program indefinitely.\n\nNo params.",
        None,
    )

    InterruptMasterDisable = Symbol(
        [0x30CC],
        [0x20030CC],
        None,
        "InterruptMasterDisable",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: previous state",
        None,
    )

    InterruptMasterEnable = Symbol(
        [0x30E4],
        [0x20030E4],
        None,
        "InterruptMasterEnable",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: previous state",
        None,
    )

    InitMemAllocTableVeneer = Symbol(
        [0x321C],
        [0x200321C],
        None,
        "InitMemAllocTableVeneer",
        "Likely a linker-generated veneer for InitMemAllocTable.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nNo params.",
        None,
    )

    ZInit8 = Symbol(
        [0x3228],
        [0x2003228],
        None,
        "ZInit8",
        "Zeroes an 8-byte buffer.\n\nr0: ptr",
        None,
    )

    PointsToZero = Symbol(
        [0x3238],
        [0x2003238],
        None,
        "PointsToZero",
        "Checks whether a pointer points to zero.\n\nr0: ptr\nreturn: bool",
        None,
    )

    MemZero = Symbol(
        [0x3250],
        [0x2003250],
        None,
        "MemZero",
        "Zeroes a buffer.\n\nr0: ptr\nr1: len",
        None,
    )

    MemZero16 = Symbol(
        [0x326C],
        [0x200326C],
        None,
        "MemZero16",
        "Zeros a buffer of 16-bit values.\n\nr0: ptr\nr1: len (# bytes)",
        None,
    )

    MemZero32 = Symbol(
        [0x3288],
        [0x2003288],
        None,
        "MemZero32",
        "Zeros a buffer of 32-bit values.\n\nr0: ptr\nr1: len (# bytes)",
        None,
    )

    MemsetSimple = Symbol(
        [0x32A4],
        [0x20032A4],
        None,
        "MemsetSimple",
        "A simple implementation of the memset(3) C library function.\n\nThis function was probably manually implemented by the developers. See memset for what's probably the real libc function.\n\nr0: ptr\nr1: value\nr2: len (# bytes)",
        None,
    )

    Memset32 = Symbol(
        [0x32BC],
        [0x20032BC],
        None,
        "Memset32",
        "Fills a buffer of 32-bit values with a given value.\n\nr0: ptr\nr1: value\nr2: len (# bytes)",
        None,
    )

    MemcpySimple = Symbol(
        [0x32D4],
        [0x20032D4],
        None,
        "MemcpySimple",
        "A simple implementation of the memcpy(3) C library function.\n\nThis function was probably manually implemented by the developers. See memcpy for what's probably the real libc function.\n\nThis function copies from src to dst in backwards byte order, so this is safe to call for overlapping src and dst if src <= dst.\n\nr0: dest\nr1: src\nr2: n",
        None,
    )

    Memcpy16 = Symbol(
        [0x32F0],
        [0x20032F0],
        None,
        "Memcpy16",
        "Copies 16-bit values from one buffer to another.\n\nr0: dest\nr1: src\nr2: n (# bytes)",
        None,
    )

    Memcpy32 = Symbol(
        [0x330C],
        [0x200330C],
        None,
        "Memcpy32",
        "Copies 32-bit values from one buffer to another.\n\nr0: dest\nr1: src\nr2: n (# bytes)",
        None,
    )

    TaskProcBoot = Symbol(
        [0x3328],
        [0x2003328],
        None,
        "TaskProcBoot",
        "Probably related to booting the game?\n\nThis function prints the debug message 'task proc boot'.\n\nNo params.",
        None,
    )

    EnableAllInterrupts = Symbol(
        [0x3608],
        [0x2003608],
        None,
        "EnableAllInterrupts",
        "Sets the Interrupt Master Enable (IME) register to 1, which enables all CPU interrupts (if enabled in the Interrupt Enable (IE) register).\n\nSee https://problemkaputt.de/gbatek.htm#dsiomaps.\n\nreturn: old value in the IME register",
        None,
    )

    GetTime = Symbol(
        [0x37B4],
        [0x20037B4],
        None,
        "GetTime",
        "Seems to get the current (system?) time as an IEEE 754 floating-point number.\n\nreturn: current time (maybe in seconds?)",
        None,
    )

    DisableAllInterrupts = Symbol(
        [0x3824],
        [0x2003824],
        None,
        "DisableAllInterrupts",
        "Sets the Interrupt Master Enable (IME) register to 0, which disables all CPU interrupts (even if enabled in the Interrupt Enable (IE) register).\n\nSee https://problemkaputt.de/gbatek.htm#dsiomaps.\n\nreturn: old value in the IME register",
        None,
    )

    SoundResume = Symbol(
        [0x3CC4],
        [0x2003CC4],
        None,
        "SoundResume",
        "Probably resumes the sound player if paused?\n\nThis function prints the debug string 'sound resume'.",
        None,
    )

    CardPullOutWithStatus = Symbol(
        [0x3D2C],
        [0x2003D2C],
        None,
        "CardPullOutWithStatus",
        "Probably aborts the program with some status code? It seems to serve a similar purpose to the exit(3) function.\n\nThis function prints the debug string 'card pull out %d' with the status code.\n\nr0: status code",
        None,
    )

    CardPullOut = Symbol(
        [0x3D70],
        [0x2003D70],
        None,
        "CardPullOut",
        "Sets some global flag that probably triggers system exit?\n\nThis function prints the debug string 'card pull out'.\n\nNo params.",
        None,
    )

    CardBackupError = Symbol(
        [0x3D94],
        [0x2003D94],
        None,
        "CardBackupError",
        "Sets some global flag that maybe indicates a save error?\n\nThis function prints the debug string 'card backup error'.\n\nNo params.",
        None,
    )

    HaltProcessDisp = Symbol(
        [0x3DB8],
        [0x2003DB8],
        None,
        "HaltProcessDisp",
        "Maybe halts the process display?\n\nThis function prints the debug string 'halt process disp %d' with the status code.\n\nr0: status code",
        None,
    )

    OverlayIsLoaded = Symbol(
        [0x3ED0],
        [0x2003ED0],
        None,
        "OverlayIsLoaded",
        "Checks if an overlay with a certain group ID is currently loaded.\n\nSee the LOADED_OVERLAY_GROUP_* data symbols or enum overlay_group_id in the C headers for a mapping between group ID and overlay number.\n\nr0: group ID of the overlay to check. A group ID of 0 denotes no overlay, and the return value will always be true in this case.\nreturn: bool",
        None,
    )

    LoadOverlay = Symbol(
        [0x40AC],
        [0x20040AC],
        None,
        "LoadOverlay",
        "Loads an overlay from ROM by its group ID.\n\nSee the LOADED_OVERLAY_GROUP_* data symbols or enum overlay_group_id in the C headers for a mapping between group ID and overlay number.\n\nr0: group ID of the overlay to load",
        None,
    )

    UnloadOverlay = Symbol(
        [0x4868],
        [0x2004868],
        None,
        "UnloadOverlay",
        "Unloads an overlay from ROM by its group ID.\n\nSee the LOADED_OVERLAY_GROUP_* data symbols or enum overlay_group_id in the C headers for a mapping between group ID and overlay number.\n\nr0: group ID of the overlay to unload\nothers: ?",
        None,
    )

    Rgb8ToRgb5 = Symbol(
        [0x4FCC],
        [0x2004FCC],
        None,
        "Rgb8ToRgb5",
        "Transform the input rgb8 color to a rgb5 color\n\nr0: pointer to target rgb5 (2 bytes, aligned to LSB)\nr1: pointer to source rgb8",
        None,
    )

    EuclideanNorm = Symbol(
        [0x5050, 0x50B0],
        [0x2005050, 0x20050B0],
        None,
        "EuclideanNorm",
        "Computes the Euclidean norm of a two-component integer array, sort of like hypotf(3).\n\nr0: integer array [x, y]\nreturn: sqrt(x*x + y*y)",
        None,
    )

    ClampComponentAbs = Symbol(
        [0x5110],
        [0x2005110],
        None,
        "ClampComponentAbs",
        "Clamps the absolute values in a two-component integer array.\n\nGiven an integer array [x, y] and a maximum absolute value M, clamps each element of the array to M such that the output array is [min(max(x, -M), M), min(max(y, -M), M)].\n\nr0: 2-element integer array, will be mutated\nr1: max absolute value",
        None,
    )

    GetHeldButtons = Symbol(
        [0x61EC],
        [0x20061EC],
        None,
        "GetHeldButtons",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: controller\nr1: btn_ptr\nreturn: any_activated",
        None,
    )

    GetPressedButtons = Symbol(
        [0x625C],
        [0x200625C],
        None,
        "GetPressedButtons",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: controller\nr1: btn_ptr\nreturn: any_activated",
        None,
    )

    GetReleasedStylus = Symbol(
        [0x6C1C],
        [0x2006C1C],
        None,
        "GetReleasedStylus",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: stylus_ptr\nreturn: any_activated",
        None,
    )

    KeyWaitInit = Symbol(
        [0x6DA4],
        [0x2006DA4],
        None,
        "KeyWaitInit",
        "Implements (most of?) SPECIAL_PROC_KEY_WAIT_INIT (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    DataTransferInit = Symbol(
        [0x8168],
        [0x2008168],
        None,
        "DataTransferInit",
        "Initializes data transfer mode to get data from the ROM cartridge.\n\nNo params.",
        None,
    )

    DataTransferStop = Symbol(
        [0x8194],
        [0x2008194],
        None,
        "DataTransferStop",
        "Finalizes data transfer from the ROM cartridge.\n\nThis function must always be called if DataTransferInit was called, or the game will crash.\n\nNo params.",
        None,
    )

    FileInitVeneer = Symbol(
        [0x8204],
        [0x2008204],
        None,
        "FileInitVeneer",
        "Likely a linker-generated veneer for FileInit.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: file_stream pointer",
        None,
    )

    FileOpen = Symbol(
        [0x8210],
        [0x2008210],
        None,
        "FileOpen",
        "Opens a file from the ROM file system at the given path, sort of like C's fopen(3) library function.\n\nr0: file_stream pointer\nr1: file path string",
        None,
    )

    FileGetSize = Symbol(
        [0x8244],
        [0x2008244],
        None,
        "FileGetSize",
        "Gets the size of an open file.\n\nr0: file_stream pointer\nreturn: file size",
        None,
    )

    FileRead = Symbol(
        [0x8254],
        [0x2008254],
        None,
        "FileRead",
        "Reads the contents of a file into the given buffer, and moves the file cursor accordingly.\n\nData transfer mode must have been initialized (with DataTransferInit) prior to calling this function. This function looks like it's doing something akin to calling read(2) or fread(3) in a loop until all the bytes have been successfully read.\n\nNote: If code is running from IRQ mode, it appears that FileRead hangs the game. When the processor mode is forced into SYSTEM mode FileRead once again works, so it appears that ROM access only works in certain processor modes. Note that forcing the processor into a different mode is generally a bad idea and should be avoided as it will easily corrupt that processor mode's states.\n\nr0: file_stream pointer\nr1: [output] buffer\nr2: number of bytes to read\nreturn: number of bytes read",
        None,
    )

    FileSeek = Symbol(
        [0x82A8],
        [0x20082A8],
        None,
        "FileSeek",
        "Sets a file stream's position indicator.\n\nThis function has the a similar API to the fseek(3) library function from C, including using the same codes for the `whence` parameter:\n- SEEK_SET=0\n- SEEK_CUR=1\n- SEEK_END=2\n\nr0: file_stream pointer\nr1: offset\nr2: whence",
        None,
    )

    FileClose = Symbol(
        [0x82C4],
        [0x20082C4],
        None,
        "FileClose",
        "Closes a file.\n\nData transfer mode must have been initialized (with DataTransferInit) prior to calling this function.\n\nNote: It is possible to keep a file stream open even if data transfer mode has been stopped, in which case the file stream can be used again if data transfer mode is reinitialized.\n\nr0: file_stream pointer",
        None,
    )

    UnloadFile = Symbol(
        [0x8BD4],
        [0x2008BD4],
        None,
        "UnloadFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: addr_ptr",
        None,
    )

    LoadFileFromRom = Symbol(
        [0x8C3C],
        [0x2008C3C],
        None,
        "LoadFileFromRom",
        "Loads a file from ROM by filepath into a heap-allocated buffer.\n\nr0: [output] pointer to an IO struct {ptr, len}\nr1: file path string pointer\nr2: flags",
        None,
    )

    TransformPaletteDataWithFlushDivideFade = Symbol(
        [0xAE38],
        [0x200AE38],
        None,
        "TransformPaletteDataWithFlushDivideFade",
        "r0: palette_data",
        None,
    )

    UpdateFadeStatus = Symbol(
        [0xBA18],
        [0x200BA18],
        None,
        "UpdateFadeStatus",
        "Updates the given screen_fade struct to initiate a fade for example.\n\nIn addition to initiating a fade this is called when a fade out is complete to set a flag for that in the struct.\n\nr0: screen_fade\nr1: probably the type of the fade\nr2: duration",
        None,
    )

    HandleFades = Symbol(
        [0xBA90],
        [0x200BA90],
        None,
        "HandleFades",
        "Handles updating the screen_fade struct in all modes except dungeon mode.\n\nGets called every frame for both screens, analyzes the fade_struct and does appropriate actions. If there's a fade in progress, it calculates the brightness on the next frame and updates the structure accordingly.\n\nr0: screen_fade\nreturn: bool",
        None,
    )

    GetFadeStatus = Symbol(
        [0xBDB4],
        [0x200BDB4],
        None,
        "GetFadeStatus",
        "Returns 1 if fading to black, 2 if fading to white, 0 otherwise.\n\nr0: screen_fade\nreturn: int",
        None,
    )

    InitDebug = Symbol(
        [0xC15C],
        [0x200C15C],
        None,
        "InitDebug",
        "Would have initialized debugging-related things, if they were not removed.\nAs for the release version, does nothing but set DEBUG_IS_INITIALIZED to true.",
        None,
    )

    InitDebugFlag = Symbol(
        [0xC194],
        [0x200C194],
        None,
        "InitDebugFlag",
        "Would have initialized the debug flags.\nDoes nothing in release binary.",
        None,
    )

    GetDebugFlag = Symbol(
        [0xC198],
        [0x200C198],
        None,
        "GetDebugFlag",
        "Should return the value of the specified debug flag. Just returns 0 in the final binary.\n\nr0: flag ID\nreturn: flag value",
        None,
    )

    SetDebugFlag = Symbol(
        [0xC1A0],
        [0x200C1A0],
        None,
        "SetDebugFlag",
        "Should set the value of a debug flag. A no-op in the final binary.\n\nr0: flag ID\nr1: flag value",
        None,
    )

    InitDebugStripped6 = Symbol(
        [0xC1A4],
        [0x200C1A4],
        None,
        "InitDebugStripped6",
        "Does nothing, only called in the debug initialization function.",
        None,
    )

    AppendProgPos = Symbol(
        [0xC1A8],
        [0x200C1A8],
        None,
        "AppendProgPos",
        "Write a base message into a string and append the file name and line number to the end in the format 'file = '%s'  line = %5d\n'.\n\nIf no program position info is given, 'ProgPos info NULL\n' is appended instead.\n\nr0: [output] str\nr1: program position info\nr2: base message\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    InitDebugStripped5 = Symbol(
        [0xC1F0],
        [0x200C1F0],
        None,
        "InitDebugStripped5",
        "Does nothing, only called in the debug initialization function.",
        None,
    )

    DebugPrintTrace = Symbol(
        [0xC1F4],
        [0x200C1F4],
        None,
        "DebugPrintTrace",
        "Would log a printf format string tagged with the file name and line number in the debug binary.\n\nThis still constructs the string, but doesn't actually do anything with it in the final binary.\n\nIf message is a null pointer, the string '  Print  ' is used instead.\n\nr0: message\nr1: program position info (can be null)",
        None,
    )

    DebugDisplay = Symbol(
        [0xC250],
        [0x200C250],
        None,
        "DebugDisplay",
        "Would display a printf format string on the top screen in the debug binary.\n\nThis still constructs the string with vsprintf, but doesn't actually do anything with it in the final binary.\n\nIdentical to DebugPrint0 in release builds.\n\nr0: format\n...: variadic",
        None,
    )

    DebugPrint0 = Symbol(
        [0xC284],
        [0x200C284],
        None,
        "DebugPrint0",
        "Would log a printf format string in the debug binary.\n\nThis still constructs the string with vsprintf, but doesn't actually do anything with it in the final binary.\n\nIdentical to DebugDisplay in release builds.\n\nr0: format\n...: variadic",
        None,
    )

    InitDebugLogFlag = Symbol(
        [0xC2B8],
        [0x200C2B8],
        None,
        "InitDebugLogFlag",
        "Would have initialized the debug log flags.\nDoes nothing in release binary.",
        None,
    )

    GetDebugLogFlag = Symbol(
        [0xC2BC],
        [0x200C2BC],
        None,
        "GetDebugLogFlag",
        "Should return the value of the specified debug log flag. Just returns 0 in the final binary.\n\nr0: flag ID\nreturn: flag value",
        None,
    )

    SetDebugLogFlag = Symbol(
        [0xC2C4],
        [0x200C2C4],
        None,
        "SetDebugLogFlag",
        "Should set the value of a debug log flag. A no-op in the final binary.\n\nr0: flag ID\nr1: flag value",
        None,
    )

    DebugPrint = Symbol(
        [0xC2C8],
        [0x200C2C8],
        None,
        "DebugPrint",
        "Would log a printf format string in the debug binary. A no-op in the final binary.\n\nr0: log level\nr1: format\n...: variadic",
        None,
    )

    InitDebugStripped4 = Symbol(
        [0xC2D4],
        [0x200C2D4],
        None,
        "InitDebugStripped4",
        "Does nothing, only called in the debug initialization function.",
        None,
    )

    InitDebugStripped3 = Symbol(
        [0xC2D8],
        [0x200C2D8],
        None,
        "InitDebugStripped3",
        "Does nothing, only called in the debug initialization function.",
        None,
    )

    InitDebugStripped2 = Symbol(
        [0xC2DC],
        [0x200C2DC],
        None,
        "InitDebugStripped2",
        "Does nothing, only called in the debug initialization function.",
        None,
    )

    InitDebugStripped1 = Symbol(
        [0xC2E0],
        [0x200C2E0],
        None,
        "InitDebugStripped1",
        "Does nothing, only called in the debug initialization function.",
        None,
    )

    FatalError = Symbol(
        [0xC2E4],
        [0x200C2E4],
        None,
        "FatalError",
        "Logs some debug messages, then hangs the process.\n\nThis function is called in lots of places to bail on a fatal error. Looking at the static data callers use to fill in the program position info is informative, as it tells you the original file name (probably from the standard __FILE__ macro) and line number (probably from the standard __LINE__ macro) in the source code.\n\nr0: program position info\nr1: format\n...: variadic",
        None,
    )

    OpenAllPackFiles = Symbol(
        [0xC364],
        [0x200C364],
        None,
        "OpenAllPackFiles",
        "Open the 6 files at PACK_FILE_PATHS_TABLE into PACK_FILES_OPENED. Called during game initialization.\n\nNo params.",
        None,
    )

    GetFileLengthInPackWithPackNb = Symbol(
        [0xC3C4],
        [0x200C3C4],
        None,
        "GetFileLengthInPackWithPackNb",
        "Call GetFileLengthInPack after looking up the global Pack archive by its number\n\nr0: pack file number\nr1: file number\nreturn: size of the file in bytes from the Pack Table of Content",
        None,
    )

    LoadFileInPackWithPackId = Symbol(
        [0xC3E4],
        [0x200C3E4],
        None,
        "LoadFileInPackWithPackId",
        "Call LoadFileInPack after looking up the global Pack archive by its identifier\n\nr0: pack file identifier\nr1: file index\nr2: [output] target buffer\nreturn: number of read bytes (identical to the length of the pack from the Table of Content)",
        None,
    )

    AllocAndLoadFileInPack = Symbol(
        [0xC410],
        [0x200C410],
        None,
        "AllocAndLoadFileInPack",
        "Allocate a file and load a file from the pack archive inside.\nThe data pointed by the pointer in the output need to be freed once is not needed anymore.\n\nr0: pack file identifier\nr1: file index\nr2: [output] result struct (will contain length and pointer)\nr3: allocation flags",
        None,
    )

    OpenPackFile = Symbol(
        [0xC468],
        [0x200C468],
        None,
        "OpenPackFile",
        "Open a Pack file, to be read later. Initialize the output structure.\n\nr0: [output] pack file struct\nr1: file name",
        None,
    )

    GetFileLengthInPack = Symbol(
        [0xC4FC],
        [0x200C4FC],
        None,
        "GetFileLengthInPack",
        "Get the length of a file entry from a Pack archive\n\nr0: pack file struct\nr1: file index\nreturn: size of the file in bytes from the Pack Table of Content",
        None,
    )

    LoadFileInPack = Symbol(
        [0xC50C],
        [0x200C50C],
        None,
        "LoadFileInPack",
        "Load the indexed file from the Pack archive, itself loaded from the ROM.\n\nr0: pack file struct\nr1: [output] target buffer\nr2: file index\nreturn: number of read bytes (identical to the length of the pack from the Table of Content)",
        None,
    )

    GetDungeonResultMsg = Symbol(
        [0xC584],
        [0x200C584],
        None,
        "GetDungeonResultMsg",
        "Gets the message that is shown on the dungeon results ('The Last Outing') screen, right after the leader's name.\n\nr0: Damage source value to use when displaying the cause of fainting or the result of the expedition\nr1: [output] Buffer where the resulting message will be stored\nr2: Buffer size\nr3: (?) Seems to point to a buffer",
        None,
    )

    GetDamageSource = Symbol(
        [0xCADC],
        [0x200CADC],
        None,
        "GetDamageSource",
        "Gets the damage source for a given move-item combination.\n\nIf there's no item, the source is the move ID. If the item is an orb, return DAMAGE_SOURCE_ORB_ITEM. Otherwise, return DAMAGE_SOURCE_NON_ORB_ITEM.\n\nr0: move ID\nr1: item ID\nreturn: damage source",
        None,
    )

    GetItemCategoryVeneer = Symbol(
        [0xCB78],
        [0x200CB78],
        None,
        "GetItemCategoryVeneer",
        "Likely a linker-generated veneer for GetItemCategory.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: Item ID\nreturn: Category ID",
        None,
    )

    GetItemMoveId16 = Symbol(
        [0xCB84],
        [0x200CB84],
        None,
        "GetItemMoveId16",
        "Wraps GetItemMoveId, ensuring that the return value is 16-bit.\n\nr0: item ID\nreturn: move ID",
        None,
    )

    IsThrownItem = Symbol(
        [0xCB98],
        [0x200CB98],
        None,
        "IsThrownItem",
        "Checks if a given item ID is a thrown item (CATEGORY_THROWN_LINE or CATEGORY_THROWN_ARC).\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsNotMoney = Symbol(
        [0xCBB4],
        [0x200CBB4],
        None,
        "IsNotMoney",
        "Checks if an item ID is not ITEM_POKE.\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsEdible = Symbol(
        [0xCBD4],
        [0x200CBD4],
        None,
        "IsEdible",
        "Checks if an item has an item category of CATEGORY_BERRIES_SEEDS_VITAMINS or CATEGORY_FOOD_GUMMIES.\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsHM = Symbol(
        [0xCBF8],
        [0x200CBF8],
        None,
        "IsHM",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsGummi = Symbol(
        [0xCC7C],
        [0x200CC7C],
        None,
        "IsGummi",
        "Checks if an item is a Gummi.\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsAuraBow = Symbol(
        [0xCC9C],
        [0x200CC9C],
        None,
        "IsAuraBow",
        "Checks if an item is one of the aura bows received at the start of the game.\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsLosableItem = Symbol(
        [0xCCC0],
        [0x200CCC0],
        None,
        "IsLosableItem",
        "Checks if an item can be lost after fainting in a dungeon. Specifically calls IsAuraBow and checks item::f_in_shop\nso that the player can't keep an aura bow they haven't paid for yet.\n\nr0: item pointer\nreturn: bool",
        None,
    )

    IsTreasureBox = Symbol(
        [0xCD0C],
        [0x200CD0C],
        None,
        "IsTreasureBox",
        "Checks if the given item ID is a treasure box\n\nIn particular, it checks if the category of the item is CATEGORY_TREASURE_BOXES_1, CATEGORY_TREASURE_BOXES_2 or CATEGORY_TREASURE_BOXES_3.\n\nr0: item ID\nreturn: True if the item is a treasure box, false otherwise",
        None,
    )

    IsStorableItem = Symbol(
        [0xCD30],
        [0x200CD30],
        None,
        "IsStorableItem",
        "Checks if an item can be put into storage. Specifically checks for the Wonder Egg, Poke, and Used TMs. Used TMs\nlikely can't be stored because the move the TM teaches would be lost when sent to storage.\n\nr0: item_id\nreturn: bool",
        None,
    )

    IsShoppableItem = Symbol(
        [0xCD68],
        [0x200CD68],
        None,
        "IsShoppableItem",
        "Checks if an item can be bought and sold from a Kecleon shop. Includes items like the Gold Thorn, Poke, Golden\nMask, Amber Tear, etc. Also has a special check to make sure an item's buy and sell price is more than 0.\n\nr0: item_id\nreturn: bool",
        None,
    )

    IsValidTargetItem = Symbol(
        [0xCE34],
        [0x200CE34],
        None,
        "IsValidTargetItem",
        "Checks if an item is a valid target item for missions. Returns true for any item less than ITEM_UNNAMED_0x16B.\nAppears to check a list for valid items above ITEM_UNNAMED_0x16B, but the list is empty?\n\nr0: item_id\nreturn: bool",
        None,
    )

    IsItemUsableNow = Symbol(
        [0xCE80],
        [0x200CE80],
        None,
        "IsItemUsableNow",
        "Checks if an item can be used right now. Returns true for all items that are not in a shop. If the item is in a\nshop, specifically checks for TMs/HMs and items that provide permanent buffs (Gummis, Sitrus Berry, Ginseng, etc).\n\nr0: item pointer\nreturn: bool",
        None,
    )

    IsTicketItem = Symbol(
        [0xCEFC],
        [0x200CEFC],
        None,
        "IsTicketItem",
        "Checks if an item is a ticket that can be used in the recycle shop (ITEM_PRIZE_TICKET, ITEM_SILVER_TICKET,\nITEM_GOLD_TICKET, and ITEM_PRISM_TICKET).\n\nr0: item_id\nreturn: bool",
        None,
    )

    InitItem = Symbol(
        [0xCF24],
        [0x200CF24],
        None,
        "InitItem",
        "Initialize an item struct with the given information.\n\nThis will resolve the quantity based on the item type. For Poké, the quantity code will always be set to 1. For thrown items, the quantity code will be randomly generated on the range of valid quantities for that item type. For non-stackable items, the quantity code will always be set to 0. Otherwise, the quantity will be assigned from the quantity argument.\n\nr0: pointer to item to initialize\nr1: item ID\nr2: quantity\nr3: sticky flag",
        None,
    )

    InitStandardItem = Symbol(
        [0xCFE0],
        [0x200CFE0],
        None,
        "InitStandardItem",
        "Wrapper around InitItem with quantity set to 0.\n\nr0: pointer to item to initialize\nr1: item ID\nr2: sticky flag",
        None,
    )

    InitBulkItem = Symbol(
        [0xD000],
        [0x200D000],
        None,
        "InitBulkItem",
        "Initialize a struct bulk_item with the given information.\n\nThis will resolve the quantity based on the item type. For Poké, the quantity code will always be set to 1. For thrown items, the quantity code will be randomly generated on the range of valid quantities for that item type. For non-stackable items, the quantity code will always be set to 0.\n\nr0: pointer to bulk item to initialize\nr1: item ID",
        None,
    )

    BulkItemToItem = Symbol(
        [0xD078],
        [0x200D078],
        None,
        "BulkItemToItem",
        "Convert a bulk_item into an equivalent item.\n\nr0: pointer to item to initialize\nr1: pointer to bulk_item",
        None,
    )

    ItemToBulkItem = Symbol(
        [0xD128],
        [0x200D128],
        None,
        "ItemToBulkItem",
        "Convert an item into an equivalent bulk_item.\n\nr0: pointer to bulk_item to initialize\nr1: pointer to item",
        None,
    )

    GetDisplayedBuyPrice = Symbol(
        [0xD158],
        [0x200D158],
        None,
        "GetDisplayedBuyPrice",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item\nreturn: buy price",
        None,
    )

    GetDisplayedSellPrice = Symbol(
        [0xD1A0],
        [0x200D1A0],
        None,
        "GetDisplayedSellPrice",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item\nreturn: sell price",
        None,
    )

    GetActualBuyPrice = Symbol(
        [0xD1E8],
        [0x200D1E8],
        None,
        "GetActualBuyPrice",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item\nreturn: buy price",
        None,
    )

    GetActualSellPrice = Symbol(
        [0xD230],
        [0x200D230],
        None,
        "GetActualSellPrice",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item\nreturn: sell price",
        None,
    )

    FindItemInInventory = Symbol(
        [0xD300],
        [0x200D300],
        None,
        "FindItemInInventory",
        "Returns x if item_id is at position x in the bag\nReturns 0x8000+x if item_id is at position x in storage\nReturns -1 if item is not found\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: item_id\nreturn: inventory index",
        None,
    )

    SprintfStatic = Symbol(
        [
            0xD6BC,
            0xE808,
            0x13800,
            0x177C4,
            0x17ADC,
            0x2378C,
            0x239B0,
            0x3822C,
            0x39734,
            0x3AC6C,
            0x3D2A0,
            0x41A48,
            0x42DA0,
            0x52750,
            0x54DDC,
            0x60D64,
        ],
        [
            0x200D6BC,
            0x200E808,
            0x2013800,
            0x20177C4,
            0x2017ADC,
            0x202378C,
            0x20239B0,
            0x203822C,
            0x2039734,
            0x203AC6C,
            0x203D2A0,
            0x2041A48,
            0x2042DA0,
            0x2052750,
            0x2054DDC,
            0x2060D64,
        ],
        None,
        "SprintfStatic",
        "Functionally the same as sprintf, just defined statically in many different places.\n\nSince this is essentially just a wrapper around vsprintf(3), this function was probably statically defined in a header somewhere and included in a bunch of different places. See the actual sprintf for the one in libc.\n\nr0: str\nr1: format\n...: variadic\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    ItemZInit = Symbol(
        [0xD8A4],
        [0x200D8A4],
        None,
        "ItemZInit",
        "Zero-initializes an item struct.\n\nr0: item",
        None,
    )

    AreItemsEquivalent = Symbol(
        [0xD8BC],
        [0x200D8BC],
        None,
        "AreItemsEquivalent",
        "Checks whether two items are equivalent and only checks the bitflags specified by the bitmask.\n\nr0: item\nr1: item\nr2: bitmask\nreturn: bool",
        None,
    )

    WriteItemsToSave = Symbol(
        [0xD9E4],
        [0x200D9E4],
        None,
        "WriteItemsToSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: start_address\nr1: total_length\nreturn: ?",
        None,
    )

    ReadItemsFromSave = Symbol(
        [0xDCCC],
        [0x200DCCC],
        None,
        "ReadItemsFromSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: start_address\nr1: total_length\nreturn: ?",
        None,
    )

    IsItemAvailableInDungeonGroup = Symbol(
        [0xE094],
        [0x200E094],
        None,
        "IsItemAvailableInDungeonGroup",
        "Checks one specific bit from AVAILABLE_ITEMS_IN_GROUP_TABLE?\n\nr0: dungeon ID\nr1: item ID\nreturn: bool",
        None,
    )

    GetItemIdFromList = Symbol(
        [0xE0DC],
        [0x200E0DC],
        None,
        "GetItemIdFromList",
        "category_num and item_num are numbers in range 0-10000\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: list_id\nr1: category_num\nr2: item_num\nreturn: item ID",
        None,
    )

    NormalizeTreasureBox = Symbol(
        [0xE280],
        [0x200E280],
        None,
        "NormalizeTreasureBox",
        "If the item is a treasure box return the first version of the treasure box in the item list.\nOtherwise, return the same item ID.\n\nr0: item ID\nreturn: normalized item ID",
        None,
    )

    SortItemList = Symbol(
        [0xE428],
        [0x200E428],
        None,
        "SortItemList",
        "Attempts to combine stacks of throwable items, sort the list, and then remove empty items.\nAppears to use selection sort to sort the list in place.\n\nr0: item array\nr1: number of items in array",
        None,
    )

    RemoveEmptyItems = Symbol(
        [0xE698],
        [0x200E698],
        None,
        "RemoveEmptyItems",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: list_pointer\nr1: size",
        None,
    )

    LoadItemPspi2n = Symbol(
        [0xE760],
        [0x200E760],
        None,
        "LoadItemPspi2n",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    GetExclusiveItemType = Symbol(
        [0xE830],
        [0x200E830],
        None,
        "GetExclusiveItemType",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: ?",
        None,
    )

    GetExclusiveItemOffsetEnsureValid = Symbol(
        [0xE84C],
        [0x200E84C],
        None,
        "GetExclusiveItemOffsetEnsureValid",
        "Gets the exclusive item offset, which is the item ID relative to that of the first exclusive item, the Prism Ruff.\n\nIf the given item ID is not a valid item ID, ITEM_PLAIN_SEED (0x55) is returned. This is a bug, since 0x55 is the valid exclusive item offset for the Icy Globe.\n\nr0: item ID\nreturn: offset",
        None,
    )

    IsItemValid = Symbol(
        [0xE890],
        [0x200E890],
        None,
        "IsItemValid",
        "Checks if an item is valid given its ID.\n\nIn particular, checks if the 'is valid' flag is set on its item_p.bin entry.\n\nr0: item ID\nreturn: bool",
        None,
    )

    GetExclusiveItemParameter = Symbol(
        [0xE8B8],
        [0x200E8B8],
        None,
        "GetExclusiveItemParameter",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: ?",
        None,
    )

    GetItemCategory = Symbol(
        [0xE8D8],
        [0x200E8D8],
        None,
        "GetItemCategory",
        "Returns the category of the specified item\n\nr0: Item ID\nreturn: Item category",
        None,
    )

    EnsureValidItem = Symbol(
        [0xE8F8],
        [0x200E8F8],
        None,
        "EnsureValidItem",
        "Checks if the given item ID is valid (using IsItemValid). If so, return the given item ID. Otherwise, return ITEM_PLAIN_SEED.\n\nr0: item ID\nreturn: valid item ID",
        None,
    )

    GetItemName = Symbol(
        [0xE934],
        [0x200E934],
        None,
        "GetItemName",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: item name",
        None,
    )

    GetItemNameFormatted = Symbol(
        [0xE954],
        [0x200E954],
        None,
        "GetItemNameFormatted",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: [output] name\nr1: item_id\nr2: flag\nr3: flag2",
        None,
    )

    GetItemBuyPrice = Symbol(
        [0xEA60],
        [0x200EA60],
        None,
        "GetItemBuyPrice",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: buy price",
        None,
    )

    GetItemSellPrice = Symbol(
        [0xEA80],
        [0x200EA80],
        None,
        "GetItemSellPrice",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: sell price",
        None,
    )

    GetItemSpriteId = Symbol(
        [0xEAA0],
        [0x200EAA0],
        None,
        "GetItemSpriteId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: sprite ID",
        None,
    )

    GetItemPaletteId = Symbol(
        [0xEAC0],
        [0x200EAC0],
        None,
        "GetItemPaletteId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: palette ID",
        None,
    )

    GetItemActionName = Symbol(
        [0xEAE0],
        [0x200EAE0],
        None,
        "GetItemActionName",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: action name ID",
        None,
    )

    GetThrownItemQuantityLimit = Symbol(
        [0xEB00],
        [0x200EB00],
        None,
        "GetThrownItemQuantityLimit",
        "Get the minimum or maximum quantity for a given thrown item ID.\n\nr0: item ID\nr1: 0 for minimum, 1 for maximum\nreturn: minimum/maximum quantity for the given item ID",
        None,
    )

    GetItemMoveId = Symbol(
        [0xEB28],
        [0x200EB28],
        None,
        "GetItemMoveId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: move ID",
        None,
    )

    TestItemAiFlag = Symbol(
        [0xEB48],
        [0x200EB48],
        None,
        "TestItemAiFlag",
        "Returns a boolean indicating whether the item is consumable, throwable at an ally, or throwable at an enemy, depending on item_flag.\nThe table used for this is inaccessible in the code, as it is loaded from a file in the ROM at runtime.\nBit 7 in the table corresponds to ITEM_FLAG_CONSUMABLE, bit 6 to ITEM_FLAG_THROWABLE_AT_ALLY, and bit 5 to ITEM_FLAG_THROWABLE_AT_ENEMY.\n\nr0: item_id enum\nr1: item_flag enum. Function will test a different allowed AI action depending on the value.\nreturn: bool",
        None,
    )

    IsItemInTimeDarkness = Symbol(
        [0xEBD8],
        [0x200EBD8],
        None,
        "IsItemInTimeDarkness",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsItemValidVeneer = Symbol(
        [0xEC00],
        [0x200EC00],
        None,
        "IsItemValidVeneer",
        "Likely a linker-generated veneer for IsItemValid.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: item ID\nreturn: bool",
        None,
    )

    SetActiveInventoryToMain = Symbol(
        [0xEC74],
        [0x200EC74],
        None,
        "SetActiveInventoryToMain",
        "Changes the currently active inventory to TEAM_MAIN.\n\nNo params.",
        None,
    )

    AllInventoriesZInit = Symbol(
        [0xEC84],
        [0x200EC84],
        None,
        "AllInventoriesZInit",
        "Initializes all inventories (TEAM_MAIN, TEAM_SPECIAL_EPISODE, TEAM_RESCUE) to empty and sets the active inventory\nto TEAM_MAIN.\n\nNo params.",
        None,
    )

    SpecialEpisodeInventoryZInit = Symbol(
        [0xECF0],
        [0x200ECF0],
        None,
        "SpecialEpisodeInventoryZInit",
        "Initializes the TEAM_SPECIAL_EPISODE inventory to be empty.\n\nNo params.",
        None,
    )

    RescueInventoryZInit = Symbol(
        [0xED38],
        [0x200ED38],
        None,
        "RescueInventoryZInit",
        "Initializes the TEAM_RESCUE inventory to be empty.\n\nNo params.",
        None,
    )

    SetActiveInventory = Symbol(
        [0xED80],
        [0x200ED80],
        None,
        "SetActiveInventory",
        "Changes the currently active inventory. Has one for the main team, rescue team, and the special\nepisode team.\n\nr0: team ID",
        None,
    )

    GetMoneyCarried = Symbol(
        [0xEDA4],
        [0x200EDA4],
        None,
        "GetMoneyCarried",
        "Gets the amount of money the player is carrying.\n\nreturn: value",
        None,
    )

    SetMoneyCarried = Symbol(
        [0xEDC4],
        [0x200EDC4],
        None,
        "SetMoneyCarried",
        "Sets the amount of money the player is carrying, clamping the value to the range [0, MAX_MONEY_CARRIED].\n\nr0: new value",
        None,
    )

    AddMoneyCarried = Symbol(
        [0xEE00],
        [0x200EE00],
        None,
        "AddMoneyCarried",
        "Adds the amount of money to the player's current amount of money. Just calls\nSetMoneyCarried with the current money + money gained.\n\nr0: money gained (can be negative)",
        None,
    )

    GetCurrentBagCapacity = Symbol(
        [0xEE2C],
        [0x200EE2C],
        None,
        "GetCurrentBagCapacity",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: bag capacity",
        None,
    )

    IsBagFull = Symbol(
        [0xEE68],
        [0x200EE68],
        None,
        "IsBagFull",
        "Implements SPECIAL_PROC_IS_BAG_FULL (see ScriptSpecialProcessCall).\n\nreturn: bool",
        None,
    )

    GetNbItemsInBag = Symbol(
        [0xEEA4],
        [0x200EEA4],
        None,
        "GetNbItemsInBag",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: # items",
        None,
    )

    CountNbItemsOfTypeInBag = Symbol(
        [0xEEF4],
        [0x200EEF4],
        None,
        "CountNbItemsOfTypeInBag",
        "Returns the number of items of the given kind in the bag\n\nr0: item ID\nreturn: count",
        None,
    )

    CountItemTypeInBag = Symbol(
        [0xEF30],
        [0x200EF30],
        None,
        "CountItemTypeInBag",
        "Implements SPECIAL_PROC_COUNT_ITEM_TYPE_IN_BAG (see ScriptSpecialProcessCall).\n\nIrdkwia's notes: Count also stackable\n\nr0: item ID\nreturn: number of items of the specified ID in the bag",
        None,
    )

    IsItemInBag = Symbol(
        [0xEF88],
        [0x200EF88],
        None,
        "IsItemInBag",
        "Checks if an item is in the player's bag.\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsItemWithFlagsInBag = Symbol(
        [0xEFC8],
        [0x200EFC8],
        None,
        "IsItemWithFlagsInBag",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nr1: flags\nreturn: bool",
        None,
    )

    IsItemInTreasureBoxes = Symbol(
        [0xF014],
        [0x200F014],
        None,
        "IsItemInTreasureBoxes",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: bool",
        None,
    )

    IsHeldItemInBag = Symbol(
        [0xF074],
        [0x200F074],
        None,
        "IsHeldItemInBag",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item\nreturn: bool",
        None,
    )

    IsItemForSpecialSpawnInBag = Symbol(
        [0xF0F8],
        [0x200F0F8],
        None,
        "IsItemForSpecialSpawnInBag",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: bool",
        None,
    )

    HasStorableItems = Symbol(
        [0xF18C],
        [0x200F18C],
        None,
        "HasStorableItems",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: bool",
        None,
    )

    GetItemIndex = Symbol(
        [0xF1F4],
        [0x200F1F4],
        None,
        "GetItemIndex",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_ptr\nreturn: index",
        None,
    )

    GetEquivItemIndex = Symbol(
        [0xF234],
        [0x200F234],
        None,
        "GetEquivItemIndex",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_ptr\nreturn: index",
        None,
    )

    GetEquippedThrowableItem = Symbol(
        [0xF2B0],
        [0x200F2B0],
        None,
        "GetEquippedThrowableItem",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: index",
        None,
    )

    GetFirstUnequippedItemOfType = Symbol(
        [0xF314],
        [0x200F314],
        None,
        "GetFirstUnequippedItemOfType",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: index",
        None,
    )

    CopyItemAtIdx = Symbol(
        [0xF388],
        [0x200F388],
        None,
        "CopyItemAtIdx",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: index\nr1: [output] item_ptr\nreturn: exists",
        None,
    )

    GetItemAtIdx = Symbol(
        [0xF3F0],
        [0x200F3F0],
        None,
        "GetItemAtIdx",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: index\nreturn: item pointer",
        None,
    )

    RemoveEmptyItemsInBag = Symbol(
        [0xF418],
        [0x200F418],
        None,
        "RemoveEmptyItemsInBag",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    RemoveItemNoHole = Symbol(
        [0xF438],
        [0x200F438],
        None,
        "RemoveItemNoHole",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: index\nreturn: ?",
        None,
    )

    RemoveItem = Symbol(
        [0xF4AC],
        [0x200F4AC],
        None,
        "RemoveItem",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: index",
        None,
    )

    RemoveHeldItemNoHole = Symbol(
        [0xF4FC],
        [0x200F4FC],
        None,
        "RemoveHeldItemNoHole",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: held_index",
        None,
    )

    RemoveItemByIdAndStackNoHole = Symbol(
        [0xF57C],
        [0x200F57C],
        None,
        "RemoveItemByIdAndStackNoHole",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_ptr\nreturn: ?",
        None,
    )

    RemoveEquivItem = Symbol(
        [0xF600],
        [0x200F600],
        None,
        "RemoveEquivItem",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_ptr\nreturn: ?",
        None,
    )

    RemoveEquivItemNoHole = Symbol(
        [0xF6A8],
        [0x200F6A8],
        None,
        "RemoveEquivItemNoHole",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_ptr\nreturn: ?",
        None,
    )

    DecrementStackItem = Symbol(
        [0xF73C],
        [0x200F73C],
        None,
        "DecrementStackItem",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_ptr\nreturn: ?",
        None,
    )

    RemoveItemNoHoleCheck = Symbol(
        [0xF7C0],
        [0x200F7C0],
        None,
        "RemoveItemNoHoleCheck",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: index\nreturn: ?",
        None,
    )

    RemoveFirstUnequippedItemOfType = Symbol(
        [0xF840],
        [0x200F840],
        None,
        "RemoveFirstUnequippedItemOfType",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nreturn: ?",
        None,
    )

    RemoveAllItems = Symbol(
        [0xF850],
        [0x200F850],
        None,
        "RemoveAllItems",
        "WARNING! Does not remove from party items\n\nNote: unverified, ported from Irdkwia's notes",
        None,
    )

    RemoveAllItemsStartingAt = Symbol(
        [0xF884],
        [0x200F884],
        None,
        "RemoveAllItemsStartingAt",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: index",
        None,
    )

    SpecialProcAddItemToBag = Symbol(
        [0xF8F4],
        [0x200F8F4],
        None,
        "SpecialProcAddItemToBag",
        "Implements SPECIAL_PROC_ADD_ITEM_TO_BAG (see ScriptSpecialProcessCall).\n\nr0: pointer to an owned_item\nreturn: bool",
        None,
    )

    AddItemToBagNoHeld = Symbol(
        [0xF91C],
        [0x200F91C],
        None,
        "AddItemToBagNoHeld",
        "A wrapper around AddItemToBag with held_by being 0 (no holder).\n\nr0: item_str\nreturn: bool item was successfully added to the bag",
        None,
    )

    AddItemToBag = Symbol(
        [0xF92C],
        [0x200F92C],
        None,
        "AddItemToBag",
        "Attempts to add an item to the bag.\n\nr0: item_str\nr1: held_by\nreturn: bool item was successfully added to the bag",
        None,
    )

    CleanStickyItemsInBag = Symbol(
        [0xF9B8],
        [0x200F9B8],
        None,
        "CleanStickyItemsInBag",
        "Removes the sticky flag from all the items currently in the bag.\n\nNo params.",
        None,
    )

    CountStickyItemsInBag = Symbol(
        [0xF9E8],
        [0x200F9E8],
        None,
        "CountStickyItemsInBag",
        "Counts the number of sticky items currently in the bag.\n\nreturn: number of sticky items",
        None,
    )

    TransmuteHeldItemInBag = Symbol(
        [0xFB10],
        [0x200FB10],
        None,
        "TransmuteHeldItemInBag",
        "Looks for an item in the bag that has the same holder (held_by) as the transmute item and convert\ntheir equivalent item in the treasure bag into the transmute item. The monster's held item on\ntheir struct should be updated accordingly directly before or after calling this function.\n\nr0: transmute_item\nreturn: bool whether or not the item could be transmuted",
        None,
    )

    SetFlagsForHeldItemInBag = Symbol(
        [0xFB94],
        [0x200FB94],
        None,
        "SetFlagsForHeldItemInBag",
        "Looks for an item in the bag that has the holder (held_by) as the item and make their equivalent\nitem in the treasure bag sticky. The monster's held item on their struct should be updated\naccordingly directly before or after calling this function. Mostly used for making existing items\nsticky.\n\nr0: held_by\nr1: item bitflags",
        None,
    )

    RemoveHolderForItemInBag = Symbol(
        [0xFBFC],
        [0x200FBFC],
        None,
        "RemoveHolderForItemInBag",
        "Looks for an item in the bag that is equivalent and make the holder none. The monster's held item\non their struct should be updated accordingly directly before or after calling this function.\n\nr0: pointer to an item",
        None,
    )

    SetHolderForItemInBag = Symbol(
        [0xFC88],
        [0x200FC88],
        None,
        "SetHolderForItemInBag",
        "Modifies the item at the index to be held by the monster specified and updates the item with the\nholder as well. This only modifies the flags and held_by of the item.\n\nr0: item index\nr1: pointer to an item\nr2: held_by",
        None,
    )

    SortItemsInBag = Symbol(
        [0xFCCC],
        [0x200FCCC],
        None,
        "SortItemsInBag",
        "Sorts the current items in the item bag but first checks if any Poke is in the bag to remove. If\nPoke is found, add it to money carried.\n\nNo params.",
        None,
    )

    RemovePokeItemsInBag = Symbol(
        [0xFD54],
        [0x200FD54],
        None,
        "RemovePokeItemsInBag",
        "Checks the bag for any Poke and removes it after adding it to money carried.\n\nNo params.",
        None,
    )

    IsStorageFull = Symbol(
        [0xFDFC],
        [0x200FDFC],
        None,
        "IsStorageFull",
        "Checks if the storage is full accounting for the current rank of the team.\nImplements SPECIAL_PROC_0x39 (see ScriptSpecialProcessCall).\n\nreturn: bool",
        None,
    )

    CountNbOfItemsInStorage = Symbol(
        [0xFE20],
        [0x200FE20],
        None,
        "CountNbOfItemsInStorage",
        "Counts the number of items currently in storage (including invalid items).\n\nreturn: number of items in storage",
        None,
    )

    CountNbOfValidItemsInStorage = Symbol(
        [0xFE58],
        [0x200FE58],
        None,
        "CountNbOfValidItemsInStorage",
        "Counts the number of items currently in storage that are valid.\n\nreturn: number of valid items in storage",
        None,
    )

    CountNbOfValidItemsInTimeDarknessInStorage = Symbol(
        [0xFEA8],
        [0x200FEA8],
        None,
        "CountNbOfValidItemsInTimeDarknessInStorage",
        "Counts the number of items currently in storage that are valid and in time and darkness.\n\nreturn: number of valid items in storage",
        None,
    )

    CountNbItemsOfTypeInStorage = Symbol(
        [0xFF50],
        [0x200FF50],
        None,
        "CountNbItemsOfTypeInStorage",
        "Counts the number of instances of an item in storage not accounting for the number of items\nin a stack.\n\nr0: item ID\nreturn: count",
        None,
    )

    CountItemTypeInStorage = Symbol(
        [0xFF8C],
        [0x200FF8C],
        None,
        "CountItemTypeInStorage",
        "Counts the number of a certain item in storage accounting for stackable items.\nImplements SPECIAL_PROC_COUNT_ITEM_TYPE_IN_STORAGE (see ScriptSpecialProcessCall).\n\nr0: pointer to an bulk_item\nreturn: number of items of the specified ID in storage",
        None,
    )

    GetEquivBulkItemIdxInStorage = Symbol(
        [0xFFF8],
        [0x200FFF8],
        None,
        "GetEquivBulkItemIdxInStorage",
        "Checks for a storage item equivalent to the bulk_item and returns the index of the item in storage.\nReturns -1 if unable to find an equivalent item.\n\nr0: pointer to a bulk_item\nreturn: index in storage",
        None,
    )

    ConvertStorageItemAtIdxToBulkItem = Symbol(
        [0x10054],
        [0x2010054],
        None,
        "ConvertStorageItemAtIdxToBulkItem",
        "Get an item in storage and converts it into an equivalent bulk_item. This does not remove the\nitem from storage.\n\nr0: item index\nr1: [output] pointer to a bulk_item\nreturn: bool whether or not the item id is not 0",
        None,
    )

    ConvertStorageItemAtIdxToItem = Symbol(
        [0x1009C],
        [0x201009C],
        None,
        "ConvertStorageItemAtIdxToItem",
        "Get an item in storage and converts it into an equivalent item. The item does NOT have the exists\nflag set to true. This does not remove the item from storage.\n\nr0: item index\nr1: [output] pointer to an item\nreturn: bool whether or not the item id is not 0",
        None,
    )

    RemoveItemAtIdxInStorage = Symbol(
        [0x10248],
        [0x2010248],
        None,
        "RemoveItemAtIdxInStorage",
        "Remove an item at the specified index from storage.\n\nr0: storage item idx\nreturn: bool whether or not the item was removed (fails if there is no storage item at the index)",
        None,
    )

    RemoveBulkItemInStorage = Symbol(
        [0x1028C],
        [0x201028C],
        None,
        "RemoveBulkItemInStorage",
        "Removes a storage item equivalent to the bulk_item passed from storage.\nProbably? Implements SPECIAL_PROC_REMOVE_ITEM_TYPE_IN_STORAGE (see ScriptSpecialProcessCall).\n\nr0: pointer to a bulk_item\nreturn: bool whether an item was removed",
        None,
    )

    RemoveItemInStorage = Symbol(
        [0x10308],
        [0x2010308],
        None,
        "RemoveItemInStorage",
        "Removes a storage item equivalent to the item passed from storage.\n\nr0: pointer to an item\nreturn: bool whether an item was removed",
        None,
    )

    StorageZInit = Symbol(
        [0x10384],
        [0x2010384],
        None,
        "StorageZInit",
        "Initializes the storage to be empty.\n\nNo params.",
        None,
    )

    AddBulkItemToStorage = Symbol(
        [0x103C4],
        [0x20103C4],
        None,
        "AddBulkItemToStorage",
        "Attempts to add the bulk_item to storage.\nImplements SPECIAL_PROC_ADD_ITEM_TO_STORAGE (see ScriptSpecialProcessCall).\n\nr0: pointer to a bulk_item\nreturn: bool whether an item was added",
        None,
    )

    AddItemToStorage = Symbol(
        [0x10454],
        [0x2010454],
        None,
        "AddItemToStorage",
        "Attempts to add the item to storage.\n\nr0: pointer to an item\nreturn: bool whether an item was added",
        None,
    )

    SortItemsInStorage = Symbol(
        [0x104CC],
        [0x20104CC],
        None,
        "SortItemsInStorage",
        "Sorts the item in storage by making converting them into normal items in a temporary list and\nusing SortItemList on them. After, it puts the list of items back into storage. This may also have\nanother use or do something broader than just sorting because it outputs a bool array.\n\nr0: [output] bool array?\nr1: number of items to sort (usually just the current size of storage)",
        None,
    )

    AllKecleonShopsZInit = Symbol(
        [0x1063C],
        [0x201063C],
        None,
        "AllKecleonShopsZInit",
        "Empties the Kecleon shop for both TEAM_MAIN and TEAM_SPECIAL_EPISODE. TEAM_RESCUE does not appear to have its own\nKecleon shop.\n\nNo params.",
        None,
    )

    SpecialEpisodeKecleonShopZInit = Symbol(
        [0x106FC],
        [0x20106FC],
        None,
        "SpecialEpisodeKecleonShopZInit",
        "Empties the special episode Kecleon shop.\n\nNo params.",
        None,
    )

    SetActiveKecleonShop = Symbol(
        [0x1076C],
        [0x201076C],
        None,
        "SetActiveKecleonShop",
        "Changes the currently active Kecleon shop. Has one for TEAM_MAIN and TEAM_SPECIAL_EPISODE. TEAM_RESCUE does not\nappear to have its own copy of the Kecleon shop it seems to use TEAM_MAIN intead of TEAM_RESCUE.\n\nr0: team ID",
        None,
    )

    GetMoneyStored = Symbol(
        [0x107B4],
        [0x20107B4],
        None,
        "GetMoneyStored",
        "Gets the amount of money the player has stored in the Duskull Bank.\n\nreturn: amount of money stored",
        None,
    )

    SetMoneyStored = Symbol(
        [0x107CC],
        [0x20107CC],
        None,
        "SetMoneyStored",
        "Sets the amount of money the player has stored in the Duskull Bank, clamping the value to the range [0, MAX_MONEY_STORED].\n\nr0: new value",
        None,
    )

    AddMoneyStored = Symbol(
        [0x10800],
        [0x2010800],
        None,
        "AddMoneyStored",
        "Adds money to the amount of money the player has stored in the Duskull Bank. Just calls SetMoneyStored with the current money + money gained.\n\nr0: money gained (can be negative)",
        None,
    )

    SortKecleonItems1 = Symbol(
        [0x109FC],
        [0x20109FC],
        None,
        "SortKecleonItems1",
        "Sorts the items for the normal Kecleon Shop items in Treasure Town.\n\nNo params.",
        None,
    )

    GenerateKecleonItems1 = Symbol(
        [0x10AF4],
        [0x2010AF4],
        None,
        "GenerateKecleonItems1",
        "Generates the Kecleon Shop items for both shopkeepers in Treasure Town. This function also calls\nGenerateKecleonItems2 despite GenerateKecleonItems2 being called directly after. This means that\nany items generated for the Orb/TM shop will be overwritten by the subsequent call to\nGenerateKecleonItems2.\n\nr0: kecleon_shop_version to use",
        None,
    )

    SortKecleonItems2 = Symbol(
        [0x10D08],
        [0x2010D08],
        None,
        "SortKecleonItems2",
        "Sorts the items for the Orb/TM Kecleon Shop items in Treasure Town.\n\nNo params.",
        None,
    )

    GenerateKecleonItems2 = Symbol(
        [0x10E00],
        [0x2010E00],
        None,
        "GenerateKecleonItems2",
        "Generates the Kecleon Shop items for the TMs/Orbs shop in Treasure Town.\n\nr0: kecleon_shop_version to use",
        None,
    )

    GetExclusiveItemOffset = Symbol(
        [0x10EE8],
        [0x2010EE8],
        None,
        "GetExclusiveItemOffset",
        "Gets the exclusive item offset, which is the item ID relative to that of the first exclusive item, the Prism Ruff.\n\nr0: item ID\nreturn: offset",
        None,
    )

    ApplyExclusiveItemStatBoosts = Symbol(
        [0x10F0C],
        [0x2010F0C],
        None,
        "ApplyExclusiveItemStatBoosts",
        "Applies stat boosts from an exclusive item.\n\nr0: item ID\nr1: pointer to attack stat to modify\nr2: pointer to special attack stat to modify\nr3: pointer to defense stat to modify\nstack[0]: pointer to special defense stat to modify",
        None,
    )

    SetExclusiveItemEffect = Symbol(
        [0x11028],
        [0x2011028],
        None,
        "SetExclusiveItemEffect",
        "Sets the bit for an exclusive item effect.\n\nr0: pointer to the effects bitvector to modify\nr1: exclusive item effect ID",
        None,
    )

    ExclusiveItemEffectFlagTest = Symbol(
        [0x1104C],
        [0x201104C],
        None,
        "ExclusiveItemEffectFlagTest",
        "Tests the exclusive item bitvector for a specific exclusive item effect.\n\nr0: the effects bitvector to test\nr1: exclusive item effect ID\nreturn: bool",
        None,
    )

    IsExclusiveItemIdForMonster = Symbol(
        [0x1106C],
        [0x201106C],
        None,
        "IsExclusiveItemIdForMonster",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item ID\nr1: monster ID\nr2: type ID 1\nr3: type ID 2\nreturn: bool",
        None,
    )

    IsExclusiveItemForMonster = Symbol(
        [0x1113C],
        [0x201113C],
        None,
        "IsExclusiveItemForMonster",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item\nr1: monster ID\nr2: type ID 1\nr3: type ID 2\nreturn: bool",
        None,
    )

    BagHasExclusiveItemTypeForMonster = Symbol(
        [0x11180],
        [0x2011180],
        None,
        "BagHasExclusiveItemTypeForMonster",
        "Checks the bag for any exclusive item that applies to the monster or type(s) and gets the item ID.\n\nr0: excl_type\nr1: monster ID\nr2: type ID 1\nr3: type ID 2\nreturn: exclusive item ID",
        None,
    )

    GetExclusiveItemForMonsterFromBag = Symbol(
        [0x11214],
        [0x2011214],
        None,
        "GetExclusiveItemForMonsterFromBag",
        "Checks the bag for any exclusive item that applies to the monster or type(s) and copies that item\ninto the passed item struct.\n\nr0: [output] item_struct\nr1: excl_type\nr2: monster ID\nr3: type ID 1\nstack[0]: type ID 2\nreturn: bool whether an exclusive item was found",
        None,
    )

    GetHpBoostFromExclusiveItems = Symbol(
        [0x1143C],
        [0x201143C],
        None,
        "GetHpBoostFromExclusiveItems",
        "Calculates the current HP boost from exclusive items. If none are active, return 0.\n\nr0: some struct that has species ID in it?\nreturn: max HP boost from exclusive items",
        None,
    )

    ApplyGummiBoostsToGroundMonster = Symbol(
        [0x115D0],
        [0x20115D0],
        None,
        "ApplyGummiBoostsToGroundMonster",
        "Applies the IQ boosts from eating a Gummi to the target monster. Basically a wrapper around\nApplyGummiBoostsGroundMode for struct ground_monster.\n\nr0: ground monster pointer\nr1: Item ID\nr2: bool to NOT increase stats\nr3: [output] pointer to a struct gummi_result to fill out",
        None,
    )

    ApplyGummiBoostsToTeamMember = Symbol(
        [0x115FC],
        [0x20115FC],
        None,
        "ApplyGummiBoostsToTeamMember",
        "Applies the IQ boosts from eating a Gummi to the target monster. Basically a wrapper around\nApplyGummiBoostsGroundMode for struct team_member.\n\nr0: team member pointer\nr1: Item ID\nr2: bool to NOT increase stats\nr3: [output] pointer to a struct gummi_result to fill out",
        None,
    )

    ApplySitrusBerryBoostToGroundMonster = Symbol(
        [0x11628],
        [0x2011628],
        None,
        "ApplySitrusBerryBoostToGroundMonster",
        "Applies the hp boost from the Sitrus Berry to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted hp boost, if not NULL\nreturn: actual hp boost",
        None,
    )

    ApplyLifeSeedBoostToGroundMonster = Symbol(
        [0x11664],
        [0x2011664],
        None,
        "ApplyLifeSeedBoostToGroundMonster",
        "Applies the hp boost from the Life Seed to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted hp boost, if not NULL\nreturn: actual hp boost",
        None,
    )

    ApplyGinsengToGroundMonster = Symbol(
        [0x116A0],
        [0x20116A0],
        None,
        "ApplyGinsengToGroundMonster",
        "Attempts to apply a ginseng boost to the highest valid move that the ground monster knows.\n\nr0: ground monster pointer\nr1: [output] move ID\nr2: [output] move boost\nreturn: actual move boost",
        None,
    )

    ApplyProteinBoostToGroundMonster = Symbol(
        [0x117B4],
        [0x20117B4],
        None,
        "ApplyProteinBoostToGroundMonster",
        "Applies the attack boost from Protein to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted attack boost, if not NULL\nreturn: actual attack boost",
        None,
    )

    ApplyCalciumBoostToGroundMonster = Symbol(
        [0x117F0],
        [0x20117F0],
        None,
        "ApplyCalciumBoostToGroundMonster",
        "Applies the special attack boost from Calcium to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted special attack boost, if not NULL\nreturn: actual special attack boost",
        None,
    )

    ApplyIronBoostToGroundMonster = Symbol(
        [0x1182C],
        [0x201182C],
        None,
        "ApplyIronBoostToGroundMonster",
        "Applies the defense boost from Iron to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted defense boost, if not NULL\nreturn: actual defense boost",
        None,
    )

    ApplyZincBoostToGroundMonster = Symbol(
        [0x11868],
        [0x2011868],
        None,
        "ApplyZincBoostToGroundMonster",
        "Applies the special defense boost from Zinc to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted special defense boost, if not NULL\nreturn: actual special defense boost",
        None,
    )

    ApplyNectarBoostToGroundMonster = Symbol(
        [0x118A4],
        [0x20118A4],
        None,
        "ApplyNectarBoostToGroundMonster",
        "Applies the iq boost from Nectar to the target monster.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted iq boost, if not NULL\nreturn: actual iq boost",
        None,
    )

    IsMonsterAffectedByGravelyrockGroundMode = Symbol(
        [0x118D8],
        [0x20118D8],
        None,
        "IsMonsterAffectedByGravelyrockGroundMode",
        "Checks if the monster is Bonsly or Sudowoodo.\n\nr0: ground monster pointer\nreturn: bool",
        None,
    )

    ApplyGravelyrockBoostToGroundMonster = Symbol(
        [0x118F8],
        [0x20118F8],
        None,
        "ApplyGravelyrockBoostToGroundMonster",
        "Applies the iq boost from Gravelyrock to the target monster. Only Bonsly and Sudowoodo gain IQ from the Gravelyrock.\n\nr0: ground monster pointer\nr1: [output] pointer to attempted iq boost, if not NULL\nreturn: actual iq boost",
        None,
    )

    ApplyGummiBoostsGroundMode = Symbol(
        [0x11944],
        [0x2011944],
        None,
        "ApplyGummiBoostsGroundMode",
        "Applies the IQ boosts from eating a Gummi to the monster's data. Generally called with not increasing stats true outside of the cafe.\n\nr0: Pointer to monster id\nr1: Pointer to monster iq\nr2: Pointer to monster offensive stats\nr3: Pointer to monster defensive stats\nstack[0]: Item ID\nstack[1]: bool to NOT increase stats\nstack[2]: [output] pointer to a struct gummi_result",
        None,
    )

    LoadSynthBin = Symbol(
        [0x12B88],
        [0x2012B88],
        None,
        "LoadSynthBin",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    CloseSynthBin = Symbol(
        [0x12BDC],
        [0x2012BDC],
        None,
        "CloseSynthBin",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    GetSynthItem = Symbol(
        [0x132F8],
        [0x20132F8],
        None,
        "GetSynthItem",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    LoadWazaP = Symbol(
        [0x1346C],
        [0x201346C],
        None,
        "LoadWazaP",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    LoadWazaP2 = Symbol(
        [0x13494],
        [0x2013494],
        None,
        "LoadWazaP2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    UnloadCurrentWazaP = Symbol(
        [0x134BC],
        [0x20134BC],
        None,
        "UnloadCurrentWazaP",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    GetMoveName = Symbol(
        [0x134FC],
        [0x20134FC],
        None,
        "GetMoveName",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: move name",
        None,
    )

    FormatMoveString = Symbol(
        [0x13520],
        [0x2013520],
        None,
        "FormatMoveString",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: string_buffer\nr1: move\nr2: type_print",
        None,
    )

    FormatMoveStringMore = Symbol(
        [0x13828],
        [0x2013828],
        None,
        "FormatMoveStringMore",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: ???\nr1: ???\nr2: move\nr3: type_print",
        None,
    )

    InitMove = Symbol(
        [0x13860],
        [0x2013860],
        None,
        "InitMove",
        "Initializes a move info struct.\n\nThis sets f_exists and f_enabled_for_ai on the flags, the ID to the given ID, the PP to the max PP for the move ID, and the ginseng boost to 0.\n\nr0: pointer to move to initialize\nr1: move ID",
        None,
    )

    InitMoveCheckId = Symbol(
        [0x13890],
        [0x2013890],
        None,
        "InitMoveCheckId",
        "Same as InitMove, but the function ensures that the specified ID is not 0. If it is, the move is initialized as invalid and nothing else happens.\n\nr0: move\nr1: move ID",
        None,
    )

    GetInfoMoveGround = Symbol(
        [0x138D0],
        [0x20138D0],
        None,
        "GetInfoMoveGround",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: ground move\nr1: move ID",
        None,
    )

    GetMoveTargetAndRange = Symbol(
        [0x138E8],
        [0x20138E8],
        None,
        "GetMoveTargetAndRange",
        "Gets the move target-and-range field. See struct move_target_and_range in the C headers.\n\nr0: move pointer\nr1: AI flag (every move has two target-and-range fields, one for players and one for AI)\nreturn: move target and range",
        None,
    )

    GetMoveType = Symbol(
        [0x1390C],
        [0x201390C],
        None,
        "GetMoveType",
        "Gets the type of a move\n\nr0: Pointer to move data\nreturn: Type of the move",
        None,
    )

    GetMovesetLevelUpPtr = Symbol(
        [0x1392C],
        [0x201392C],
        None,
        "GetMovesetLevelUpPtr",
        "Given the ID of a monster in the current dungeon, returns a pointer to the list of moves it learns by leveling up and the level in which each move is learnt.\n\nThe list contains pairs of <encoded move ID, level>. The move ID is encoded and can be 1 or 2 bytes long. GetEncodedHalfword must be used to decode it. The end of the list is marked by a null byte.\n\nr0: monster ID\nreturn: Pointer to encoded level-up move list",
        None,
    )

    IsInvalidMoveset = Symbol(
        [0x13974],
        [0x2013974],
        None,
        "IsInvalidMoveset",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_id\nreturn: bool",
        None,
    )

    GetMovesetHmTmPtr = Symbol(
        [0x1399C],
        [0x201399C],
        None,
        "GetMovesetHmTmPtr",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: ?",
        None,
    )

    GetMovesetEggPtr = Symbol(
        [0x139E8],
        [0x20139E8],
        None,
        "GetMovesetEggPtr",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: ?",
        None,
    )

    GetMoveAiWeight = Symbol(
        [0x13A34],
        [0x2013A34],
        None,
        "GetMoveAiWeight",
        "Gets the AI weight of a move\n\nr0: Pointer to move data\nreturn: AI weight of the move",
        None,
    )

    GetMoveNbStrikes = Symbol(
        [0x13A54],
        [0x2013A54],
        None,
        "GetMoveNbStrikes",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move\nreturn: # strikes",
        None,
    )

    GetMoveBasePower = Symbol(
        [0x13A74],
        [0x2013A74],
        None,
        "GetMoveBasePower",
        "Gets the base power of a move from the move data table.\n\nr0: move pointer\nreturn: base power",
        None,
    )

    GetMoveBasePowerGround = Symbol(
        [0x13A94],
        [0x2013A94],
        None,
        "GetMoveBasePowerGround",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: ground_move\nreturn: base power",
        None,
    )

    GetMoveAccuracyOrAiChance = Symbol(
        [0x13AB4],
        [0x2013AB4],
        None,
        "GetMoveAccuracyOrAiChance",
        "Gets one of the two accuracy values of a move or its ai_condition_random_chance field.\n\nr0: Move pointer\nr1: 0 to get the move's first accuracy1 field, 1 to get its accuracy2, 2 to get its ai_condition_random_chance.\nreturn: Move's accuracy1, accuracy2 or ai_condition_random_chance",
        None,
    )

    GetMoveBasePp = Symbol(
        [0x13AD8],
        [0x2013AD8],
        None,
        "GetMoveBasePp",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move\nreturn: base PP",
        None,
    )

    GetMaxPp = Symbol(
        [0x13AF8],
        [0x2013AF8],
        None,
        "GetMaxPp",
        "Gets the maximum PP for a given move.\n\nIrkdwia's notes: GetMovePPWithBonus\n\nr0: move pointer\nreturn: max PP for the given move, capped at 99",
        None,
    )

    GetMoveMaxGinsengBoost = Symbol(
        [0x13B78],
        [0x2013B78],
        None,
        "GetMoveMaxGinsengBoost",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move\nreturn: max ginseng boost",
        None,
    )

    GetMoveMaxGinsengBoostGround = Symbol(
        [0x13B98],
        [0x2013B98],
        None,
        "GetMoveMaxGinsengBoostGround",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: ground_move\nreturn: max ginseng boost",
        None,
    )

    GetMoveCritChance = Symbol(
        [0x13BB8],
        [0x2013BB8],
        None,
        "GetMoveCritChance",
        "Gets the critical hit chance of a move.\n\nr0: move pointer\nreturn: critical hit chance",
        None,
    )

    IsThawingMove = Symbol(
        [0x13BD8],
        [0x2013BD8],
        None,
        "IsThawingMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move\nreturn: bool",
        None,
    )

    IsAffectedByTaunt = Symbol(
        [0x13BF8],
        [0x2013BF8],
        None,
        "IsAffectedByTaunt",
        "Note: unverified, ported from Irdkwia's notes\n\nBased on struct move_data, maybe this should be IsUsableWhileTaunted?\n\nr0: move\nreturn: bool",
        None,
    )

    GetMoveRangeId = Symbol(
        [0x13C18],
        [0x2013C18],
        None,
        "GetMoveRangeId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move\nreturn: range ID",
        None,
    )

    GetMoveActualAccuracy = Symbol(
        [0x13C38],
        [0x2013C38],
        None,
        "GetMoveActualAccuracy",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: accuracy",
        None,
    )

    GetMoveBasePowerFromId = Symbol(
        [0x13C90],
        [0x2013C90],
        None,
        "GetMoveBasePowerFromId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: base power",
        None,
    )

    IsMoveRangeString19 = Symbol(
        [0x13CAC],
        [0x2013CAC],
        None,
        "IsMoveRangeString19",
        "Returns whether a move's range string is 19 ('User').\n\nr0: Move pointer\nreturn: True if the move's range string field has a value of 19.",
        None,
    )

    GetMoveMessageFromId = Symbol(
        [0x13CD8],
        [0x2013CD8],
        None,
        "GetMoveMessageFromId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID?\nreturn: string",
        None,
    )

    GetNbMoves = Symbol(
        [0x13D0C],
        [0x2013D0C],
        None,
        "GetNbMoves",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nreturn: # moves",
        None,
    )

    GetMovesetIdx = Symbol(
        [0x13D54, 0x148AC],
        [0x2013D54, 0x20148AC],
        None,
        "GetMovesetIdx",
        "Returns the move position in the moveset if it is found, -1 otherwise\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nr1: move ID\nreturn: ?",
        None,
    )

    IsReflectedByMagicCoat = Symbol(
        [0x13DB0],
        [0x2013DB0],
        None,
        "IsReflectedByMagicCoat",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    CanBeSnatched = Symbol(
        [0x13DCC],
        [0x2013DCC],
        None,
        "CanBeSnatched",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    FailsWhileMuzzled = Symbol(
        [0x13DE8],
        [0x2013DE8],
        None,
        "FailsWhileMuzzled",
        "Note: unverified, ported from Irdkwia's notes\n\nCalled IsMouthMove in Irdkwia's notes, which presumably is relevant to the Muzzled status.\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsSoundMove = Symbol(
        [0x13E04],
        [0x2013E04],
        None,
        "IsSoundMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move\nreturn: bool",
        None,
    )

    IsRecoilMove = Symbol(
        [0x13EBC],
        [0x2013EBC],
        None,
        "IsRecoilMove",
        "Checks if the given move is a recoil move (affected by Reckless).\n\nr0: move ID\nreturn: bool",
        None,
    )

    AllManip1 = Symbol(
        [0x14288],
        [0x2014288],
        None,
        "AllManip1",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    AllManip2 = Symbol(
        [0x142B0],
        [0x20142B0],
        None,
        "AllManip2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    ManipMoves1v1 = Symbol(
        [0x14344],
        [0x2014344],
        None,
        "ManipMoves1v1",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    ManipMoves1v2 = Symbol(
        [0x143E4],
        [0x20143E4],
        None,
        "ManipMoves1v2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    ManipMoves2v1 = Symbol(
        [0x1454C],
        [0x201454C],
        None,
        "ManipMoves2v1",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    ManipMoves2v2 = Symbol(
        [0x145EC],
        [0x20145EC],
        None,
        "ManipMoves2v2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    DungeonMoveToGroundMove = Symbol(
        [0x14754],
        [0x2014754],
        None,
        "DungeonMoveToGroundMove",
        "Converts a struct move to a struct ground_move.\n\nr0: [output] ground_move\nr1: move",
        None,
    )

    GroundToDungeonMoveset = Symbol(
        [0x1478C],
        [0x201478C],
        None,
        "GroundToDungeonMoveset",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: [output] moveset_dun_str\nr1: moveset_str",
        None,
    )

    DungeonToGroundMoveset = Symbol(
        [0x14820],
        [0x2014820],
        None,
        "DungeonToGroundMoveset",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: [output] moveset_str\nr1: moveset_dun_str",
        None,
    )

    GetInfoGroundMoveset = Symbol(
        [0x14860],
        [0x2014860],
        None,
        "GetInfoGroundMoveset",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nr1: moves_id",
        None,
    )

    FindFirstFreeMovesetIdx = Symbol(
        [0x14908],
        [0x2014908],
        None,
        "FindFirstFreeMovesetIdx",
        "Returns the first position of an empty move in the moveset if it is found, -1 otherwise\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nreturn: index",
        None,
    )

    LearnMoves = Symbol(
        [0x14954],
        [0x2014954],
        None,
        "LearnMoves",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nr1: moves_id",
        None,
    )

    CopyMoveTo = Symbol(
        [0x14AF4],
        [0x2014AF4],
        None,
        "CopyMoveTo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: write_info\nr1: buffer_write",
        None,
    )

    CopyMoveFrom = Symbol(
        [0x14B2C],
        [0x2014B2C],
        None,
        "CopyMoveFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info\nr1: buffer_read",
        None,
    )

    CopyMovesetTo = Symbol(
        [0x14B64],
        [0x2014B64],
        None,
        "CopyMovesetTo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: write_info\nr1: buffer_write",
        None,
    )

    CopyMovesetFrom = Symbol(
        [0x14B94],
        [0x2014B94],
        None,
        "CopyMovesetFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info\nr1: buffer_read",
        None,
    )

    Is2TurnsMove = Symbol(
        [0x14D0C],
        [0x2014D0C],
        None,
        "Is2TurnsMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsRegularAttackOrProjectile = Symbol(
        [0x14D94],
        [0x2014D94],
        None,
        "IsRegularAttackOrProjectile",
        "Checks if a move ID is MOVE_REGULAR_ATTACK or MOVE_PROJECTILE.\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsPunchMove = Symbol(
        [0x14DC0],
        [0x2014DC0],
        None,
        "IsPunchMove",
        "Checks if the given move is a punch move (affected by Iron Fist).\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsHealingWishOrLunarDance = Symbol(
        [0x14E00],
        [0x2014E00],
        None,
        "IsHealingWishOrLunarDance",
        "Checks if a move ID is MOVE_HEALING_WISH or MOVE_LUNAR_DANCE.\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsCopyingMove = Symbol(
        [0x14E2C],
        [0x2014E2C],
        None,
        "IsCopyingMove",
        "Checks if a move ID is MOVE_MIMIC, MOVE_SKETCH, or MOVE_COPYCAT.\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsTrappingMove = Symbol(
        [0x14E64],
        [0x2014E64],
        None,
        "IsTrappingMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsOneHitKoMove = Symbol(
        [0x14EA8],
        [0x2014EA8],
        None,
        "IsOneHitKoMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsNot2TurnsMoveOrSketch = Symbol(
        [0x14EE0],
        [0x2014EE0],
        None,
        "IsNot2TurnsMoveOrSketch",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsRealMove = Symbol(
        [0x14F0C],
        [0x2014F0C],
        None,
        "IsRealMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsMovesetValid = Symbol(
        [0x14FA0],
        [0x2014FA0],
        None,
        "IsMovesetValid",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nreturn: bool",
        None,
    )

    IsRealMoveInTimeDarkness = Symbol(
        [0x1500C],
        [0x201500C],
        None,
        "IsRealMoveInTimeDarkness",
        "Seed Flare isn't a real move in Time/Darkness\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: move ID\nreturn: bool",
        None,
    )

    IsMovesetValidInTimeDarkness = Symbol(
        [0x150AC],
        [0x20150AC],
        None,
        "IsMovesetValidInTimeDarkness",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nreturn: bool",
        None,
    )

    GetFirstNotRealMoveInTimeDarkness = Symbol(
        [0x150CC],
        [0x20150CC],
        None,
        "GetFirstNotRealMoveInTimeDarkness",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_str\nreturn: index",
        None,
    )

    IsSameMove = Symbol(
        [0x151F4],
        [0x20151F4],
        None,
        "IsSameMove",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: moveset_dun_str\nr1: move_data_dun_str\nreturn: bool",
        None,
    )

    GetMoveCategory = Symbol(
        [0x15270],
        [0x2015270],
        None,
        "GetMoveCategory",
        "Gets a move's category (physical, special, status).\n\nr0: move ID\nreturn: move category enum",
        None,
    )

    GetPpIncrease = Symbol(
        [0x1528C],
        [0x201528C],
        None,
        "GetPpIncrease",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nr1: IQ skills bitvector\nreturn: PP increase",
        None,
    )

    OpenWaza = Symbol(
        [0x1533C],
        [0x201533C],
        None,
        "OpenWaza",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: waza_id",
        None,
    )

    SelectWaza = Symbol(
        [0x153A4],
        [0x20153A4],
        None,
        "SelectWaza",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: waza_id",
        None,
    )

    PlayBgmByIdVeneer = Symbol(
        [0x17BF4],
        [0x2017BF4],
        None,
        "PlayBgmByIdVeneer",
        "Likely a linker-generated veneer for PlayBgmById.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: Music ID",
        None,
    )

    PlayBgmByIdVolumeVeneer = Symbol(
        [0x17C00],
        [0x2017C00],
        None,
        "PlayBgmByIdVolumeVeneer",
        "Likely a linker-generated veneer for PlayBgmByIdVolume.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: Music ID\nr1: (?) Stored on byte 8 on the struct passed to SendAudioCommand\nr2: Volume (0-255)",
        None,
    )

    PlaySeVolumeWrapper = Symbol(
        [0x17D68],
        [0x2017D68],
        None,
        "PlaySeVolumeWrapper",
        "Wrapper for PlaySeVolume. Takes an index and uses it to determine the ID of the sound to play.\n\nr0: Index",
        None,
    )

    PlayBgmById = Symbol(
        [0x17E90],
        [0x2017E90],
        None,
        "PlayBgmById",
        "Initializes some values and then calls SendAudioCommand to play a BGM track.\n\nChecks for DEBUG_FLAG_BGM_OFF. The volume is set to either 0 or 255 depending on the flag before calling SendAudioCommand.\n\nr0: Music ID",
        None,
    )

    PlayBgmByIdVolume = Symbol(
        [0x17F0C],
        [0x2017F0C],
        None,
        "PlayBgmByIdVolume",
        "Initializes some values and then calls SendAudioCommand to play a BGM track.\n\nChecks for DEBUG_FLAG_BGM_OFF. If 1, sets the volume to 0 before calling SendAudioCommand.\n\nr0: Music ID\nr1: (?) Stored on byte 8 on the struct passed to SendAudioCommand\nr2: Volume (0-255)",
        None,
    )

    StopBgmCommand = Symbol(
        [0x17F84],
        [0x2017F84],
        None,
        "StopBgmCommand",
        "Stops the BGM that is being currently played by calling SendAudioCommand.\n\nNo params.",
        None,
    )

    PlaySeByIdVolume = Symbol(
        [0x18354],
        [0x2018354],
        None,
        "PlaySeByIdVolume",
        "Plays the specified sound effect with the specified volume.\n\nChecks for DEBUG_FLAG_SE_OFF and sets the volume to 0 if the flag is set. Calls SendAudioCommand2.\n\nr0: Sound effect ID\nr1: Volume (0-255)",
        None,
    )

    SendAudioCommand2 = Symbol(
        [0x18B80],
        [0x2018B80],
        None,
        "SendAudioCommand2",
        "Very similar to SendAudioCommand. Contains an additional function call.\n\nr0: Command to send",
        None,
    )

    AllocAudioCommand = Symbol(
        [0x18C08],
        [0x2018C08],
        None,
        "AllocAudioCommand",
        "Searches for an entry in AUDIO_COMMANDS_BUFFER that's not currently in use (audio_command::status == 0). Returns the first entry not in use, or null if none was found.\n\nAlso sets the status of the found entry to the value specified in r0.\n\nThe game doesn't bother checking if the result of the function is null, so the buffer is not supposed to ever get filled.\n\nr0: Status to set the found entry to\nreturn: The first unused entry, or null if none was found",
        None,
    )

    SendAudioCommand = Symbol(
        [0x18C44],
        [0x2018C44],
        None,
        "SendAudioCommand",
        "Used to send commands to the audio engine (seems to be used mainly to play and stop music)\n\nThis function calls a stubbed-out one with the string 'audio command list'\n\nr0: Command to send",
        None,
    )

    InitSoundSystem = Symbol(
        [0x18CC4],
        [0x2018CC4],
        None,
        "InitSoundSystem",
        "Initialize the DSE sound engine?\n\nThis function is called somewhere in the hierarchy under TaskProcBoot and appears to allocate a bunch of memory (including a dedicated memory arena, see SOUND_MEMORY_ARENA) for sound data, and reads a bunch of core sound files.\n\nFile paths referenced:\n- SOUND/SYSTEM/se_sys.swd\n- SOUND/SYSTEM/se_sys.sed\n- SOUND/SE/motion.swd\n- SOUND/SE/motion.sed\n- SOUND/BGM/bgm.swd (this is the main sample bank, see https://projectpokemon.org/home/docs/mystery-dungeon-nds/pok%C3%A9mon-mystery-dungeon-explorers-r78/)\n\nDebug strings:\n- entry system se swd %04x\n\n- entry system se sed %04x\n\n- entry motion se swd %04x\n\n- entry motion se sed %04x\n",
        None,
    )

    ManipBgmPlayback = Symbol(
        [0x18F40],
        [0x2018F40],
        None,
        "ManipBgmPlayback",
        "Uncertain. More like bgm1&2 end\n\nNote: unverified, ported from Irdkwia's notes",
        None,
    )

    SoundDriverReset = Symbol(
        [0x19164],
        [0x2019164],
        None,
        "SoundDriverReset",
        "Uncertain.\n\nNote: unverified, ported from Irdkwia's notes",
        None,
    )

    LoadDseFile = Symbol(
        [0x19428],
        [0x2019428],
        None,
        "LoadDseFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: [output] iovec\nr1: filename\nreturn: bytes read",
        None,
    )

    PlaySeLoad = Symbol(
        [0x19610],
        [0x2019610],
        None,
        "PlaySeLoad",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    IsSongOver = Symbol(
        [0x198EC],
        [0x20198EC],
        None,
        "IsSongOver",
        "True if the song that is currently being played has finished playing.\n\nreturn: True if the current song is over",
        None,
    )

    PlayBgm = Symbol(
        [0x19954],
        [0x2019954],
        None,
        "PlayBgm",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    StopBgm = Symbol(
        [0x19BC4],
        [0x2019BC4],
        None,
        "StopBgm",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    ChangeBgm = Symbol(
        [0x19CEC],
        [0x2019CEC],
        None,
        "ChangeBgm",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    PlayBgm2 = Symbol(
        [0x19E20],
        [0x2019E20],
        None,
        "PlayBgm2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    StopBgm2 = Symbol(
        [0x1A084],
        [0x201A084],
        None,
        "StopBgm2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    ChangeBgm2 = Symbol(
        [0x1A184],
        [0x201A184],
        None,
        "ChangeBgm2",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    PlayME = Symbol(
        [0x1A264],
        [0x201A264],
        None,
        "PlayME",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    StopME = Symbol(
        [0x1A4A8],
        [0x201A4A8],
        None,
        "StopME",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: fade_out",
        None,
    )

    PlaySe = Symbol(
        [0x1A598],
        [0x201A598],
        None,
        "PlaySe",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    PlaySeFullSpec = Symbol(
        [0x1A708],
        [0x201A708],
        None,
        "PlaySeFullSpec",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    SeChangeVolume = Symbol(
        [0x1A8C4],
        [0x201A8C4],
        None,
        "SeChangeVolume",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    SeChangePan = Symbol(
        [0x1A99C],
        [0x201A99C],
        None,
        "SeChangePan",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    StopSe = Symbol(
        [0x1AA80],
        [0x201AA80],
        None,
        "StopSe",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    InitAnimationControl = Symbol(
        [0x1C0EC],
        [0x201C0EC],
        None,
        "InitAnimationControl",
        "Initialize the animation_control structure\n\nr0: animation_control",
        None,
    )

    InitAnimationControlWithSet = Symbol(
        [0x1C14C, 0x1C168],
        [0x201C14C, 0x201C168],
        None,
        "InitAnimationControlWithSet",
        "Initialize the animation_control structure, and set a certain value in a bitflag to 1\n\nr0: animation_control",
        None,
    )

    SetSpriteIdForAnimationControl = Symbol(
        [0x1C184],
        [0x201C184],
        None,
        "SetSpriteIdForAnimationControl",
        "Set the sprite id (from WAN_TABLE) in the given animation control\nAlso set field 0x72 to the sprite id if they differ\nIf they differ, it’ll also set field 0x43 to 0xFF\n\nr0: animation control\nr1: sprite id in WAN_TABLE",
        None,
    )

    SetAnimationForAnimationControlInternal = Symbol(
        [0x1C218],
        [0x201C218],
        None,
        "SetAnimationForAnimationControlInternal",
        "Set the wan animation (and other related settings) of an animation_control\nUsed by SetAnimationForAnimationControl\n\nr0: animation_control\nr1: wan_header\nr2: animation group id\nr3: animation id\nstack[0]: ?\nstack[1] (0x4): palette pos low (see the field on animation_control)\nstack[2] (0x8): ?\nstack[3] (0xC): ?\nstack[4] (0x10): palette_bank (directly set to the animation_control field with said name)",
        None,
    )

    SetAnimationForAnimationControl = Symbol(
        [0x1C368],
        [0x201C368],
        None,
        "SetAnimationForAnimationControl",
        "Set the animation to play with this animation control, but do not start it.\n\n(args same as SetAndPlayAnimationForAnimationControl)\nr0: animation_control\nr1: animation key (either an animation or animation group depending on the type of sprite and if it does have animation group with this animation key as index)\nr2: direction_id (unsure) (the key to the wan_animation in itself, only used when animation key represent a wan_animation_group)\nr3: ?\nstack[0]: low_palette_pos\nstack[1] (0x4): ?\nstack[2] (0x8): ?\nstack[3] (0xC): ?",
        None,
    )

    GetWanForAnimationControl = Symbol(
        [0x1C484],
        [0x201C484],
        None,
        "GetWanForAnimationControl",
        "Return the WAN to use for the given animation control\nReturn the override if it exists, otherwise look up the sprite id in WAN_TABLE\n\nr0: animation_control\nreturn: wan_header",
        None,
    )

    SetAndPlayAnimationForAnimationControl = Symbol(
        [0x1C4B4],
        [0x201C4B4],
        None,
        "SetAndPlayAnimationForAnimationControl",
        "Set the animation to play with the animation control, and start it.\n\nr0: animation_control\nr1: animation key (either an animation or animation group depending on the type of sprite and if it does have animation group with this animation key as index)\nr2: direction_id (unsure) (the key to the wan_animation in itself, only used when animation key represent a wan_animation_group)\nr3: ?\nstack[0]: low_palette_pos\nstack[1] (0x4): ?\nstack[2] (0x8): ?\nstack[3] (0xC): ?",
        None,
    )

    SwitchAnimationControlToNextFrame = Symbol(
        [0x1C4F4],
        [0x201C4F4],
        None,
        "SwitchAnimationControlToNextFrame",
        "Handle switching to the next frame of an animation control, including looping.\n\nr0: animation_control",
        None,
    )

    LoadAnimationFrameAndIncrementInAnimationControl = Symbol(
        [0x1C5FC],
        [0x201C5FC],
        None,
        "LoadAnimationFrameAndIncrementInAnimationControl",
        "Read some value of the input animation frame, and update animation control with it.\nAlso switch next_animation_frame of animation_control to the next animation frame\nSeems to only be called on said next_animation_frame\nAlso set bit of some_bitfield at 0x0800 to 1\n\nr0: animation_control\nr1: animation_frame",
        None,
    )

    AnimationControlGetAllocForMaxFrame = Symbol(
        [0x1D20C],
        [0x201D20C],
        None,
        "AnimationControlGetAllocForMaxFrame",
        "Return the maximum allocation for a frame of this sprite, as stored in the WAN file\nReturn 0 if missing and takes sprite override into account\n\nr0: animation_control\nreturn: allocation for max frame",
        None,
    )

    DeleteWanTableEntry = Symbol(
        [0x1D278],
        [0x201D278],
        None,
        "DeleteWanTableEntry",
        "Always delete an entry if the file is allocated externally (file_externally_allocated is set), otherwise, decrease the reference counter. If it reach 0, delete the sprite.\n\nr0: wan_table_ptr\nr1: wan_id",
        None,
    )

    AllocateWanTableEntry = Symbol(
        [0x1D2E0],
        [0x201D2E0],
        None,
        "AllocateWanTableEntry",
        "Return the identifier to a free wan table entry (-1 if none are avalaible). The entry is zeroed.\n\nr0: wan_table_ptr\nreturn: the entry id in wan_table",
        None,
    )

    FindWanTableEntry = Symbol(
        [0x1D370],
        [0x201D370],
        None,
        "FindWanTableEntry",
        "Search in the given table (in practice always seems to be WAN_TABLE) for an entry with the given file name.\n\nr0: table pointer\nr1: file name\nreturn: index of the found file, if found, or -1 if not found",
        None,
    )

    GetLoadedWanTableEntry = Symbol(
        [0x1D3D0],
        [0x201D3D0],
        None,
        "GetLoadedWanTableEntry",
        "Look up a sprite with the provided pack_id and file_index in the wan table.\n\nr0: wan_table_ptr\nr1: pack_id\nr2: file_index\nreturn: sprite id in the wan table, -1 if not found",
        None,
    )

    InitWanTable = Symbol(
        [0x1D458],
        [0x201D458],
        None,
        "InitWanTable",
        "Initialize the input WAN table with 0x60 free entries (it needs a length of 0x1510 bytes)\n\nr0: wan_table_ptr",
        None,
    )

    LoadWanTableEntry = Symbol(
        [0x1D478],
        [0x201D478],
        None,
        "LoadWanTableEntry",
        "Appears to load data from the given file (in practice always seems to be animation data), using previously loaded data in the given table (see FindWanTableEntry) if possible.\n\nr0: table pointer\nr1: file name\nr2: flags\nreturn: table index of the loaded data",
        None,
    )

    LoadWanTableEntryFromPack = Symbol(
        [0x1D520],
        [0x201D520],
        None,
        "LoadWanTableEntryFromPack",
        "Return an already allocated entry for this sprite if it exists, otherwise allocate a new one and load the optionally compressed sprite.\n\nr0: wan_table_ptr\nr1: pack_id\nr2: file_index\nr3: allocation flags\nstack[0]: compressed\nreturn: the entry id in wan_table",
        None,
    )

    LoadWanTableEntryFromPackUseProvidedMemory = Symbol(
        [0x1D62C],
        [0x201D62C],
        None,
        "LoadWanTableEntryFromPackUseProvidedMemory",
        "Return an already allocated entry for this sprite if it exists, otherwise allocate a new one and load the optionally compressed sprite into the provided memory area. Mark the sprite as externally allocated.\n\nr0: wan_table_ptr\nr1: pack_id\nr2: file_index\nr3: sprite_storage_ptr\nstack[0]: compressed\nreturn: the entry id in wan_table",
        None,
    )

    ReplaceWanFromBinFile = Symbol(
        [0x1D720],
        [0x201D720],
        None,
        "ReplaceWanFromBinFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: wan_table_ptr\nr1: wan_id\nr2: bin_file_id\nr3: file_id\nstack[0]: compressed",
        None,
    )

    DeleteWanTableEntryVeneer = Symbol(
        [0x1D7C8],
        [0x201D7C8],
        None,
        "DeleteWanTableEntryVeneer",
        "Likely a linker-generated veneer for DeleteWanTableEntry.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: wan_table_ptr\nr1: wan_id",
        None,
    )

    WanHasAnimationGroup = Symbol(
        [0x1DAE0],
        [0x201DAE0],
        None,
        "WanHasAnimationGroup",
        "Check if the input WAN file loaded in memory has an animation group with this ID\nValid means that the animation group is in the range of existing animation, and that it has at least one animation.\n\nr0: pointer to the header of the WAN\nr1: id of the animation group\nreturn: whether the WAN file has the given animation group",
        None,
    )

    WanTableSpriteHasAnimationGroup = Symbol(
        [0x1DB1C],
        [0x201DB1C],
        None,
        "WanTableSpriteHasAnimationGroup",
        "Check if the sprite in the global WAN table has the given animation group\nsee WanHasAnimationGroup for more detail\n\nr0: sprite id in the WAN table\nr1: animation group id\nreturn: whether the associated sprite has the given animation group",
        None,
    )

    SpriteTypeInWanTable = Symbol(
        [0x1DD0C],
        [0x201DD0C],
        None,
        "SpriteTypeInWanTable",
        "Look up the sprite in the WAN table, and return its type\n\nr0: sprite id in the WAN table\nreturn: sprite type",
        None,
    )

    LoadWteFromRom = Symbol(
        [0x1DEE8],
        [0x201DEE8],
        None,
        "LoadWteFromRom",
        "Loads a SIR0-wrapped WTE file from ROM, and returns a handle to it\n\nr0: [output] pointer to wte handle\nr1: file path string\nr2: load file flags",
        None,
    )

    LoadWteFromFileDirectory = Symbol(
        [0x1DF60],
        [0x201DF60],
        None,
        "LoadWteFromFileDirectory",
        "Loads a SIR0-wrapped WTE file from a file directory, and returns a handle to it\n\nr0: [output] pointer to wte handle\nr1: file directory id\nr2: file index\nr3: malloc flags",
        None,
    )

    UnloadWte = Symbol(
        [0x1DFB4],
        [0x201DFB4],
        None,
        "UnloadWte",
        "Frees the buffer used to store the WTE data in the handle, and sets both pointers to null\n\nr0: pointer to wte handle",
        None,
    )

    LoadWtuFromBin = Symbol(
        [0x1E050],
        [0x201E050],
        None,
        "LoadWtuFromBin",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: bin_file_id\nr1: file_id\nr2: load_type\nreturn: ?",
        None,
    )

    ProcessWte = Symbol(
        [0x1E14C],
        [0x201E14C],
        None,
        "ProcessWte",
        "Prepare a WTE data to be loaded into VRAM. Seems to need to be called with another undocumented function (at 0x0201e1d8 (EU))\nIt skips the texture and/or the palette if missing from the file. The texture VRAM has 128KiB of space, and palette has 16KiB.\nThe true palette VRAM offset will be upper_part*0x100+lower_part\n\nThis may or may not be the function that adds to the queue so it can be added during VBlank.\n\nr0: pointer to the WTE file header loaded in memory\nr1: where the WTE texture will be loaded in the VRAM (from 0 to 0x1FFFF)\nr2: upper part of the palette VRAM\nr3: lower part of the palette VRAM",
        None,
    )

    GeomSetTexImageParam = Symbol(
        [0x1E530],
        [0x201E530],
        None,
        "GeomSetTexImageParam",
        "Send the TEXIMAGE_PARAM geometry engine command, that defines some parameters for the texture\nSee http://problemkaputt.de/gbatek.htm#ds3dtextureattributes for more information on the parameters\n\nr0: texture format\nr1: texture coordinates transformation modes\nr2: texture S-Size\nr3: texture T-Size\nstack[0] (0x0): repeat in S (bit 0) and/or T (bit 1) direction\nstack[1] (0x4): flip in S (bit 0) and/or T (bit 1) direction\nstack[2] (0x8): What to make of color 0 (bit 29)\nstack[3] (0xC): Texture VRAM offset divided by 8",
        None,
    )

    GeomSetVertexCoord16 = Symbol(
        [0x1E570],
        [0x201E570],
        None,
        "GeomSetVertexCoord16",
        "Send the 'VTX_16' geometry engine command, that defines the coordinate of a point of a polygon, using 16 bits.\nInputs are clamped over their 16 lower bits\n\nr0: x coordinate\nr1: y coordinate\nr2: z coordinate",
        None,
    )

    InitRender3dData = Symbol(
        [0x1E5A0],
        [0x201E5A0],
        None,
        "InitRender3dData",
        "Initialize the global 'RENDER_3D' structure.\n\nNo params.",
        None,
    )

    GeomSwapBuffers = Symbol(
        [0x1E7B8],
        [0x201E7B8],
        None,
        "GeomSwapBuffers",
        "Call the 'SWAP_BUFFERS' command. This will swap the geometry buffer. The parameter of 1 is provided, which enables manual Y-sorting of translucent polygons.\n\nNo params.",
        None,
    )

    InitRender3dElement64 = Symbol(
        [0x1E7CC],
        [0x201E7CC],
        None,
        "InitRender3dElement64",
        "Initialize the render_3d_element_64 structure (without performing any drawing or external data access)\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64Texture0x7 = Symbol(
        [0x1E8E0],
        [0x201E8E0],
        None,
        "Render3d64Texture0x7",
        "RENDER_3D_FUNCTIONS_64[7]. Renders a render_3d_element_64 with type RENDER64_TEXTURE_0x7.\n\nConverts the render_3d_element_64 to a render_3d_element on the render queue of RENDER_3D, with type RENDER_TEXTURE.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64WindowFrame = Symbol(
        [0x1EA88],
        [0x201EA88],
        None,
        "Render3d64WindowFrame",
        "Draw the frame for a window, using the 3D engine.\n\nThe render_3d_element_64 contains certain value that needs to be set to a correct value for it to work.\nThe element is not immediately sent to the geometry engine, but is converted to a render_3d_element and queued up in RENDER_3D.\n\nRENDER_3D_FUNCTIONS_64[6], corresponding to a type of RENDER64_WINDOW_FRAME.\n\nr0: render_3d_element_64",
        None,
    )

    EnqueueRender3d64Tiling = Symbol(
        [0x1ED38],
        [0x201ED38],
        None,
        "EnqueueRender3d64Tiling",
        "Converts a render_3d_element_64 with type RENDER64_TILING to a render_3d_element on the render queue of RENDER_3D, with type RENDER_TILING.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64Tiling = Symbol(
        [0x1EE24],
        [0x201EE24],
        None,
        "Render3d64Tiling",
        "RENDER_3D_FUNCTIONS_64[5]. Renders a render_3d_element_64 with type RENDER64_TILING.\n\nConverts the render_3d_element_64 to a render_3d_element on the render queue of RENDER_3D, with type RENDER_TILING.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64Quadrilateral = Symbol(
        [0x1EEEC],
        [0x201EEEC],
        None,
        "Render3d64Quadrilateral",
        "RENDER_3D_FUNCTIONS_64[4]. Renders a render_3d_element_64 with type RENDER64_QUADRILATERAL.\n\nConverts the render_3d_element_64 to a render_3d_element on the render queue of RENDER_3D, with type RENDER_QUADRILATERAL.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64RectangleMulticolor = Symbol(
        [0x1EF8C],
        [0x201EF8C],
        None,
        "Render3d64RectangleMulticolor",
        "RENDER_3D_FUNCTIONS_64[3]. Renders a render_3d_element_64 with type RENDER64_RECTANGLE_MULTICOLOR.\n\nConverts the render_3d_element_64 to a render_3d_element on the render queue of RENDER_3D, with type RENDER_RECTANGLE.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64Rectangle = Symbol(
        [0x1F0F8],
        [0x201F0F8],
        None,
        "Render3d64Rectangle",
        "RENDER_3D_FUNCTIONS_64[2]. Renders a render_3d_element_64 with type RENDER64_RECTANGLE.\n\nConverts the render_3d_element_64 to a render_3d_element on the render queue of RENDER_3D, with type RENDER_RECTANGLE.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64Nothing = Symbol(
        [0x1F1A4],
        [0x201F1A4],
        None,
        "Render3d64Nothing",
        "RENDER_3D_FUNCTIONS_64[1]. Renders a render_3d_element_64 with type RENDER64_NOTHING. This function is entirely empty.\n\nr0: render_3d_element_64",
        None,
    )

    Render3d64Texture = Symbol(
        [0x1F1A8],
        [0x201F1A8],
        None,
        "Render3d64Texture",
        "RENDER_3D_FUNCTIONS_64[0]. Renders a render_3d_element_64 with type RENDER64_TEXTURE.\n\nConverts the render_3d_element_64 to a render_3d_element on the render queue of RENDER_3D, with type RENDER_TEXTURE.\n\nr0: render_3d_element_64",
        None,
    )

    Render3dElement64 = Symbol(
        [0x1F270],
        [0x201F270],
        None,
        "Render3dElement64",
        "Dispatches a render_3d_element_64 to the render function corresponding to its type.\n\nr0: render_3d_element_64",
        None,
    )

    HandleSir0Translation = Symbol(
        [0x1F550],
        [0x201F550],
        None,
        "HandleSir0Translation",
        "Translates the offsets in a SIR0 file into NDS memory addresses, changes the magic number to SirO (opened), and returns a pointer to the first pointer specified in the SIR0 header (beginning of the data).\n\nIrkdiwa's notes:\n  ret_code = 0 if it wasn't a SIR0 file\n  ret_code = 1 if it has been transformed in SIRO file\n  ret_code = 2 if it was already a SIRO file\n  [output] contains a pointer to the header of the SIRO file if ret_code = 1 or 2\n  [output] contains a pointer which is exactly the same as the sir0_ptr if ret_code = 0\n\nr0: [output] double pointer to beginning of data\nr1: pointer to source file buffer\nreturn: return code",
        None,
    )

    ConvertPointersSir0 = Symbol(
        [0x1F5D0],
        [0x201F5D0],
        None,
        "ConvertPointersSir0",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: sir0_ptr",
        None,
    )

    HandleSir0TranslationVeneer = Symbol(
        [0x1F628],
        [0x201F628],
        None,
        "HandleSir0TranslationVeneer",
        "Likely a linker-generated veneer for HandleSir0Translation.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: [output] double pointer to beginning of data\nr1: pointer to source file buffer\nreturn: return code",
        None,
    )

    DecompressAtNormalVeneer = Symbol(
        [0x1F65C],
        [0x201F65C],
        None,
        "DecompressAtNormalVeneer",
        "Likely a linker-generated veneer for DecompressAtNormal.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: addr_decomp\nr1: expected_size\nr2: AT pointer\nreturn: ?",
        None,
    )

    DecompressAtNormal = Symbol(
        [0x1F668],
        [0x201F668],
        None,
        "DecompressAtNormal",
        "Overwrites r3 probably passed to match DecompressAtHalf's definition.\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: addr_decomp\nr1: expected_size\nr2: AT pointer\nreturn: ?",
        None,
    )

    DecompressAtHalf = Symbol(
        [0x1FAAC],
        [0x201FAAC],
        None,
        "DecompressAtHalf",
        "Same as DecompressAtNormal, except it stores each nibble as a byte\nand adds the high nibble (r3).\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: addr_decomp\nr1: expected_size\nr2: AT pointer\nr3: high_nibble\nreturn: ?",
        None,
    )

    DecompressAtFromMemoryPointerVeneer = Symbol(
        [0x1FFE8],
        [0x201FFE8],
        None,
        "DecompressAtFromMemoryPointerVeneer",
        "Likely a linker-generated veneer for DecompressAtFromMemoryPointer.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: addr_decomp\nr1: expected_size\nr2: AT pointer\nreturn: ?",
        None,
    )

    DecompressAtFromMemoryPointer = Symbol(
        [0x1FFF4],
        [0x201FFF4],
        None,
        "DecompressAtFromMemoryPointer",
        "Overwrites r3 probably passed to match DecompressAtHalf's definition.\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: addr_decomp\nr1: expected_size\nr2: AT pointer\nreturn: ?",
        None,
    )

    WriteByteFromMemoryPointer = Symbol(
        [0x2050C],
        [0x202050C],
        None,
        "WriteByteFromMemoryPointer",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: byte",
        None,
    )

    GetAtSize = Symbol(
        [0x20588],
        [0x2020588],
        None,
        "GetAtSize",
        "Doesn't work for AT3PX and AT4PN\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: AT pointer\nr1: ?\nreturn: ?",
        None,
    )

    GetLanguageType = Symbol(
        [0x20688],
        [0x2020688],
        None,
        "GetLanguageType",
        "Gets the language type.\n\nThis is the value backing the special LANGUAGE_TYPE script variable.\n\nreturn: language type",
        None,
    )

    GetLanguage = Symbol(
        [0x206B0],
        [0x20206B0],
        None,
        "GetLanguage",
        "Gets the single-byte language ID of the current program.\n\nThe language ID appears to be used to index some global tables.\n\nreturn: language ID",
        None,
    )

    StrcmpTag = Symbol(
        [0x20A20],
        [0x2020A20],
        None,
        "StrcmpTag",
        "Checks if a null-terminated string s1 either exactly equals a null-terminated string s2, or starts with s2 followed by a ':' or a ']'.\n\nr0: s1\nr1: s2\nreturn: bool",
        None,
    )

    AtoiTag = Symbol(
        [0x20A64],
        [0x2020A64],
        None,
        "AtoiTag",
        "Parses a null-terminated string to a base-10 integer, reading digit characters between '0' and '9' until ':', ']', or the end of the string is encountered.\n\nAny characters that are not digits, ':', or ']' are ignored, and the string is converted as if those characters were removed from the string.\n\nr0: string to convert\nreturn: int",
        None,
    )

    AnalyzeText = Symbol(
        [0x20F20],
        [0x2020F20],
        None,
        "AnalyzeText",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: buffer\nreturn: ?",
        None,
    )

    PreprocessString = Symbol(
        [0x225EC],
        [0x20225EC],
        None,
        "PreprocessString",
        "An enhanced sprintf, which recognizes certain tags and replaces them with appropiate game values.\nThis function can also be used to simply insert values passed within the preprocessor args\n\nThe tags utilized for this function are lowercase, it might produce uppercase tags\nthat only are used when the text is being typewrited into a message box\n\nIrdkwia's notes: MenuCreateOptionString\n\nr0: [output] formatted string\nr1: maximum capacity of the output buffer\nr2: input format string\nr3: preprocessor flags\nstack[0]: pointer to preprocessor args",
        None,
    )

    PreprocessStringFromId = Symbol(
        [0x237B4],
        [0x20237B4],
        None,
        "PreprocessStringFromId",
        "Calls PreprocessString after resolving the given string ID to a string.\n\nr0: [output] formatted string\nr1: maximum capacity of the output buffer\nr2: string ID\nr3: preprocessor flags\nstack[0]: pointer to preprocessor args",
        None,
    )

    StrcmpTagVeneer = Symbol(
        [0x237F4],
        [0x20237F4],
        None,
        "StrcmpTagVeneer",
        "Likely a linker-generated veneer for StrcmpTag.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: s1\nr1: s2\nreturn: bool",
        None,
    )

    AtoiTagVeneer = Symbol(
        [0x23800],
        [0x2023800],
        None,
        "AtoiTagVeneer",
        "Likely a linker-generated veneer for AtoiTag.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: s\nreturn: int",
        None,
    )

    InitPreprocessorArgs = Symbol(
        [0x238B4],
        [0x20238B4],
        None,
        "InitPreprocessorArgs",
        "Initializes a struct preprocess_args.\n\nr0: preprocessor args pointer",
        None,
    )

    SetStringAccuracy = Symbol(
        [0x245C0],
        [0x20245C0],
        None,
        "SetStringAccuracy",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    SetStringPower = Symbol(
        [0x24688],
        [0x2024688],
        None,
        "SetStringPower",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    GetRankString = Symbol(
        [0x24D88],
        [0x2024D88],
        None,
        "GetRankString",
        "Gets the string corresponding to the player's current explorer rank.\n\nr0: [output] Pointer to the buffer where the string will be written\nr1: First 16 bits contain the rank, next 4 are some sort of bitflags\nreturn: r0 if flags are 0, pointer to some static address otherwise",
        None,
    )

    GetCurrentTeamNameString = Symbol(
        [0x24F00],
        [0x2024F00],
        None,
        "GetCurrentTeamNameString",
        "Returns the current team name with a check for special episodes and story progression. If the story\nhas not progressed enough or the special episode is not for Team Charm, '???' will be displayed.\nDuring the Team Charm special episode, it will return 'Team Charm'.\n\nr0: [output] Pointer to the buffer where the string will be written\nr1: 0, 1 or 2???\nreturn: Pointer to the buffer where the string was written (in other words, the same value passed in r0)",
        None,
    )

    GetBagNameString = Symbol(
        [0x250C8],
        [0x20250C8],
        None,
        "GetBagNameString",
        "Returns 'One-Item Inventory' or 'Treasure Bag' depending on the size of the bag.\n\nr0: [output] Pointer to the buffer where the string will be written\nreturn: Pointer to the buffer where the string was written (in other words, the same value passed in r0)",
        None,
    )

    GetDungeonResultString = Symbol(
        [0x252A4],
        [0x20252A4],
        None,
        "GetDungeonResultString",
        "Returns a string containing some information to be used when displaying the dungeon results screen.\n\nThe exact string returned depends on the value of r0:\n0: Name of the move that fainted the leader. Empty string if the leader didn't faint.\n1-3: Seems to always result in an empty string.\n4: Name of the pokémon that fainted the leader, or name of the leader if the leader didn't faint.\n5: Name of the fainted leader. Empty string if the leader didn't faint.\n\nr0: String to return\nreturn: Pointer to resulting string",
        None,
    )

    SetQuestionMarks = Symbol(
        [0x253B0],
        [0x20253B0],
        None,
        "SetQuestionMarks",
        "Fills the buffer with the string '???'\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: buffer",
        None,
    )

    StrcpySimple = Symbol(
        [0x253CC],
        [0x20253CC],
        None,
        "StrcpySimple",
        "A simple implementation of the strcpy(3) C library function.\n\nThis function was probably manually implemented by the developers. See strcpy for what's probably the real libc function.\n\nr0: dest\nr1: src",
        None,
    )

    StrncpySimple = Symbol(
        [0x253E8],
        [0x20253E8],
        None,
        "StrncpySimple",
        "A simple implementation of the strncpy(3) C library function.\n\nThis function was probably manually implemented by the developers. See strncpy for what's probably the real libc function.\n\nr0: dest\nr1: src\nr2: n",
        None,
    )

    StrncpySimpleNoPad = Symbol(
        [0x2543C],
        [0x202543C],
        None,
        "StrncpySimpleNoPad",
        "Similar to StrncpySimple, but does not zero-pad the end of dest beyond the null-terminator.\n\nr0: dest\nr1: src\nr2: n",
        None,
    )

    StrncmpSimple = Symbol(
        [0x25478],
        [0x2025478],
        None,
        "StrncmpSimple",
        "A simple implementation of the strncmp(3) C library function.\n\nThis function was probably manually implemented by the developers. See strncmp for what's probably the real libc function.\n\nr0: s1\nr1: s2\nr2: n\nreturn: comparison value",
        None,
    )

    StrncpySimpleNoPadSafe = Symbol(
        [0x254C0],
        [0x20254C0],
        None,
        "StrncpySimpleNoPadSafe",
        "Like StrncpySimpleNoPad, except there's a useless check on that each character is less than 0x100 (which is impossible for the result of a ldrb instruction).\n\nr0: dest\nr1: src\nr2: n",
        None,
    )

    StrcpyName = Symbol(
        [0x254FC],
        [0x20254FC],
        None,
        "StrcpyName",
        "A special version of strcpy for handling names. Appears to use character 0x7E as some kind of\nformatting character in NA?\n\nr0: dst\nr1: src",
        None,
    )

    StrncpyName = Symbol(
        [0x255E0],
        [0x20255E0],
        None,
        "StrncpyName",
        "A special version of strncpy for handling names. Appears to use character 0x7E as some kind of\nformatting character in NA? Copies at most n characters.\n\nr0: dst\nr1: src\nr2: n",
        None,
    )

    GetStringFromFile = Symbol(
        [0x25A54],
        [0x2025A54],
        None,
        "GetStringFromFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: Buffer\nr1: String ID",
        None,
    )

    LoadStringFile = Symbol(
        [0x25AE4],
        [0x2025AE4],
        None,
        "LoadStringFile",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    AllocateTemp1024ByteBufferFromPool = Symbol(
        [0x25B54],
        [0x2025B54],
        None,
        "AllocateTemp1024ByteBufferFromPool",
        "return: Pointer to byte buffer",
        None,
    )

    GetStringFromFileVeneer = Symbol(
        [0x25B84],
        [0x2025B84],
        None,
        "GetStringFromFileVeneer",
        "Likely a linker-generated veneer for GetStringFromFile.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: Buffer\nr1: String ID",
        None,
    )

    StringFromId = Symbol(
        [0x25B90],
        [0x2025B90],
        None,
        "StringFromId",
        "Gets the string corresponding to a given string ID.\n\nr0: string ID\nreturn: string from the string files with the given string ID",
        None,
    )

    CopyStringFromId = Symbol(
        [0x25BB0],
        [0x2025BB0],
        None,
        "CopyStringFromId",
        "Gets the string corresponding to a given string ID and copies it to the buffer specified in r0.\n\nr0: buffer\nr1: string ID",
        None,
    )

    CopyNStringFromId = Symbol(
        [0x25BD8],
        [0x2025BD8],
        None,
        "CopyNStringFromId",
        "Gets the string corresponding to a given string ID and copies it to the buffer specified in r0.\n\nThis function won't write more than <buffer length> bytes.\n\nr0: buffer\nr1: string ID\nr2: buffer length",
        None,
    )

    LoadTblTalk = Symbol(
        [0x25C08],
        [0x2025C08],
        None,
        "LoadTblTalk",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    GetTalkLine = Symbol(
        [0x25C58],
        [0x2025C58],
        None,
        "GetTalkLine",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: personality_index\nr1: group_id\nr2: restrictions\nreturn: ?",
        None,
    )

    IsAOrBPressed = Symbol(
        [0x261CC],
        [0x20261CC],
        None,
        "IsAOrBPressed",
        "Checks if A or B is currently being held.\n\nreturn: bool",
        None,
    )

    DrawTextInWindow = Symbol(
        [0x264F8],
        [0x20264F8],
        None,
        "DrawTextInWindow",
        "Seems to be responsible for drawing the text in a window.\n\nNeeds a call to UpdateWindow after to actually display the contents.\nUnclear if this is generic for windows or just text boxes.\n\nr0: window_id\nr1: x offset within window\nr2: y offset within window\nr3: text to draw",
        None,
    )

    GetWindow = Symbol(
        [0x278EC],
        [0x20278EC],
        None,
        "GetWindow",
        "Get the window with a given ID from WINDOW_LIST.\n\nr0: window_id\nreturn: window",
        None,
    )

    NewWindowScreenCheck = Symbol(
        [0x2793C],
        [0x202793C],
        None,
        "NewWindowScreenCheck",
        "Calls NewWindow, with a pre-check for any valid existing windows in WINDOW_LIST on each screen.\n\nr0: window_params (see NewWindow)\nr1: ?\nreturn: window_id",
        None,
    )

    NewWindow = Symbol(
        [0x279B4],
        [0x20279B4],
        None,
        "NewWindow",
        "Seems to return the ID of a newly initialized window in the next available slot in WINDOW_LIST, given some starting information.\n\nIf WINDOW_LIST is full, it will be overflowed, with the slot with an ID of 20 being initialized and returned.\n\nr0: window_params pointer to be copied by value into window::hdr in the new window\nr1: ?\nreturn: window_id",
        None,
    )

    SetScreenWindowsColor = Symbol(
        [0x27D5C],
        [0x2027D5C],
        None,
        "SetScreenWindowsColor",
        "Sets the palette of the frames of windows in the specified screen\n\nr0: palette index\nr1: is upper screen",
        None,
    )

    SetBothScreensWindowsColor = Symbol(
        [0x27D74],
        [0x2027D74],
        None,
        "SetBothScreensWindowsColor",
        "Sets the palette of the frames of windows in both screens\n\nr0: palette index",
        None,
    )

    UpdateWindow = Symbol(
        [0x27DE4],
        [0x2027DE4],
        None,
        "UpdateWindow",
        "Seems to cause updated window contents to be displayed.\n   \nGets called for example at the end of a text box window update and seems to 'commit' the update, but in general also gets called with all kinds of window updates. \n\nr0: window_id",
        None,
    )

    ClearWindow = Symbol(
        [0x27E4C],
        [0x2027E4C],
        None,
        "ClearWindow",
        "Clears the window, at least in the case of a text box.\n\nThe low number of XREFs makes it seem like there might be more such functions.\n\nr0: window_id",
        None,
    )

    DeleteWindow = Symbol(
        [0x28488],
        [0x2028488],
        None,
        "DeleteWindow",
        "Seems to uninitialize an active window in WINDOW_LIST with a given ID, freeing the slot for reuse by another window.\n\nr0: window_id",
        None,
    )

    GetWindowRectangle = Symbol(
        [0x28578],
        [0x2028578],
        None,
        "GetWindowRectangle",
        "Get the rectangle defined by a window.\n\nr0: window_id\nr1: [output] rectangle",
        None,
    )

    GetWindowContents = Symbol(
        [0x28630],
        [0x2028630],
        None,
        "GetWindowContents",
        "Gets the contents structure from the window with the given ID.\n\nr0: window_id\nreturn: contents",
        None,
    )

    LoadCursors = Symbol(
        [0x29800],
        [0x2029800],
        None,
        "LoadCursors",
        "Load and initialize the cursor and cursor16 sprites, storing the result in CURSOR_ANIMATION_CONTROL and CURSOR_16_ANIMATION_CONTROL\n\nNo params.",
        None,
    )

    InitWindowTrailer = Symbol(
        [0x29964],
        [0x2029964],
        None,
        "InitWindowTrailer",
        "Seems to initialize a window_trailer within a new window.\n\nr0: window_trailer pointer",
        None,
    )

    Arm9LoadUnkFieldNa0x2029EC8 = Symbol(
        [0x2A1BC],
        [0x202A1BC],
        None,
        "Arm9LoadUnkFieldNa0x2029EC8",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id",
        None,
    )

    Arm9StoreUnkFieldNa0x2029ED8 = Symbol(
        [0x2A1CC],
        [0x202A1CC],
        None,
        "Arm9StoreUnkFieldNa0x2029ED8",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: value",
        None,
    )

    LoadAlert = Symbol(
        [0x2A1DC],
        [0x202A1DC],
        None,
        "LoadAlert",
        "Load and initialize the alert sprite, storing the result in ALERT_ANIMATION_CONTROL\n\nNo params.",
        None,
    )

    PrintClearMark = Symbol(
        [0x2A6D8],
        [0x202A6D8],
        None,
        "PrintClearMark",
        "Prints the specified clear mark on the screen.\n\nClear marks are shown on the save file load screen. They are used to show which plot milestones have already been completed.\n\nr0: Clear mark ID\nr1: X pos (unknown units, usually ranges between 3 and 27)\nr2: Y pos (unknown units, normally 14)\nr3: ?",
        None,
    )

    PrintBadgeMark = Symbol(
        [0x2A728],
        [0x202A728],
        None,
        "PrintBadgeMark",
        "Prints the specified badge mark on the screen.\n\nThe badge mark is shown when opening the menu in the overworld.\n\nr0: Badge ID\nr1: X pos (unknown units, always 3)\nr2: Y pos (unknown units, always 18)\nr3: ? (always 3)",
        None,
    )

    PrintMark = Symbol(
        [0x2A750],
        [0x202A750],
        None,
        "PrintMark",
        "Prints a mark from one of the .w16 files in FONT.\n\nr0: 0 if file is clrmark1.w16, 1 if file is clrmark2.w16, 2 if file is rankmark.w16.\nr1: Mark ID in file\nr2: X pos (unknown units)\nr3: Y pos (unknown units)\nstack[0]: ?",
        None,
    )

    CreateParentMenuFromStringIds = Symbol(
        [0x2A8C0],
        [0x202A8C0],
        None,
        "CreateParentMenuFromStringIds",
        "A wrapper around CreateParentMenuInternal, where the menu items can be defined by string ID instead of as strings.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: simple_menu_id_item struct array, terminated with an item with string_id 0\nreturn: window_id",
        None,
    )

    IsEmptyString = Symbol(
        [0x2A960],
        [0x202A960],
        None,
        "IsEmptyString",
        "Checks if a null-terminated string is empty. A NULL pointer counts as empty.\n\nr0: string\nreturn: whether the string is NULL or empty",
        None,
    )

    CreateParentMenu = Symbol(
        [0x2A984],
        [0x202A984],
        None,
        "CreateParentMenu",
        "A wrapper around CreateParentMenuInternal where ownership of the items array parameter won't be transferred to the menu.\n\nThe menu item array will be copied onto a new array on the heap. This means the argument doesn't need to remain valid after the function returns (e.g., it can be stack-allocated).\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: simple_menu_ptr_item struct array, terminated with an item with an NULL string pointer\nreturn: window_id",
        None,
    )

    CreateParentMenuWrapper = Symbol(
        [0x2AA24],
        [0x202AA24],
        None,
        "CreateParentMenuWrapper",
        "A wrapper around CreateParentMenu that sets field_0x1b0 to 1 if the returned window_id is not -2.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: simple_menu_ptr_item struct array, terminated with an item with an NULL string pointer\nreturn: window_id",
        None,
    )

    CreateParentMenuInternal = Symbol(
        [0x2AA50],
        [0x202AA50],
        None,
        "CreateParentMenuInternal",
        "Creates a window containing a simple textual menu with a list of options that might open submenus when selected. Also see struct simple_menu.\n\nMultiple levels of nesting is possible, i.e., a submenu could itself be a parent menu.\n\nThis is used in various menus that lead to submenus. For example, the top-level ground and dungeon mode menus.\n\nIf window_params is NULL, PARENT_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: heap-allocated simple_menu_items array, the menu takes ownership\nreturn: window_id",
        None,
    )

    ResumeParentMenu = Symbol(
        [0x2AC48],
        [0x202AC48],
        None,
        "ResumeParentMenu",
        "Resumes input for a window created with CreateParentMenuInternal. Used for menus that do not close even after selecting an option.\n\nr0: window_id",
        None,
    )

    SetParentMenuState7 = Symbol(
        [0x2AD9C],
        [0x202AD9C],
        None,
        "SetParentMenuState7",
        "Sets the state of a parent menu to 7.\n\nr0: window_id",
        None,
    )

    CloseParentMenu = Symbol(
        [0x2ADB0],
        [0x202ADB0],
        None,
        "CloseParentMenu",
        "Closes a window created with CreateParentMenu or CreateParentMenuFromStringIds.\n\nr0: window_id",
        None,
    )

    IsParentMenuActive = Symbol(
        [0x2AE34],
        [0x202AE34],
        None,
        "IsParentMenuActive",
        "This is a guess.\n\nChecks if the state of a parent menu is something other than 8 or 9.\n\nr0: window_id\nreturn: bool",
        None,
    )

    CheckParentMenuField0x1A0 = Symbol(
        [0x2AE54],
        [0x202AE54],
        None,
        "CheckParentMenuField0x1A0",
        "Checks if a parent menu's field_0x1a0 is 0.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateParentMenu = Symbol(
        [0x2AEF0],
        [0x202AEF0],
        None,
        "UpdateParentMenu",
        "Window update function for parent menus.\n\nr0: window pointer",
        None,
    )

    CreateSimpleMenuFromStringIds = Symbol(
        [0x2B3E0],
        [0x202B3E0],
        None,
        "CreateSimpleMenuFromStringIds",
        "A wrapper around CreateSimpleMenuInternal, where the menu items can be defined by string ID instead of as strings.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: simple_menu_id_item struct array, terminated with an item with string_id 0\nstack[0]: number of items\nreturn: window_id",
        None,
    )

    CreateSimpleMenu = Symbol(
        [0x2B4A0],
        [0x202B4A0],
        None,
        "CreateSimpleMenu",
        "A wrapper around CreateSimpleMenuInternal where ownership of the simple_menu_items array parameter won't be transferred to the menu.\n\nThe menu item array will be copied onto a new array on the heap. This means the argument doesn't need to remain valid after the function returns (e.g., it can be stack-allocated).\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: simple_menu_items array\nstack[0]: number of items\nreturn: window_id",
        None,
    )

    CreateSimpleMenuInternal = Symbol(
        [0x2B578],
        [0x202B578],
        None,
        "CreateSimpleMenuInternal",
        "Creates a window containing a simple textual menu with a list of options. Also see struct simple_menu.\n\nThis is used in lots of places. For example, some simple Yes/No prompts.\n\nIf window_params is NULL, SIMPLE_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: heap-allocated simple_menu_items array, the menu takes ownership\nstack[0]: number of items\nreturn: window_id",
        None,
    )

    ResumeSimpleMenu = Symbol(
        [0x2B784],
        [0x202B784],
        None,
        "ResumeSimpleMenu",
        "Resumes input for a window created with CreateSimpleMenuInternal. Used for menus that do not close even after selecting an option.\n\nr0: window_id",
        None,
    )

    CloseSimpleMenu = Symbol(
        [0x2B7B8],
        [0x202B7B8],
        None,
        "CloseSimpleMenu",
        "Closes a window created with CreateSimpleMenu or CreateSimpleMenuFromStringIds.\n\nr0: window_id",
        None,
    )

    IsSimpleMenuActive = Symbol(
        [0x2B7E4],
        [0x202B7E4],
        None,
        "IsSimpleMenuActive",
        "Note: unverified, ported from Irdkwia's notes\n\nChecks if the menu state is anything other than 7 or 8.\n\nr0: window_id\nreturn: bool",
        None,
    )

    CheckSimpleMenuField0x1A0 = Symbol(
        [0x2B804],
        [0x202B804],
        None,
        "CheckSimpleMenuField0x1A0",
        "Checks if simple_menu::field_0x1a0 is 0.\n\nr0: window_id\nreturn: bool",
        None,
    )

    GetSimpleMenuField0x1A4 = Symbol(
        [0x2B84C],
        [0x202B84C],
        None,
        "GetSimpleMenuField0x1A4",
        "Gets the value of simple_menu::field_0x1a4.\n\nr0: window_id\nreturn: field_0x1a4",
        None,
    )

    GetSimpleMenuResult = Symbol(
        [0x2B870],
        [0x202B870],
        None,
        "GetSimpleMenuResult",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: window_id\nreturn: ?",
        None,
    )

    UpdateSimpleMenu = Symbol(
        [0x2B8BC],
        [0x202B8BC],
        None,
        "UpdateSimpleMenu",
        "Window update function for simple menus.\n\nr0: window pointer",
        None,
    )

    SetSimpleMenuField0x1AC = Symbol(
        [0x2BD00],
        [0x202BD00],
        None,
        "SetSimpleMenuField0x1AC",
        "Sets simple_menu::field_0x1ac to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    CreateAdvancedMenu = Symbol(
        [0x2BD14],
        [0x202BD14],
        None,
        "CreateAdvancedMenu",
        "Creates a window containing a textual menu with complex layout and functionality (e.g., paging through multiple pages). Also see struct advanced_menu.\n\nThis is used for menus like the IQ skills menu, and the dungeon selection menu from the overworld crossroads. Curiously, it's also used in some non-interactive contexts like the Adventure Log.\n\nIf window_params is NULL, ADVANCED_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nThe entry function is used to get the strings for all currently available options, so when the page is flipped the entry function is used to get the strings for the entries on the other page?\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: entry_function\nstack[0]: total number of options\nstack[1]: number of options per page\nreturn: window_id",
        None,
    )

    ResumeAdvancedMenu = Symbol(
        [0x2BEE4],
        [0x202BEE4],
        None,
        "ResumeAdvancedMenu",
        "Resumes input for a window created with CreateAdvancedMenu. Used for menus that do not close even after selecting an option.\n\nr0: window_id",
        None,
    )

    CloseAdvancedMenu = Symbol(
        [0x2BF38],
        [0x202BF38],
        None,
        "CloseAdvancedMenu",
        "Closes a window created with CreateAdvancedMenu.\n\nr0: window_id",
        None,
    )

    IsAdvancedMenuActive2 = Symbol(
        [0x2BFB0],
        [0x202BFB0],
        None,
        "IsAdvancedMenuActive2",
        "This is a guess, by analogy to IsSimpleMenuActive, which does the same thing. Most of window types also have an analogous function that checks the state value. It's unclear how this relates to the other IsAdvancedMenuActive, or if this guess is completely wrong.\n\nChecks if the state of an advanced menu is something other than 7 or 8.\n\nr0: window_id\nreturn: bool",
        None,
    )

    IsAdvancedMenuActive = Symbol(
        [0x2BFD0],
        [0x202BFD0],
        None,
        "IsAdvancedMenuActive",
        "Note: unverified, ported from Irdkwia's notes\n\nChecks if advanced_menu::field_0x1a0 is 0.\n\nThis seems to resemble the Check*Field* functions of some of the other menu types. It's unclear whether these are the real 'IsActive' functions, or whether the ones that check the state value are. It may be noteworthy that all menu types seem to have a variant of the 'state checking' function, but only some menu types seem to have a variant of the 'check field' function.\n\nr0: window_id\nreturn: bool",
        None,
    )

    GetAdvancedMenuCurrentOption = Symbol(
        [0x2BFF0],
        [0x202BFF0],
        None,
        "GetAdvancedMenuCurrentOption",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: window_id\nreturn: ?",
        None,
    )

    GetAdvancedMenuResult = Symbol(
        [0x2C004],
        [0x202C004],
        None,
        "GetAdvancedMenuResult",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: window_id\nreturn: ?",
        None,
    )

    UpdateAdvancedMenu = Symbol(
        [0x2C058],
        [0x202C058],
        None,
        "UpdateAdvancedMenu",
        "Window update function for advanced menus.\n\nr0: window pointer",
        None,
    )

    CreateCollectionMenu = Symbol(
        [0x2C69C],
        [0x202C69C],
        None,
        "CreateCollectionMenu",
        "Creates a window containing a menu for manipulating a collection of objects, with complex layout and functionality (e.g., paging). Also see struct collection_menu.\n\nCollection menus seem similar to advanced menus, but are used for certain menus involving item management (Kangaskhan Storage, Kecleon shop, Croagunk Swap Shop), missions (job selection, bulletin board), and possibly other things.\n\nIf window_params is NULL, COLLECTION_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: some function pointer?\nstack[0]: ?\nstack[1]: total number of options\nstack[2]: number of options per page\nreturn: window_id",
        None,
    )

    SetCollectionMenuField0x1BC = Symbol(
        [0x2C8D4],
        [0x202C8D4],
        None,
        "SetCollectionMenuField0x1BC",
        "Sets collection_menu::field_0x1bc to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    SetCollectionMenuWidth = Symbol(
        [0x2C8E8],
        [0x202C8E8],
        None,
        "SetCollectionMenuWidth",
        "Sets collection_menu::width to a new value, clamped to be no greater than (window_params::width * 8 - 1) for the window.\n\nr0: window_id\nr1: width",
        None,
    )

    CloseCollectionMenu = Symbol(
        [0x2CA00],
        [0x202CA00],
        None,
        "CloseCollectionMenu",
        "Closes a window created with CreateCollectionMenu.\n\nr0: window_id",
        None,
    )

    IsCollectionMenuActive = Symbol(
        [0x2CA1C],
        [0x202CA1C],
        None,
        "IsCollectionMenuActive",
        "This is a guess.\n\nChecks if the state of a collection menu is something other than 6 or 7.\n\nr0: window_id\nreturn: bool",
        None,
    )

    SetCollectionMenuField0x1C8 = Symbol(
        [0x2CA88],
        [0x202CA88],
        None,
        "SetCollectionMenuField0x1C8",
        "Sets collection_menu::field_0x1c8 to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    SetCollectionMenuField0x1A0 = Symbol(
        [0x2CA9C],
        [0x202CA9C],
        None,
        "SetCollectionMenuField0x1A0",
        "Sets collection_menu::field_0x1a0 to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    SetCollectionMenuField0x1A4 = Symbol(
        [0x2CAB0],
        [0x202CAB0],
        None,
        "SetCollectionMenuField0x1A4",
        "Sets collection_menu::field_0x1a4 to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    SetCollectionMenuVoidFn = Symbol(
        [0x2CAC4],
        [0x202CAC4],
        None,
        "SetCollectionMenuVoidFn",
        "Sets collection_menu::field_0x1a8 to the given function pointer.\n\nr0: window_id\nr1: some function pointer?",
        None,
    )

    UpdateCollectionMenu = Symbol(
        [0x2CAFC],
        [0x202CAFC],
        None,
        "UpdateCollectionMenu",
        "Window update function for collection menus.\n\nr0: window pointer",
        None,
    )

    SetCollectionMenuField0x1B2 = Symbol(
        [0x2D3CC],
        [0x202D3CC],
        None,
        "SetCollectionMenuField0x1B2",
        "Sets collection_menu::field_0x1b2 to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    IsCollectionMenuState3 = Symbol(
        [0x2D408],
        [0x202D408],
        None,
        "IsCollectionMenuState3",
        "Checks if a collection menu has a state value of 3.\n\nr0: window_id\nreturn: bool",
        None,
    )

    CreateOptionsMenu = Symbol(
        [0x2D4E4],
        [0x202D4E4],
        None,
        "CreateOptionsMenu",
        "Creates a window containing a menu controlling game options. Also see struct options_menu.\n\nThis is used for the options and window options menus, among other things.\n\nIf window_params is NULL, OPTIONS_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: options_menu_id_item struct array, terminated with an item with msg_id 0\nstack[0]: number of items\nstack[1]: ?\nreturn: window_id",
        None,
    )

    CloseOptionsMenu = Symbol(
        [0x2D824],
        [0x202D824],
        None,
        "CloseOptionsMenu",
        "Closes a window created with CreateOptionsMenu.\n\nr0: window_id",
        None,
    )

    IsOptionsMenuActive = Symbol(
        [0x2D850],
        [0x202D850],
        None,
        "IsOptionsMenuActive",
        "This is a guess.\n\nChecks if the state of an options menu is something other than 6 or 7.\n\nr0: window_id\nreturn: bool",
        None,
    )

    CheckOptionsMenuField0x1A4 = Symbol(
        [0x2D870],
        [0x202D870],
        None,
        "CheckOptionsMenuField0x1A4",
        "Checks if options_menu::field_0x1a4 is 0.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateOptionsMenu = Symbol(
        [0x2D90C],
        [0x202D90C],
        None,
        "UpdateOptionsMenu",
        "Window update function for options menus.\n\nr0: window pointer",
        None,
    )

    CreateDebugMenu = Symbol(
        [0x2DF44],
        [0x202DF44],
        None,
        "CreateDebugMenu",
        "Creates a window containing the debug menu (probably). Also see struct debug_menu.\n\nThis is an educated guess, since this function references string IDs of debug menu strings.\n\nSee enum debug_flag and enum debug_log_flag.\n\nIf window_params is NULL, DEBUG_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: array of menu item string IDs\nstack[0]: number of menu items\nstack[1]: ?\nreturn: window_id",
        None,
    )

    CloseDebugMenu = Symbol(
        [0x2E1EC],
        [0x202E1EC],
        None,
        "CloseDebugMenu",
        "Closes a window created with CreateDebugMenu.\n\nr0: window_id",
        None,
    )

    IsDebugMenuActive = Symbol(
        [0x2E218],
        [0x202E218],
        None,
        "IsDebugMenuActive",
        "This is a guess.\n\nChecks if the state of a debug menu is something other than 6 or 7.\n\nr0: window_id\nreturn: bool",
        None,
    )

    CheckDebugMenuField0x1A4 = Symbol(
        [0x2E238],
        [0x202E238],
        None,
        "CheckDebugMenuField0x1A4",
        "Checks if debug_menu::field_0x1a4 is 0.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateDebugMenu = Symbol(
        [0x2E28C],
        [0x202E28C],
        None,
        "UpdateDebugMenu",
        "Window update function for debug menus.\n\nr0: window pointer",
        None,
    )

    CreateScrollBoxSingle = Symbol(
        [0x2E6C0],
        [0x202E6C0],
        None,
        "CreateScrollBoxSingle",
        "Creates window containing text that pages vertically on overflow, with a single pair of strings. Also see struct scroll_box.\n\nThis includes things like descriptions for items and moves.\n\nIf window_params is NULL, SCROLL_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: string ID 1\nstack[0]: preprocessor args 1\nstack[1]: string ID 2\nstack[2]: preprocessor args 2\nreturn: window_id",
        None,
    )

    CreateScrollBoxMulti = Symbol(
        [0x2E80C],
        [0x202E80C],
        None,
        "CreateScrollBoxMulti",
        "Creates window containing text that pages vertically on overflow, with an array of string pairs. Also see struct scroll_box.\n\nThis includes things like descriptions for items and moves.\n\nIf window_params is NULL, SCROLL_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: number of string pairs\nstack[0]: string ID 1 array\nstack[1]: preprocessor args 1 array\nstack[2]: string ID 2 array\nstack[3]: preprocessor args 2 array\nreturn: window_id",
        None,
    )

    SetScrollBoxState7 = Symbol(
        [0x2E9A4],
        [0x202E9A4],
        None,
        "SetScrollBoxState7",
        "Sets the state of a scroll box to 7.\n\nr0: window_id",
        None,
    )

    CloseScrollBox = Symbol(
        [0x2E9BC],
        [0x202E9BC],
        None,
        "CloseScrollBox",
        "Closes a window created with CreateScrollBoxSingle or CreateScrollBoxMulti.\n\nr0: window_id",
        None,
    )

    IsScrollBoxActive = Symbol(
        [0x2E9D8],
        [0x202E9D8],
        None,
        "IsScrollBoxActive",
        "This is a guess.\n\nChecks if the state of a scroll box is not 8.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateScrollBox = Symbol(
        [0x2E9FC],
        [0x202E9FC],
        None,
        "UpdateScrollBox",
        "Window update function for scroll boxes.\n\nr0: window pointer",
        None,
    )

    CreateDialogueBox = Symbol(
        [0x2F3A4],
        [0x202F3A4],
        None,
        "CreateDialogueBox",
        "Creates a window containing text that is gradually revealed via scrolling, and pages on overflow. Also see struct dialogue_box.\n\nThis is primarily used for character dialogue, hence the name. However, it can also be used for other types of messages. The defining feature of this window type is the scrolling/paging behavior.\n\nIf window_params is NULL, DIALOGUE_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nr0: window_params\nreturn: window_id",
        None,
    )

    CloseDialogueBox = Symbol(
        [0x2F43C],
        [0x202F43C],
        None,
        "CloseDialogueBox",
        "Closes a window created with CreateDialogueBox.\n\nr0: window_id",
        None,
    )

    IsDialogueBoxActive = Symbol(
        [0x2F474],
        [0x202F474],
        None,
        "IsDialogueBoxActive",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: window_id\nreturn: bool",
        None,
    )

    ShowStringIdInDialogueBox = Symbol(
        [0x2F4A8],
        [0x202F4A8],
        None,
        "ShowStringIdInDialogueBox",
        "Preprocesses the corresponding string_id message in the text file and puts it into the dialogue box.\n\nr0: window_id\nr1: preprocessor flags (see PreprocessString)\nr2: string_id\nr3: pointer to preprocessor args (see PreprocessString)",
        None,
    )

    ShowStringInDialogueBox = Symbol(
        [0x2F530],
        [0x202F530],
        None,
        "ShowStringInDialogueBox",
        "Preprocesses the passed string and puts it into the dialogue box.\n\nr0: window_id\nr1: preprocessor flags (see PreprocessString)\nr2: string\nr3: pointer to preprocessor args (see PreprocessString)",
        None,
    )

    ShowDialogueBox = Symbol(
        [0x2F698],
        [0x202F698],
        None,
        "ShowDialogueBox",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: window_id",
        None,
    )

    ReadStringFromDialogueBox = Symbol(
        [0x2F740],
        [0x202F740],
        None,
        "ReadStringFromDialogueBox",
        "Copies data from the dialogue box's string buffer into an output buffer.\n\nr0: window_id\nr1: [output] string buffer\nr2: number of bytes to read",
        None,
    )

    UpdateDialogueBox = Symbol(
        [0x2F77C],
        [0x202F77C],
        None,
        "UpdateDialogueBox",
        "Window update function for dialogue boxes.\n\nr0: window pointer",
        None,
    )

    CreatePortraitBox = Symbol(
        [0x2F8A0],
        [0x202F8A0],
        None,
        "CreatePortraitBox",
        "Creates a window containing a character portrait. Also see struct portrait_box.\n\nThis is commonly paired with a dialogue box, but can also be used standalone.\n\nIf framed, the window box type will be 0xFC, otherwise it will be 0xF9.\n\nThe new window will always default to PORTRAIT_BOX_DEFAULT_WINDOW_PARAMS.\n\nr0: screen index\nr1: palette_idx\nr2: framed\nreturn: window_id",
        None,
    )

    ClosePortraitBox = Symbol(
        [0x2F944],
        [0x202F944],
        None,
        "ClosePortraitBox",
        "Closes a window created with CreatePortraitBox.\n\nr0: window_id",
        None,
    )

    PortraitBoxNeedsUpdate = Symbol(
        [0x2F960],
        [0x202F960],
        None,
        "PortraitBoxNeedsUpdate",
        "Checks if a portrait box has a state of PORTRAIT_BOX_TRY_UPDATE or PORTRAIT_BOX_UPDATE.\n\nr0: window_id\nreturn: bool",
        None,
    )

    ShowPortraitInPortraitBox = Symbol(
        [0x2F984],
        [0x202F984],
        None,
        "ShowPortraitInPortraitBox",
        "Stages a portrait to be rendered in a portrait box at next update (sets portrait_box::buffer_state).\n\nIf portrait is NULL, the default portrait will be shown (see InitPortraitParams).\n\nr0: window_id\nr1: portrait params pointer",
        None,
    )

    HidePortraitBox = Symbol(
        [0x2F9D0],
        [0x202F9D0],
        None,
        "HidePortraitBox",
        "Flags a portrait box to be hidden at next update (sets portrait_box::hide) if it's not already in the PORTRAIT_BOX_HIDDEN state, and resets its buffer state.\n\nr0: window_id",
        None,
    )

    UpdatePortraitBox = Symbol(
        [0x2FA00],
        [0x202FA00],
        None,
        "UpdatePortraitBox",
        "Window update function for portrait boxes.\n\nr0: window pointer",
        None,
    )

    CreateTextBox = Symbol(
        [0x2FBB8],
        [0x202FBB8],
        None,
        "CreateTextBox",
        "Calls CreateTextBoxInternal, sets the callback without an argument, and returns the window_id.\n\nr0: window_params\nr1: text box callback function\nreturn: window_id",
        None,
    )

    CreateTextBoxWithArg = Symbol(
        [0x2FBD0],
        [0x202FBD0],
        None,
        "CreateTextBoxWithArg",
        "Calls CreateTextBoxInternal, sets the callback with an argument, and returns the window_id.\n\nr0: window_params\nr1: text box callback with arg function\nr2: callback argument\nreturn: window_id",
        None,
    )

    CloseTextBox = Symbol(
        [0x2FBF0],
        [0x202FBF0],
        None,
        "CloseTextBox",
        "Closes a window created with CreateTextBox or CreateTextBoxWithArg.\n\nr0: window_id",
        None,
    )

    CloseTextBox2 = Symbol(
        [0x2FC0C],
        [0x202FC0C],
        None,
        "CloseTextBox2",
        "Seems to do some things with the text box, before doing the same things that CloseTextBox does.\n\nr0: window_id",
        None,
    )

    CreateTextBoxInternal = Symbol(
        [0x2FCD0],
        [0x202FCD0],
        None,
        "CreateTextBoxInternal",
        "Creates a window containing simple text, without much advanced functionality. Also see struct text_box.\n\nIf window_params is NULL, TEXT_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nr0: window_params\nreturn: text_box pointer",
        None,
    )

    UpdateTextBox = Symbol(
        [0x2FD50],
        [0x202FD50],
        None,
        "UpdateTextBox",
        "Window update function for text boxes.\n\nr0: window pointer",
        None,
    )

    IsTextBoxActive = Symbol(
        [0x2FE90],
        [0x202FE90],
        None,
        "IsTextBoxActive",
        "This is a guess.\n\nChecks if the state of a text box is not 7.\n\nr0: window_id\nreturn: bool",
        None,
    )

    CreateAreaNameBox = Symbol(
        [0x2FEB0],
        [0x202FEB0],
        None,
        "CreateAreaNameBox",
        "Creates a window containing the area name, as resolved from the '[area:0]' tag.\n\nThis only seems to be used for the 'area name' text box in the top-level menu in ground mode (not dungeon mode), and the analogous text box on the world map transition screen before entering a dungeon.\n\nIf window_params is NULL, AREA_NAME_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width is 0, it will be computed based on the contained text. If window_params::height is 0, it will default to 2.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: ID (for preprocessor_args)\nreturn: window_id",
        None,
    )

    SetAreaNameBoxState3 = Symbol(
        [0x30030],
        [0x2030030],
        None,
        "SetAreaNameBoxState3",
        "Sets the state of an area name box to 3.\n\nr0: window_id",
        None,
    )

    CloseAreaNameBox = Symbol(
        [0x30044],
        [0x2030044],
        None,
        "CloseAreaNameBox",
        "Closes a window created with CreateAreaNameBox.\n\nr0: window_id",
        None,
    )

    IsAreaNameBoxActive = Symbol(
        [0x30060],
        [0x2030060],
        None,
        "IsAreaNameBoxActive",
        "This is a guess.\n\nChecks if the state of an area name box is something other than 2 or 4.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateAreaNameBox = Symbol(
        [0x30080],
        [0x2030080],
        None,
        "UpdateAreaNameBox",
        "Window update function for area name boxes.\n\nr0: window pointer",
        None,
    )

    CreateControlsChart = Symbol(
        [0x30120],
        [0x2030120],
        None,
        "CreateControlsChart",
        "Creates a window containing a chart of player controls for some context. Also see struct controls_chart.\n\nThis is usually used for static top-screen control reference charts.\n\nIf window_params is NULL, CONTROLS_CHART_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: string ID\nreturn: window_id",
        None,
    )

    CloseControlsChart = Symbol(
        [0x301C8],
        [0x20301C8],
        None,
        "CloseControlsChart",
        "Closes a window created with CreateControlsChart.\n\nr0: window_id",
        None,
    )

    IsControlsChartActive = Symbol(
        [0x301E4],
        [0x20301E4],
        None,
        "IsControlsChartActive",
        "This is a guess.\n\nChecks if the state of a controls chart is something other than 2 or 4.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateControlsChart = Symbol(
        [0x30204],
        [0x2030204],
        None,
        "UpdateControlsChart",
        "Window update function for controls charts.\n\nr0: window pointer",
        None,
    )

    CreateAlertBox = Symbol(
        [0x302A4],
        [0x20302A4],
        None,
        "CreateAlertBox",
        "Creates a window containing text that will disappear after a certain amount of time. Also see struct alert_box.\n\nThis is only used in dungeon mode, for the 'popup alert' messages about things happening in the dungeon (which will also be accessible in the message logs).\n\nIf window_params is NULL, ALERT_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nr0: window_params\nreturn: window_id",
        None,
    )

    CloseAlertBox = Symbol(
        [0x30338],
        [0x2030338],
        None,
        "CloseAlertBox",
        "Closes a window created with CreateAlertBox.\n\nr0: window_id",
        None,
    )

    IsAlertBoxActive = Symbol(
        [0x304E8],
        [0x20304E8],
        None,
        "IsAlertBoxActive",
        "This is a guess.\n\nChecks if the state of an alert box is 3.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateAlertBox = Symbol(
        [0x30568],
        [0x2030568],
        None,
        "UpdateAlertBox",
        "Window update function for alert boxes.\n\nr0: window pointer",
        None,
    )

    CreateAdvancedTextBox = Symbol(
        [0x308A8],
        [0x20308A8],
        None,
        "CreateAdvancedTextBox",
        "Calls CreateAdvancedTextBoxInternal with all the selectable items on one page (n_items_per_page = n_items), sets the callback without an argument, and returns the window_id.\n\nIf window_params is NULL, ADVANCED_TEXT_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: text box callback function\nstack[0]: number of selectable items\nreturn: window_id",
        None,
    )

    CreateAdvancedTextBoxWithArg = Symbol(
        [0x308D8],
        [0x20308D8],
        None,
        "CreateAdvancedTextBoxWithArg",
        "Calls CreateAdvancedTextBoxInternal with all the selectable items on one page (n_items_per_page = n_items), sets the callback with an argument, and returns the window_id.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: text box callback with arg function\nstack[0]: callback argument\nstack[1]: number of selectable items\nreturn: window_id",
        None,
    )

    CreateAdvancedTextBoxInternal = Symbol(
        [0x30910],
        [0x2030910],
        None,
        "CreateAdvancedTextBoxInternal",
        "Creates a window containing text formatted in complex, potentially sectioned layouts. Also see struct advanced_text_box.\n\nThis is usually used to display text with 'pretty' formatting in certain contexts, such as the message log, the move selection menu, team member summaries, etc.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: total number of selectable items\nstack[0]: number of selectable items per page\nreturn: advanced_text_box pointer",
        None,
    )

    SetAdvancedTextBoxPartialMenu = Symbol(
        [0x30A70],
        [0x2030A70],
        None,
        "SetAdvancedTextBoxPartialMenu",
        "Seems to set advanced_text_box::flags::partial_menu to the given value?\n\nr0: window_id\nr1: partial_menu flag value",
        None,
    )

    SetAdvancedTextBoxField0x1C4 = Symbol(
        [0x30A98],
        [0x2030A98],
        None,
        "SetAdvancedTextBoxField0x1C4",
        "Sets the value of advanced_text_box::field_0x1c4 to the given value.\n\nr0: window_id\nr1: value",
        None,
    )

    SetAdvancedTextBoxField0x1C2 = Symbol(
        [0x30B30],
        [0x2030B30],
        None,
        "SetAdvancedTextBoxField0x1C2",
        "Sets advanced_text_box::field_0x1c2 to 1.\n\nr0: window_id",
        None,
    )

    CloseAdvancedTextBox2 = Symbol(
        [0x30B44],
        [0x2030B44],
        None,
        "CloseAdvancedTextBox2",
        "Seems to do some things with the text box, before doing the same things that CloseAdvancedTextBox does.\n\nr0: window_id",
        None,
    )

    SetAdvancedTextBoxState5 = Symbol(
        [0x30B80],
        [0x2030B80],
        None,
        "SetAdvancedTextBoxState5",
        "Sets the state of an advanced text box to 5.\n\nr0: window_id",
        None,
    )

    CloseAdvancedTextBox = Symbol(
        [0x30B94],
        [0x2030B94],
        None,
        "CloseAdvancedTextBox",
        "Closes a window created with CreateAdvancedTextBox or CreateAdvancedTextBoxWithArg.\n\nr0: window_id",
        None,
    )

    IsAdvancedTextBoxActive = Symbol(
        [0x30BB8],
        [0x2030BB8],
        None,
        "IsAdvancedTextBoxActive",
        "This is a guess.\n\nChecks if the state of an advanced text box is something other than 6 or 7.\n\nr0: window_id\nreturn: bool",
        None,
    )

    GetAdvancedTextBoxFlags2 = Symbol(
        [0x30D34],
        [0x2030D34],
        None,
        "GetAdvancedTextBoxFlags2",
        "Gets the value of advanced_text_box::flags2.\n\nr0: window_id\nreturn: flags2",
        None,
    )

    SetUnkAdvancedTextBoxFn = Symbol(
        [0x30DB4],
        [0x2030DB4],
        None,
        "SetUnkAdvancedTextBoxFn",
        "Sets the value of advanced_text_box::field_0x1b4 to the given function pointer.\n\nr0: window_id\nr1: some function pointer?",
        None,
    )

    SetUnkAdvancedTextBoxWindowFn = Symbol(
        [0x30DC8],
        [0x2030DC8],
        None,
        "SetUnkAdvancedTextBoxWindowFn",
        "Sets the value of advanced_text_box::field_0x1b8 to the given function pointer.\n\nr0: window_id\nr1: some function pointer?",
        None,
    )

    UpdateAdvancedTextBox = Symbol(
        [0x30DDC],
        [0x2030DDC],
        None,
        "UpdateAdvancedTextBox",
        "Window update function for advanced text boxes.\n\nr0: window pointer",
        None,
    )

    PlayAdvancedTextBoxInputSound = Symbol(
        [0x3121C],
        [0x203121C],
        None,
        "PlayAdvancedTextBoxInputSound",
        "Calls PlayWindowInputSound for an advanced text box.\n\nr0: window_id\nr1: index for PlayWindowInputSound",
        None,
    )

    CreateTeamSelectionMenu = Symbol(
        [0x31238],
        [0x2031238],
        None,
        "CreateTeamSelectionMenu",
        "Creates a window containing a menu for selecting a single team member. Also see struct team_selection_menu.\n\nIf window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nThis appears to be used for various shop (and shop-like) interfaces when a single team member needs to be selected. For example, the Electivire Link Shop, the Chimecho Assembly, the Croagunk Swap Shop, and Luminous Spring. It's unknown if this is used for other contexts besides team member selection.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: function to get the menu item text for a given team member\nstack[0]: total number of options\nstack[1]: number of options per page\nreturn: window_id",
        None,
    )

    CloseTeamSelectionMenu = Symbol(
        [0x3148C],
        [0x203148C],
        None,
        "CloseTeamSelectionMenu",
        "Closes a window created with CreateTeamSelectionMenu.\n\nr0: window_id",
        None,
    )

    IsTeamSelectionMenuActive = Symbol(
        [0x314A8],
        [0x20314A8],
        None,
        "IsTeamSelectionMenuActive",
        "This is a guess.\n\nChecks if the state of a team selection menu is something other than 6 or 7.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateTeamSelectionMenu = Symbol(
        [0x31530],
        [0x2031530],
        None,
        "UpdateTeamSelectionMenu",
        "Window update function for team selection menus.\n\nr0: window pointer",
        None,
    )

    IsTeamSelectionMenuState3 = Symbol(
        [0x31BA4],
        [0x2031BA4],
        None,
        "IsTeamSelectionMenuState3",
        "Checks if the state of a team selection menu is 3.\n\nr0: window_id",
        None,
    )

    CalcMenuHeightDiv8 = Symbol(
        [0x31D98, 0x32CD8],
        [0x2031D98, 0x2032CD8],
        None,
        "CalcMenuHeightDiv8",
        "Calculates the window height (divided by 8, as in struct window_params) of a menu, given its items and input flags.\n\nFor certain input flags, the number of options per page will be clamped to the total number of options if the per-page count exceeds the total.\n\nr0: window_flags\nr1: window_extra_info pointer\nr2: total number of options\nr3: number of options per page\nreturn: height / 8",
        None,
    )

    InitWindowInput = Symbol(
        [0x31DEC],
        [0x2031DEC],
        None,
        "InitWindowInput",
        "This seems to be called when creating most interactive windows that respond to user input, like menus (but also other interactive windows like scroll boxes and advanced text boxes). It presumably sets up the state necessary for detecting and responding to user input.\n\nr0: window_input_ctx pointer\nr1: window_flags\nr2: window_extra_info pointer\nr3: window rectangle\nstack[0]: total number of selectable items\nstack[1]: number of selectable items per page",
        None,
    )

    IsMenuOptionActive = Symbol(
        [0x32768],
        [0x2032768],
        None,
        "IsMenuOptionActive",
        "Called whenever a menu option is selected. Returns whether the option is active or not.\n\nr0: ?\nreturn: True if the menu option is enabled, false otherwise.",
        None,
    )

    PlayWindowInputSound = Symbol(
        [0x32C54],
        [0x2032C54],
        None,
        "PlayWindowInputSound",
        "Plays a 'beep' sound when giving an input to an interactive window (typically, when choosing a menu option).\n\nr0: window_input_ctx pointer\nr1: Some kind of index used to determine the ID of the sound to play",
        None,
    )

    InitInventoryMenuInput = Symbol(
        [0x32D2C],
        [0x2032D2C],
        None,
        "InitInventoryMenuInput",
        "Almost exactly the same as InitWindowInput, except two differences in field assignments on the window input context, one of which uses an extra parameter.\n\nr0: inventory_menu_input_ctx pointer\nr1: window_flags\nr2: window_extra_info pointer\nr3: window rectangle\nstack[0]: total number of selectable items\nstack[1]: number of selectable items per page\nstack[2]: ?",
        None,
    )

    ShowKeyboard = Symbol(
        [0x36AE4],
        [0x2036AE4],
        None,
        "ShowKeyboard",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: string ID\nr1: buffer1\nr2: ???\nr3: buffer2\nreturn: ?",
        None,
    )

    GetKeyboardStatus = Symbol(
        [0x36FD0],
        [0x2036FD0],
        None,
        "GetKeyboardStatus",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: ?",
        None,
    )

    GetKeyboardStringResult = Symbol(
        [0x37858],
        [0x2037858],
        None,
        "GetKeyboardStringResult",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: ?",
        None,
    )

    TeamSelectionMenuGetItem = Symbol(
        [0x3AA58],
        [0x203AA58],
        None,
        "TeamSelectionMenuGetItem",
        "Gets the menu item text (member name) for a given team member for a team selection menu.\n\nr0: buffer\nr1: team member index\nreturn: menu item text (points into buffer)",
        None,
    )

    PrintMoveOptionMenu = Symbol(
        [0x405BC],
        [0x20405BC],
        None,
        "PrintMoveOptionMenu",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    PrintIqSkillsMenu = Symbol(
        [0x41D3C],
        [0x2041D3C],
        None,
        "PrintIqSkillsMenu",
        "Draws the IQ skills menu for a certain monster.\n\nr0: Monster species\nr1: Pointer to bitarray where the enabled skills will be written when enabling or disabling them in the menu\nr2: Monster IQ\nr3: True if the monster is blinded",
        None,
    )

    GetNotifyNote = Symbol(
        [0x487BC],
        [0x20487BC],
        None,
        "GetNotifyNote",
        "Returns the current value of NOTIFY_NOTE.\n\nreturn: bool",
        None,
    )

    SetNotifyNote = Symbol(
        [0x487CC],
        [0x20487CC],
        None,
        "SetNotifyNote",
        "Sets NOTIFY_NOTE to the given value.\n\nr0: bool",
        None,
    )

    InitSpecialEpisodeHero = Symbol(
        [0x48804],
        [0x2048804],
        None,
        "InitSpecialEpisodeHero",
        "Removes/invalidates the special episode member slots, zero inits the special episode treasure bag, zero inits the\nspecial episode Kecleon shops, zero inits VAR_WORLD_MAP_MARK_LIST_SPECIAL, sets VAR_SPECIAL_EPISODE_OPEN_OLD for\nthe corresponding special episode, and initializes the hero for the special episode.\n\nNo params.",
        None,
    )

    EventFlagBackupVeneer = Symbol(
        [0x48A74],
        [0x2048A74],
        None,
        "EventFlagBackupVeneer",
        "Likely a linker-generated veneer for EventFlagBackup.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nNo params.",
        None,
    )

    InitMainTeamAfterQuiz = Symbol(
        [0x48AE0],
        [0x2048AE0],
        None,
        "InitMainTeamAfterQuiz",
        "Implements SPECIAL_PROC_INIT_MAIN_TEAM_AFTER_QUIZ (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    InitSpecialEpisodePartners = Symbol(
        [0x48D28],
        [0x2048D28],
        None,
        "InitSpecialEpisodePartners",
        "Initializes the partners for the current special episode and sets the team to be the hero and partner only.\nImplements SPECIAL_PROC_0x3 (see ScriptSpecialProcessCall). \n\nNo params.",
        None,
    )

    InitSpecialEpisodeExtraPartner = Symbol(
        [0x48DA0],
        [0x2048DA0],
        None,
        "InitSpecialEpisodeExtraPartner",
        "Initializes any partners/special episode members that join the team later in a special episode. This is used to add\nCelebi in the In the Future of Darkness special episode.\nImplements SPECIAL_PROC_0x4 (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    ReadStringSave = Symbol(
        [0x48ED0],
        [0x2048ED0],
        None,
        "ReadStringSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: buffer",
        None,
    )

    CheckStringSave = Symbol(
        [0x48EEC],
        [0x2048EEC],
        None,
        "CheckStringSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: buffer\nreturn: bool",
        None,
    )

    WriteSaveFile = Symbol(
        [0x49190],
        [0x2049190],
        None,
        "WriteSaveFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: save_info\nr1: buffer\nr2: size\nreturn: status code",
        None,
    )

    ReadSaveFile = Symbol(
        [0x491EC],
        [0x20491EC],
        None,
        "ReadSaveFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: save_info\nr1: buffer\nr2: size\nreturn: status code",
        None,
    )

    CalcChecksum = Symbol(
        [0x49240],
        [0x2049240],
        None,
        "CalcChecksum",
        "Calculates the checksum of the save file and stores it at the start of the data.\n\nr0: Pointer to a buffer containing the save data\nr1: Size in bytes",
        None,
    )

    CheckChecksumInvalid = Symbol(
        [0x49268],
        [0x2049268],
        None,
        "CheckChecksumInvalid",
        "Calculates the checksum of the save file and compares it with the one stored in it.\n\nr0: Pointer to a buffer containing the save data\nr1: Size in bytes\nreturn: True if the calculated and stored checksums don't match, false if they do.",
        None,
    )

    NoteSaveBase = Symbol(
        [0x492A0],
        [0x20492A0],
        None,
        "NoteSaveBase",
        "Probably related to saving or quicksaving?\n\nThis function prints the debug message 'NoteSave Base %d %d' with some values. It's also the only place where GetRngSeed is called.\n\nr0: Irdkwia's notes: state ID\nothers: ?\nreturn: status code",
        None,
    )

    WriteQuickSaveInfo = Symbol(
        [0x49564],
        [0x2049564],
        None,
        "WriteQuickSaveInfo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: buffer\nr1: size",
        None,
    )

    ReadSaveHeader = Symbol(
        [0x49588],
        [0x2049588],
        None,
        "ReadSaveHeader",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    NoteLoadBase = Symbol(
        [0x496A8],
        [0x20496A8],
        None,
        "NoteLoadBase",
        "Probably related to loading a save file or quicksave?\n\nThis function prints the debug message 'NoteLoad Base %d' with some value. It's also the only place where SetRngSeed is called.\n\nreturn: status code",
        None,
    )

    ReadQuickSaveInfo = Symbol(
        [0x49960],
        [0x2049960],
        None,
        "ReadQuickSaveInfo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: buffer\nr1: size\nreturn: status code",
        None,
    )

    GetGameMode = Symbol(
        [0x4B2F8],
        [0x204B2F8],
        None,
        "GetGameMode",
        "Gets the value of GAME_MODE.\n\nreturn: game mode",
        None,
    )

    InitScriptVariableValues = Symbol(
        [0x4B384],
        [0x204B384],
        None,
        "InitScriptVariableValues",
        "Initialize the script variable values table (SCRIPT_VARS_VALUES).\n\nThe whole table is first zero-initialized. Then, all script variable values are first initialized to their defaults, after which some of them are overwritten with other hard-coded values.\n\nNo params.",
        None,
    )

    InitEventFlagScriptVars = Symbol(
        [0x4B63C],
        [0x204B63C],
        None,
        "InitEventFlagScriptVars",
        "Initializes an assortment of event flag script variables (see the code for an exhaustive list).\n\nNo params.",
        None,
    )

    ZinitScriptVariable = Symbol(
        [0x4B76C],
        [0x204B76C],
        None,
        "ZinitScriptVariable",
        "Zero-initialize the values of the given script variable.\n\nr0: pointer to the local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID",
        None,
    )

    LoadScriptVariableRaw = Symbol(
        [0x4B7D4],
        [0x204B7D4],
        None,
        "LoadScriptVariableRaw",
        "Loads a script variable descriptor for a given ID.\n\nr0: [output] script variable descriptor pointer\nr1: pointer to the local variable table (doesn't need to be valid; just controls the output value pointer)\nr2: script variable ID",
        None,
    )

    LoadScriptVariableValue = Symbol(
        [0x4B824],
        [0x204B824],
        None,
        "LoadScriptVariableValue",
        "Loads the value of a script variable.\n\nr0: pointer to the local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID\nreturn: value",
        None,
    )

    LoadScriptVariableValueAtIndex = Symbol(
        [0x4B9B0],
        [0x204B9B0],
        None,
        "LoadScriptVariableValueAtIndex",
        "Loads the value of a script variable at some index (for script variables that are arrays).\n\nr0: pointer to the local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID\nr2: value index for the given script var\nreturn: value",
        None,
    )

    SaveScriptVariableValue = Symbol(
        [0x4BB58],
        [0x204BB58],
        None,
        "SaveScriptVariableValue",
        "Saves the given value to a script variable.\n\nr0: pointer to local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID\nr2: value to save",
        None,
    )

    SaveScriptVariableValueAtIndex = Symbol(
        [0x4BCC0],
        [0x204BCC0],
        None,
        "SaveScriptVariableValueAtIndex",
        "Saves the given value to a script variable at some index (for script variables that are arrays).\n\nr0: pointer to local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID\nr2: value index for the given script var\nr3: value to save",
        None,
    )

    LoadScriptVariableValueSum = Symbol(
        [0x4BE38],
        [0x204BE38],
        None,
        "LoadScriptVariableValueSum",
        "Loads the sum of all values of a given script variable (for script variables that are arrays).\n\nr0: pointer to the local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID\nreturn: sum of values",
        None,
    )

    LoadScriptVariableValueBytes = Symbol(
        [0x4BE9C],
        [0x204BE9C],
        None,
        "LoadScriptVariableValueBytes",
        "Loads some number of bytes from the value of a given script variable.\n\nr0: script variable ID\nr1: [output] script variable value bytes\nr2: number of bytes to load",
        None,
    )

    SaveScriptVariableValueBytes = Symbol(
        [0x4BF04],
        [0x204BF04],
        None,
        "SaveScriptVariableValueBytes",
        "Saves some number of bytes to the given script variable.\n\nr0: script variable ID\nr1: bytes to save\nr2: number of bytes",
        None,
    )

    ScriptVariablesEqual = Symbol(
        [0x4BF50],
        [0x204BF50],
        None,
        "ScriptVariablesEqual",
        "Checks if two script variables have equal values. For arrays, compares elementwise for the length of the first variable.\n\nr0: pointer to the local variable table (only needed if id >= VAR_LOCAL0)\nr1: script variable ID 1\nr2: script variable ID 2\nreturn: true if values are equal, false otherwise",
        None,
    )

    EventFlagResume = Symbol(
        [0x4C2F8],
        [0x204C2F8],
        None,
        "EventFlagResume",
        "Restores BACKUP event flag script variables (see the code for an exhaustive list) to their\nrespective script variables, but only in certain game modes.\n\nThis function prints the debug string 'EventFlag BackupGameMode %d' with the game mode.\n\nNo params.",
        None,
    )

    EventFlagBackup = Symbol(
        [0x4C51C],
        [0x204C51C],
        None,
        "EventFlagBackup",
        "Saves event flag script variables (see the code for an exhaustive list) to their respective BACKUP script variables, but only in certain game modes.\n\nThis function prints the debug string 'EventFlag BackupGameMode %d' with the game mode.\n\nNo params.",
        None,
    )

    DumpScriptVariableValues = Symbol(
        [0x4C740],
        [0x204C740],
        None,
        "DumpScriptVariableValues",
        "Runs EventFlagBackup, then copies the script variable values table (SCRIPT_VARS_VALUES) to the given pointer.\n\nr0: destination pointer for the data dump\nreturn: always 1",
        None,
    )

    RestoreScriptVariableValues = Symbol(
        [0x4C768],
        [0x204C768],
        None,
        "RestoreScriptVariableValues",
        "Restores the script variable values table (SCRIPT_VARS_VALUES) with the given data. The source data is assumed to be exactly 1024 bytes in length.\n\nIrdkwia's notes: CheckCorrectVersion\n\nr0: raw data to copy to the values table\nreturn: whether the restored value for VAR_VERSION is equal to its default value",
        None,
    )

    InitScenarioScriptVars = Symbol(
        [0x4C7C0],
        [0x204C7C0],
        None,
        "InitScenarioScriptVars",
        "Initializes most of the SCENARIO_* script variables (except SCENARIO_TALK_BIT_FLAG for some reason). Also initializes the PLAY_OLD_GAME variable.\n\nNo params.",
        None,
    )

    SetScenarioScriptVar = Symbol(
        [0x4C950],
        [0x204C950],
        None,
        "SetScenarioScriptVar",
        "Sets the given SCENARIO_* script variable with a given pair of values [val0, val1].\n\nIn the special case when the ID is VAR_SCENARIO_MAIN, and the set value is different from the old one, the REQUEST_CLEAR_COUNT script variable will be set to 0.\n\nr0: script variable ID\nr1: val0\nr2: val1",
        None,
    )

    GetSpecialEpisodeType = Symbol(
        [0x4CC24],
        [0x204CC24],
        None,
        "GetSpecialEpisodeType",
        "Gets the special episode type from the SPECIAL_EPISODE_TYPE script variable.\n\nreturn: special episode type",
        None,
    )

    SetSpecialEpisodeType = Symbol(
        [0x4CC38],
        [0x204CC38],
        None,
        "SetSpecialEpisodeType",
        "Sets the special episode type by changing the SPECIAL_EPISODE_TYPE script variable.\n\nr0: special episode type",
        None,
    )

    GetExecuteSpecialEpisodeType = Symbol(
        [0x4CC70],
        [0x204CC70],
        None,
        "GetExecuteSpecialEpisodeType",
        "Gets the special episode type from the EXECUTE_SPECIAL_EPISODE_TYPE script variable.\n\nreturn: special episode type",
        None,
    )

    IsSpecialEpisodeOpen = Symbol(
        [0x4CC84],
        [0x204CC84],
        None,
        "IsSpecialEpisodeOpen",
        "Checks if a special episode is unlocked from the SPECIAL_EPISODE_OPEN script variable.\n\nr0: special episode type\nreturn: bool",
        None,
    )

    HasPlayedOldGame = Symbol(
        [0x4CDA8],
        [0x204CDA8],
        None,
        "HasPlayedOldGame",
        "Returns the value of the VAR_PLAY_OLD_GAME script variable.\n\nreturn: bool",
        None,
    )

    GetPerformanceFlagWithChecks = Symbol(
        [0x4CDCC],
        [0x204CDCC],
        None,
        "GetPerformanceFlagWithChecks",
        "Returns the value of one of the flags in VAR_PERFORMANCE_PROGRESS_LIST, with some edge cases.\n\nList of cases where the function behaves differently:\n- If the requested flag is 0, returns true if and only if SCENARIO_MAIN == 0x35\n- If the requested flag is 1 or 2 and GAME_MODE == GAME_MODE_SPECIAL_EPISODE, returns true\n- If the requested flag is between 3 and 7 (both included) and GAME_MODE == GAME_MODE_SPECIAL_EPISODE, returns false\n\nr0: ID of the flag to get\nreturn: Value of the flag",
        None,
    )

    GetScenarioBalance = Symbol(
        [0x4CECC],
        [0x204CECC],
        None,
        "GetScenarioBalance",
        "Returns the current SCENARIO_BALANCE value.\n\nThe exact value returned depends on multiple factors:\n- If the first special episode is active, returns 1\n- If a different special episode is active, returns 3\n- If the SCENARIO_BALANCE_DEBUG variable is >= 0, returns its value\n- In all other cases, the value of the SCENARIO_BALANCE_FLAG variable is returned\n\nreturn: Current SCENARIO_BALANCE value.",
        None,
    )

    ScenarioFlagBackup = Symbol(
        [0x4CFF0],
        [0x204CFF0],
        None,
        "ScenarioFlagBackup",
        "Saves scenario flag script variables (SCENARIO_SELECT, SCENARIO_MAIN_BIT_FLAG) to their respective BACKUP script variables, but only in certain game modes.\n\nThis function prints the debug string 'ScenarioFlag BackupGameMode %d' with the game mode.\n\nNo params.",
        None,
    )

    InitWorldMapScriptVars = Symbol(
        [0x4D0C0],
        [0x204D0C0],
        None,
        "InitWorldMapScriptVars",
        "Initializes the WORLD_MAP_* script variable values (IDs 0x55-0x57).\n\nNo params.",
        None,
    )

    InitDungeonListScriptVars = Symbol(
        [0x4D1C8],
        [0x204D1C8],
        None,
        "InitDungeonListScriptVars",
        "Initializes the DUNGEON_*_LIST script variable values (IDs 0x4f-0x54).\n\nNo params.",
        None,
    )

    SetDungeonConquest = Symbol(
        [0x4D270],
        [0x204D270],
        None,
        "SetDungeonConquest",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nr1: bit_value",
        None,
    )

    GetDungeonMode = Symbol(
        [0x4D2D4],
        [0x204D2D4],
        None,
        "GetDungeonMode",
        "Returns the mode of the specified dungeon\n\nr0: Dungeon ID\nreturn: Dungeon mode",
        None,
    )

    GlobalProgressAlloc = Symbol(
        [0x4D440],
        [0x204D440],
        None,
        "GlobalProgressAlloc",
        "Allocates a new global progress struct.\n\nThis updates the global pointer and returns a copy of that pointer.\n\nreturn: pointer to a newly allocated global progress struct",
        None,
    )

    ResetGlobalProgress = Symbol(
        [0x4D468],
        [0x204D468],
        None,
        "ResetGlobalProgress",
        "Zero-initializes the global progress struct.\n\nNo params.",
        None,
    )

    SetMonsterFlag1 = Symbol(
        [0x4D484],
        [0x204D484],
        None,
        "SetMonsterFlag1",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID",
        None,
    )

    GetMonsterFlag1 = Symbol(
        [0x4D4C0],
        [0x204D4C0],
        None,
        "GetMonsterFlag1",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: ?",
        None,
    )

    SetMonsterFlag2 = Symbol(
        [0x4D4FC],
        [0x204D4FC],
        None,
        "SetMonsterFlag2",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID",
        None,
    )

    HasMonsterBeenAttackedInDungeons = Symbol(
        [0x4D540],
        [0x204D540],
        None,
        "HasMonsterBeenAttackedInDungeons",
        "Checks whether the specified monster has been attacked by the player at some point in their adventure during an exploration.\n\nThe check is performed using the result of passing the ID to FemaleToMaleForm.\n\nr0: Monster ID\nreturn: True if the specified mosnter (after converting its ID through FemaleToMaleForm) has been attacked by the player before, false otherwise.",
        None,
    )

    SetDungeonTipShown = Symbol(
        [0x4D588],
        [0x204D588],
        None,
        "SetDungeonTipShown",
        "Marks a dungeon tip as already shown to the player\n\nr0: Dungeon tip ID",
        None,
    )

    GetDungeonTipShown = Symbol(
        [0x4D5C8],
        [0x204D5C8],
        None,
        "GetDungeonTipShown",
        "Checks if a dungeon tip has already been shown before or not.\n\nr0: Dungeon tip ID\nreturn: True if the tip has been shown before, false otherwise.",
        None,
    )

    SetMaxReachedFloor = Symbol(
        [0x4D614],
        [0x204D614],
        None,
        "SetMaxReachedFloor",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nr1: max floor",
        None,
    )

    GetMaxReachedFloor = Symbol(
        [0x4D630],
        [0x204D630],
        None,
        "GetMaxReachedFloor",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: max floor",
        None,
    )

    IncrementNbAdventures = Symbol(
        [0x4D650],
        [0x204D650],
        None,
        "IncrementNbAdventures",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    GetNbAdventures = Symbol(
        [0x4D684],
        [0x204D684],
        None,
        "GetNbAdventures",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: # adventures",
        None,
    )

    CanMonsterSpawn = Symbol(
        [0x4D698],
        [0x204D698],
        None,
        "CanMonsterSpawn",
        "Always returns true.\n\nThis function seems to be a debug switch that the developers may have used to disable the random enemy spawn. \nIf it returned false, the call to SpawnMonster inside TrySpawnMonsterAndTickSpawnCounter would not be executed.\n\nr0: monster ID\nreturn: bool (always true)",
        None,
    )

    IncrementExclusiveMonsterCounts = Symbol(
        [0x4D6A0],
        [0x204D6A0],
        None,
        "IncrementExclusiveMonsterCounts",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID",
        None,
    )

    CopyProgressInfoTo = Symbol(
        [0x4D6F8],
        [0x204D6F8],
        None,
        "CopyProgressInfoTo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: write_info\nothers: ?",
        None,
    )

    CopyProgressInfoFromScratchTo = Symbol(
        [0x4D880],
        [0x204D880],
        None,
        "CopyProgressInfoFromScratchTo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: start_address\nr1: total_length\nreturn: ?",
        None,
    )

    CopyProgressInfoFrom = Symbol(
        [0x4D8B8],
        [0x204D8B8],
        None,
        "CopyProgressInfoFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info",
        None,
    )

    CopyProgressInfoFromScratchFrom = Symbol(
        [0x4DA80],
        [0x204DA80],
        None,
        "CopyProgressInfoFromScratchFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: start_address\nr1: total_length",
        None,
    )

    InitKaomadoStream = Symbol(
        [0x4DAB8],
        [0x204DAB8],
        None,
        "InitKaomadoStream",
        "Initializes the stream used to load all Kaomado portraits, called once on game start!\n\nNo params.",
        None,
    )

    InitPortraitParams = Symbol(
        [0x4DAD4],
        [0x204DAD4],
        None,
        "InitPortraitParams",
        "Initializes a struct portrait_params.\n\nThe emote is set to PORTRAIT_NONE and the layout to the default. Everything else is initialized to 0.\n\nr0: portrait params pointer",
        None,
    )

    InitPortraitParamsWithMonsterId = Symbol(
        [0x4DB0C],
        [0x204DB0C],
        None,
        "InitPortraitParamsWithMonsterId",
        "Calls InitPortraitParams, and also initializes emote to PORTRAIT_NORMAL and monster ID to the passed argument.\n\nr0: portrait params pointer\nr1: monster ID",
        None,
    )

    SetPortraitEmotion = Symbol(
        [0x4DB2C],
        [0x204DB2C],
        None,
        "SetPortraitEmotion",
        "Sets the emote in the passed portrait params, only if the monster ID isn't MONSTER_NONE.\n\nr0: portrait params pointer\nr1: emotion ID",
        None,
    )

    SetPortraitLayout = Symbol(
        [0x4DB3C],
        [0x204DB3C],
        None,
        "SetPortraitLayout",
        "Sets the layout in the passed portrait from the array of possible layouts.\n\nIf the layout is 32 or if the monster ID is MONSTER_NONE, then it does nothing.\n\nr0: portrait params pointer\nr1: layout index",
        None,
    )

    SetPortraitOffset = Symbol(
        [0x4DB80],
        [0x204DB80],
        None,
        "SetPortraitOffset",
        "Offsets the portrait from the original offset determined by the layout, by the vector passed as argument.\n\nIf the monster ID is MONSTER_NONE, then it does nothing.\n\nr0: portrait params pointer\nr1: (x, y) offset in tiles from the original offset, derived from the layout",
        None,
    )

    AllowPortraitDefault = Symbol(
        [0x4DBCC],
        [0x204DBCC],
        None,
        "AllowPortraitDefault",
        "Allows the portrait to try and load the default emote (PORTRAIT_NORMAL) if it can't find the specified emote.\n\nr0: portrait params pointer\nr1: allow default",
        None,
    )

    IsValidPortrait = Symbol(
        [0x4DBD4],
        [0x204DBD4],
        None,
        "IsValidPortrait",
        "Returns whether this portrait params represents a valid portrait.\n\nr0: portrait params pointer\nreturn: bool",
        None,
    )

    LoadPortrait = Symbol(
        [0x4DBF4],
        [0x204DBF4],
        None,
        "LoadPortrait",
        "Tries to load the portrait data associated with the passed portrait params.\n\nReturns whether the operation was successful (the portrait could be found). If the passed buffer is null, the check if performed without loading any data.\n\nThis function also modifies the flip fields in the passed portrait params.\n\nr0: portrait params pointer\nr1: kaomado_buffer pointer\nreturn: portrait exists",
        None,
    )

    WonderMailPasswordToMission = Symbol(
        [0x4E0B8],
        [0x204E0B8],
        None,
        "WonderMailPasswordToMission",
        "Tries to convert a Wonder Mail S password to a mission struct.\n\nReturns whether the conversion was successful. This function does not include any checks if the mission itself is valid, only if the code is valid.\n\nr0: string\nr1: Pointer to the struct where the data of the converted mission will be written to\nreturn: successful conversion",
        None,
    )

    SetEnterDungeon = Symbol(
        [0x4EC84],
        [0x204EC84],
        None,
        "SetEnterDungeon",
        "Used to set the dungeon that will be accessed when switching from ground to dungeon mode.\n\nr0: Dungeon ID",
        None,
    )

    InitDungeonInit = Symbol(
        [0x4ED94],
        [0x204ED94],
        None,
        "InitDungeonInit",
        "Initializes the dungeon_init struct before entering a dungeon.\n\nr0: [output] Pointer to the struct to init\nr1: Dungeon ID",
        None,
    )

    IsNoLossPenaltyDungeon = Symbol(
        [0x4F318],
        [0x204F318],
        None,
        "IsNoLossPenaltyDungeon",
        "Returns true if the specified dungeon shouldn't have a loss penalty.\n\nIf true you won't lose your money and items upon fainting. Also used to initialize dungeon_init::skip_faint_animation_flag.\n\nReturns: True for DUNGEON_CRYSTAL_LAKE and DUNGEON_5TH_STATION_CLEARING, as well as for DUNGEON_DEEP_STAR_CAVE_TEAM_ROGUE if the ground variable SIDE01_BOSS2ND is 0; false otherwise.",
        None,
    )

    CheckMissionRestrictions = Symbol(
        [0x4F6FC],
        [0x204F6FC],
        None,
        "CheckMissionRestrictions",
        "Seems to be used to check if you have any missions that have unmet restrictions when trying to access a dungeon.\n\nr0: ?\nreturn: (?) Seems to be composed of multiple bitflags.",
        None,
    )

    GetNbFloors = Symbol(
        [0x4F8B4],
        [0x204F8B4],
        None,
        "GetNbFloors",
        "Returns the number of floors of the given dungeon.\n\nThe result is hardcoded for certain dungeons, such as dojo mazes.\n\nr0: Dungeon ID\nreturn: Number of floors",
        None,
    )

    GetNbFloorsPlusOne = Symbol(
        [0x4F8EC],
        [0x204F8EC],
        None,
        "GetNbFloorsPlusOne",
        "Returns the number of floors of the given dungeon + 1.\n\nr0: Dungeon ID\nreturn: Number of floors + 1",
        None,
    )

    GetDungeonGroup = Symbol(
        [0x4F900],
        [0x204F900],
        None,
        "GetDungeonGroup",
        "Returns the dungeon group associated to the given dungeon.\n\nFor IDs greater or equal to dungeon_id::DUNGEON_NORMAL_FLY_MAZE, returns dungeon_group_id::DGROUP_MAROWAK_DOJO.\n\nr0: Dungeon ID\nreturn: Group ID",
        None,
    )

    GetNbPrecedingFloors = Symbol(
        [0x4F918],
        [0x204F918],
        None,
        "GetNbPrecedingFloors",
        "Given a dungeon ID, returns the total amount of floors summed by all the previous dungeons in its group.\n\nThe value is normally pulled from dungeon_data_list_entry::n_preceding_floors_group, except for dungeons with an ID >= dungeon_id::DUNGEON_NORMAL_FLY_MAZE, for which this function always returns 0.\n\nr0: Dungeon ID\nreturn: Number of preceding floors of the dungeon",
        None,
    )

    GetNbFloorsDungeonGroup = Symbol(
        [0x4F930],
        [0x204F930],
        None,
        "GetNbFloorsDungeonGroup",
        "Returns the total amount of floors among all the dungeons in the dungeon group of the specified dungeon.\n\nr0: Dungeon ID\nreturn: Total number of floors in the group of the specified dungeon",
        None,
    )

    DungeonFloorToGroupFloor = Symbol(
        [0x4F984],
        [0x204F984],
        None,
        "DungeonFloorToGroupFloor",
        "Given a dungeon ID and a floor number, returns a struct with the corresponding dungeon group and floor number in that group.\n\nThe function normally uses the data in mappa_s.bin to calculate the result, but there's some dungeons (such as dojo mazes) that have hardcoded return values.\n\nIrdkwia's notes:\n  [r1]: dungeon_id\n  [r1+1]: dungeon_floor_id\n  [r0]: group_id\n  [r0+1]: group_floor_id\n\nr0: [output] Struct containing the dungeon group and floor group\nr1: Struct containing the dungeon ID and floor number",
        None,
    )

    GetMissionRank = Symbol(
        [0x4FB4C],
        [0x204FB4C],
        None,
        "GetMissionRank",
        "Gets the mission rank for the given dungeon and floor.\n\nIf the dungeon ID is >= DUNGEON_NORMAL_FLY_MAZE or the group of the dungeon is > DGROUP_DUMMY_0x63, returns MISSION_RANK_E.\n\nr0: Dungeon and floor\nreturn: Mission rank",
        None,
    )

    GetOutlawLevel = Symbol(
        [0x4FBC4],
        [0x204FBC4],
        None,
        "GetOutlawLevel",
        "Gets the level that should be used for outlaws for the given dungeon and floor\n\nr0: Dungeon and floor\nreturn: Outlaw level",
        None,
    )

    GetOutlawLeaderLevel = Symbol(
        [0x4FBE0],
        [0x204FBE0],
        None,
        "GetOutlawLeaderLevel",
        "Gets the level that should be used for team leader outlaws for the given dungeon and floor. Identical to GetOutlawLevel.\n\nr0: Dungeon and floor\nreturn: Outlaw leader level",
        None,
    )

    GetOutlawMinionLevel = Symbol(
        [0x4FBFC],
        [0x204FBFC],
        None,
        "GetOutlawMinionLevel",
        "Gets the level that should be used for minion outlaws for the given dungeon and floor.\n\nr0: Dungeon and floor\nreturn: Outlaw minion level",
        None,
    )

    AddGuestMonster = Symbol(
        [0x4FC18],
        [0x204FC18],
        None,
        "AddGuestMonster",
        "Adds a guest monster to the active team\n\nr0: dungeon_init struct for the dungeon that is about to be entered\nr1: Number of the guest monster to add. Used when more than one monster is added.\nr2: Pointer to the guest monster entry to add to the team (usually located within GUEST_MONSTER_DATA)",
        None,
    )

    GetGroundNameId = Symbol(
        [0x4FC90],
        [0x204FC90],
        None,
        "GetGroundNameId",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    SetAdventureLogStructLocation = Symbol(
        [0x4FD5C],
        [0x204FD5C],
        None,
        "SetAdventureLogStructLocation",
        "Sets the location of the adventure log struct in memory.\n\nSets it in a static memory location (At 0x22AB69C [US], 0x22ABFDC [EU], 0x22ACE58 [JP])\n\nNo params.",
        None,
    )

    SetAdventureLogDungeonFloor = Symbol(
        [0x4FD74],
        [0x204FD74],
        None,
        "SetAdventureLogDungeonFloor",
        "Sets the current dungeon floor pair.\n\nr0: struct dungeon_floor_pair",
        None,
    )

    GetAdventureLogDungeonFloor = Symbol(
        [0x4FD94],
        [0x204FD94],
        None,
        "GetAdventureLogDungeonFloor",
        "Gets the current dungeon floor pair.\n\nreturn: struct dungeon_floor_pair",
        None,
    )

    ClearAdventureLogStruct = Symbol(
        [0x4FDA8],
        [0x204FDA8],
        None,
        "ClearAdventureLogStruct",
        "Clears the adventure log structure.\n\nNo params.",
        None,
    )

    SetAdventureLogCompleted = Symbol(
        [0x4FED4],
        [0x204FED4],
        None,
        "SetAdventureLogCompleted",
        "Marks one of the adventure log entry as completed.\n\nr0: entry ID",
        None,
    )

    IsAdventureLogNotEmpty = Symbol(
        [0x4FEFC],
        [0x204FEFC],
        None,
        "IsAdventureLogNotEmpty",
        "Checks if at least one of the adventure log entries is completed.\n\nreturn: bool",
        None,
    )

    GetAdventureLogCompleted = Symbol(
        [0x4FF34],
        [0x204FF34],
        None,
        "GetAdventureLogCompleted",
        "Checks if one adventure log entry is completed.\n\nr0: entry ID\nreturn: bool",
        None,
    )

    IncrementNbDungeonsCleared = Symbol(
        [0x4FF60],
        [0x204FF60],
        None,
        "IncrementNbDungeonsCleared",
        "Increments by 1 the number of dungeons cleared.\n\nImplements SPECIAL_PROC_INCREMENT_DUNGEONS_CLEARED (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    GetNbDungeonsCleared = Symbol(
        [0x4FFA4],
        [0x204FFA4],
        None,
        "GetNbDungeonsCleared",
        "Gets the number of dungeons cleared.\n\nreturn: the number of dungeons cleared",
        None,
    )

    IncrementNbFriendRescues = Symbol(
        [0x4FFB8],
        [0x204FFB8],
        None,
        "IncrementNbFriendRescues",
        "Increments by 1 the number of successful friend rescues.\n\nNo params.",
        None,
    )

    GetNbFriendRescues = Symbol(
        [0x50000],
        [0x2050000],
        None,
        "GetNbFriendRescues",
        "Gets the number of successful friend rescues.\n\nreturn: the number of successful friend rescues",
        None,
    )

    IncrementNbEvolutions = Symbol(
        [0x50014],
        [0x2050014],
        None,
        "IncrementNbEvolutions",
        "Increments by 1 the number of evolutions.\n\nNo params.",
        None,
    )

    GetNbEvolutions = Symbol(
        [0x5005C],
        [0x205005C],
        None,
        "GetNbEvolutions",
        "Gets the number of evolutions.\n\nreturn: the number of evolutions",
        None,
    )

    IncrementNbSteals = Symbol(
        [0x50070],
        [0x2050070],
        None,
        "IncrementNbSteals",
        "Leftover from Time & Darkness. Does not do anything.\n\nCalls to this matches the ones for incrementing the number of successful steals in Time & Darkness.\n\nNo params.",
        None,
    )

    IncrementNbEggsHatched = Symbol(
        [0x50074],
        [0x2050074],
        None,
        "IncrementNbEggsHatched",
        "Increments by 1 the number of eggs hatched.\n\nNo params.",
        None,
    )

    GetNbEggsHatched = Symbol(
        [0x500B0],
        [0x20500B0],
        None,
        "GetNbEggsHatched",
        "Gets the number of eggs hatched.\n\nreturn: the number of eggs hatched",
        None,
    )

    GetNbPokemonJoined = Symbol(
        [0x500C4],
        [0x20500C4],
        None,
        "GetNbPokemonJoined",
        "Gets the number of different pokémon that joined.\n\nreturn: the number of different pokémon that joined",
        None,
    )

    GetNbMovesLearned = Symbol(
        [0x500D8],
        [0x20500D8],
        None,
        "GetNbMovesLearned",
        "Gets the number of different moves learned.\n\nreturn: the number of different moves learned",
        None,
    )

    SetVictoriesOnOneFloor = Symbol(
        [0x500EC],
        [0x20500EC],
        None,
        "SetVictoriesOnOneFloor",
        "Sets the record of victories on one floor.\n\nr0: the new record of victories",
        None,
    )

    GetVictoriesOnOneFloor = Symbol(
        [0x50120],
        [0x2050120],
        None,
        "GetVictoriesOnOneFloor",
        "Gets the record of victories on one floor.\n\nreturn: the record of victories",
        None,
    )

    SetPokemonJoined = Symbol(
        [0x50134],
        [0x2050134],
        None,
        "SetPokemonJoined",
        "Marks one pokémon as joined.\n\nr0: monster ID",
        None,
    )

    SetPokemonBattled = Symbol(
        [0x50190],
        [0x2050190],
        None,
        "SetPokemonBattled",
        "Marks one pokémon as battled.\n\nr0: monster ID",
        None,
    )

    GetNbPokemonBattled = Symbol(
        [0x501EC],
        [0x20501EC],
        None,
        "GetNbPokemonBattled",
        "Gets the number of different pokémon that battled against you.\n\nreturn: the number of different pokémon that battled against you",
        None,
    )

    IncrementNbBigTreasureWins = Symbol(
        [0x50200],
        [0x2050200],
        None,
        "IncrementNbBigTreasureWins",
        "Increments by 1 the number of big treasure wins.\n\nImplements SPECIAL_PROC_INCREMENT_BIG_TREASURE_WINS (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    SetNbBigTreasureWins = Symbol(
        [0x50220],
        [0x2050220],
        None,
        "SetNbBigTreasureWins",
        "Sets the number of big treasure wins.\n\nr0: the new number of big treasure wins",
        None,
    )

    GetNbBigTreasureWins = Symbol(
        [0x50258],
        [0x2050258],
        None,
        "GetNbBigTreasureWins",
        "Gets the number of big treasure wins.\n\nreturn: the number of big treasure wins",
        None,
    )

    SetNbRecycled = Symbol(
        [0x5026C],
        [0x205026C],
        None,
        "SetNbRecycled",
        "Sets the number of items recycled.\n\nr0: the new number of items recycled",
        None,
    )

    GetNbRecycled = Symbol(
        [0x502A4],
        [0x20502A4],
        None,
        "GetNbRecycled",
        "Gets the number of items recycled.\n\nreturn: the number of items recycled",
        None,
    )

    IncrementNbSkyGiftsSent = Symbol(
        [0x502B8],
        [0x20502B8],
        None,
        "IncrementNbSkyGiftsSent",
        "Increments by 1 the number of sky gifts sent.\n\nImplements SPECIAL_PROC_SEND_SKY_GIFT_TO_GUILDMASTER (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    SetNbSkyGiftsSent = Symbol(
        [0x502D8],
        [0x20502D8],
        None,
        "SetNbSkyGiftsSent",
        "Sets the number of Sky Gifts sent.\n\nreturn: the number of Sky Gifts sent",
        None,
    )

    GetNbSkyGiftsSent = Symbol(
        [0x50310],
        [0x2050310],
        None,
        "GetNbSkyGiftsSent",
        "Gets the number of Sky Gifts sent.\n\nreturn: the number of Sky Gifts sent",
        None,
    )

    ComputeSpecialCounters = Symbol(
        [0x50324],
        [0x2050324],
        None,
        "ComputeSpecialCounters",
        "Computes the counters from the bit fields in the adventure log, as they are not updated automatically when bit fields are altered.\n\nAffects GetNbPokemonJoined, GetNbMovesLearned, GetNbPokemonBattled and GetNbItemAcquired.\n\nNo params.",
        None,
    )

    RecruitSpecialPokemonLog = Symbol(
        [0x5057C],
        [0x205057C],
        None,
        "RecruitSpecialPokemonLog",
        "Marks a specified special pokémon as recruited in the adventure log.\n\nIrdkwia's notes: Useless in Sky\n\nr0: monster ID",
        None,
    )

    IncrementNbFainted = Symbol(
        [0x505E8],
        [0x20505E8],
        None,
        "IncrementNbFainted",
        "Increments by 1 the number of times you fainted.\n\nNo params.",
        None,
    )

    GetNbFainted = Symbol(
        [0x50624],
        [0x2050624],
        None,
        "GetNbFainted",
        "Gets the number of times you fainted.\n\nreturn: the number of times you fainted",
        None,
    )

    SetItemAcquired = Symbol(
        [0x50638],
        [0x2050638],
        None,
        "SetItemAcquired",
        "Marks one specific item as acquired.\n\nr0: item",
        None,
    )

    GetNbItemAcquired = Symbol(
        [0x50704],
        [0x2050704],
        None,
        "GetNbItemAcquired",
        "Gets the number of items acquired.\n\nreturn: the number of items acquired",
        None,
    )

    SetChallengeLetterCleared = Symbol(
        [0x50758],
        [0x2050758],
        None,
        "SetChallengeLetterCleared",
        "Sets a challenge letter as cleared.\n\nr0: challenge ID",
        None,
    )

    GetSentryDutyGamePoints = Symbol(
        [0x507DC],
        [0x20507DC],
        None,
        "GetSentryDutyGamePoints",
        "Gets the points for the associated rank in the footprints minigame.\n\nr0: the rank (range 0-4, 1st to 5th)\nreturn: points",
        None,
    )

    SetSentryDutyGamePoints = Symbol(
        [0x507F4],
        [0x20507F4],
        None,
        "SetSentryDutyGamePoints",
        "Sets a new record in the footprints minigame.\n\nr0: points\nreturn: the rank (range 0-4, 1st to 5th; -1 if out of ranking)",
        None,
    )

    CopyLogTo = Symbol(
        [0x50884],
        [0x2050884],
        None,
        "CopyLogTo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: write_info",
        None,
    )

    CopyLogFrom = Symbol(
        [0x50A70],
        [0x2050A70],
        None,
        "CopyLogFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info",
        None,
    )

    GetAbilityString = Symbol(
        [0x50C54],
        [0x2050C54],
        None,
        "GetAbilityString",
        "Copies the string for the ability id into the buffer.\n\nr0: [output] buffer\nr1: ability ID",
        None,
    )

    GetAbilityDescStringId = Symbol(
        [0x50C74],
        [0x2050C74],
        None,
        "GetAbilityDescStringId",
        "Gets the ability description string ID for the corresponding ability.\n\nr0: ability ID\nreturn: string ID",
        None,
    )

    GetTypeStringId = Symbol(
        [0x50C88],
        [0x2050C88],
        None,
        "GetTypeStringId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: type ID\nreturn: string ID",
        None,
    )

    GetConversion2ConvertToType = Symbol(
        [0x50C9C],
        [0x2050C9C],
        None,
        "GetConversion2ConvertToType",
        "Determines which type a monster with Conversion2 should turn into after being hit by a certain\ntype of move.\n\nr0: type ID\nreturn: type ID",
        None,
    )

    CopyBitsTo = Symbol(
        [0x50CF8],
        [0x2050CF8],
        None,
        "CopyBitsTo",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: write_info\nr1: buffer_write\nr2: nb_bits",
        None,
    )

    CopyBitsFrom = Symbol(
        [0x50D78],
        [0x2050D78],
        None,
        "CopyBitsFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info\nr1: buffer_read\nr2: nb_bits",
        None,
    )

    StoreDefaultTeamData = Symbol(
        [0x50E04],
        [0x2050E04],
        None,
        "StoreDefaultTeamData",
        "Sets the name of the team for the main story to the default team name Poképals. Also initializes\nthe team to Normal Rank and possibly set Secret Rank unlocked to false?\n\nNo params.",
        None,
    )

    GetMainTeamNameWithCheck = Symbol(
        [0x50E48],
        [0x2050E48],
        None,
        "GetMainTeamNameWithCheck",
        "Gets the name of the team for the main story with an additional check if the team name should be\n'???' because the story has not progressed enough.\n\nr0: [output] buffer",
        None,
    )

    GetMainTeamName = Symbol(
        [0x50EB4],
        [0x2050EB4],
        None,
        "GetMainTeamName",
        "Gets the name of the team for the main story.\n\nr0: [output] buffer",
        None,
    )

    SetMainTeamName = Symbol(
        [0x50ECC],
        [0x2050ECC],
        None,
        "SetMainTeamName",
        "Sets the main team name to the name in the passed buffer.\n\nr0: buffer",
        None,
    )

    GetRankupPoints = Symbol(
        [0x50EF0],
        [0x2050EF0],
        None,
        "GetRankupPoints",
        "Returns the number of points required to reach the next rank.\n\nIf PERFORMANCE_PROGRESS_LIST[8] is 0 and the current rank is RANK_MASTER, or if the current rank is RANK_GUILDMASTER, returns 0.\n\nreturn: Points required to reach the next rank",
        None,
    )

    GetRank = Symbol(
        [0x50FAC],
        [0x2050FAC],
        None,
        "GetRank",
        "Returns the team's rank\n\nIf PERFORMANCE_PROGRESS_LIST[8] is 0, the maximum rank that can be returned is RANK_MASTER.\n\nreturn: Rank",
        None,
    )

    GetRankStorageSize = Symbol(
        [0x5101C],
        [0x205101C],
        None,
        "GetRankStorageSize",
        "Gets the size of storage for the current rank.\n\nreturn: storage size",
        None,
    )

    ResetPlayTimer = Symbol(
        [0x51140],
        [0x2051140],
        None,
        "ResetPlayTimer",
        "Reset the file timer.\n\nr0: play_time",
        None,
    )

    PlayTimerTick = Symbol(
        [0x51150],
        [0x2051150],
        None,
        "PlayTimerTick",
        "Advance the file timer by 1 frame.\n\nr0: play_time",
        None,
    )

    GetPlayTimeSeconds = Symbol(
        [0x5118C],
        [0x205118C],
        None,
        "GetPlayTimeSeconds",
        "Returns the current play time in seconds.\n\nreturn: play time in seconds",
        None,
    )

    SubFixedPoint = Symbol(
        [0x51248],
        [0x2051248],
        None,
        "SubFixedPoint",
        "Compute the subtraction of two decimal fixed-point numbers (16 fraction bits).\n\nNumbers are in the format {16-bit integer part, 16-bit thousandths}, where the integer part is the lower word. Probably used primarily for belly.\n\nr0: number\nr1: decrement\nreturn: max(number - decrement, 0)",
        None,
    )

    BinToDecFixedPoint = Symbol(
        [0x51358],
        [0x2051358],
        None,
        "BinToDecFixedPoint",
        "Convert a binary fixed-point number (16 fraction bits) to the decimal fixed-point number (16 fraction bits) used for belly calculations. Thousandths are floored.\n\nIf <data> holds the raw binary data, a binary fixed-point number (16 fraction bits) has the value ((unsigned)data) * 2^-16), and the decimal fixed-point number (16 fraction bits) used for belly has the value (data & 0xffff) + (data >> 16)/1000.\n\nr0: pointer p, where ((const unsigned *)p)[1] is the fractional number in binary fixed-point format to convert\nreturn: fractional number in decimal fixed-point format",
        None,
    )

    CeilFixedPoint = Symbol(
        [0x5139C],
        [0x205139C],
        None,
        "CeilFixedPoint",
        "Compute the ceiling of a decimal fixed-point number (16 fraction bits).\n\nNumbers are in the format {16-bit integer part, 16-bit thousandths}, where the integer part is the lower word. Probably used primarily for belly.\n\nr0: number\nreturn: ceil(number)",
        None,
    )

    DungeonGoesUp = Symbol(
        [0x515C0],
        [0x20515C0],
        None,
        "DungeonGoesUp",
        "Returns whether the specified dungeon is considered as going upward or not\n\nr0: dungeon id\nreturn: bool",
        None,
    )

    GetTurnLimit = Symbol(
        [0x515E8],
        [0x20515E8],
        None,
        "GetTurnLimit",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: turn limit",
        None,
    )

    DoesNotSaveWhenEntering = Symbol(
        [0x51600],
        [0x2051600],
        None,
        "DoesNotSaveWhenEntering",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    TreasureBoxDropsEnabled = Symbol(
        [0x51628],
        [0x2051628],
        None,
        "TreasureBoxDropsEnabled",
        "Checks if enemy Treasure Box drops are enabled in the dungeon.\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    IsLevelResetDungeon = Symbol(
        [0x51650],
        [0x2051650],
        None,
        "IsLevelResetDungeon",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    GetMaxItemsAllowed = Symbol(
        [0x51678],
        [0x2051678],
        None,
        "GetMaxItemsAllowed",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: max items allowed",
        None,
    )

    IsMoneyAllowed = Symbol(
        [0x51690],
        [0x2051690],
        None,
        "IsMoneyAllowed",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    GetMaxRescueAttempts = Symbol(
        [0x516B8],
        [0x20516B8],
        None,
        "GetMaxRescueAttempts",
        "Returns the maximum rescue attempts allowed in the specified dungeon.\n\nr0: dungeon id\nreturn: Max rescue attempts, or -1 if rescues are disabled.",
        None,
    )

    IsRecruitingAllowed = Symbol(
        [0x516D0],
        [0x20516D0],
        None,
        "IsRecruitingAllowed",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    GetLeaderChangeFlag = Symbol(
        [0x516F8],
        [0x20516F8],
        None,
        "GetLeaderChangeFlag",
        "Returns true if the flag that allows changing leaders is set in the restrictions of the specified dungeon\n\nr0: dungeon id\nreturn: True if the restrictions of the current dungeon allow changing leaders, false otherwise.",
        None,
    )

    GetRandomMovementChance = Symbol(
        [0x51720],
        [0x2051720],
        None,
        "GetRandomMovementChance",
        "Returns dungeon_restriction::random_movement_chance for the specified dungeon ID.\n\nr0: dungeon ID\nreturn: Random movement chance",
        None,
    )

    CanEnemyEvolve = Symbol(
        [0x51738],
        [0x2051738],
        None,
        "CanEnemyEvolve",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    GetMaxMembersAllowed = Symbol(
        [0x51760],
        [0x2051760],
        None,
        "GetMaxMembersAllowed",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: max members allowed",
        None,
    )

    IsIqEnabled = Symbol(
        [0x51778],
        [0x2051778],
        None,
        "IsIqEnabled",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    IsTrapInvisibleWhenAttacking = Symbol(
        [0x517A0],
        [0x20517A0],
        None,
        "IsTrapInvisibleWhenAttacking",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    JoinedAtRangeCheck = Symbol(
        [0x517C8],
        [0x20517C8],
        None,
        "JoinedAtRangeCheck",
        "Returns whether a certain joined_at field value is between dungeon_id::DUNGEON_JOINED_AT_BIDOOF and dungeon_id::DUNGEON_DUMMY_0xE3.\n\nIrdkwia's notes: IsSupportPokemon\n\nr0: joined_at id\nreturn: bool",
        None,
    )

    IsDojoDungeon = Symbol(
        [0x517E8],
        [0x20517E8],
        None,
        "IsDojoDungeon",
        "Checks if the given dungeon is a Marowak Dojo dungeon.\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    IsFutureDungeon = Symbol(
        [0x51804],
        [0x2051804],
        None,
        "IsFutureDungeon",
        "Checks if the given dungeon is a dungeon in the future arc of the main story.\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    IsSpecialEpisodeDungeon = Symbol(
        [0x51820],
        [0x2051820],
        None,
        "IsSpecialEpisodeDungeon",
        "Checks if the given dungeon is a special episode dungeon.\n\nr0: dungeon ID\nreturn: bool",
        None,
    )

    RetrieveFromItemList1 = Symbol(
        [0x5183C],
        [0x205183C],
        None,
        "RetrieveFromItemList1",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon_info\nr1: ?\nreturn: ?",
        None,
    )

    IsForbiddenFloor = Symbol(
        [0x518A0],
        [0x20518A0],
        None,
        "IsForbiddenFloor",
        "Related to missions floors forbidden\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: dungeon_info\nothers: ?\nreturn: bool",
        None,
    )

    Copy16BitsFrom = Symbol(
        [0x51924],
        [0x2051924],
        None,
        "Copy16BitsFrom",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info\nr1: buffer_read",
        None,
    )

    RetrieveFromItemList2 = Symbol(
        [0x519B4],
        [0x20519B4],
        None,
        "RetrieveFromItemList2",
        "Same as RetrieveFromItemList1, except there is one more comparison\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: dungeon_info",
        None,
    )

    IsInvalidForMission = Symbol(
        [0x51A14],
        [0x2051A14],
        None,
        "IsInvalidForMission",
        "It's a guess\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: dungeon_id\nreturn: bool",
        None,
    )

    IsExpEnabledInDungeon = Symbol(
        [0x51A54],
        [0x2051A54],
        None,
        "IsExpEnabledInDungeon",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon_id\nreturn: bool",
        None,
    )

    IsSkyExclusiveDungeon = Symbol(
        [0x51A7C],
        [0x2051A7C],
        None,
        "IsSkyExclusiveDungeon",
        "Also the dungeons where Giratina has its Origin Form\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: dungeon_id\nreturn: bool",
        None,
    )

    JoinedAtRangeCheck2 = Symbol(
        [0x51A98],
        [0x2051A98],
        None,
        "JoinedAtRangeCheck2",
        "Returns whether a certain joined_at field value is equal to dungeon_id::DUNGEON_BEACH or is between dungeon_id::DUNGEON_DUMMY_0xEC and dungeon_id::DUNGEON_DUMMY_0xF0.\n\nIrdkwia's notes: IsSEPokemon\n\nr0: joined_at id\nreturn: bool",
        None,
    )

    GetBagCapacity = Symbol(
        [0x51B0C],
        [0x2051B0C],
        None,
        "GetBagCapacity",
        "Returns the player's bag capacity for a given point in the game.\n\nr0: scenario_balance\nreturn: bag capacity",
        None,
    )

    GetBagCapacitySpecialEpisode = Symbol(
        [0x51B1C],
        [0x2051B1C],
        None,
        "GetBagCapacitySpecialEpisode",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: se_type\nreturn: bag capacity",
        None,
    )

    GetRankUpEntry = Symbol(
        [0x51B2C],
        [0x2051B2C],
        None,
        "GetRankUpEntry",
        "Gets the rank up data for the specified rank.\n\nr0: rank index\nreturn: struct rankup_table_entry*",
        None,
    )

    GetBgRegionArea = Symbol(
        [0x521C4],
        [0x20521C4],
        None,
        "GetBgRegionArea",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: offset\nr1: subregion_id\nr2: region_id\nreturn: ?",
        None,
    )

    LoadMonsterMd = Symbol(
        [0x52690],
        [0x2052690],
        None,
        "LoadMonsterMd",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    GetNameRaw = Symbol(
        [0x526CC],
        [0x20526CC],
        None,
        "GetNameRaw",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dst_ptr\nr1: id",
        None,
    )

    GetName = Symbol(
        [0x52708],
        [0x2052708],
        None,
        "GetName",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dst_ptr\nr1: id\nr2: color_id",
        None,
    )

    GetNameWithGender = Symbol(
        [0x52778],
        [0x2052778],
        None,
        "GetNameWithGender",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dst_ptr\nr1: id\nr2: color_id",
        None,
    )

    GetSpeciesString = Symbol(
        [0x52838],
        [0x2052838],
        None,
        "GetSpeciesString",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dst_ptr\nr1: id",
        None,
    )

    GetNameString = Symbol(
        [0x52A00],
        [0x2052A00],
        None,
        "GetNameString",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: name",
        None,
    )

    GetSpriteIndex = Symbol(
        [0x52A24, 0x52A40, 0x52A5C],
        [0x2052A24, 0x2052A40, 0x2052A5C],
        None,
        "GetSpriteIndex",
        "Return the sprite index for this monster (inside m_attack.bin, m_ground.bin and monster.bin)\nAll three sprites have the same index\n\nr0: monster id\nreturn: sprite index",
        None,
    )

    GetDexNumber = Symbol(
        [0x52A78],
        [0x2052A78],
        None,
        "GetDexNumber",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: dex number",
        None,
    )

    GetCategoryString = Symbol(
        [0x52A94],
        [0x2052A94],
        None,
        "GetCategoryString",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: category",
        None,
    )

    GetMonsterGender = Symbol(
        [0x52AE0],
        [0x2052AE0],
        None,
        "GetMonsterGender",
        "Returns the gender field of a monster given its ID.\n\nr0: monster id\nreturn: monster gender",
        None,
    )

    GetBodySize = Symbol(
        [0x52AFC],
        [0x2052AFC],
        None,
        "GetBodySize",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: body size",
        None,
    )

    GetSpriteSize = Symbol(
        [0x52B18],
        [0x2052B18],
        None,
        "GetSpriteSize",
        "Returns the sprite size of the specified monster. If the size is between 1 and 6, 6 will be returned.\n\nr0: monster id\nreturn: sprite size",
        None,
    )

    GetSpriteFileSize = Symbol(
        [0x52B54],
        [0x2052B54],
        None,
        "GetSpriteFileSize",
        "Returns the sprite file size of the specified monster.\n\nr0: monster id\nreturn: sprite file size",
        None,
    )

    GetShadowSize = Symbol(
        [0x52B74],
        [0x2052B74],
        None,
        "GetShadowSize",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: shadow size",
        None,
    )

    GetSpeedStatus = Symbol(
        [0x52B90],
        [0x2052B90],
        None,
        "GetSpeedStatus",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: speed status",
        None,
    )

    GetMobilityType = Symbol(
        [0x52BAC],
        [0x2052BAC],
        None,
        "GetMobilityType",
        "Gets the mobility type for a given monster species.\n\nr0: species ID\nreturn: mobility type",
        None,
    )

    GetRegenSpeed = Symbol(
        [0x52BC8],
        [0x2052BC8],
        None,
        "GetRegenSpeed",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: regen speed",
        None,
    )

    GetCanMoveFlag = Symbol(
        [0x52BEC],
        [0x2052BEC],
        None,
        "GetCanMoveFlag",
        "Returns the flag that determines if a monster can move in dungeons.\n\nr0: Monster ID\nreturn: 'Can move' flag",
        None,
    )

    GetChanceAsleep = Symbol(
        [0x52C18],
        [0x2052C18],
        None,
        "GetChanceAsleep",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: chance asleep",
        None,
    )

    GetWeightMultiplier = Symbol(
        [0x52C34],
        [0x2052C34],
        None,
        "GetWeightMultiplier",
        "Gets the weight multiplier value for the given species. This value is passed as the damage_mult_fp parameter to DealDamage when calculating the damage dealt by Low Kick and Grass Knot.\n\nr0: monster ID\nreturn: Monster weight multiplier, as a binary fixed-point number with 8 fraction bits.",
        None,
    )

    GetSize = Symbol(
        [0x52C50],
        [0x2052C50],
        None,
        "GetSize",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: size",
        None,
    )

    GetBaseHp = Symbol(
        [0x52C6C],
        [0x2052C6C],
        None,
        "GetBaseHp",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: base HP",
        None,
    )

    CanThrowItems = Symbol(
        [0x52C88],
        [0x2052C88],
        None,
        "CanThrowItems",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: bool",
        None,
    )

    CanEvolve = Symbol(
        [0x52CB4],
        [0x2052CB4],
        None,
        "CanEvolve",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: bool",
        None,
    )

    GetMonsterPreEvolution = Symbol(
        [0x52CE0],
        [0x2052CE0],
        None,
        "GetMonsterPreEvolution",
        "Returns the pre-evolution id of a monster given its ID.\n\nr0: monster id\nreturn: ID of the monster that evolves into the one specified in r0",
        None,
    )

    GetBaseOffensiveStat = Symbol(
        [0x52CFC],
        [0x2052CFC],
        None,
        "GetBaseOffensiveStat",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: stat index\nreturn: base attack/special attack stat",
        None,
    )

    GetBaseDefensiveStat = Symbol(
        [0x52D1C],
        [0x2052D1C],
        None,
        "GetBaseDefensiveStat",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: stat index\nreturn: base defense/special defense stat",
        None,
    )

    GetType = Symbol(
        [0x52D3C],
        [0x2052D3C],
        None,
        "GetType",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: type index (0 for primary type or 1 for secondary type)\nreturn: type",
        None,
    )

    GetAbility = Symbol(
        [0x52D5C],
        [0x2052D5C],
        None,
        "GetAbility",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: ability index (0 for primary ability or 1 for secondary ability)\nreturn: ability",
        None,
    )

    GetRecruitRate2 = Symbol(
        [0x52D7C],
        [0x2052D7C],
        None,
        "GetRecruitRate2",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: recruit rate 2",
        None,
    )

    GetRecruitRate1 = Symbol(
        [0x52D98],
        [0x2052D98],
        None,
        "GetRecruitRate1",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: recruit rate 1",
        None,
    )

    GetExp = Symbol(
        [0x52DB4],
        [0x2052DB4],
        None,
        "GetExp",
        "Base Formula = ((Level-1)*ExpYield)//10+ExpYield\nNote: Defeating an enemy without using a move will divide this amount by 2\n\nr0: id\nr1: level\nreturn: exp",
        None,
    )

    GetEvoParameters = Symbol(
        [0x52DE8],
        [0x2052DE8],
        None,
        "GetEvoParameters",
        "Bx\nHas something to do with evolution\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: [output] struct_evo_param\nr1: id",
        None,
    )

    GetTreasureBoxChances = Symbol(
        [0x52E18],
        [0x2052E18],
        None,
        "GetTreasureBoxChances",
        "Has something to do with bytes 3C-3E\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: [output] struct_chances",
        None,
    )

    GetIqGroup = Symbol(
        [0x52E60],
        [0x2052E60],
        None,
        "GetIqGroup",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: IQ group",
        None,
    )

    GetSpawnThreshold = Symbol(
        [0x52E7C],
        [0x2052E7C],
        None,
        "GetSpawnThreshold",
        "Returns the spawn threshold of the given monster ID\n\nThe spawn threshold determines the minimum SCENARIO_BALANCE_FLAG value required by a monster to spawn in dungeons.\n\nr0: monster id\nreturn: Spawn threshold",
        None,
    )

    NeedsItemToSpawn = Symbol(
        [0x52E98],
        [0x2052E98],
        None,
        "NeedsItemToSpawn",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: bool",
        None,
    )

    GetExclusiveItem = Symbol(
        [0x52EC4],
        [0x2052EC4],
        None,
        "GetExclusiveItem",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nr1: determines which exclusive item\nreturn: exclusive item",
        None,
    )

    GetFamilyIndex = Symbol(
        [0x52EF0],
        [0x2052EF0],
        None,
        "GetFamilyIndex",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: family index",
        None,
    )

    LoadM2nAndN2m = Symbol(
        [0x52F0C],
        [0x2052F0C],
        None,
        "LoadM2nAndN2m",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    GuestMonsterToGroundMonster = Symbol(
        [0x531CC],
        [0x20531CC],
        None,
        "GuestMonsterToGroundMonster",
        "Inits a ground_monster entry with the given guest_monster struct.\n\nr0: [output] ground_monster struct to init\nr1: guest_monster struct to use",
        None,
    )

    StrcmpMonsterName = Symbol(
        [0x5332C],
        [0x205332C],
        None,
        "StrcmpMonsterName",
        "Checks if the string_buffer matches the name of the species\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: string_buffer\nr1: monster ID\nreturn: bool",
        None,
    )

    GetLvlUpEntry = Symbol(
        [0x53B18],
        [0x2053B18],
        None,
        "GetLvlUpEntry",
        "Gets the level-up entry of the given monster ID at the specified level.\n\nThe monster's entire level up data is also decompressed to LEVEL_UP_DATA_DECOMPRESS_BUFFER, and its ID is stored in LEVEL_UP_DATA_MONSTER_ID.\n\nr0: [output] Level-up entry\nr1: monster ID\nr2: level",
        None,
    )

    GetEncodedHalfword = Symbol(
        [0x53BC8],
        [0x2053BC8],
        None,
        "GetEncodedHalfword",
        "Decodes a 2-byte value that may be encoded using 1 or 2 bytes and writes it to the specified buffer.\n\nThe encoding system uses the most significant bit of the first byte to signal if the value is encoded as a single byte or as a halfword. If the bit is unset, the value is read as (encoded byte) & 0x7F. If it's set, the value is read as ((first encoded byte) & 0x7F << 7) | (second encoded byte) & 0x7F.\n\nr0: Pointer to encoded value\nr1: [output] Buffer where the resulting 2-byte value will be stored.\nreturn: Pointer to the next byte to decode",
        None,
    )

    GetEvoFamily = Symbol(
        [0x5414C],
        [0x205414C],
        None,
        "GetEvoFamily",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster_str\nr1: evo_family_str\nreturn: nb_family",
        None,
    )

    GetEvolutions = Symbol(
        [0x54204],
        [0x2054204],
        None,
        "GetEvolutions",
        "Returns a list of all the possible evolutions for a given monster id.\n\nr0: Monster id\nr1: [Output] Array that will hold the list of monster ids the specified monster can evolve into\nr2: True to skip the check that prevents returning monsters with a different sprite size than the current one\nr3: True to skip the check that prevents Shedinja from being counted as a potential evolution\nreturn: Number of possible evolutions for the specified monster id",
        None,
    )

    ShuffleHiddenPower = Symbol(
        [0x54344],
        [0x2054344],
        None,
        "ShuffleHiddenPower",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dmons_addr",
        None,
    )

    GetBaseForm = Symbol(
        [0x543A0],
        [0x20543A0],
        None,
        "GetBaseForm",
        "Checks if the specified monster ID corresponds to any of the pokémon that have multiple forms and returns the ID of the base form if so. If it doesn't, the same ID is returned.\n\nSome of the pokémon included in the check are Castform, Unown, Deoxys, Cherrim, Shaymin, and Giratina\n\nr0: Monster ID\nreturn: ID of the base form of the specified monster, or the same if the specified monster doesn't have a base form.",
        None,
    )

    GetBaseFormBurmyWormadamShellosGastrodonCherrim = Symbol(
        [0x545CC],
        [0x20545CC],
        None,
        "GetBaseFormBurmyWormadamShellosGastrodonCherrim",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: base form",
        None,
    )

    GetBaseFormCastformCherrimDeoxys = Symbol(
        [0x54714],
        [0x2054714],
        None,
        "GetBaseFormCastformCherrimDeoxys",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: base form",
        None,
    )

    GetAllBaseForms = Symbol(
        [0x547E0],
        [0x20547E0],
        None,
        "GetAllBaseForms",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: base form",
        None,
    )

    GetDexNumberVeneer = Symbol(
        [0x547F0],
        [0x20547F0],
        None,
        "GetDexNumberVeneer",
        "Likely a linker-generated veneer for GetDexNumber.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: id\nreturn: dex number",
        None,
    )

    GetMonsterIdFromSpawnEntry = Symbol(
        [0x547FC],
        [0x20547FC],
        None,
        "GetMonsterIdFromSpawnEntry",
        "Returns the monster ID of the specified monster spawn entry\n\nr0: Pointer to the monster spawn entry\nreturn: monster_spawn_entry::id",
        None,
    )

    SetMonsterId = Symbol(
        [0x5481C],
        [0x205481C],
        None,
        "SetMonsterId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: mons_spawn_str\nr1: monster ID",
        None,
    )

    SetMonsterLevelAndId = Symbol(
        [0x54824],
        [0x2054824],
        None,
        "SetMonsterLevelAndId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: mons_spawn_str\nr1: level\nr2: monster ID",
        None,
    )

    GetMonsterLevelFromSpawnEntry = Symbol(
        [0x54834],
        [0x2054834],
        None,
        "GetMonsterLevelFromSpawnEntry",
        "Returns the level of the specified monster spawn entry.\n\nr0: pointer to the monster spawn entry\nreturn: uint8_t",
        None,
    )

    GetMonsterGenderVeneer = Symbol(
        [0x54ADC],
        [0x2054ADC],
        None,
        "GetMonsterGenderVeneer",
        "Likely a linker-generated veneer for GetMonsterGender.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: monster id\nreturn: monster gender",
        None,
    )

    IsMonsterValid = Symbol(
        [0x54AE8],
        [0x2054AE8],
        None,
        "IsMonsterValid",
        "Checks if an monster ID is valid.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    IsUnown = Symbol(
        [0x54E04],
        [0x2054E04],
        None,
        "IsUnown",
        "Checks if a monster ID is an Unown.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    IsShaymin = Symbol(
        [0x54E20],
        [0x2054E20],
        None,
        "IsShaymin",
        "Checks if a monster ID is a Shaymin form.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    IsCastform = Symbol(
        [0x54E50],
        [0x2054E50],
        None,
        "IsCastform",
        "Checks if a monster ID is a Castform form.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    IsCherrim = Symbol(
        [0x54EA8],
        [0x2054EA8],
        None,
        "IsCherrim",
        "Checks if a monster ID is a Cherrim form.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    IsDeoxys = Symbol(
        [0x54EF0],
        [0x2054EF0],
        None,
        "IsDeoxys",
        "Checks if a monster ID is a Deoxys form.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    GetSecondFormIfValid = Symbol(
        [0x54F20],
        [0x2054F20],
        None,
        "GetSecondFormIfValid",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: second form",
        None,
    )

    FemaleToMaleForm = Symbol(
        [0x54F5C],
        [0x2054F5C],
        None,
        "FemaleToMaleForm",
        "Returns the ID of the first form of the specified monster if the specified ID corresponds to a secondary form with female gender and the first form has male gender. If those conditions don't meet, returns the same ID unchanged.\n\nr0: Monster ID\nreturn: ID of the male form of the monster if the requirements meet, same ID otherwise.",
        None,
    )

    GetBaseFormCastformDeoxysCherrim = Symbol(
        [0x54FA0],
        [0x2054FA0],
        None,
        "GetBaseFormCastformDeoxysCherrim",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id\nreturn: base form",
        None,
    )

    BaseFormsEqual = Symbol(
        [0x55054],
        [0x2055054],
        None,
        "BaseFormsEqual",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: id1\nr1: id2\nreturn: if the base forms are the same",
        None,
    )

    DexNumbersEqual = Symbol(
        [0x55140],
        [0x2055140],
        None,
        "DexNumbersEqual",
        "Each Unown is considered as different\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: id1\nr1: id2\nreturn: bool",
        None,
    )

    GendersEqual = Symbol(
        [0x551C8],
        [0x20551C8],
        None,
        "GendersEqual",
        "Checks if the genders for two monster IDs are equal.\n\nr0: id1\nr1: id2\nreturn: bool",
        None,
    )

    GendersEqualNotGenderless = Symbol(
        [0x551F4],
        [0x20551F4],
        None,
        "GendersEqualNotGenderless",
        "Checks if the genders for two monster IDs are equal. Always returns false if either gender is GENDER_GENDERLESS.\n\nr0: id1\nr1: id2\nreturn: bool",
        None,
    )

    GendersNotEqualNotGenderless = Symbol(
        [0x55244],
        [0x2055244],
        None,
        "GendersNotEqualNotGenderless",
        "Checks if the genders for two monster IDs are not equal. Always returns false\nif either gender is GENDER_GENDERLESS.\n\nr0: id1\nr1: id2\nreturn: bool",
        None,
    )

    IsMonsterOnTeam = Symbol(
        [0x554C4],
        [0x20554C4],
        None,
        "IsMonsterOnTeam",
        "Checks if a given monster is on the exploration team (not necessarily the active party)?\n\nIrdkwia's notes:\n  recruit_strategy=0: strict equality\n  recruit_strategy=1: relative equality\n\nr0: monster ID\nr1: recruit_strategy\nreturn: bool",
        None,
    )

    GetNbRecruited = Symbol(
        [0x555F0],
        [0x20555F0],
        None,
        "GetNbRecruited",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: recruit_str",
        None,
    )

    IsValidTeamMember = Symbol(
        [0x5570C],
        [0x205570C],
        None,
        "IsValidTeamMember",
        "Returns whether or not the team member at the given index is valid for the current game mode.\n\nDuring normal play, this will only be false for the special-episode-reserved indexes (2, 3, 4). During special episodes, this will be false for the hero and partner (0, 1).\n\nr0: team member index\nreturn: bool",
        None,
    )

    IsMainCharacter = Symbol(
        [0x558A4],
        [0x20558A4],
        None,
        "IsMainCharacter",
        "Returns whether or not the team member at the given index is a 'main character'.\n\nDuring normal play, this will only be true for the hero and partner (0, 1). During special episodes, this will be true for the special-episode-reserved indexes (2, 3, 4).\n\nr0: team member index\nreturn: bool",
        None,
    )

    GetTeamMember = Symbol(
        [0x55924],
        [0x2055924],
        None,
        "GetTeamMember",
        "Gets the team member at the given index.\n\nr0: team member index\nreturn: ground monster pointer",
        None,
    )

    GetHeroMemberIdx = Symbol(
        [0x559CC],
        [0x20559CC],
        None,
        "GetHeroMemberIdx",
        "Returns the team member index of the hero (0) if the hero is valid, otherwise return -1.\n\nreturn: team member index",
        None,
    )

    GetPartnerMemberIdx = Symbol(
        [0x559F8],
        [0x20559F8],
        None,
        "GetPartnerMemberIdx",
        "Returns the team member index of the partner (1) if the partner is valid, otherwise return -1.\n\nreturn: team member index",
        None,
    )

    GetMainCharacter1MemberIdx = Symbol(
        [0x55A24],
        [0x2055A24],
        None,
        "GetMainCharacter1MemberIdx",
        "Returns the team member index of the first main character for the given game mode, if valid, otherwise return -1.\n\nIn normal play, this will be the hero (0). During special episodes, this will be 2.\n\nreturn: team member index",
        None,
    )

    GetMainCharacter2MemberIdx = Symbol(
        [0x55A68],
        [0x2055A68],
        None,
        "GetMainCharacter2MemberIdx",
        "Returns the team member index of the second main character for the given game mode, if valid, otherwise return -1.\n\nIn normal play, this will be the partner (1). During special episodes, this will be 3 if there's a second main character.\n\nreturn: team member index",
        None,
    )

    GetMainCharacter3MemberIdx = Symbol(
        [0x55AAC],
        [0x2055AAC],
        None,
        "GetMainCharacter3MemberIdx",
        "Returns the team member index of the third main character for the given game mode, if valid, otherwise return -1.\n\nIn normal play, this will be invalid (-1). During special episodes, this will be 4 if there's a third main character.\n\nreturn: team member index",
        None,
    )

    GetHero = Symbol(
        [0x55AEC],
        [0x2055AEC],
        None,
        "GetHero",
        "Returns the ground monster data of the hero.\n\nreturn: ground monster pointer",
        None,
    )

    GetPartner = Symbol(
        [0x55B14],
        [0x2055B14],
        None,
        "GetPartner",
        "Returns the ground monster data of the partner.\n\nreturn: ground monster pointer",
        None,
    )

    GetMainCharacter1 = Symbol(
        [0x55B40],
        [0x2055B40],
        None,
        "GetMainCharacter1",
        "Returns the ground monster data of the first main character for the given game mode.\n\nIn normal play, this will be the hero. During special episodes, this will be the first special episode main character (index 2).\n\nreturn: ground monster pointer",
        None,
    )

    GetMainCharacter2 = Symbol(
        [0x55B88],
        [0x2055B88],
        None,
        "GetMainCharacter2",
        "Returns the ground monster data of the second main character for the given game mode, or null if invalid.\n\nIn normal play, this will be the partner. During special episodes, this will be the second special episode main character (index 3) if one is present.\n\nreturn: ground monster pointer",
        None,
    )

    GetMainCharacter3 = Symbol(
        [0x55BD0],
        [0x2055BD0],
        None,
        "GetMainCharacter3",
        "Returns the ground monster data of the third main character for the given game mode, or null if invalid.\n\nIn normal play, this will be null. During special episodes, this will be the third special episode main character (index 4) if one is present.\n\nreturn: ground monster pointer",
        None,
    )

    GetFirstMatchingMemberIdx = Symbol(
        [0x55C70],
        [0x2055C70],
        None,
        "GetFirstMatchingMemberIdx",
        "Gets the first team member index (in the Chimecho Assembly) that has a specific monster ID, or -1 if there is none.\n\nIf valid, this will always be 5 or greater, since indexes 0-4 are reserved for main characters.\n\nr0: monster ID\nreturn: team member index of the first matching slot",
        None,
    )

    GetFirstEmptyMemberIdx = Symbol(
        [0x55CE0],
        [0x2055CE0],
        None,
        "GetFirstEmptyMemberIdx",
        "Gets the first unoccupied team member index (in the Chimecho Assembly), or -1 if there is none.\n\nIf valid, this will always be 5 or greater, since indexes 0-4 are reserved for main characters.\n\nr0: ?\nreturn: team member index of the first available slot",
        None,
    )

    IsMonsterNotNicknamed = Symbol(
        [0x563EC],
        [0x20563EC],
        None,
        "IsMonsterNotNicknamed",
        "Checks if the string_buffer matches the name of the species\n\nr0: ground monster pointer\nreturn: bool",
        None,
    )

    RemoveActiveMembersFromAllTeams = Symbol(
        [0x56444],
        [0x2056444],
        None,
        "RemoveActiveMembersFromAllTeams",
        "Removes all of the active monsters on every type of team from the team member table.\n\nNo params.",
        None,
    )

    RemoveActiveMembersFromSpecialEpisodeTeam = Symbol(
        [0x564D4],
        [0x20564D4],
        None,
        "RemoveActiveMembersFromSpecialEpisodeTeam",
        "Removes the active monsters on the Special Episode Team from the team member table.\n\nNo params.",
        None,
    )

    RemoveActiveMembersFromRescueTeam = Symbol(
        [0x5653C],
        [0x205653C],
        None,
        "RemoveActiveMembersFromRescueTeam",
        "Removes the active monsters on the Rescue Team from the team member table.\n\nNo params.",
        None,
    )

    CheckTeamMemberIdx = Symbol(
        [0x565E0],
        [0x20565E0],
        None,
        "CheckTeamMemberIdx",
        "Checks if a team member's member index (team_member::member_idx) is equal to certain values.\n\nThis is known to return true for some or all of the guest monsters.\n\nr0: member index\nreturn: True if the value is equal to 0x55AA or 0x5AA5",
        None,
    )

    IsMonsterIdInNormalRange = Symbol(
        [0x56610],
        [0x2056610],
        None,
        "IsMonsterIdInNormalRange",
        "Checks if a monster ID is in the range [0, 554], meaning it's before the special story monster IDs and secondary gender IDs.\n\nr0: monster ID\nreturn: bool",
        None,
    )

    SetActiveTeam = Symbol(
        [0x56648],
        [0x2056648],
        None,
        "SetActiveTeam",
        "Sets the specified team to active in TEAM_MEMBER_TABLE.\n\nr0: team ID",
        None,
    )

    GetActiveTeamMember = Symbol(
        [0x56708],
        [0x2056708],
        None,
        "GetActiveTeamMember",
        "Returns a struct containing information about the active team member in the given slot index.\n\nr0: roster index\nreturn: team member pointer, or null if index is -1",
        None,
    )

    GetActiveRosterIndex = Symbol(
        [0x56738],
        [0x2056738],
        None,
        "GetActiveRosterIndex",
        "Searches for the roster index for the given team member within the current active roster.\n\nr0: team member index\nreturn: roster index if the team member is active, -1 otherwise",
        None,
    )

    TryAddMonsterToActiveTeam = Symbol(
        [0x56AD0],
        [0x2056AD0],
        None,
        "TryAddMonsterToActiveTeam",
        "Attempts to add a monster from the team member table to the active team.\n\nReturns the team index of the newly added monster. If the monster was already on the team, returns its current team index. If the monster is not on the team and there's no space left, returns -1.\n\nr0: member index\nreturn: Team index",
        None,
    )

    RemoveActiveMembersFromMainTeam = Symbol(
        [0x56CDC],
        [0x2056CDC],
        None,
        "RemoveActiveMembersFromMainTeam",
        "Removes the active monsters on the Main Team from the team member table.\n\nNo params.",
        None,
    )

    SetTeamSetupHeroAndPartnerOnly = Symbol(
        [0x56D48],
        [0x2056D48],
        None,
        "SetTeamSetupHeroAndPartnerOnly",
        "Implements SPECIAL_PROC_SET_TEAM_SETUP_HERO_AND_PARTNER_ONLY (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    SetTeamSetupHeroOnly = Symbol(
        [0x56E2C],
        [0x2056E2C],
        None,
        "SetTeamSetupHeroOnly",
        "Implements SPECIAL_PROC_SET_TEAM_SETUP_HERO_ONLY (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    GetPartyMembers = Symbol(
        [0x56F9C],
        [0x2056F9C],
        None,
        "GetPartyMembers",
        "Appears to get the team's active party members. Implements most of SPECIAL_PROC_IS_TEAM_SETUP_SOLO (see ScriptSpecialProcessCall).\n\nr0: [output] Array of 4 2-byte values (they seem to be indexes of some sort) describing each party member, which will be filled in by the function. The input can be a null pointer if the party members aren't needed\nreturn: Number of party members",
        None,
    )

    RefillTeam = Symbol(
        [0x580D4],
        [0x20580D4],
        None,
        "RefillTeam",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    ClearItem = Symbol(
        [0x5856C],
        [0x205856C],
        None,
        "ClearItem",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: team_id\nr1: check",
        None,
    )

    ChangeGiratinaFormIfSkyDungeon = Symbol(
        [0x58954],
        [0x2058954],
        None,
        "ChangeGiratinaFormIfSkyDungeon",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: dungeon ID",
        None,
    )

    GetIqSkillStringId = Symbol(
        [0x58F98],
        [0x2058F98],
        None,
        "GetIqSkillStringId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: iq skill id\nreturn: iq skill string id",
        None,
    )

    DoesTacticFollowLeader = Symbol(
        [0x58FB8],
        [0x2058FB8],
        None,
        "DoesTacticFollowLeader",
        "Returns whether or not the tactic involves following the team leader.\n\nr0: tactic_id\nreturn: bool",
        None,
    )

    GetUnlockedTactics = Symbol(
        [0x58FC8],
        [0x2058FC8],
        None,
        "GetUnlockedTactics",
        "Returns an array with all the enabled tactics. TACTIC_NONE is used to fill the empty/unused entries\nin the array.\n\nr0: [output] Array of tactic_ids that are enabled\nr1: Monster level",
        None,
    )

    GetUnlockedTacticFlags = Symbol(
        [0x59018],
        [0x2059018],
        None,
        "GetUnlockedTacticFlags",
        "Returns an array with an entry for each tactic and if they're unlocked at the passed level.\n\nr0: [output] bool Array where the unlocked status of each tactic is stored\nr1: Monster level",
        None,
    )

    CanLearnIqSkill = Symbol(
        [0x59054],
        [0x2059054],
        None,
        "CanLearnIqSkill",
        "Returns whether an IQ skill can be learned with a given IQ amount or not.\n\nIf the specified amount is 0, it always returns false.\n\nr0: IQ amount\nr1: IQ skill\nreturn: True if the specified skill can be learned with the specified IQ amount.",
        None,
    )

    GetLearnableIqSkills = Symbol(
        [0x59080],
        [0x2059080],
        None,
        "GetLearnableIqSkills",
        "Determines the list of IQ skills that a given monster can learn given its IQ value.\n\nThe list of skills is written in the array specified in r0. The array has 69 slots in total. Unused slots are set to 0.\n\nr0: [output] Array where the list of skills will be written\nr1: Monster species\nr2: Monster IQ\nreturn: Amount of skills written to the output array",
        None,
    )

    DisableIqSkill = Symbol(
        [0x59120],
        [0x2059120],
        None,
        "DisableIqSkill",
        "Disables an IQ skill.\n\nr0: Pointer to the bitarray containing the list of enabled IQ skills\nr1: ID of the skill to disable",
        None,
    )

    EnableIqSkill = Symbol(
        [0x59170],
        [0x2059170],
        None,
        "EnableIqSkill",
        "Enables an IQ skill and disables any other skills that are incompatible with it.\n\nr0: Pointer to the bitarray containing the list of enabled IQ skills\nr1: ID of the skill to enable",
        None,
    )

    GetSpeciesIqSkill = Symbol(
        [0x591E4],
        [0x20591E4],
        None,
        "GetSpeciesIqSkill",
        "Gets the <index>th skill on the list of IQ skills that a given monster species can learn.\n\nr0: Species ID\nr1: Index (starting at 0)\nreturn: IQ skill ID",
        None,
    )

    DisableAllIqSkills = Symbol(
        [0x59208],
        [0x2059208],
        None,
        "DisableAllIqSkills",
        "Disables all IQ skills in the bitarray.\n\nr0: Pointer to the bitarray containing the list of enabled IQ skills",
        None,
    )

    EnableAllLearnableIqSkills = Symbol(
        [0x5922C],
        [0x205922C],
        None,
        "EnableAllLearnableIqSkills",
        "Attempts to enable all the IQ skills available to the monster. If there are incompatible IQ skils,\nthe one with the highest ID will be activated while the others will be inactivated.\n\nr0: [output] Array where the list of skills will be written\nr1: Monster species\nr2: Monster IQ",
        None,
    )

    IqSkillFlagTest = Symbol(
        [0x59280],
        [0x2059280],
        None,
        "IqSkillFlagTest",
        "Tests whether an IQ skill with a given ID is active.\n\nr0: IQ skill bitvector to test\nr1: IQ skill ID\nreturn: bool",
        None,
    )

    GetNextIqSkill = Symbol(
        [0x592A0],
        [0x20592A0],
        None,
        "GetNextIqSkill",
        "Returns the next IQ skill that a given monster will learn given its current IQ value, or IQ_NONE if the monster won't learn any more skills.\n\nr0: Monster ID\nr1: Monster IQ\nreturn: ID of the next skill learned by the monster, or IQ_NONE if the monster won't learn any more skills.",
        None,
    )

    GetExplorerMazeTeamName = Symbol(
        [0x593DC],
        [0x20593DC],
        None,
        "GetExplorerMazeTeamName",
        "Returns the name of the explorer maze team. If the language of the team name is different from the\nlanguage of selected in this game a default team name is written to the buffer instead.\n\nr0: [output] Buffer",
        None,
    )

    GetExplorerMazeMonster = Symbol(
        [0x59474],
        [0x2059474],
        None,
        "GetExplorerMazeMonster",
        "Returns the data of a monster sent into the Explorer Dojo using the 'exchange teams' option.\n\nr0: Entry number (0-3)\nreturn: Ground monster data of the specified entry",
        None,
    )

    WriteMonsterInfoToSave = Symbol(
        [0x59494],
        [0x2059494],
        None,
        "WriteMonsterInfoToSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: start_address\nr1: total_length\nreturn: ?",
        None,
    )

    ReadMonsterInfoFromSave = Symbol(
        [0x595A0],
        [0x20595A0],
        None,
        "ReadMonsterInfoFromSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: start_address\nr1: total_length",
        None,
    )

    WriteMonsterToSave = Symbol(
        [0x596B0],
        [0x20596B0],
        None,
        "WriteMonsterToSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: write_info\nr1: ground_monster",
        None,
    )

    ReadMonsterFromSave = Symbol(
        [0x597C0],
        [0x20597C0],
        None,
        "ReadMonsterFromSave",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: read_info\nr1: ground_monster",
        None,
    )

    GetEvolutionPossibilities = Symbol(
        [0x59E94],
        [0x2059E94],
        None,
        "GetEvolutionPossibilities",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: ground_monster\nr1: evo_struct_addr",
        None,
    )

    GetMonsterEvoStatus = Symbol(
        [0x5A58C],
        [0x205A58C],
        None,
        "GetMonsterEvoStatus",
        "evo_status = 0: Not possible now\nevo_status = 1: Possible now\nevo_status = 2: No further\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: ground_monster\nreturn: evo_status",
        None,
    )

    CopyTacticString = Symbol(
        [0x5A7AC],
        [0x205A7AC],
        None,
        "CopyTacticString",
        "Gets the string corresponding to a given string ID and copies it to the buffer specified in r0.\n\nThis function won't write more than 64 bytes.\n\nr0: [output] buffer\nr1: tactic_id",
        None,
    )

    GetStatBoostsForMonsterSummary = Symbol(
        [0x5A7CC],
        [0x205A7CC],
        None,
        "GetStatBoostsForMonsterSummary",
        "Gets the stat boosts from held items, exclusive items, and iq skills and stores them into the\nmonster_summary struct.\n\nr0: monster_summary\nr1: enum monster_id monster_id\nr2: pointer to held item\nr3: iq\nstack[0]: bool if Klutz is active",
        None,
    )

    CreateMonsterSummaryFromTeamMember = Symbol(
        [0x5B1A4],
        [0x205B1A4],
        None,
        "CreateMonsterSummaryFromTeamMember",
        "Creates a snapshot of the condition of a team_member struct in a monster_summary struct.\n\nr0: [output] monster_summary\nr1: team_member\nr2: bool is leader",
        None,
    )

    GetSosMailCount = Symbol(
        [0x5BCF8],
        [0x205BCF8],
        None,
        "GetSosMailCount",
        "Implements SPECIAL_PROC_GET_SOS_MAIL_COUNT (see ScriptSpecialProcessCall).\n\nr0: ?\nr1: some flag?\nreturn: SOS mail count",
        None,
    )

    IsMissionSuspendedAndValid = Symbol(
        [0x5CBD0],
        [0x205CBD0],
        None,
        "IsMissionSuspendedAndValid",
        "Checks if a mission is currently suspended and contains valid fields. Calls IsMissionValid for the validity check.\n\nr0: mission to check\nreturn: bool",
        None,
    )

    AreMissionsEquivalent = Symbol(
        [0x5CCB0],
        [0x205CCB0],
        None,
        "AreMissionsEquivalent",
        "Checks if two missions are equivalent.\n\nr0: mission1\nr1: mission2\nreturn: bool",
        None,
    )

    IsMissionValid = Symbol(
        [0x5CDBC],
        [0x205CDBC],
        None,
        "IsMissionValid",
        "Checks if a mission contains valid fields.\n\nFor example, a mission will be considered invalid if the ID of the monsters or items involved are out of bounds, if their entries are marked as invalid, if the destination floor does not exist, etc.\nIf the mission fails one of the checks, the game will print an error message explaining what is wrong using DebugPrint0.\n\nr0: mission to check\nreturn: True if the mission is valid, false if it's not.",
        None,
    )

    GenerateMission = Symbol(
        [0x5D5A0],
        [0x205D5A0],
        None,
        "GenerateMission",
        "Attempts to generate a random mission.\n\nr0: Pointer to something\nr1: Pointer to the struct where the data of the generated mission will be written to\nreturn: MISSION_GENERATION_SUCCESS if the mission was successfully generated, MISSION_GENERATION_FAILURE if it failed and MISSION_GENERATION_GLOBAL_FAILURE if it failed and the game shouldn't try to generate more.",
        None,
    )

    IsMissionTypeSpecialEpisode = Symbol(
        [0x5E5B4],
        [0x205E5B4],
        None,
        "IsMissionTypeSpecialEpisode",
        "Checks if a mission is for a Special Episode Transmission, which unlocks Special Episode 3. This specifically checks for a mission of type MISSION_SPECIAL_EPISODE and subtype 0x2.\n\nr0: mission pointer\nreturn: bool",
        None,
    )

    GenerateDailyMissions = Symbol(
        [0x5E94C],
        [0x205E94C],
        None,
        "GenerateDailyMissions",
        "Generates the missions displayed on the Job Bulletin Board and the Outlaw Notice Board.\n\nNo params.",
        None,
    )

    AlreadyHaveMission = Symbol(
        [0x5F014],
        [0x205F014],
        None,
        "AlreadyHaveMission",
        "Checks if a specified mission already exists in the Job List.\n\nr0: mission to check\nreturn: bool",
        None,
    )

    CountJobListMissions = Symbol(
        [0x5F100],
        [0x205F100],
        None,
        "CountJobListMissions",
        "Gets the number of missions currently in the Job List.\n\nreturn: number of missions",
        None,
    )

    DungeonRequestsDone = Symbol(
        [0x5F120],
        [0x205F120],
        None,
        "DungeonRequestsDone",
        "Seems to return the number of missions completed.\n\nPart of the implementation for SPECIAL_PROC_DUNGEON_HAD_REQUEST_DONE (see ScriptSpecialProcessCall).\n\nr0: ?\nr1: some flag?\nreturn: number of missions completed",
        None,
    )

    DungeonRequestsDoneWrapper = Symbol(
        [0x5F18C],
        [0x205F18C],
        None,
        "DungeonRequestsDoneWrapper",
        "Calls DungeonRequestsDone with the second argument set to false.\n\nr0: ?\nreturn: number of mission completed",
        None,
    )

    AnyDungeonRequestsDone = Symbol(
        [0x5F19C],
        [0x205F19C],
        None,
        "AnyDungeonRequestsDone",
        "Calls DungeonRequestsDone with the second argument set to true, and converts the integer output to a boolean.\n\nr0: ?\nreturn: bool: whether the number of missions completed is greater than 0",
        None,
    )

    AddMissionToJobList = Symbol(
        [0x5F434],
        [0x205F434],
        None,
        "AddMissionToJobList",
        "Adds a mission to the Job List.\n\nr0: mission to add",
        None,
    )

    GetAcceptedMission = Symbol(
        [0x5F454],
        [0x205F454],
        None,
        "GetAcceptedMission",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: mission_id\nreturn: mission",
        None,
    )

    GetMissionByTypeAndDungeon = Symbol(
        [0x5F728],
        [0x205F728],
        None,
        "GetMissionByTypeAndDungeon",
        "Returns the position on the mission list of the first mission of the specified type that takes place in the specified dungeon.\n\nIf the type of the mission has a subtype, the subtype of the checked mission must match the one in [r2] too for it to be returned.\n\nr0: Position on the mission list where the search should start. Missions before this position on the list will be ignored.\nr1: Mission type\nr2: Pointer to some struct that contains the subtype of the mission to check on its first byte\nr3: Dungeon ID\nreturn: Index of the first mission that meets the specified requirements, or -1 if there aren't any missions that do so.",
        None,
    )

    CheckAcceptedMissionByTypeAndDungeon = Symbol(
        [0x5F820],
        [0x205F820],
        None,
        "CheckAcceptedMissionByTypeAndDungeon",
        "Returns true if there are any accepted missions on the mission list that are of the specified type and take place in the specified dungeon.\n\nIf the type of the mission has a subtype, the subtype of the checked mission must match the one in [r2] too for it to be returned.\n\nr0: Mission type\nr1: Pointer to some struct that contains the subtype of the mission to check on its first byte\nr2: Dungeon ID\nreturn: True if at least one mission meets the specified requirements, false otherwise.",
        None,
    )

    GetAllPossibleMonsters = Symbol(
        [0x5FAB4],
        [0x205FAB4],
        None,
        "GetAllPossibleMonsters",
        "Stores MISSION_MONSTER_LIST_PTR into the passed buffer and retrieves the number of monsters that can be used in a mission.\n\nr0: buffer\nreturn: Number of monsters usable for a mission",
        None,
    )

    GenerateAllPossibleMonstersList = Symbol(
        [0x5FAD4],
        [0x205FAD4],
        None,
        "GenerateAllPossibleMonstersList",
        "Attempts to add monster IDs 1 (Bulbasaur) through 535 (Shaymin Sky) as entries to a heap-allocated list.\n\nIf no monsters are valid mission targets, the heap-allocated list is freed. Otherwise, sets MISSION_MONSTER_LIST_PTR and MISSION_MONSTER_COUNT.\n\nreturn: Number of monsters usable for a mission",
        None,
    )

    DeleteAllPossibleMonstersList = Symbol(
        [0x5FB40],
        [0x205FB40],
        None,
        "DeleteAllPossibleMonstersList",
        "If MISSION_MONSTER_LIST_PTR is not null, frees its heap-allocated list and nulls MISSION_MONSTER_LIST_PTR and MISSION_MONSTER_COUNT.\n\nNo params.",
        None,
    )

    GenerateAllPossibleDungeonsList = Symbol(
        [0x5FB70],
        [0x205FB70],
        None,
        "GenerateAllPossibleDungeonsList",
        "Attempts to add dungeon IDs 1 (DUNGEON_TEST_DUNGEON) through 179 (DUNGEON_RESCUE) as entries to a heap-allocated list.\n\nIf no dungeons are valid mission targets, the heap-allocated list is freed. Otherwise, sets MISSION_DUNGEON_LIST_PTR and MISSION_DUNGEON_COUNT.\n\nreturn: Number of dungeons usable for a mission",
        None,
    )

    DeleteAllPossibleDungeonsList = Symbol(
        [0x5FC1C],
        [0x205FC1C],
        None,
        "DeleteAllPossibleDungeonsList",
        "If MISSION_DUNGEON_LIST_PTR is not null, frees its heap-allocated list and nulls MISSION_DUNGEON_LIST_PTR and MISSION_DUNGEON_COUNT.\n\nNo params.",
        None,
    )

    GenerateAllPossibleDeliverList = Symbol(
        [0x5FC4C],
        [0x205FC4C],
        None,
        "GenerateAllPossibleDeliverList",
        "Attempts to add all items in ITEM_DELIVERY_TABLE as entries to a heap-allocated list.\n\nIf no items are valid for a delivery mission, the heap-allocated list is freed. Otherwise, sets MISSION_DELIVER_LIST_PTR and MISSION_DELIVER_COUNT.\n\nreturn: Number of deliverable items for a mission",
        None,
    )

    DeleteAllPossibleDeliverList = Symbol(
        [0x5FC88],
        [0x205FC88],
        None,
        "DeleteAllPossibleDeliverList",
        "If MISSION_DELIVER_LIST_PTR is not null, frees its heap-allocated list and nulls MISSION_DELIVER_LIST_PTR and MISSION_DELIVER_COUNT.\n\nNo params.",
        None,
    )

    ClearMissionData = Symbol(
        [0x5FD34],
        [0x205FD34],
        None,
        "ClearMissionData",
        "Given a mission struct, clears some of it fields.\n\nIn particular, mission::status is set to mission_status::MISSION_STATUS_INVALID, mission::dungeon_id is set to -1, mission::floor is set to 0 and mission::reward_type is set to mission_reward_type::MISSION_REWARD_MONEY.\n\nr0: Pointer to the mission to clear",
        None,
    )

    IsMonsterMissionAllowed = Symbol(
        [0x62D90],
        [0x2062D90],
        None,
        "IsMonsterMissionAllowed",
        "Checks if the specified monster is contained in the MISSION_BANNED_MONSTERS array.\n\nThe function converts the ID by calling GetBaseForm and FemaleToMaleForm first.\n\nr0: Monster ID\nreturn: False if the monster ID (after converting it) is contained in MISSION_BANNED_MONSTERS, true if it isn't.",
        None,
    )

    CanMonsterBeUsedForMissionWrapper = Symbol(
        [0x62DD4],
        [0x2062DD4],
        None,
        "CanMonsterBeUsedForMissionWrapper",
        "Calls CanMonsterBeUsedForMission with r1 = 1.\n\nr0: Monster ID\nreturn: Result of CanMonsterBeUsedForMission",
        None,
    )

    CanMonsterBeUsedForMission = Symbol(
        [0x62DE4],
        [0x2062DE4],
        None,
        "CanMonsterBeUsedForMission",
        "Returns whether a certain monster can be used (probably as the client or as the target) when generating a mission.\n\nExcluded monsters include those that haven't been fought in dungeons yet, the second form of certain monsters and, if PERFOMANCE_PROGRESS_FLAG[9] is 0, monsters in MISSION_BANNED_STORY_MONSTERS, the species of the player and the species of the partner.\n\nr0: Monster ID\nr1: True to exclude monsters in the MISSION_BANNED_MONSTERS array, false to allow them\nreturn: True if the specified monster can be part of a mission",
        None,
    )

    IsMonsterMissionAllowedStory = Symbol(
        [0x62E60],
        [0x2062E60],
        None,
        "IsMonsterMissionAllowedStory",
        "Checks if the specified monster should be allowed to be part of a mission (probably as the client or the target), accounting for the progress on the story.\n\nIf PERFOMANCE_PROGRESS_FLAG[9] is true, the function returns true.\nIf it isn't, the function checks if the specified monster is contained in the MISSION_BANNED_STORY_MONSTERS array, or if it corresponds to the ID of the player or the partner.\n\nThe function converts the ID by calling GetBaseForm and FemaleToMaleForm first.\n\nr0: Monster ID\nreturn: True if PERFOMANCE_PROGRESS_FLAG[9] is true, false if it isn't and the monster ID (after converting it) is contained in MISSION_BANNED_STORY_MONSTERS or if it's the ID of the player or the partner, true otherwise.",
        None,
    )

    CanDungeonBeUsedForMission = Symbol(
        [0x62F34],
        [0x2062F34],
        None,
        "CanDungeonBeUsedForMission",
        "Returns whether a certain dungeon can be used when generating a mission.\n\nExcluded dungeons include DUNGEON_ICE_AEGIS_CAVE, DUNGEON_DESTINY_TOWER, all Special Episode dungeons, dungeons with IDs greater than 174 (DUNGEON_STAR_CAVE), DUNGEON_CRYSTAL_CAVE and DUNGEON_CRYSTAL_CROSSING if PERFORMANCE_PROGRESS_LIST[9] is false, and any dungeon that does not have a dungeon mode of DMODE_OPEN_AND_REQUEST.\n\nr0: Dungeon ID\nreturn: True if the specified dungeon can be part of a mission",
        None,
    )

    CanSendItem = Symbol(
        [0x63158],
        [0x2063158],
        None,
        "CanSendItem",
        "Returns whether a certain item can be sent to another player via Wonder Mail.\n\nr0: item ID\nr1: to_sky\nreturn: bool",
        None,
    )

    IsAvailableItem = Symbol(
        [0x637D8],
        [0x20637D8],
        None,
        "IsAvailableItem",
        "Checks if a certain item is valid to be used in delivery missions. \n\nValidity entails a loop throughout all dungeons, checking if they have been visited before (via a call to GetMaxReachedFloor), and checking if the item is available within a dungeon's group (via a call to IsItemAvailableInDungeonGroup).\n\nr0: item ID\nreturn: bool",
        None,
    )

    GetAvailableItemDeliveryList = Symbol(
        [0x63824],
        [0x2063824],
        None,
        "GetAvailableItemDeliveryList",
        "Iterates through ITEM_DELIVERY_TABLE and checks if each entry is valid to be used in delivery missions.\n\nr0: item_buffer\nreturn: Number of deliverable items for a mission",
        None,
    )

    GetActorMatchingStorageId = Symbol(
        [0x65D14],
        [0x2065D14],
        None,
        "GetActorMatchingStorageId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: actor_id\nreturn: storage ID",
        None,
    )

    SetActorTalkMainAndActorTalkSub = Symbol(
        [0x65EB8],
        [0x2065EB8],
        None,
        "SetActorTalkMainAndActorTalkSub",
        "Sets ACTOR_TALK_MAIN and ACTOR_TALK_SUB to given actor IDs.\n\nr0: actor_id for ACTOR_TALK_MAIN\nr1: actor_id for ACTOR_TALK_SUB",
        None,
    )

    SetActorTalkMain = Symbol(
        [0x65ECC],
        [0x2065ECC],
        None,
        "SetActorTalkMain",
        "Sets ACTOR_TALK_MAIN to be actor_id.\nImplements SPECIAL_PROC_SET_ACTOR_TALK_MAIN (see ScriptSpecialProcessCall).\n\nr0: actor_id",
        None,
    )

    SetActorTalkSub = Symbol(
        [0x65EDC],
        [0x2065EDC],
        None,
        "SetActorTalkSub",
        "Sets ACTOR_TALK_SUB to be actor_id.\nImplements SPECIAL_PROC_SET_ACTOR_TALK_SUB (see ScriptSpecialProcessCall).\n\nr0: actor_id",
        None,
    )

    RandomizeDemoActors = Symbol(
        [0x65FC4],
        [0x2065FC4],
        None,
        "RandomizeDemoActors",
        "Randomly picks one of the 18 teams from DEMO_TEAMS and sets ENTITY_NPC_DEMO_HERO and ENTITY_NPC_DEMO_PARTNER\nto the randomly selected hero and partner.\nImplements SPECIAL_PROC_RANDOMIZE_DEMO_ACTORS (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    ItemAtTableIdx = Symbol(
        [0x66074],
        [0x2066074],
        None,
        "ItemAtTableIdx",
        "Gets info about the item at a given item table (not sure what this table is...) index.\n\nUsed by SPECIAL_PROC_COUNT_TABLE_ITEM_TYPE_IN_BAG and friends (see ScriptSpecialProcessCall).\n\nr0: table index\nr1: [output] pointer to an owned_item",
        None,
    )

    MainLoop = Symbol(
        [0x66098],
        [0x2066098],
        None,
        "MainLoop",
        "This function gets called shortly after the game is started. Contains a single infinite loop and has no return statement.\n\nNo params.",
        None,
    )

    CreateJobSummary = Symbol(
        [0x69B98],
        [0x2069B98],
        None,
        "CreateJobSummary",
        "Creates a window containing a summary of a specific mission on the Top Screen.\n\nr0: mission pointer\nr1: ?",
        None,
    )

    DungeonSwapIdToIdx = Symbol(
        [0x6AAAC],
        [0x206AAAC],
        None,
        "DungeonSwapIdToIdx",
        "Converts a dungeon ID to its corresponding index in DUNGEON_SWAP_ID_TABLE, or -1 if not found.\n\nr0: dungeon ID\nreturn: index",
        None,
    )

    DungeonSwapIdxToId = Symbol(
        [0x6AAE8],
        [0x206AAE8],
        None,
        "DungeonSwapIdxToId",
        "Converts an index in DUNGEON_SWAP_ID_TABLE to the corresponding dungeon ID, or DUNGEON_DUMMY_0xFF if the index is -1.\n\nr0: index\nreturn: dungeon ID",
        None,
    )

    GetDungeonModeSpecial = Symbol(
        [0x6AB04],
        [0x206AB04],
        None,
        "GetDungeonModeSpecial",
        "Returns the status of the given dungeon, with some modifications.\n\nIf the dungeon ID is DUNGEON_BEACH, returns DMODE_REQUEST.\nIf it's DUNGEON_JOINED_AT_UNKNOWN, returns DMODE_OPEN_AND_REQUEST.\nIf it's >= DUNGEON_NORMAL_FLY_MAZE and <= DUNGEON_DOJO_0xD3, returns DMODE_OPEN_AND_REQUEST.\nElse, calls GetDungeonMode and returns DMODE_REQUEST if the dungeon has been cleared, or DMODE_OPEN if it's not.\n\nr0: Dungeon ID\nreturn: Dungeon mode",
        None,
    )

    FileRom_InitDataTransfer = _Deprecated("FileRom_InitDataTransfer", DataTransferInit)

    FileRom_StopDataTransfer = _Deprecated("FileRom_StopDataTransfer", DataTransferStop)

    FileRom_Veneer_FileInit = _Deprecated("FileRom_Veneer_FileInit", FileInitVeneer)

    FileRom_HandleOpen = _Deprecated("FileRom_HandleOpen", FileOpen)

    FileRom_HandleRead = _Deprecated("FileRom_HandleRead", FileRead)

    FileRom_HandleSeek = _Deprecated("FileRom_HandleSeek", FileSeek)

    Debug_Init = _Deprecated("Debug_Init", InitDebug)

    Debug_InitDebugFlag = _Deprecated("Debug_InitDebugFlag", InitDebugFlag)

    Debug_GetDebugFlag = _Deprecated("Debug_GetDebugFlag", GetDebugFlag)

    Debug_SetDebugFlag = _Deprecated("Debug_SetDebugFlag", SetDebugFlag)

    Debug_Stripped6 = _Deprecated("Debug_Stripped6", InitDebugStripped6)

    Debug_Stripped5 = _Deprecated("Debug_Stripped5", InitDebugStripped5)

    Debug_PrintTrace = _Deprecated("Debug_PrintTrace", DebugPrintTrace)

    Debug_Print0 = _Deprecated("Debug_Print0", DebugPrint0)

    Debug_InitLogFlag = _Deprecated("Debug_InitLogFlag", InitDebugLogFlag)

    Debug_GetLogFlag = _Deprecated("Debug_GetLogFlag", GetDebugLogFlag)

    Debug_SetLogFlag = _Deprecated("Debug_SetLogFlag", SetDebugLogFlag)

    Debug_Print = _Deprecated("Debug_Print", DebugPrint)

    Debug_Stripped4 = _Deprecated("Debug_Stripped4", InitDebugStripped4)

    Debug_Stripped3 = _Deprecated("Debug_Stripped3", InitDebugStripped3)

    Debug_Stripped2 = _Deprecated("Debug_Stripped2", InitDebugStripped2)

    Debug_Stripped1 = _Deprecated("Debug_Stripped1", InitDebugStripped1)

    Debug_FatalError = _Deprecated("Debug_FatalError", FatalError)

    DirectoryFileMngr_ExtractAllDirectoryFiles = _Deprecated(
        "DirectoryFileMngr_ExtractAllDirectoryFiles", OpenAllPackFiles
    )

    DirectoryFileMngr_GetDirectoryFileSize = _Deprecated(
        "DirectoryFileMngr_GetDirectoryFileSize", GetFileLengthInPackWithPackNb
    )

    DirectoryFileMngr_LoadDirectoryFile = _Deprecated(
        "DirectoryFileMngr_LoadDirectoryFile", LoadFileInPackWithPackId
    )

    DirectoryFileMngr_OpenDirectoryFile = _Deprecated(
        "DirectoryFileMngr_OpenDirectoryFile", AllocAndLoadFileInPack
    )

    DirectoryFile_ExtractDirectoryFile = _Deprecated(
        "DirectoryFile_ExtractDirectoryFile", OpenPackFile
    )

    DirectoryFile_GetDirectoryFileSize = _Deprecated(
        "DirectoryFile_GetDirectoryFileSize", GetFileLengthInPack
    )

    DirectoryFile_LoadDirectoryFile = _Deprecated(
        "DirectoryFile_LoadDirectoryFile", LoadFileInPack
    )

    GetLowKickMultiplier = _Deprecated("GetLowKickMultiplier", GetWeightMultiplier)


class EuArm9Data:

    SECURE = Symbol(
        [0x0],
        [0x2000000],
        0x800,
        "SECURE",
        "The header of the DS cartridge secure area. See https://problemkaputt.de/gbatek.htm#dscartridgesecurearea",
        "",
    )

    START_MODULE_PARAMS = Symbol(
        [0xBA0],
        [0x2000BA0],
        0xCC,
        "START_MODULE_PARAMS",
        "Parameters used by the NitroSDK to read the ROM.",
        "struct start_module_params*",
    )

    DEFAULT_MEMORY_ARENA_SIZE = Symbol(
        [0xE58],
        [0x2000E58],
        0x4,
        "DEFAULT_MEMORY_ARENA_SIZE",
        "Length in bytes of the default memory allocation arena, 1991680.",
        "uint32_t",
    )

    LOG_MAX_ARG = Symbol(
        None,
        None,
        None,
        "LOG_MAX_ARG",
        "The maximum argument value for the Log function, 2047.",
        "int",
    )

    DAMAGE_SOURCE_CODE_ORB_ITEM = Symbol(
        None,
        None,
        None,
        "DAMAGE_SOURCE_CODE_ORB_ITEM",
        "The damage source value for any item in CATEGORY_ORBS, 0x262.",
        "enum damage_source_non_move",
    )

    DAMAGE_SOURCE_CODE_NON_ORB_ITEM = Symbol(
        None,
        None,
        None,
        "DAMAGE_SOURCE_CODE_NON_ORB_ITEM",
        "The damage source value for any item not in CATEGORY_ORBS, 0x263.",
        "enum damage_source_non_move",
    )

    AURA_BOW_ID_LAST = Symbol(
        [0xCCBC],
        [0x200CCBC],
        0x4,
        "AURA_BOW_ID_LAST",
        "Highest item ID of the aura bows.",
        "enum item_id",
    )

    NUMBER_OF_ITEMS = Symbol(
        [0xE88C, 0xE930],
        [0x200E88C, 0x200E930],
        0x4,
        "NUMBER_OF_ITEMS",
        "Number of items in the game.",
        "uint32_t",
    )

    MAX_MONEY_CARRIED = Symbol(
        [0xEDF8],
        [0x200EDF8],
        0x4,
        "MAX_MONEY_CARRIED",
        "Maximum amount of money the player can carry, 99999.",
        "uint32_t",
    )

    MAX_MONEY_STORED = Symbol(
        [0x107F8],
        [0x20107F8],
        0x4,
        "MAX_MONEY_STORED",
        "Maximum amount of money the player can store in the Duskull Bank, 9999999.",
        "uint32_t",
    )

    WINDOW_LIST_PTR = Symbol(
        None,
        None,
        None,
        "WINDOW_LIST_PTR",
        "Hard-coded pointer to WINDOW_LIST.",
        "struct window_list*",
    )

    SCRIPT_VARS_VALUES_PTR = Symbol(
        [0x4B630, 0x4B81C, 0x4C764, 0x4C7BC],
        [0x204B630, 0x204B81C, 0x204C764, 0x204C7BC],
        0x4,
        "SCRIPT_VARS_VALUES_PTR",
        "Hard-coded pointer to SCRIPT_VARS_VALUES.",
        "struct script_var_value_table*",
    )

    MAX_PLAY_TIME = Symbol(
        [0x51188],
        [0x2051188],
        0x4,
        "MAX_PLAY_TIME",
        "Maximum number of seconds that the file timer counts up to.\n\n35999999 seconds (one second under 10000 hours).",
        "uint32_t",
    )

    MONSTER_ID_LIMIT = Symbol(
        [0x54818],
        [0x2054818],
        0x4,
        "MONSTER_ID_LIMIT",
        "One more than the maximum valid monster ID (0x483).",
        "uint32_t",
    )

    MAX_RECRUITABLE_TEAM_MEMBERS = Symbol(
        [0x555B4, 0x559C8],
        [0x20555B4, 0x20559C8],
        0x4,
        "MAX_RECRUITABLE_TEAM_MEMBERS",
        "555, appears to be the maximum number of members recruited to an exploration team, at least for the purposes of some checks that need to iterate over all team members.",
        "uint32_t",
    )

    NATURAL_LOG_VALUE_TABLE = Symbol(
        [0x917E0],
        [0x20917E0],
        None,
        "NATURAL_LOG_VALUE_TABLE",
        "A table of values for the natural log function corresponding to integer arguments in the range [0, 2047].\n\nEach value is stored as a 16-bit fixed-point number with 12 fractional bits. I.e., to get the actual natural log value, take the table entry and divide it by 2^12.\n\nThe value at an input of 0 is just listed as 0; the Log function makes sure the input is always at least 1 before reading the table.\n\ntype: fx16_12[2048]",
        "fx16_12[2048]",
    )

    CART_REMOVED_IMG_DATA = Symbol(
        [0x92EE4], [0x2092EE4], 0x2000, "CART_REMOVED_IMG_DATA", "", "undefined[0]"
    )

    STRING_DEBUG_EMPTY = Symbol(
        [0x94EF8], [0x2094EF8], None, "STRING_DEBUG_EMPTY", "", "char[4]"
    )

    STRING_DEBUG_FORMAT_LINE_FILE = Symbol(
        [0x94EFC], [0x2094EFC], None, "STRING_DEBUG_FORMAT_LINE_FILE", "", "char[28]"
    )

    STRING_DEBUG_NO_PROG_POS = Symbol(
        [0x94F18], [0x2094F18], None, "STRING_DEBUG_NO_PROG_POS", "", "char[24]"
    )

    STRING_DEBUG_SPACED_PRINT = Symbol(
        [0x94F30], [0x2094F30], None, "STRING_DEBUG_SPACED_PRINT", "", "char[12]"
    )

    STRING_DEBUG_FATAL = Symbol(
        [0x94F3C], [0x2094F3C], None, "STRING_DEBUG_FATAL", "", "char[20]"
    )

    STRING_DEBUG_NEWLINE = Symbol(
        [0x94F50], [0x2094F50], None, "STRING_DEBUG_NEWLINE", "", "char[4]"
    )

    STRING_DEBUG_LOG_NULL = Symbol(
        [0x94F54], [0x2094F54], None, "STRING_DEBUG_LOG_NULL", "", "char[8]"
    )

    STRING_DEBUG_STRING_NEWLINE = Symbol(
        [0x94F5C], [0x2094F5C], None, "STRING_DEBUG_STRING_NEWLINE", "", "char[4]"
    )

    STRING_EFFECT_EFFECT_BIN = Symbol(
        [0x94F60], [0x2094F60], None, "STRING_EFFECT_EFFECT_BIN", "", "char[20]"
    )

    STRING_MONSTER_MONSTER_BIN = Symbol(
        [0x94F74], [0x2094F74], None, "STRING_MONSTER_MONSTER_BIN", "", "char[20]"
    )

    STRING_BALANCE_M_LEVEL_BIN = Symbol(
        [0x94F88], [0x2094F88], None, "STRING_BALANCE_M_LEVEL_BIN", "", "char[20]"
    )

    STRING_DUNGEON_DUNGEON_BIN = Symbol(
        [0x94F9C], [0x2094F9C], None, "STRING_DUNGEON_DUNGEON_BIN", "", "char[20]"
    )

    STRING_MONSTER_M_ATTACK_BIN = Symbol(
        [0x94FB0], [0x2094FB0], None, "STRING_MONSTER_M_ATTACK_BIN", "", "char[24]"
    )

    STRING_MONSTER_M_GROUND_BIN = Symbol(
        [0x94FC8], [0x2094FC8], None, "STRING_MONSTER_M_GROUND_BIN", "", "char[24]"
    )

    STRING_FILE_DIRECTORY_INIT = Symbol(
        [0x94FE0], [0x2094FE0], None, "STRING_FILE_DIRECTORY_INIT", "", "char[40]"
    )

    AVAILABLE_ITEMS_IN_GROUP_TABLE = Symbol(
        [0x95130],
        [0x2095130],
        0x3200,
        "AVAILABLE_ITEMS_IN_GROUP_TABLE",
        "100*0x80\nLinked to the dungeon group id\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    ARM9_UNKNOWN_TABLE__NA_2097FF8 = Symbol(
        [0x98444],
        [0x2098444],
        0x40,
        "ARM9_UNKNOWN_TABLE__NA_2097FF8",
        "16*0x4 (0x2+0x2)\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    KECLEON_SHOP_ITEM_TABLE_LISTS_1 = Symbol(
        [0x98504],
        [0x2098504],
        0x10,
        "KECLEON_SHOP_ITEM_TABLE_LISTS_1",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: enum item_id[4]",
        "enum item_id[4]",
    )

    KECLEON_SHOP_ITEM_TABLE_LISTS_2 = Symbol(
        [0x98514],
        [0x2098514],
        0x10,
        "KECLEON_SHOP_ITEM_TABLE_LISTS_2",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: enum item_id[4]",
        "enum item_id[4]",
    )

    EXCLUSIVE_ITEM_STAT_BOOST_DATA = Symbol(
        [0x9852C],
        [0x209852C],
        0x3C,
        "EXCLUSIVE_ITEM_STAT_BOOST_DATA",
        "Contains stat boost effects for different exclusive item classes.\n\nEach 4-byte entry contains the boost data for (attack, defense, special attack, special defense), 1 byte each, for a specific exclusive item class, indexed according to the stat boost data index list.\n\ntype: struct exclusive_item_stat_boost_entry[15]",
        "struct exclusive_item_stat_boost_entry[15]",
    )

    EXCLUSIVE_ITEM_DEFENSE_BOOSTS = Symbol(
        [0x9852D],
        [0x209852D],
        0x39,
        "EXCLUSIVE_ITEM_DEFENSE_BOOSTS",
        "EXCLUSIVE_ITEM_STAT_BOOST_DATA, offset by 1",
        "",
    )

    EXCLUSIVE_ITEM_SPECIAL_ATTACK_BOOSTS = Symbol(
        [0x9852E],
        [0x209852E],
        0x39,
        "EXCLUSIVE_ITEM_SPECIAL_ATTACK_BOOSTS",
        "EXCLUSIVE_ITEM_STAT_BOOST_DATA, offset by 2",
        "",
    )

    EXCLUSIVE_ITEM_SPECIAL_DEFENSE_BOOSTS = Symbol(
        [0x9852F],
        [0x209852F],
        0x39,
        "EXCLUSIVE_ITEM_SPECIAL_DEFENSE_BOOSTS",
        "EXCLUSIVE_ITEM_STAT_BOOST_DATA, offset by 3",
        "",
    )

    EXCLUSIVE_ITEM_EFFECT_DATA = Symbol(
        [0x98568],
        [0x2098568],
        0x778,
        "EXCLUSIVE_ITEM_EFFECT_DATA",
        "Contains special effects for each exclusive item.\n\nEach entry is 2 bytes, with the first entry corresponding to the first exclusive item (Prism Ruff). The first byte is the exclusive item effect ID, and the second byte is an index into other data tables (related to the more generic stat boosting effects for specific monsters).\n\ntype: struct exclusive_item_effect_entry[956]",
        "struct exclusive_item_effect_entry[956]",
    )

    EXCLUSIVE_ITEM_STAT_BOOST_DATA_INDEXES = Symbol(
        [0x98569],
        [0x2098569],
        0x777,
        "EXCLUSIVE_ITEM_STAT_BOOST_DATA_INDEXES",
        "EXCLUSIVE_ITEM_EFFECT_DATA, offset by 1",
        "",
    )

    RECYCLE_SHOP_ITEM_LIST = Symbol(
        [0x98D10],
        [0x2098D10],
        0x360,
        "RECYCLE_SHOP_ITEM_LIST",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    TYPE_SPECIFIC_EXCLUSIVE_ITEMS = Symbol(
        [0x99070],
        [0x2099070],
        0x88,
        "TYPE_SPECIFIC_EXCLUSIVE_ITEMS",
        "Lists of type-specific exclusive items (silk, dust, gem, globe) for each type.\n\ntype: struct item_id_16[17][4]",
        "struct item_id_16[17][4]",
    )

    RECOIL_MOVE_LIST = Symbol(
        [0x991B8],
        [0x20991B8],
        0x16,
        "RECOIL_MOVE_LIST",
        "Null-terminated list of all the recoil moves, as 2-byte move IDs.\n\ntype: struct move_id_16[11]",
        "struct move_id_16[11]",
    )

    PUNCH_MOVE_LIST = Symbol(
        [0x991CE],
        [0x20991CE],
        0x20,
        "PUNCH_MOVE_LIST",
        "Null-terminated list of all the punch moves, as 2-byte move IDs.\n\ntype: struct move_id_16[16]",
        "struct move_id_16[16]",
    )

    MOVE_POWER_STARS_TABLE = Symbol(
        [0x9A150],
        [0x209A150],
        None,
        "MOVE_POWER_STARS_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int[6]",
        "int[6]",
    )

    MOVE_ACCURACY_STARS_TABLE = Symbol(
        [0x9A168],
        [0x209A168],
        None,
        "MOVE_ACCURACY_STARS_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int[8]",
        "int[8]",
    )

    PARENT_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B3CC],
        [0x209B3CC],
        None,
        "PARENT_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a simple_menu created with CreateParentMenuInternal.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateParentMenuInternal.\n\nAdditionally, width and height are 0, and will be computed in CreateParentMenuInternal.",
        "struct window_params",
    )

    SIMPLE_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B3DC],
        [0x209B3DC],
        None,
        "SIMPLE_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a simple_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateSimpleMenuInternal.\n\nAdditionally, width and height are 0, and will be computed in CreateSimpleMenuInternal.",
        "struct window_params",
    )

    ADVANCED_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B3EC],
        [0x209B3EC],
        None,
        "ADVANCED_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an advanced_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateAdvancedMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateAdvancedMenu.",
        "struct window_params",
    )

    COLLECTION_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B3FC],
        [0x209B3FC],
        None,
        "COLLECTION_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a collection_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateCollectionMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateCollectionMenu.",
        "struct window_params",
    )

    OPTIONS_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B40C],
        [0x209B40C],
        None,
        "OPTIONS_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an options_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateOptionsMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateOptionsMenu.",
        "struct window_params",
    )

    DEBUG_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B448],
        [0x209B448],
        None,
        "DEBUG_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a debug_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateDebugMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateDebugMenu.",
        "struct window_params",
    )

    SCROLL_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B458],
        [0x209B458],
        None,
        "SCROLL_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a scroll_box.",
        "struct window_params",
    )

    DIALOGUE_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B468],
        [0x209B468],
        None,
        "DIALOGUE_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a dialogue_box.",
        "struct window_params",
    )

    PORTRAIT_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B478],
        [0x209B478],
        None,
        "PORTRAIT_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a portrait_box.\n\nNote that the screen and box type are unset, and are determined in CreatePortraitBox.",
        "struct window_params",
    )

    TEXT_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B488],
        [0x209B488],
        None,
        "TEXT_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a text_box.",
        "struct window_params",
    )

    AREA_NAME_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B498],
        [0x209B498],
        None,
        "AREA_NAME_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an area_name_box.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateAreaNameBox.\n\nAdditionally, width and height are 0, and will be computed in CreateAreaNameBox.",
        "struct window_params",
    )

    CONTROLS_CHART_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B4B4],
        [0x209B4B4],
        None,
        "CONTROLS_CHART_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a controls_chart.",
        "struct window_params",
    )

    ALERT_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B4D0],
        [0x209B4D0],
        None,
        "ALERT_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an alert_box.",
        "struct window_params",
    )

    ADVANCED_TEXT_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B4E0],
        [0x209B4E0],
        None,
        "ADVANCED_TEXT_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an advanced_text_box.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateAdvancedTextBoxInternal.",
        "struct window_params",
    )

    TEAM_SELECTION_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x9B4F0],
        [0x209B4F0],
        None,
        "TEAM_SELECTION_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a team_selection_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateTeamSelectionMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateTeamSelectionMenu.",
        "struct window_params",
    )

    PARTNER_TALK_KIND_TABLE = Symbol(
        [0x9D268],
        [0x209D268],
        0x58,
        "PARTNER_TALK_KIND_TABLE",
        "Table of values for the PARTNER_TALK_KIND script variable.\n\ntype: struct partner_talk_kind_table_entry[11]",
        "struct partner_talk_kind_table_entry[11]",
    )

    SCRIPT_VARS_LOCALS = Symbol(
        [0x9D450],
        [0x209D450],
        0x40,
        "SCRIPT_VARS_LOCALS",
        "List of special 'local' variables available to the script engine. There are 4 16-byte entries.\n\nEach entry has the same structure as an entry in SCRIPT_VARS.\n\ntype: struct script_local_var_table",
        "struct script_local_var_table",
    )

    SCRIPT_VARS = Symbol(
        [0x9DDF4],
        [0x209DDF4],
        0x730,
        "SCRIPT_VARS",
        "List of predefined global variables that track game state, which are available to the script engine. There are 115 16-byte entries.\n\nThese variables underpin the various ExplorerScript global variables you can use in the SkyTemple SSB debugger.\n\ntype: struct script_var_table",
        "struct script_var_table",
    )

    PORTRAIT_LAYOUTS = Symbol(
        [0x9E598],
        [0x209E598],
        0xC0,
        "PORTRAIT_LAYOUTS",
        "All the possible layouts a portrait can be placed in by default.\n\ntype: struct portrait_layout[32]",
        "struct portrait_layout[32]",
    )

    KAOMADO_FILEPATH = Symbol(
        [0x9E658],
        [0x209E658],
        None,
        "KAOMADO_FILEPATH",
        "'Path of the file where all the portraits are stored. 'FONT/kaomado.kao', padded with null to a multiple of 4'\n\ntype: char[20]",
        "char[20]",
    )

    WONDER_MAIL_BITS_MAP = Symbol(
        [0x9E66C],
        [0x209E66C],
        0x20,
        "WONDER_MAIL_BITS_MAP",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: uint8_t[32]",
        "uint8_t[32]",
    )

    WONDER_MAIL_BITS_SWAP = Symbol(
        [0x9E68C],
        [0x209E68C],
        0x24,
        "WONDER_MAIL_BITS_SWAP",
        "Last 2 bytes are unused\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: uint8_t[36]",
        "uint8_t[36]",
    )

    ARM9_UNKNOWN_TABLE__NA_209E12C = Symbol(
        [0x9E6B0],
        [0x209E6B0],
        0x38,
        "ARM9_UNKNOWN_TABLE__NA_209E12C",
        "52*0x2 + 2 bytes unused\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    ARM9_UNKNOWN_TABLE__NA_209E164 = Symbol(
        [0x9E6E8],
        [0x209E6E8],
        0x100,
        "ARM9_UNKNOWN_TABLE__NA_209E164",
        "256*0x1\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    ARM9_UNKNOWN_TABLE__NA_209E280 = Symbol(
        [0x9E804],
        [0x209E804],
        0x20,
        "ARM9_UNKNOWN_TABLE__NA_209E280",
        "32*0x1\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    WONDER_MAIL_ENCRYPTION_TABLE = Symbol(
        [0x9E824],
        [0x209E824],
        0x100,
        "WONDER_MAIL_ENCRYPTION_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: uint8_t[256]",
        "uint8_t[256]",
    )

    DUNGEON_DATA_LIST = Symbol(
        [0x9E924],
        [0x209E924],
        0x2D0,
        "DUNGEON_DATA_LIST",
        "Data about every dungeon in the game.\n\nThis is an array of 180 dungeon data list entry structs. Each entry is 4 bytes, and contains floor count information along with an index into the bulk of the dungeon's data in mappa_s.bin.\n\nSee the struct definitions and Frostbyte's dungeon data document for more info.\n\ntype: struct dungeon_data_list_entry[180]",
        "struct dungeon_data_list_entry[180]",
    )

    ADVENTURE_LOG_ENCOUNTERS_MONSTER_IDS = Symbol(
        [0x9EBF4],
        [0x209EBF4],
        0x4C,
        "ADVENTURE_LOG_ENCOUNTERS_MONSTER_IDS",
        "List of monster IDs with a corresponding milestone in the Adventure Log.\n\ntype: struct monster_id_16[38]",
        "struct monster_id_16[38]",
    )

    ARM9_UNKNOWN_DATA__NA_209E6BC = Symbol(
        [0x9EC40],
        [0x209EC40],
        0x4,
        "ARM9_UNKNOWN_DATA__NA_209E6BC",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    TACTIC_NAME_STRING_IDS = Symbol(
        [0x9EC44],
        [0x209EC44],
        0x18,
        "TACTIC_NAME_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[12]",
        "int16_t[12]",
    )

    STATUS_NAME_STRING_IDS = Symbol(
        [0x9EC5C],
        [0x209EC5C],
        0xCC,
        "STATUS_NAME_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[102]",
        "int16_t[102]",
    )

    DUNGEON_RETURN_STATUS_TABLE = Symbol(
        [0x9ED28],
        [0x209ED28],
        0x16C,
        "DUNGEON_RETURN_STATUS_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct dungeon_return_status[91]",
        "struct dungeon_return_status[91]",
    )

    STATUSES_FULL_DESCRIPTION_STRING_IDS = Symbol(
        [0x9EE94],
        [0x209EE94],
        0x19C,
        "STATUSES_FULL_DESCRIPTION_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct status_description[103]",
        "struct status_description[103]",
    )

    ARM9_UNKNOWN_DATA__NA_209EAAC = Symbol(
        [0x9F030],
        [0x209F030],
        0x4,
        "ARM9_UNKNOWN_DATA__NA_209EAAC",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_FLOOR_RANKS_AND_ITEM_LISTS_1 = Symbol(
        [0x9F034],
        [0x209F034],
        0xC64,
        "MISSION_FLOOR_RANKS_AND_ITEM_LISTS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_FLOORS_FORBIDDEN = Symbol(
        [0x9FC98],
        [0x209FC98],
        0xC8,
        "MISSION_FLOORS_FORBIDDEN",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct mission_floors_forbidden[100]",
        "struct mission_floors_forbidden[100]",
    )

    MISSION_FLOOR_RANKS_AND_ITEM_LISTS_2 = Symbol(
        [0x9FD60],
        [0x209FD60],
        0x12F8,
        "MISSION_FLOOR_RANKS_AND_ITEM_LISTS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_FLOOR_RANKS_PTRS = Symbol(
        [0xA1058],
        [0x20A1058],
        0x190,
        "MISSION_FLOOR_RANKS_PTRS",
        "Uses MISSION_FLOOR_RANKS_AND_ITEM_LISTS\n\nNote: unverified, ported from Irdkwia's notes",
        "undefined*[100]",
    )

    DUNGEON_RESTRICTIONS = Symbol(
        [0xA11E8],
        [0x20A11E8],
        0xC00,
        "DUNGEON_RESTRICTIONS",
        "Data related to dungeon restrictions for every dungeon in the game.\n\nThis is an array of 256 dungeon restriction structs. Each entry is 12 bytes, and contains information about restrictions within the given dungeon.\n\nSee the struct definitions and Frostbyte's dungeon data document for more info.\n\ntype: struct dungeon_restriction[256]",
        "struct dungeon_restriction[256]",
    )

    SPECIAL_BAND_STAT_BOOST = Symbol(
        [0xA1DF0],
        [0x20A1DF0],
        0x2,
        "SPECIAL_BAND_STAT_BOOST",
        "Stat boost value for the Special Band.",
        "int16_t",
    )

    MUNCH_BELT_STAT_BOOST = Symbol(
        [0xA1E00],
        [0x20A1E00],
        0x2,
        "MUNCH_BELT_STAT_BOOST",
        "Stat boost value for the Munch Belt.",
        "int16_t",
    )

    GUMMI_STAT_BOOST = Symbol(
        [0xA1E0C],
        [0x20A1E0C],
        0x2,
        "GUMMI_STAT_BOOST",
        "Stat boost value if a stat boost occurs when eating normal Gummis.",
        "int16_t",
    )

    MIN_IQ_EXCLUSIVE_MOVE_USER = Symbol(
        [0xA1E10],
        [0x20A1E10],
        0x4,
        "MIN_IQ_EXCLUSIVE_MOVE_USER",
        "Minimum IQ required for enemies to use Exclusive-Move User",
        "int32_t",
    )

    WONDER_GUMMI_IQ_GAIN = Symbol(
        [0xA1E14],
        [0x20A1E14],
        0x2,
        "WONDER_GUMMI_IQ_GAIN",
        "IQ gain when ingesting wonder gummis.",
        "int16_t",
    )

    AURA_BOW_STAT_BOOST = Symbol(
        [0xA1E1C],
        [0x20A1E1C],
        0x2,
        "AURA_BOW_STAT_BOOST",
        "Stat boost value for the aura bows.",
        "int16_t",
    )

    MIN_IQ_ITEM_MASTER = Symbol(
        [0xA1E28],
        [0x20A1E28],
        0x4,
        "MIN_IQ_ITEM_MASTER",
        "Minimum IQ required for enemies to use Item Master",
        "int32_t",
    )

    DEF_SCARF_STAT_BOOST = Symbol(
        [0xA1E2C],
        [0x20A1E2C],
        0x2,
        "DEF_SCARF_STAT_BOOST",
        "Stat boost value for the Defense Scarf.",
        "int16_t",
    )

    POWER_BAND_STAT_BOOST = Symbol(
        [0xA1E30],
        [0x20A1E30],
        0x2,
        "POWER_BAND_STAT_BOOST",
        "Stat boost value for the Power Band.",
        "int16_t",
    )

    WONDER_GUMMI_STAT_BOOST = Symbol(
        [0xA1E34],
        [0x20A1E34],
        0x2,
        "WONDER_GUMMI_STAT_BOOST",
        "Stat boost value if a stat boost occurs when eating Wonder Gummis.",
        "int16_t",
    )

    ZINC_BAND_STAT_BOOST = Symbol(
        [0xA1E38],
        [0x20A1E38],
        0x2,
        "ZINC_BAND_STAT_BOOST",
        "Stat boost value for the Zinc Band.",
        "int16_t",
    )

    EGG_HP_BONUS = Symbol(
        [0xA1E3C],
        [0x20A1E3C],
        0x2,
        "EGG_HP_BONUS",
        "Note: unverified, ported from Irdkwia's notes",
        "int16_t",
    )

    EVOLUTION_HP_BONUS = Symbol(
        [0xA1E48],
        [0x20A1E48],
        0x2,
        "EVOLUTION_HP_BONUS",
        "Note: unverified, ported from Irdkwia's notes",
        "int16_t",
    )

    DAMAGE_FORMULA_FLV_SHIFT = Symbol(
        [0xA1E50],
        [0x20A1E50],
        None,
        "DAMAGE_FORMULA_FLV_SHIFT",
        "The constant shift added to the 'FLV' intermediate quantity in the damage formula (see dungeon::last_move_damage_calc_flv), as a binary fixed-point number with 8 fraction bits (50).",
        "fx32_8",
    )

    EVOLUTION_PHYSICAL_STAT_BONUSES = Symbol(
        [0xA1E54],
        [0x20A1E54],
        0x4,
        "EVOLUTION_PHYSICAL_STAT_BONUSES",
        "0x2: Atk + 0x2: Def\n\nNote: unverified, ported from Irdkwia's notes",
        "int16_t[2]",
    )

    DAMAGE_FORMULA_CONSTANT_SHIFT = Symbol(
        [0xA1E58],
        [0x20A1E58],
        None,
        "DAMAGE_FORMULA_CONSTANT_SHIFT",
        "The constant shift applied to the overall output of the 'unshifted base' damage formula (the sum of the scaled AT, DEF, and ClampedLn terms), as a binary fixed-point number with 8 fraction bits (-311).\n\nThe value of -311 is notably equal to -round[DAMAGE_FORMULA_LN_PREFACTOR * ln(DAMAGE_FORMULA_LN_ARG_PREFACTOR * DAMAGE_FORMULA_FLV_SHIFT)]. This is probably not a coincidence.",
        "fx32_8",
    )

    DAMAGE_FORMULA_FLV_DEFICIT_DIVISOR = Symbol(
        [0xA1E5C],
        [0x20A1E5C],
        None,
        "DAMAGE_FORMULA_FLV_DEFICIT_DIVISOR",
        "The divisor of the (AT - DEF) term within the 'FLV' intermediate quantity in the damage formula (see dungeon::last_move_damage_calc_flv), as a binary fixed-point number with 8 fraction bits (8).",
        "fx32_8",
    )

    EGG_STAT_BONUSES = Symbol(
        [0xA1E60],
        [0x20A1E60],
        0x8,
        "EGG_STAT_BONUSES",
        "0x2: Atk + 0x2: SpAtk + 0x2: Def + 0x2: SpDef\n\nNote: unverified, ported from Irdkwia's notes",
        "int16_t[4]",
    )

    EVOLUTION_SPECIAL_STAT_BONUSES = Symbol(
        [0xA1E68],
        [0x20A1E68],
        0x4,
        "EVOLUTION_SPECIAL_STAT_BONUSES",
        "0x2: SpAtk + 0x2: SpDef\n\nNote: unverified, ported from Irdkwia's notes",
        "int16_t[2]",
    )

    DAMAGE_FORMULA_NON_TEAM_MEMBER_MODIFIER = Symbol(
        [0xA1E6C],
        [0x20A1E6C],
        None,
        "DAMAGE_FORMULA_NON_TEAM_MEMBER_MODIFIER",
        "The divisor applied to the overall output of the 'shifted base' damage formula (the sum of the scaled AT, Def, ClampedLn, and DAMAGE_FORMULA_CONSTANT_SHIFT terms) if the attacker is not a team member (and the current fixed room is not the substitute room...for some reason), as a binary fixed-point number with 8 fraction bits (85/64).",
        "fx32_8",
    )

    DAMAGE_FORMULA_LN_PREFACTOR = Symbol(
        [0xA1E70],
        [0x20A1E70],
        None,
        "DAMAGE_FORMULA_LN_PREFACTOR",
        "The prefactor to the output of the ClampedLn in the damage formula, as a binary fixed-point number with 8 fraction bits (50).",
        "fx32_8",
    )

    DAMAGE_FORMULA_DEF_PREFACTOR = Symbol(
        [0xA1E74],
        [0x20A1E74],
        None,
        "DAMAGE_FORMULA_DEF_PREFACTOR",
        "The prefactor to the 'DEF' (defense) intermediate quantity in the damage formula (see dungeon::last_move_damage_calc_def), as a binary fixed-point number with 8 fraction bits (-0.5).",
        "fx32_8",
    )

    DAMAGE_FORMULA_AT_PREFACTOR = Symbol(
        [0xA1E78],
        [0x20A1E78],
        None,
        "DAMAGE_FORMULA_AT_PREFACTOR",
        "The prefactor to the 'AT' (attack) intermediate quantity in the damage formula (see dungeon::last_move_damage_calc_at), as a binary fixed-point number with 8 fraction bits (153/256, which is close to 0.6).",
        "fx32_8",
    )

    DAMAGE_FORMULA_LN_ARG_PREFACTOR = Symbol(
        [0xA1E7C],
        [0x20A1E7C],
        None,
        "DAMAGE_FORMULA_LN_ARG_PREFACTOR",
        "The prefactor to the argument of ClampedLn in the damage formula (FLV + DAMAGE_FORMULA_FLV_SHIFT), as a binary fixed-point number with 8 fraction bits (10).",
        "fx32_8",
    )

    FORBIDDEN_FORGOT_MOVE_LIST = Symbol(
        [0xA1E9C],
        [0x20A1E9C],
        0x12,
        "FORBIDDEN_FORGOT_MOVE_LIST",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct forbidden_forgot_move_entry[3]",
        "struct forbidden_forgot_move_entry[3]",
    )

    TACTICS_UNLOCK_LEVEL_TABLE = Symbol(
        [0xA1EC4],
        [0x20A1EC4],
        0x18,
        "TACTICS_UNLOCK_LEVEL_TABLE",
        "type: int16_t[12]",
        "int16_t[12]",
    )

    CLIENT_LEVEL_TABLE = Symbol(
        [0xA1EFC],
        [0x20A1EFC],
        0x20,
        "CLIENT_LEVEL_TABLE",
        "Still a guess\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: int16_t[16]",
        "int16_t[16]",
    )

    OUTLAW_LEVEL_TABLE = Symbol(
        [0xA1F1C],
        [0x20A1F1C],
        0x20,
        "OUTLAW_LEVEL_TABLE",
        "Table of 2-byte outlaw levels for outlaw missions, indexed by mission rank.\n\ntype: int16_t[16]",
        "int16_t[16]",
    )

    OUTLAW_MINION_LEVEL_TABLE = Symbol(
        [0xA1F3C],
        [0x20A1F3C],
        0x20,
        "OUTLAW_MINION_LEVEL_TABLE",
        "Table of 2-byte outlaw minion levels for outlaw hideout missions, indexed by mission rank.\n\ntype: int16_t[16]",
        "int16_t[16]",
    )

    HIDDEN_POWER_BASE_POWER_TABLE = Symbol(
        [0xA1F5C],
        [0x20A1F5C],
        0x28,
        "HIDDEN_POWER_BASE_POWER_TABLE",
        "Still a guess\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: int[10]",
        "int[10]",
    )

    VERSION_EXCLUSIVE_MONSTERS = Symbol(
        [0xA1F84],
        [0x20A1F84],
        0x5C,
        "VERSION_EXCLUSIVE_MONSTERS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct version_exclusive_monster[23]",
        "struct version_exclusive_monster[23]",
    )

    IQ_SKILL_RESTRICTIONS = Symbol(
        [0xA1FE0],
        [0x20A1FE0],
        0x8A,
        "IQ_SKILL_RESTRICTIONS",
        "Table of 2-byte values for each IQ skill that represent a group. IQ skills in the same group can not be enabled at the same time.\n\ntype: int16_t[69]",
        "int16_t[69]",
    )

    SECONDARY_TERRAIN_TYPES = Symbol(
        [0xA206C],
        [0x20A206C],
        0xC8,
        "SECONDARY_TERRAIN_TYPES",
        "The type of secondary terrain for each dungeon in the game.\n\nThis is an array of 200 bytes. Each byte is an enum corresponding to one dungeon.\n\ntype: struct secondary_terrain_type_8[200]",
        "struct secondary_terrain_type_8[200]",
    )

    SENTRY_DUTY_MONSTER_IDS = Symbol(
        [0xA2134],
        [0x20A2134],
        0xCC,
        "SENTRY_DUTY_MONSTER_IDS",
        "Table of monster IDs usable in the sentry duty minigame.\n\ntype: struct monster_id_16[102]",
        "struct monster_id_16[102]",
    )

    IQ_SKILLS = Symbol(
        [0xA2200],
        [0x20A2200],
        0x114,
        "IQ_SKILLS",
        "Table of 4-byte values for each IQ skill that represent the required IQ value to unlock a skill.\n\ntype: int[69]",
        "int32_t[69]",
    )

    IQ_GROUP_SKILLS = Symbol(
        [0xA2314],
        [0x20A2314],
        0x190,
        "IQ_GROUP_SKILLS",
        "Irdkwia's notes: 25*16*0x1",
        "uint8_t[400]",
    )

    MONEY_QUANTITY_TABLE = Symbol(
        [0xA24A4],
        [0x20A24A4],
        0x190,
        "MONEY_QUANTITY_TABLE",
        "Table that maps money quantity codes (as recorded in, e.g., struct item) to actual amounts.\n\ntype: int[100]",
        "int[100]",
    )

    ARM9_UNKNOWN_TABLE__NA_20A20B0 = Symbol(
        [0xA2634],
        [0x20A2634],
        0x200,
        "ARM9_UNKNOWN_TABLE__NA_20A20B0",
        "256*0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    IQ_GUMMI_GAIN_TABLE = Symbol(
        [0xA2834],
        [0x20A2834],
        0x288,
        "IQ_GUMMI_GAIN_TABLE",
        "type: int16_t[18][18]",
        "int16_t[18][18]",
    )

    GUMMI_BELLY_RESTORE_TABLE = Symbol(
        [0xA2ABC],
        [0x20A2ABC],
        0x288,
        "GUMMI_BELLY_RESTORE_TABLE",
        "type: int16_t[18][18]",
        "int16_t[18][18]",
    )

    BAG_CAPACITY_TABLE_SPECIAL_EPISODES = Symbol(
        [0xA2D44],
        [0x20A2D44],
        0x14,
        "BAG_CAPACITY_TABLE_SPECIAL_EPISODES",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: uint32_t[5]",
        "uint32_t[5]",
    )

    BAG_CAPACITY_TABLE = Symbol(
        [0xA2D58],
        [0x20A2D58],
        0x20,
        "BAG_CAPACITY_TABLE",
        "Array of 4-byte integers containing the bag capacity for each bag level.\n\ntype: uint32_t[8]",
        "uint32_t[8]",
    )

    SPECIAL_EPISODE_MAIN_CHARACTERS = Symbol(
        [0xA2D78],
        [0x20A2D78],
        0xC8,
        "SPECIAL_EPISODE_MAIN_CHARACTERS",
        "type: struct monster_id_16[100]",
        "struct monster_id_16[100]",
    )

    GUEST_MONSTER_DATA = Symbol(
        [0xA2E40],
        [0x20A2E40],
        0x288,
        "GUEST_MONSTER_DATA",
        "Data for guest monsters that join you during certain story dungeons.\n\nArray of 18 36-byte entries.\n\nSee the struct definitions and Frostbyte's dungeon data document for more info.\n\ntype: struct guest_monster[18]",
        "struct guest_monster[18]",
    )

    RANK_UP_TABLE = Symbol(
        [0xA30C8],
        [0x20A30C8],
        0xD0,
        "RANK_UP_TABLE",
        "",
        "struct rankup_table_entry[13]",
    )

    DS_DOWNLOAD_TEAMS = Symbol(
        [0xA3198],
        [0x20A3198],
        0x70,
        "DS_DOWNLOAD_TEAMS",
        "Seems like this is just a collection of null-terminated lists concatenated together.\n\nNote: unverified, ported from Irdkwia's notes\n\nstruct monster_id_16[56]",
        "struct monster_id_16[56]",
    )

    ARM9_UNKNOWN_PTR__NA_20A2C84 = Symbol(
        [0xA3208],
        [0x20A3208],
        0x4,
        "ARM9_UNKNOWN_PTR__NA_20A2C84",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    UNOWN_SPECIES_ADDITIONAL_CHARS = Symbol(
        [0xA320C],
        [0x20A320C],
        0x80,
        "UNOWN_SPECIES_ADDITIONAL_CHARS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: enum monster_id[28]",
        "enum monster_id[28]",
    )

    MONSTER_SPRITE_DATA = Symbol(
        [0xA332C],
        [0x20A332C],
        0x4B0,
        "MONSTER_SPRITE_DATA",
        "Contains information about the sprite size and sprite file size of each monster",
        "struct monster_sprite_data_entry[600]",
    )

    REMOTE_STRINGS = Symbol(
        [0xA4140],
        [0x20A4140],
        0x2C,
        "REMOTE_STRINGS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    RANK_STRINGS_1 = Symbol(
        [0xA416C],
        [0x20A416C],
        0x30,
        "RANK_STRINGS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_MENU_STRING_IDS_1 = Symbol(
        [0xA419C],
        [0x20A419C],
        0x10,
        "MISSION_MENU_STRING_IDS_1",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[8]",
        "int16_t[8]",
    )

    RANK_STRINGS_2 = Symbol(
        [0xA41AC],
        [0x20A41AC],
        0x30,
        "RANK_STRINGS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_MENU_STRING_IDS_2 = Symbol(
        [0xA41DC],
        [0x20A41DC],
        0x10,
        "MISSION_MENU_STRING_IDS_2",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[8]",
        "int16_t[8]",
    )

    RANK_STRINGS_3 = Symbol(
        [0xA41EC],
        [0x20A41EC],
        0xB4,
        "RANK_STRINGS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_DUNGEON_UNLOCK_TABLE = Symbol(
        [0xA42AC],
        [0x20A42AC],
        0x6,
        "MISSION_DUNGEON_UNLOCK_TABLE",
        "Irdkwia's notes: SpecialDungeonMissions\n\ntype: struct dungeon_unlock_entry[3]",
        "struct dungeon_unlock_entry[3]",
    )

    NO_SEND_ITEM_TABLE = Symbol(
        [0xA42B2],
        [0x20A42B2],
        0x6,
        "NO_SEND_ITEM_TABLE",
        "A list of items that are forbidden from being used in a mission sent by Wonder Mail.\n\ntype: struct item_id_16[3]",
        "struct item_id_16[3]",
    )

    ARM9_UNKNOWN_TABLE__NA_20A3CC8 = Symbol(
        [0xA42C8],
        [0x20A42C8],
        0x1C,
        "ARM9_UNKNOWN_TABLE__NA_20A3CC8",
        "14*0x2\nLinked to ARM9_UNKNOWN_TABLE__NA_20A3CE4\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    ARM9_UNKNOWN_TABLE__NA_20A3CE4 = Symbol(
        [0xA42E4],
        [0x20A42E4],
        0x10,
        "ARM9_UNKNOWN_TABLE__NA_20A3CE4",
        "8*0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    ARM9_UNKNOWN_FUNCTION_TABLE__NA_20A3CF4 = Symbol(
        [0xA42F4],
        [0x20A42F4],
        0x20,
        "ARM9_UNKNOWN_FUNCTION_TABLE__NA_20A3CF4",
        "Could be related to missions\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    MISSION_BANNED_STORY_MONSTERS = Symbol(
        [0xA4314],
        [0x20A4314],
        0x2A,
        "MISSION_BANNED_STORY_MONSTERS",
        "Null-terminated list of monster IDs that can't be used (probably as clients or targets) when generating missions before a certain point in the story.\n\nTo be precise, PERFOMANCE_PROGRESS_FLAG[9] must be enabled so these monsters can appear as mission clients.\n\ntype: struct monster_id_16[length / 2]",
        "struct monster_id_16[21]",
    )

    ITEM_DELIVERY_TABLE = Symbol(
        [0xA433E],
        [0x20A433E],
        0x2E,
        "ITEM_DELIVERY_TABLE",
        "A list of valid items used for delivering an item for a mission client.\n\ntype: struct item_id_16[23]",
        "struct item_id_16[23]",
    )

    MISSION_RANK_POINTS = Symbol(
        [0xA436C],
        [0x20A436C],
        0x40,
        "MISSION_RANK_POINTS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int[16]",
        "int[16]",
    )

    MISSION_BANNED_MONSTERS = Symbol(
        [0xA43AC],
        [0x20A43AC],
        0xF8,
        "MISSION_BANNED_MONSTERS",
        "Null-terminated list of monster IDs that can't be used (probably as clients or targets) when generating missions.\n\ntype: struct monster_id_16[124]",
        "struct monster_id_16[124]",
    )

    MISSION_STRING_IDS = Symbol(
        [0xA44A4],
        [0x20A44A4],
        0x788,
        "MISSION_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[964]",
        "int16_t[964]",
    )

    LEVEL_LIST = Symbol(
        [0xA4CEC],
        [0x20A4CEC],
        0x2470,
        "LEVEL_LIST",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    EVENTS = Symbol(
        [0xA5BD8],
        [0x20A5BD8],
        0x1584,
        "EVENTS",
        "Table of levels for the script engine, in which scenes can take place. There are a version-dependent number of 12-byte entries.\n\ntype: struct script_level[length / 12]",
        "struct script_level[0]",
    )

    ARM9_UNKNOWN_TABLE__NA_20A68BC = Symbol(
        [0xA715C],
        [0x20A715C],
        0xC,
        "ARM9_UNKNOWN_TABLE__NA_20A68BC",
        "6*0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    DEMO_TEAMS = Symbol(
        [0xA7168],
        [0x20A7168],
        0x48,
        "DEMO_TEAMS",
        "18*0x4 (Hero ID 0x2, Partner ID 0x2)\n\nNote: unverified, ported from Irdkwia's notes",
        "struct monster_id_16[18][2]",
    )

    ACTOR_LIST = Symbol(
        [0xA71B0],
        [0x20A71B0],
        0x28F8,
        "ACTOR_LIST",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    ENTITIES = Symbol(
        [0xA8890],
        [0x20A8890],
        0x1218,
        "ENTITIES",
        "Table of entities for the script engine, which can move around and do things within a scene. There are 386 12-byte entries.\n\ntype: struct script_entity[386]",
        "struct script_entity[386]",
    )

    JOB_WINDOW_PARAMS_1 = Symbol(
        [0xA9AB8],
        [0x20A9AB8],
        0x10,
        "JOB_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    JOB_MENU_ITEMS_1 = Symbol(
        [0xA9AC8],
        [0x20A9AC8],
        0x20,
        "JOB_MENU_ITEMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[4]",
    )

    JOB_MENU_ITEMS_2 = Symbol(
        [0xA9AE8],
        [0x20A9AE8],
        0x20,
        "JOB_MENU_ITEMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[4]",
    )

    JOB_MENU_ITEMS_3 = Symbol(
        [0xA9B58],
        [0x20A9B58],
        0x18,
        "JOB_MENU_ITEMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_4 = Symbol(
        [0xA9B70],
        [0x20A9B70],
        0x18,
        "JOB_MENU_ITEMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_5 = Symbol(
        [0xA9B88],
        [0x20A9B88],
        0x18,
        "JOB_MENU_ITEMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_6 = Symbol(
        [0xA9BA0],
        [0x20A9BA0],
        0x18,
        "JOB_MENU_ITEMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_7 = Symbol(
        [0xA9BB8],
        [0x20A9BB8],
        0x18,
        "JOB_MENU_ITEMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_8 = Symbol(
        [0xA9BD0],
        [0x20A9BD0],
        0x18,
        "JOB_MENU_ITEMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_9 = Symbol(
        [0xA9BE8],
        [0x20A9BE8],
        0x18,
        "JOB_MENU_ITEMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_10 = Symbol(
        [0xA9C00],
        [0x20A9C00],
        0x18,
        "JOB_MENU_ITEMS_10",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_11 = Symbol(
        [0xA9C18],
        [0x20A9C18],
        0x18,
        "JOB_MENU_ITEMS_11",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    JOB_MENU_ITEMS_12 = Symbol(
        [0xA9C30],
        [0x20A9C30],
        0x20,
        "JOB_MENU_ITEMS_12",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[4]",
    )

    JOB_MENU_ITEMS_13 = Symbol(
        [0xA9C50],
        [0x20A9C50],
        0x20,
        "JOB_MENU_ITEMS_13",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[4]",
    )

    JOB_WINDOW_PARAMS_2 = Symbol(
        [0xA9C70],
        [0x20A9C70],
        0x10,
        "JOB_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_SWAP_ID_TABLE = Symbol(
        [0xA9C80],
        [0x20A9C80],
        0xD4,
        "DUNGEON_SWAP_ID_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct dungeon_id_8[212]",
        "struct dungeon_id_8[212]",
    )

    MAP_MARKER_PLACEMENTS = Symbol(
        [0xA9D70],
        [0x20A9D70],
        0x9B0,
        "MAP_MARKER_PLACEMENTS",
        "The map marker position of each dungeon on the Wonder Map.\n\nThis is an array of 310 map marker structs. Each entry is 8 bytes, and contains positional information about a dungeon on the map.\n\nSee the struct definitions and Frostbyte's dungeon data document for more info.\n\ntype: struct map_marker[310]",
        "struct map_marker[310]",
    )

    LFO_OUTPUT_VOICE_UPDATE_FLAGS = Symbol(
        [0xAA840],
        [0x20AA840],
        0x10,
        "LFO_OUTPUT_VOICE_UPDATE_FLAGS",
        "",
        "struct dse_voice_update_flags",
    )

    TRIG_TABLE = Symbol(
        [0xAA850],
        [0x20AA850],
        0x4974,
        "TRIG_TABLE",
        "Interleaved table of sine and cosine values at 4096 divisions over a full period (2π radians).\n\nMore precisely, the trig_values entry at index i corresponds to {sin(i * 2π/4096), cos(i * 2π/4096)} (each division is ~1/10 of a degree). Values are stored as signed fixed-point numbers with 12 fraction bits.\n\ntype: struct trig_values[4096]",
        "struct trig_values[4096]",
    )

    FX_ATAN_IDX_TABLE = Symbol(
        [0xAE850],
        [0x20AE850],
        0x102,
        "FX_ATAN_IDX_TABLE",
        "Table of arctangent values at 129 divisions over the domain [0, 1].\n\nMore precisely, entry at index i corresponds to (atan(i/128) / (π/2)). Values are stored as signed fixed-point numbers with 14 fraction bits.",
        "fx16_14[129]",
    )

    TEX_PLTT_START_ADDR_TABLE = Symbol(
        [0xAE954], [0x20AE954], 0x10, "TEX_PLTT_START_ADDR_TABLE", "", "int16_t[8]"
    )

    TEX_START_ADDR_TABLE = Symbol(
        [0xAE964], [0x20AE964], 0x60, "TEX_START_ADDR_TABLE", "", "int16_t[48]"
    )

    ARM9_UNKNOWN_TABLE__NA_20AE924 = Symbol(
        [0xAF1C4],
        [0x20AF1C4],
        0x2D4,
        "ARM9_UNKNOWN_TABLE__NA_20AE924",
        "724*0x1\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    MEMORY_ALLOCATION_ARENA_GETTERS = Symbol(
        [0xAF7A0],
        [0x20AF7A0],
        0x8,
        "MEMORY_ALLOCATION_ARENA_GETTERS",
        "Functions to get the desired memory arena for allocating and freeing heap memory.\n\ntype: struct mem_arena_getters",
        "struct mem_arena_getters",
    )

    PRNG_SEQUENCE_NUM = Symbol(
        [0xAF7CC],
        [0x20AF7CC],
        0x2,
        "PRNG_SEQUENCE_NUM",
        "[Runtime] The current PRNG sequence number for the general-purpose PRNG. See Rand16Bit for more information on how the general-purpose PRNG works.",
        "uint16_t",
    )

    LOADED_OVERLAY_GROUP_0 = Symbol(
        [0xAFAD0],
        [0x20AFAD0],
        0x4,
        "LOADED_OVERLAY_GROUP_0",
        "[Runtime] The overlay group ID of the overlay currently loaded in slot 0. A group ID of 0 denotes no overlay.\n\nOverlay group IDs that can be loaded in slot 0:\n- 0x06 (overlay 3)\n- 0x07 (overlay 6)\n- 0x08 (overlay 4)\n- 0x09 (overlay 5)\n- 0x0A (overlay 7)\n- 0x0B (overlay 8)\n- 0x0C (overlay 9)\n- 0x10 (overlay 12)\n- 0x11 (overlay 13)\n- 0x12 (overlay 14)\n- 0x13 (overlay 15)\n- 0x14 (overlay 16)\n- 0x15 (overlay 17)\n- 0x16 (overlay 18)\n- 0x17 (overlay 19)\n- 0x18 (overlay 20)\n- 0x19 (overlay 21)\n- 0x1A (overlay 22)\n- 0x1B (overlay 23)\n- 0x1C (overlay 24)\n- 0x1D (overlay 25)\n- 0x1E (overlay 26)\n- 0x1F (overlay 27)\n- 0x20 (overlay 28)\n- 0x21 (overlay 30)\n- 0x22 (overlay 31)\n- 0x23 (overlay 32)\n- 0x24 (overlay 33)\n\ntype: enum overlay_group_id",
        "enum overlay_group_id",
    )

    LOADED_OVERLAY_GROUP_1 = Symbol(
        [0xAFAD4],
        [0x20AFAD4],
        0x4,
        "LOADED_OVERLAY_GROUP_1",
        "[Runtime] The overlay group ID of the overlay currently loaded in slot 1. A group ID of 0 denotes no overlay.\n\nOverlay group IDs that can be loaded in slot 1:\n- 0x4 (overlay 1)\n- 0x5 (overlay 2)\n- 0xD (overlay 11)\n- 0xE (overlay 29)\n- 0xF (overlay 34)\n\ntype: enum overlay_group_id",
        "enum overlay_group_id",
    )

    LOADED_OVERLAY_GROUP_2 = Symbol(
        [0xAFAD8],
        [0x20AFAD8],
        0x4,
        "LOADED_OVERLAY_GROUP_2",
        "[Runtime] The overlay group ID of the overlay currently loaded in slot 2. A group ID of 0 denotes no overlay.\n\nOverlay group IDs that can be loaded in slot 2:\n- 0x1 (overlay 0)\n- 0x2 (overlay 10)\n- 0x3 (overlay 35)\n\ntype: enum overlay_group_id",
        "enum overlay_group_id",
    )

    DEBUG_IS_INITIALIZED = Symbol(
        [0xAFF50], [0x20AFF50], None, "DEBUG_IS_INITIALIZED", "", "bool"
    )

    PACK_FILES_OPENED = Symbol(
        [0xAFF54],
        [0x20AFF54],
        0x4,
        "PACK_FILES_OPENED",
        "[Runtime] A pointer to the 6 opened Pack files (listed at PACK_FILE_PATHS_TABLE)\n\ntype: struct pack_file_opened*",
        "struct pack_file_opened*",
    )

    PACK_FILE_PATHS_TABLE = Symbol(
        [0xAFF58],
        [0x20AFF58],
        0x18,
        "PACK_FILE_PATHS_TABLE",
        "List of pointers to path strings to all known pack files.\nThe game uses this table to load its resources when launching dungeon mode.\n\ntype: char*[6]",
        "char*[6]",
    )

    GAME_STATE_VALUES = Symbol(
        [0xAFF70], [0x20AFF70], None, "GAME_STATE_VALUES", "[Runtime]", ""
    )

    BAG_ITEMS_PTR_MIRROR = Symbol(
        [0xAFF70],
        [0x20AFF70],
        0x4,
        "BAG_ITEMS_PTR_MIRROR",
        "[Runtime] Probably a mirror of ram.yml::BAG_ITEMS_PTR?\n\nNote: unverified, ported from Irdkwia's notes",
        "struct item*",
    )

    ITEM_DATA_TABLE_PTRS = Symbol(
        [0xAFF78],
        [0x20AFF78],
        0xC,
        "ITEM_DATA_TABLE_PTRS",
        "[Runtime] List of pointers to various item data tables.\n\nThe first two pointers are definitely item-related (although the order appears to be flipped between EU/NA?). Not sure about the third pointer.",
        "void*[3]",
    )

    DUNGEON_MOVE_TABLES = Symbol(
        [0xAFFA8],
        [0x20AFFA8],
        None,
        "DUNGEON_MOVE_TABLES",
        "[Runtime] Seems to be some sort of region (a table of tables?) that holds pointers to various important tables related to moves.",
        "",
    )

    MOVE_DATA_TABLE_PTR = Symbol(
        [0xAFFB0],
        [0x20AFFB0],
        0x4,
        "MOVE_DATA_TABLE_PTR",
        "[Runtime] Points to the contents of the move data table loaded from waza_p.bin\n\ntype: struct move_data_table*",
        "struct move_data_table*",
    )

    WAN_TABLE = Symbol(
        [0xB0524],
        [0x20B0524],
        None,
        "WAN_TABLE",
        "pointer to the list of wan sprite loaded in RAM\n\nstruct wan_table*",
        "struct wan_table*",
    )

    RENDER_3D = Symbol(
        [0xB0540],
        [0x20B0540],
        0x44,
        "RENDER_3D",
        "The (seemingly) unique instance render_3d_global in the game\n\ntype: struct render_3d_global",
        "struct render_3d_global",
    )

    RENDER_3D_FUNCTIONS_64 = Symbol(
        [0xB0584],
        [0x20B0584],
        0x20,
        "RENDER_3D_FUNCTIONS_64",
        "Pointers to the 8 functions available for rendering a render_3d_element_64\n\ntype: render_3d_element_64_fn_t[8]",
        "render_3d_element_64_fn_t[8]",
    )

    LANGUAGE_INFO_DATA = Symbol(
        [0xB05A8], [0x20B05A8], None, "LANGUAGE_INFO_DATA", "[Runtime]", ""
    )

    TBL_TALK_GROUP_STRING_ID_START = Symbol(
        [0xB0614],
        [0x20B0614],
        None,
        "TBL_TALK_GROUP_STRING_ID_START",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[6]",
        "int16_t[6]",
    )

    KEYBOARD_STRING_IDS = Symbol(
        [0xB0718],
        [0x20B0718],
        0x3C,
        "KEYBOARD_STRING_IDS",
        "30*0x2\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: int16_t[30]",
        "int16_t[30]",
    )

    NOTIFY_NOTE = Symbol(
        [0xB0814],
        [0x20B0814],
        0x1,
        "NOTIFY_NOTE",
        "[Runtime] Flag related to saving and loading state?\n\ntype: bool",
        "bool",
    )

    DEFAULT_HERO_ID = Symbol(
        [0xB0818],
        [0x20B0818],
        0x2,
        "DEFAULT_HERO_ID",
        "The default monster ID for the hero (0x4: Charmander)\n\ntype: struct monster_id_16",
        "struct monster_id_16",
    )

    DEFAULT_PARTNER_ID = Symbol(
        [0xB081A],
        [0x20B081A],
        0x2,
        "DEFAULT_PARTNER_ID",
        "The default monster ID for the partner (0x1: Bulbasaur)\n\ntype: struct monster_id_16",
        "struct monster_id_16",
    )

    GAME_MODE = Symbol(
        [0xB088C],
        [0x20B088C],
        0x1,
        "GAME_MODE",
        "[Runtime] Game mode, see enum game_mode for possible values.\n\ntype: uint8_t",
        "uint8_t",
    )

    GLOBAL_PROGRESS_PTR = Symbol(
        [0xB0890],
        [0x20B0890],
        0x4,
        "GLOBAL_PROGRESS_PTR",
        "[Runtime]\n\ntype: struct global_progress*",
        "struct global_progress*",
    )

    ADVENTURE_LOG_PTR = Symbol(
        [0xB0894],
        [0x20B0894],
        0x4,
        "ADVENTURE_LOG_PTR",
        "[Runtime]\n\ntype: struct adventure_log*",
        "struct adventure_log*",
    )

    ITEM_TABLES_PTRS_1 = Symbol(
        [0xB1264],
        [0x20B1264],
        0x68,
        "ITEM_TABLES_PTRS_1",
        "Irdkwia's notes: 26*0x4, uses MISSION_FLOOR_RANKS_AND_ITEM_LISTS",
        "void*[26]",
    )

    UNOWN_SPECIES_ADDITIONAL_CHAR_PTR_TABLE = Symbol(
        [0xB131C],
        [0x20B131C],
        0x70,
        "UNOWN_SPECIES_ADDITIONAL_CHAR_PTR_TABLE",
        "Uses UNOWN_SPECIES_ADDITIONAL_CHARS\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: enum monster_id*[28]",
        "enum monster_id*[28]",
    )

    TEAM_MEMBER_TABLE_PTR = Symbol(
        [0xB138C],
        [0x20B138C],
        0x4,
        "TEAM_MEMBER_TABLE_PTR",
        "Pointer to TEAM_MEMBER_TABLE",
        "struct team_member_table*",
    )

    MISSION_DELIVER_LIST_PTR = Symbol(
        [0xB13A4],
        [0x20B13A4],
        0x4,
        "MISSION_DELIVER_LIST_PTR",
        "A pointer to a heap-allocated list of items usable for delivery missions",
        "undefined*",
    )

    MISSION_DELIVER_COUNT = Symbol(
        [0xB13A8],
        [0x20B13A8],
        0x4,
        "MISSION_DELIVER_COUNT",
        "The total number of items usable for delivery missions",
        "int",
    )

    MISSION_DUNGEON_LIST_PTR = Symbol(
        [0xB13AC],
        [0x20B13AC],
        0x4,
        "MISSION_DUNGEON_LIST_PTR",
        "A pointer to a heap-allocated list of dungeons usable for missions",
        "undefined*",
    )

    MISSION_DUNGEON_COUNT = Symbol(
        [0xB13B0],
        [0x20B13B0],
        0x4,
        "MISSION_DUNGEON_COUNT",
        "The total number of dungeons usable for missions",
        "int",
    )

    MISSION_MONSTER_LIST_PTR = Symbol(
        [0xB13B4],
        [0x20B13B4],
        0x4,
        "MISSION_MONSTER_LIST_PTR",
        "A pointer to a heap-allocated list of monsters usable for missions",
        "undefined*",
    )

    MISSION_MONSTER_COUNT = Symbol(
        [0xB13B8],
        [0x20B13B8],
        0x4,
        "MISSION_MONSTER_COUNT",
        "The total number of monsters usable for missions",
        "int",
    )

    MISSION_LIST_PTR = Symbol(
        [0xB13BC],
        [0x20B13BC],
        0x4,
        "MISSION_LIST_PTR",
        "Note: unverified, ported from Irdkwia's notes",
        "undefined*",
    )

    REMOTE_STRING_PTR_TABLE = Symbol(
        [0xB13C0],
        [0x20B13C0],
        0x1C,
        "REMOTE_STRING_PTR_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: const char*[7]",
        "char*[7]",
    )

    RANK_STRING_PTR_TABLE = Symbol(
        [0xB13DC],
        [0x20B13DC],
        0x40,
        "RANK_STRING_PTR_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: const char*[16]",
        "char*[16]",
    )

    SMD_EVENTS_FUN_TABLE = Symbol(
        [0xB14D4],
        [0x20B14D4],
        0x1FC,
        "SMD_EVENTS_FUN_TABLE",
        "Table of all DSE events, see https://projectpokemon.org/docs/mystery-dungeon-nds/procyon-studios-digital-sound-elements-r12/\n\nIrdkwia's notes: named DSEEventFunctionPtrTable with length 0x3C0 (note the disagreement), 240*0x4.",
        "void*[127]",
    )

    MUSIC_DURATION_LOOKUP_TABLE_1 = Symbol(
        [0xB1894],
        [0x20B1894],
        0x100,
        "MUSIC_DURATION_LOOKUP_TABLE_1",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[128]",
        "int16_t[128]",
    )

    MUSIC_DURATION_LOOKUP_TABLE_2 = Symbol(
        [0xB1994],
        [0x20B1994],
        0x200,
        "MUSIC_DURATION_LOOKUP_TABLE_2",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int32_t[128]",
        "int32_t[128]",
    )

    LFO_WAVEFORM_CALLBACKS = Symbol(
        [0xB1B94],
        [0x20B1B94],
        0x40,
        "LFO_WAVEFORM_CALLBACKS",
        "",
        "sound_lfo_waveform_callback[16]",
    )

    IS_DISP_ON = Symbol([0xB34D8], [0x20B34D8], 0x1, "IS_DISP_ON", "", "bool")

    GXI_DMA_ID = Symbol([0xB34DC], [0x20B34DC], 0x4, "GXI_DMA_ID", "", "uint32_t")

    JUICE_BAR_NECTAR_IQ_GAIN = Symbol(
        [0x118B8],
        [0x20118B8],
        None,
        "JUICE_BAR_NECTAR_IQ_GAIN",
        "IQ gain when ingesting nectar at the Juice Bar.",
        "struct data_processing_instruction",
    )

    DEBUG_TEXT_SPEED = Symbol(
        [0x20DEC],
        [0x2020DEC],
        None,
        "DEBUG_TEXT_SPEED",
        "Text speed when debug flag DEBUG_FLAG_TEXT_SPEEDUP is enabled.",
        "struct data_processing_instruction",
    )

    REGULAR_TEXT_SPEED = Symbol(
        [0x20DF0],
        [0x2020DF0],
        None,
        "REGULAR_TEXT_SPEED",
        "Text speed when debug flag DEBUG_FLAG_TEXT_SPEEDUP is disabled.",
        "struct data_processing_instruction",
    )

    HERO_START_LEVEL = Symbol(
        [0x48B9C],
        [0x2048B9C],
        None,
        "HERO_START_LEVEL",
        "Starting level of the hero.",
        "struct data_processing_instruction",
    )

    PARTNER_START_LEVEL = Symbol(
        [0x48C0C],
        [0x2048C0C],
        None,
        "PARTNER_START_LEVEL",
        "Starting level of the partner.",
        "struct data_processing_instruction",
    )

    EXCLUSIVE_ITEM_ATTACK_BOOSTS = _Deprecated(
        "EXCLUSIVE_ITEM_ATTACK_BOOSTS", EXCLUSIVE_ITEM_STAT_BOOST_DATA
    )

    DIRECTORY_FILES_EXTRACTED = _Deprecated(
        "DIRECTORY_FILES_EXTRACTED", PACK_FILES_OPENED
    )

    DIRECTORY_FILE_TABLE = _Deprecated("DIRECTORY_FILE_TABLE", PACK_FILE_PATHS_TABLE)

    TEXT_SPEED = _Deprecated("TEXT_SPEED", REGULAR_TEXT_SPEED)


class EuArm9Section:
    name = "arm9"
    description = "The main ARM9 binary.\n\nThis is the main binary that gets loaded when the game is launched, and contains the core code that runs the game, low level facilities such as memory allocation, compression, other external dependencies (such as linked libraries), and the functions and tables necessary to load overlays and dispatch execution to them.\n\nSpeaking generally, this is the program run by the Nintendo DS's main ARM946E-S CPU, which handles all gameplay mechanisms and graphics rendering."
    loadaddress = 0x2000000
    length = 0xB7D38
    functions = EuArm9Functions
    data = EuArm9Data


class EuItcmFunctions:

    Render3dSetTextureParams = Symbol(
        [0x130],
        [0x20B3DF0],
        None,
        "Render3dSetTextureParams",
        "A wrapper around GeomSetTexImageParam that caches the VRAM offset on RENDER_3D.\n\nAlways disables flipping and sets color values of 0 to be transparent.\n\nr0: render_3d_texture_params pointer\nr1: texture VRAM offset",
        None,
    )

    Render3dSetPaletteBase = Symbol(
        [0x1CC],
        [0x20B3E8C],
        None,
        "Render3dSetPaletteBase",
        "Send the PLTT_BASE geometry engine command, that sets the texture palette base address. Also caches the base address on RENDER_3D.\nSee http://problemkaputt.de/gbatek.htm#ds3dtextureattributes for more information on the parameters.\n\nr0: render_3d_texture_params pointer\nr1: palette base address",
        None,
    )

    Render3dRectangle = Symbol(
        [0x224],
        [0x20B3EE4],
        None,
        "Render3dRectangle",
        "RENDER_3D_FUNCTIONS[0]. Renders a render_3d_element with type RENDER_RECTANGLE.\n\nr0: render_3d_rectangle",
        None,
    )

    GeomSetPolygonAttributes = Symbol(
        [0x480],
        [0x20B4140],
        None,
        "GeomSetPolygonAttributes",
        "Send the POLYGON_ATTR geometry engine command, that defines some polygon attributes for rendering.\nSee https://problemkaputt.de/gbatek.htm#ds3dpolygonattributes for more information\n\nr0: polygon ID\nr1: alpha",
        None,
    )

    Render3dQuadrilateral = Symbol(
        [0x49C],
        [0x20B415C],
        None,
        "Render3dQuadrilateral",
        "RENDER_3D_FUNCTIONS[1]. Renders a render_3d_element with type RENDER_QUADRILATERAL.\n\nr0: render_3d_quadrilateral",
        None,
    )

    Render3dTiling = Symbol(
        [0x728],
        [0x20B43E8],
        None,
        "Render3dTiling",
        "RENDER_3D_FUNCTIONS[2]. Renders a render_3d_element with type RENDER_TILING.\n\nr0: render_3d_tiling",
        None,
    )

    Render3dTextureInternal = Symbol(
        None,
        None,
        None,
        "Render3dTextureInternal",
        "Implements most of the rendering logic for Render3dTexture.\n\nr0: render_3d_texture",
        None,
    )

    Render3dTexture = Symbol(
        [0xC28],
        [0x20B48E8],
        None,
        "Render3dTexture",
        "RENDER_3D_FUNCTIONS[3]. Renders a render_3d_element with type RENDER_TEXTURE.\n\nThis is primarily just a wrapper around Render3dTextureInternal, with a preceding alpha check and calls to Render3dSetTextureParams and Render3dSetPaletteBase.\n\nr0: render_3d_texture",
        None,
    )

    Render3dTextureNoSetup = Symbol(
        None,
        None,
        None,
        "Render3dTextureNoSetup",
        "Same as Render3dTexture except without calls to Render3dSetTextureParams and Render3dSetPaletteBase to set up geometry engine parameters.\n\nPresumably used to render multiple texture tiles with the same parameters without the extra setup overhead? But this function doesn't actually seem to be referenced anywhere.\n\nr0: render_3d_texture",
        None,
    )

    NewRender3dElement = Symbol(
        [0xC78],
        [0x20B4938],
        None,
        "NewRender3dElement",
        "Return a new render_3d_element from RENDER_3D's render queue, to draw a new element using the 3d render engine later in the frame.\n\nreturn: render_3d_element or NULL if there is no more available space in the queue",
        None,
    )

    EnqueueRender3dTexture = Symbol(
        [0xCAC],
        [0x20B496C],
        None,
        "EnqueueRender3dTexture",
        "Copies the first 40 bytes of a render_3d_element onto the render queue of RENDER_3D, with type set to RENDER_TEXTURE.\n\nr0: render_3d_element",
        None,
    )

    EnqueueRender3dTiling = Symbol(
        [0xCDC],
        [0x20B499C],
        None,
        "EnqueueRender3dTiling",
        "Copies a render_3d_element onto the render queue of RENDER_3D, with type set to RENDER_TILING.\n\nr0: render_3d_element",
        None,
    )

    NewRender3dRectangle = Symbol(
        [0xD0C],
        [0x20B49CC],
        None,
        "NewRender3dRectangle",
        "Return a render_3d_element from NewRender3dElement with a type of RENDER_RECTANGLE, and all other fields in the first 38 bytes zeroed.\n\nreturn: render_3d_element or NULL if there is no more available space in the queue",
        None,
    )

    NewRender3dQuadrilateral = Symbol(
        [0xD3C],
        [0x20B49FC],
        None,
        "NewRender3dQuadrilateral",
        "Return a render_3d_element from NewRender3dElement with a type of RENDER_QUADRILATERAL, and all other fields in the first 38 bytes zeroed.\n\nreturn: render_3d_element or NULL if there is no more available space in the queue",
        None,
    )

    NewRender3dTexture = Symbol(
        [0xD6C],
        [0x20B4A2C],
        None,
        "NewRender3dTexture",
        "Return a render_3d_element from NewRender3dElement with a type of RENDER_TEXTURE, and all other fields in the first 40 bytes zeroed.\n\nreturn: render_3d_element or NULL if there is no more available space in the queue",
        None,
    )

    NewRender3dTiling = Symbol(
        [0xD9C],
        [0x20B4A5C],
        None,
        "NewRender3dTiling",
        "Return a render_3d_element from NewRender3dElement with a type of RENDER_TILING, and all other fields zeroed.\n\nreturn: render_3d_element or NULL if there is no more available space in the queue",
        None,
    )

    Render3dProcessQueue = Symbol(
        [0xDCC],
        [0x20B4A8C],
        None,
        "Render3dProcessQueue",
        "Perform rendering of the render queue of RENDER_3D structure. Does nothing if there are no elements, otherwise, sort them based on a value, and render them all consecutively.\n\nNo params.",
        None,
    )

    GetKeyN2MSwitch = Symbol(
        [0x1434],
        [0x20B50F4],
        None,
        "GetKeyN2MSwitch",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: key\nr1: switch",
        None,
    )

    GetKeyN2M = Symbol(
        [0x1468],
        [0x20B5128],
        None,
        "GetKeyN2M",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: key\nreturn: monster ID",
        None,
    )

    GetKeyN2MBaseForm = Symbol(
        [0x14D4],
        [0x20B5194],
        None,
        "GetKeyN2MBaseForm",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: key\nreturn: monster ID",
        None,
    )

    GetKeyM2NSwitch = Symbol(
        [0x150C],
        [0x20B51CC],
        None,
        "GetKeyM2NSwitch",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nr1: switch",
        None,
    )

    GetKeyM2N = Symbol(
        [0x1540],
        [0x20B5200],
        None,
        "GetKeyM2N",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: key",
        None,
    )

    GetKeyM2NBaseForm = Symbol(
        [0x15AC],
        [0x20B526C],
        None,
        "GetKeyM2NBaseForm",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: key",
        None,
    )

    HardwareInterrupt = Symbol(
        [0x15E8],
        [0x20B52A8],
        None,
        "HardwareInterrupt",
        "Called whenever a hardware interrupt takes place.\n\nReturns immediately if the IME flag is 0 or if none of the devices that requested an interrupt has the corresponding Interrupt Enable flag set.\nIt searches for the first device that requested an interrupt, clears its Interrupt Request flag, then jumps to the start of the corresponding interrupt function. The return address is manually set to ReturnFromInterrupt.\nThe address of the function to jump to is read from the interrupt vector at the start of the DTCM region (0x27E0000).\nThis function does not return.\n\nNo params.",
        None,
    )

    ReturnFromInterrupt = Symbol(
        [0x1650],
        [0x20B5310],
        None,
        "ReturnFromInterrupt",
        "The execution returns to this function after a hardware interrupt function is run.\n\nNo params.",
        None,
    )

    ShouldMonsterRunAwayVariationOutlawCheck = Symbol(
        [0x2390],
        [0x20B6050],
        None,
        "ShouldMonsterRunAwayVariationOutlawCheck",
        "Calls ShouldMonsterRunAwayVariation. If the result is true, returns true. Otherwise, returns true only if the monster's behavior field is equal to monster_behavior::BEHAVIOR_FLEEING_OUTLAW.\n\nr0: Entity pointer\nr1: ?\nreturn: True if ShouldMonsterRunAway returns true or the monster is a fleeing outlaw",
        None,
    )

    AiMovement = Symbol(
        [0x23C4],
        [0x20B6084],
        None,
        "AiMovement",
        "Used by the AI to determine the direction in which a monster should move\n\nr0: Entity pointer\nr1: ?",
        None,
    )

    CalculateAiTargetPos = Symbol(
        [0x32C8],
        [0x20B6F88],
        None,
        "CalculateAiTargetPos",
        "Calculates the target position of an AI-controlled monster and stores it in the monster's ai_target_pos field\n\nr0: Entity pointer",
        None,
    )

    ChooseAiMove = Symbol(
        [0x3658],
        [0x20B7318],
        None,
        "ChooseAiMove",
        "Determines if an AI-controlled monster will use a move and which one it will use\n\nr0: Entity pointer",
        None,
    )

    LightningRodStormDrainCheck = Symbol(
        [0x3E5C],
        [0x20B7B1C],
        None,
        "LightningRodStormDrainCheck",
        "Appears to check whether LightningRod or Storm Drain should draw in a move.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move pointer\nr3: true if checking for Storm Drain, false if checking for LightningRod\nreturn: whether the move should be drawn in",
        None,
    )


class EuItcmData:

    MEMORY_ALLOCATION_TABLE = Symbol(
        [0x0],
        [0x20B3CC0],
        0x40,
        "MEMORY_ALLOCATION_TABLE",
        "[Runtime] Keeps track of all active heap allocations.\n\nThe memory allocator in the ARM9 binary uses region-based memory management (see https://en.wikipedia.org/wiki/Region-based_memory_management). The heap is broken up into smaller contiguous chunks called arenas (struct mem_arena), which are in turn broken up into chunks referred to as blocks (struct mem_block). Most of the time, an allocation results in a block being split off from a free part of an existing memory arena.\n\nNote: This symbol isn't actually part of the ITCM, it gets created at runtime on the spot in RAM that used to contain the code that was moved to the ITCM.\n\ntype: struct mem_alloc_table",
        "struct mem_alloc_table",
    )

    DEFAULT_MEMORY_ARENA = Symbol(
        [0x4],
        [0x20B3CC4],
        0x1C,
        "DEFAULT_MEMORY_ARENA",
        "[Runtime] The default memory allocation arena. This is part of MEMORY_ALLOCATION_TABLE, but is also referenced on its own by various functions.\n\nNote: This symbol isn't actually part of the ITCM, it gets created at runtime on the spot in RAM that used to contain the code that was moved to the ITCM.\n\ntype: struct mem_arena",
        "struct mem_arena",
    )

    DEFAULT_MEMORY_ARENA_BLOCKS = Symbol(
        [0x40],
        [0x20B3D00],
        0x1800,
        "DEFAULT_MEMORY_ARENA_BLOCKS",
        "[Runtime] The block array for DEFAULT_MEMORY_ARENA.\n\nNote: This symbol isn't actually part of the ITCM, it gets created at runtime on the spot in RAM that used to contain the code that was moved to the ITCM.\n\ntype: struct mem_block[256]",
        "struct mem_block[256]",
    )

    RENDER_3D_FUNCTIONS = Symbol(
        [0x120],
        [0x20B3DE0],
        None,
        "RENDER_3D_FUNCTIONS",
        "Pointers to the 4 functions available for rendering a render_3d_element (in ITCM)\n\ntype: render_3d_element_fn_t[4]",
        "render_3d_element_fn_t[4]",
    )


class EuItcmSection:
    name = "itcm"
    description = "The instruction TCM (tightly-coupled memory) and the corresponding region in the ARM9 binary.\n\nThe ITCM is a special area of low-latency memory meant for performance-critical routines. It's similar to an instruction cache, but more predictable. See the ARMv5 Architecture Reference Manual, Chapter B7 (https://developer.arm.com/documentation/ddi0100/i).\n\nThe Nintendo DS ITCM region is located at 0x0-0x7FFF in memory, but the 32 KiB segment is mirrored throughout the 16 MiB block from 0x0-0x1FFFFFF. The Explorers of Sky code seems to reference only the mirror at 0x1FF8000, the closest one to main memory.\n\nIn Explorers of Sky, a fixed region of the ARM9 binary appears to be loaded in the ITCM at all times, and seems to contain functions related to the dungeon AI, among other things. The ITCM has a max capacity of 0x8000, although not all of it is used."
    loadaddress = 0x20B3CC0
    length = 0x4000
    functions = EuItcmFunctions
    data = EuItcmData


class EuLibsFunctions:

    DseDriver_LoadDefaultSettings = Symbol(
        [0xE8], [0x206C558], None, "DseDriver_LoadDefaultSettings", "", None
    )

    DseDriver_IsSettingsValid = Symbol(
        [0x180],
        [0x206C5F0],
        None,
        "DseDriver_IsSettingsValid",
        "r0: DSE driver settings\nreturn: Flags specifying what settings are invalid.",
        None,
    )

    DseDriver_ConfigureHeap = Symbol(
        [0x264], [0x206C6D4], None, "DseDriver_ConfigureHeap", "", None
    )

    DseDriver_Init = Symbol([0x308], [0x206C778], None, "DseDriver_Init", "", None)

    Dse_SetError = Symbol([0x77C], [0x206CBEC], None, "Dse_SetError", "", None)

    Dse_SetError2 = Symbol([0x7B0], [0x206CC20], None, "Dse_SetError2", "", None)

    DseUtil_ByteSwap32 = Symbol(
        [0x7EC], [0x206CC5C], None, "DseUtil_ByteSwap32", "", None
    )

    SoundUtil_GetRandomNumber = Symbol(
        [0x81C],
        [0x206CC8C],
        None,
        "SoundUtil_GetRandomNumber",
        "return: random number in the range [0, 32767]",
        None,
    )

    DseMem_Init = Symbol([0x844], [0x206CCB4], None, "DseMem_Init", "", None)

    DseMem_Quit = Symbol([0x8B4], [0x206CD24], None, "DseMem_Quit", "", None)

    DseMem_AllocateUser = Symbol(
        [0x8D0], [0x206CD40], None, "DseMem_AllocateUser", "", None
    )

    DseMem_Allocate = Symbol([0x8E4], [0x206CD54], None, "DseMem_Allocate", "", None)

    DseMem_AllocateThreadStack = Symbol(
        [0x9F4], [0x206CE64], None, "DseMem_AllocateThreadStack", "", None
    )

    DseMem_Free = Symbol([0xB3C], [0x206CFAC], None, "DseMem_Free", "", None)

    DseMem_Clear = Symbol([0xBE4], [0x206D054], None, "DseMem_Clear", "", None)

    DseFile_CheckHeader = Symbol(
        [0xC44], [0x206D0B4], None, "DseFile_CheckHeader", "", None
    )

    DseSwd_SysInit = Symbol([0xCC4], [0x206D134], None, "DseSwd_SysInit", "", None)

    DseSwd_SysQuit = Symbol([0xD50], [0x206D1C0], None, "DseSwd_SysQuit", "", None)

    DseSwd_SampleLoaderMain = Symbol(
        [0xD90], [0x206D200], None, "DseSwd_SampleLoaderMain", "", None
    )

    DseSwd_MainBankDummyCallback = Symbol(
        [0xDF0], [0x206D260], None, "DseSwd_MainBankDummyCallback", "", None
    )

    DseSwd_LoadMainBank = Symbol(
        [0xDF8], [0x206D268], None, "DseSwd_LoadMainBank", "", None
    )

    DseSwd_LoadBank = Symbol([0x1030], [0x206D4A0], None, "DseSwd_LoadBank", "", None)

    DseSwd_IsBankLoading = Symbol(
        [0x1234], [0x206D6A4], None, "DseSwd_IsBankLoading", "", None
    )

    DseSwd_LoadWaves = Symbol([0x1250], [0x206D6C0], None, "DseSwd_LoadWaves", "", None)

    DseSwd_LoadWavesInternal = Symbol(
        [0x1300], [0x206D770], None, "DseSwd_LoadWavesInternal", "", None
    )

    DseSwd_Unload = Symbol([0x140C], [0x206D87C], None, "DseSwd_Unload", "", None)

    ReadWaviEntry = Symbol(
        [0x1480],
        [0x206D8F0],
        None,
        "ReadWaviEntry",
        "Reads an entry from the pointer table of a wavi container and returns a pointer to the data of said entry, which contains information about a particular sample.\n\nr0: Wavi data struct\nr1: Entry index\nreturn: Pointer to the entry's data",
        None,
    )

    DseSwd_GetInstrument = Symbol(
        [0x14B8], [0x206D928], None, "DseSwd_GetInstrument", "", None
    )

    DseSwd_GetNextSplitInRange = Symbol(
        [0x14F0], [0x206D960], None, "DseSwd_GetNextSplitInRange", "", None
    )

    DseSwd_GetMainBankById = Symbol(
        [0x1578], [0x206D9E8], None, "DseSwd_GetMainBankById", "", None
    )

    DseSwd_GetBankById = Symbol(
        [0x15C8], [0x206DA38], None, "DseSwd_GetBankById", "", None
    )

    DseSwd_InitMainBankFileReader = Symbol(
        [0x1618], [0x206DA88], None, "DseSwd_InitMainBankFileReader", "", None
    )

    DseSwd_OpenMainBankFileReader = Symbol(
        [0x1628], [0x206DA98], None, "DseSwd_OpenMainBankFileReader", "", None
    )

    DseSwd_CloseMainBankFileReader = Symbol(
        [0x1654], [0x206DAC4], None, "DseSwd_CloseMainBankFileReader", "", None
    )

    DseSwd_ReadMainBank = Symbol(
        [0x1664], [0x206DAD4], None, "DseSwd_ReadMainBank", "", None
    )

    DseBgm_DefaultSignalCallback = Symbol(
        [0x1728], [0x206DB98], None, "DseBgm_DefaultSignalCallback", "", None
    )

    DseBgm_Load = Symbol([0x1730], [0x206DBA0], None, "DseBgm_Load", "", None)

    DseBgm_Unload = Symbol([0x1834], [0x206DCA4], None, "DseBgm_Unload", "", None)

    DseBgm_SetSignalCallback = Symbol(
        [0x186C], [0x206DCDC], None, "DseBgm_SetSignalCallback", "", None
    )

    DseBgm_IsPlaying = Symbol([0x18CC], [0x206DD3C], None, "DseBgm_IsPlaying", "", None)

    ResumeBgm = Symbol(
        [0x18E4],
        [0x206DD54],
        None,
        "ResumeBgm",
        "Uncertain.\n\nNote: unverified, ported from Irdkwia's notes",
        None,
    )

    DseBgm_Stop = Symbol([0x19C4], [0x206DE34], None, "DseBgm_Stop", "", None)

    DseBgm_StopAll = Symbol([0x1A04], [0x206DE74], None, "DseBgm_StopAll", "", None)

    DseBgm_SetFades = Symbol([0x1A64], [0x206DED4], None, "DseBgm_SetFades", "", None)

    DseSequence_Start = Symbol(
        [0x1AA4], [0x206DF14], None, "DseSequence_Start", "", None
    )

    DseSequence_PauseList = Symbol(
        [0x1B34], [0x206DFA4], None, "DseSequence_PauseList", "", None
    )

    DseSequence_SetFades = Symbol(
        [0x1C98], [0x206E108], None, "DseSequence_SetFades", "", None
    )

    DseSequence_GetParameter = Symbol(
        [0x1F8C], [0x206E3FC], None, "DseSequence_GetParameter", "", None
    )

    DseSequence_GetSmallestNumLoops = Symbol(
        [0x2140], [0x206E5B0], None, "DseSequence_GetSmallestNumLoops", "", None
    )

    DseSequence_Reset = Symbol(
        [0x2194], [0x206E604], None, "DseSequence_Reset", "", None
    )

    DseSequence_Stop = Symbol([0x22EC], [0x206E75C], None, "DseSequence_Stop", "", None)

    FindSmdlSongChunk = Symbol(
        [0x2410],
        [0x206E880],
        None,
        "FindSmdlSongChunk",
        "Finds the first song chunk within an SMDL file that has the specified value on its 0x10 field.\n\nSee https://projectpokemon.org/home/docs/mystery-dungeon-nds/dse-smdl-format-r13/.\n\nr0: Pointer to the start of the SMDL file\nr1: Value to search for\nreturn: Pointer to the first chunk that has the specified value + 0x10, or null if no chunk was found.",
        None,
    )

    DseSequence_LoadSong = Symbol(
        [0x247C], [0x206E8EC], None, "DseSequence_LoadSong", "", None
    )

    DseSequence_GetById = Symbol(
        [0x257C], [0x206E9EC], None, "DseSequence_GetById", "", None
    )

    DseSequence_AllocateNew = Symbol(
        [0x25C8], [0x206EA38], None, "DseSequence_AllocateNew", "", None
    )

    DseSequence_Unload = Symbol(
        [0x2700], [0x206EB70], None, "DseSequence_Unload", "", None
    )

    DseSequence_InitTracks = Symbol(
        [0x2784], [0x206EBF4], None, "DseSequence_InitTracks", "", None
    )

    DseBgm_SysSetupNoteList = Symbol(
        [0x27D4], [0x206EC44], None, "DseBgm_SysSetupNoteList", "", None
    )

    DseSe_SysReset = Symbol([0x2848], [0x206ECB8], None, "DseSe_SysReset", "", None)

    DseSe_Load = Symbol([0x2940], [0x206EDB0], None, "DseSe_Load", "", None)

    DseSe_Unload = Symbol([0x2AF4], [0x206EF64], None, "DseSe_Unload", "", None)

    DseSe_GetUsedBankIDs = Symbol(
        [0x2B84], [0x206EFF4], None, "DseSe_GetUsedBankIDs", "", None
    )

    DseSe_HasPlayingInstances = Symbol(
        [0x2C58], [0x206F0C8], None, "DseSe_HasPlayingInstances", "", None
    )

    DseSe_Play = Symbol([0x2D24], [0x206F194], None, "DseSe_Play", "", None)

    DseSe_GetEffectSong = Symbol(
        [0x2ED8], [0x206F348], None, "DseSe_GetEffectSong", "", None
    )

    DseSe_CheckTooManyInstances = Symbol(
        [0x2F20], [0x206F390], None, "DseSe_CheckTooManyInstances", "", None
    )

    DseSe_CheckTooManyInstancesInGroup = Symbol(
        [0x3028], [0x206F498], None, "DseSe_CheckTooManyInstancesInGroup", "", None
    )

    DseSe_GetBestSeqAllocation = Symbol(
        [0x31EC], [0x206F65C], None, "DseSe_GetBestSeqAllocation", "", None
    )

    DseSe_GetById = Symbol([0x3268], [0x206F6D8], None, "DseSe_GetById", "", None)

    DseSe_Stop = Symbol([0x32B4], [0x206F724], None, "DseSe_Stop", "", None)

    DseSe_StopAll = Symbol([0x3408], [0x206F878], None, "DseSe_StopAll", "", None)

    DseSe_StopSeq = Symbol([0x3474], [0x206F8E4], None, "DseSe_StopSeq", "", None)

    FlushChannels = Symbol(
        [0x459C],
        [0x2070A0C],
        None,
        "FlushChannels",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    DseDriver_StartMainThread = Symbol(
        [0x4D34], [0x20711A4], None, "DseDriver_StartMainThread", "", None
    )

    DseDriver_StartTickTimer = Symbol(
        [0x4E04], [0x2071274], None, "DseDriver_StartTickTimer", "", None
    )

    DseDriver_NotifyTick = Symbol(
        [0x4EFC], [0x207136C], None, "DseDriver_NotifyTick", "", None
    )

    DseDriver_Main = Symbol([0x4F3C], [0x20713AC], None, "DseDriver_Main", "", None)

    DseSequence_TickNotes = Symbol(
        [0x5088], [0x20714F8], None, "DseSequence_TickNotes", "", None
    )

    ParseDseEvent = Symbol(
        [0x514C],
        [0x20715BC],
        None,
        "ParseDseEvent",
        "Parses and executes a DSE event for the specified track, if necessary.\n\nThe function checks the time left before the next event (track_data::event_delay), and parses it if said time is 0.\n\nSee also https://projectpokemon.org/docs/mystery-dungeon-nds/procyon-studios-digital-sound-elements-r12/\n\nr0: Pointer to some struct that seems to hold the state of the audio engine\nr1: Pointer to track data",
        None,
    )

    UpdateSequencerTracks = Symbol(
        [0x5310],
        [0x2071780],
        None,
        "UpdateSequencerTracks",
        "From https://projectpokemon.org/docs/mystery-dungeon-nds/procyon-studios-digital-sound-elements-r12/",
        None,
    )

    DseSequence_TickFades = Symbol(
        [0x56AC], [0x2071B1C], None, "DseSequence_TickFades", "", None
    )

    DseTrackEvent_Invalid = Symbol(
        [0x5844], [0x2071CB4], None, "DseTrackEvent_Invalid", "", None
    )

    DseTrackEvent_WaitSame = Symbol(
        [0x5850], [0x2071CC0], None, "DseTrackEvent_WaitSame", "", None
    )

    DseTrackEvent_WaitDelta = Symbol(
        [0x585C], [0x2071CCC], None, "DseTrackEvent_WaitDelta", "", None
    )

    DseTrackEvent_Wait8 = Symbol(
        [0x5874], [0x2071CE4], None, "DseTrackEvent_Wait8", "", None
    )

    DseTrackEvent_Wait16 = Symbol(
        [0x5884], [0x2071CF4], None, "DseTrackEvent_Wait16", "", None
    )

    DseTrackEvent_Wait24 = Symbol(
        [0x58A0], [0x2071D10], None, "DseTrackEvent_Wait24", "", None
    )

    DseTrackEvent_WaitUntilFadeout = Symbol(
        [0x58C4], [0x2071D34], None, "DseTrackEvent_WaitUntilFadeout", "", None
    )

    DseTrackEvent_EndTrack = Symbol(
        [0x58F0], [0x2071D60], None, "DseTrackEvent_EndTrack", "", None
    )

    DseTrackEvent_MainLoopBegin = Symbol(
        [0x593C], [0x2071DAC], None, "DseTrackEvent_MainLoopBegin", "", None
    )

    DseTrackEvent_SubLoopBegin = Symbol(
        [0x5944], [0x2071DB4], None, "DseTrackEvent_SubLoopBegin", "", None
    )

    DseTrackEvent_SubLoopEnd = Symbol(
        [0x5984], [0x2071DF4], None, "DseTrackEvent_SubLoopEnd", "", None
    )

    DseTrackEvent_SubLoopBreakOnLastIteration = Symbol(
        [0x59C0],
        [0x2071E30],
        None,
        "DseTrackEvent_SubLoopBreakOnLastIteration",
        "",
        None,
    )

    DseTrackEvent_SetOctave = Symbol(
        [0x59E8], [0x2071E58], None, "DseTrackEvent_SetOctave", "", None
    )

    DseTrackEvent_OctaveDelta = Symbol(
        [0x59F4], [0x2071E64], None, "DseTrackEvent_OctaveDelta", "", None
    )

    DseTrackEvent_SetBpm = Symbol(
        [0x5A08], [0x2071E78], None, "DseTrackEvent_SetBpm", "", None
    )

    DseTrackEvent_SetBpm2 = Symbol(
        [0x5A48], [0x2071EB8], None, "DseTrackEvent_SetBpm2", "", None
    )

    DseTrackEvent_SetBank = Symbol(
        [0x5A88], [0x2071EF8], None, "DseTrackEvent_SetBank", "", None
    )

    DseTrackEvent_SetBankMsb = Symbol(
        [0x5AB4], [0x2071F24], None, "DseTrackEvent_SetBankMsb", "", None
    )

    DseTrackEvent_SetBankLsb = Symbol(
        [0x5AE4], [0x2071F54], None, "DseTrackEvent_SetBankLsb", "", None
    )

    DseTrackEvent_Dummy1Byte = Symbol(
        [0x5B14], [0x2071F84], None, "DseTrackEvent_Dummy1Byte", "", None
    )

    DseTrackEvent_SetInstrument = Symbol(
        [0x5B1C], [0x2071F8C], None, "DseTrackEvent_SetInstrument", "", None
    )

    DseTrackEvent_SongVolumeFade = Symbol(
        [0x5B64], [0x2071FD4], None, "DseTrackEvent_SongVolumeFade", "", None
    )

    DseTrackEvent_RestoreEnvelopeDefaults = Symbol(
        [0x5BF0], [0x2072060], None, "DseTrackEvent_RestoreEnvelopeDefaults", "", None
    )

    DseTrackEvent_SetEnvelopeAttackBegin = Symbol(
        [0x5C08], [0x2072078], None, "DseTrackEvent_SetEnvelopeAttackBegin", "", None
    )

    DseTrackEvent_SetEnvelopeAttackTime = Symbol(
        [0x5C28], [0x2072098], None, "DseTrackEvent_SetEnvelopeAttackTime", "", None
    )

    DseTrackEvent_SetEnvelopeHoldTime = Symbol(
        [0x5C48], [0x20720B8], None, "DseTrackEvent_SetEnvelopeHoldTime", "", None
    )

    DseTrackEvent_SetEnvelopeDecayTimeAndSustainLevel = Symbol(
        [0x5C68],
        [0x20720D8],
        None,
        "DseTrackEvent_SetEnvelopeDecayTimeAndSustainLevel",
        "",
        None,
    )

    DseTrackEvent_SetEnvelopeSustainTime = Symbol(
        [0x5C98], [0x2072108], None, "DseTrackEvent_SetEnvelopeSustainTime", "", None
    )

    DseTrackEvent_SetEnvelopeReleaseTime = Symbol(
        [0x5CB8], [0x2072128], None, "DseTrackEvent_SetEnvelopeReleaseTime", "", None
    )

    DseTrackEvent_SetNoteDurationMultiplier = Symbol(
        [0x5CD8], [0x2072148], None, "DseTrackEvent_SetNoteDurationMultiplier", "", None
    )

    DseTrackEvent_ForceLfoEnvelopeLevel = Symbol(
        [0x5CE4], [0x2072154], None, "DseTrackEvent_ForceLfoEnvelopeLevel", "", None
    )

    DseTrackEvent_SetHoldNotes = Symbol(
        [0x5D00], [0x2072170], None, "DseTrackEvent_SetHoldNotes", "", None
    )

    DseTrackEvent_SetFlagBit1Unknown = Symbol(
        [0x5D38], [0x20721A8], None, "DseTrackEvent_SetFlagBit1Unknown", "", None
    )

    DseTrackEvent_SetOptionalVolume = Symbol(
        [0x5D48], [0x20721B8], None, "DseTrackEvent_SetOptionalVolume", "", None
    )

    DseTrackEvent_Dummy2Bytes = Symbol(
        [0x5D54], [0x20721C4], None, "DseTrackEvent_Dummy2Bytes", "", None
    )

    DseTrackEvent_SetTuning = Symbol(
        [0x5D5C], [0x20721CC], None, "DseTrackEvent_SetTuning", "", None
    )

    DseTrackEvent_TuningDeltaCoarse = Symbol(
        [0x5DDC], [0x207224C], None, "DseTrackEvent_TuningDeltaCoarse", "", None
    )

    DseTrackEvent_TuningDeltaFine = Symbol(
        [0x5E64], [0x20722D4], None, "DseTrackEvent_TuningDeltaFine", "", None
    )

    DseTrackEvent_TuningDeltaFull = Symbol(
        [0x5EEC], [0x207235C], None, "DseTrackEvent_TuningDeltaFull", "", None
    )

    DseTrackEvent_TuningFade = Symbol(
        [0x5F7C], [0x20723EC], None, "DseTrackEvent_TuningFade", "", None
    )

    DseTrackEvent_SetNoteRandomRegion = Symbol(
        [0x606C], [0x20724DC], None, "DseTrackEvent_SetNoteRandomRegion", "", None
    )

    DseTrackEvent_SetTuningJitterAmplitude = Symbol(
        [0x6094], [0x2072504], None, "DseTrackEvent_SetTuningJitterAmplitude", "", None
    )

    DseTrackEvent_SetKeyBend = Symbol(
        [0x60AC], [0x207251C], None, "DseTrackEvent_SetKeyBend", "", None
    )

    DseTrackEvent_SetUnknown2 = Symbol(
        [0x60D8], [0x2072548], None, "DseTrackEvent_SetUnknown2", "", None
    )

    DseTrackEvent_SetKeyBendRange = Symbol(
        [0x60F0], [0x2072560], None, "DseTrackEvent_SetKeyBendRange", "", None
    )

    DseTrackEvent_SetupKeyBendLfo = Symbol(
        [0x60FC], [0x207256C], None, "DseTrackEvent_SetupKeyBendLfo", "", None
    )

    DseTrackEvent_SetupKeyBendLfoEnvelope = Symbol(
        [0x6154], [0x20725C4], None, "DseTrackEvent_SetupKeyBendLfoEnvelope", "", None
    )

    DseTrackEvent_UseKeyBendLfo = Symbol(
        [0x617C], [0x20725EC], None, "DseTrackEvent_UseKeyBendLfo", "", None
    )

    DseTrackEvent_SetVolume = Symbol(
        [0x61A4], [0x2072614], None, "DseTrackEvent_SetVolume", "", None
    )

    DseTrackEvent_VolumeDelta = Symbol(
        [0x6238], [0x20726A8], None, "DseTrackEvent_VolumeDelta", "", None
    )

    DseTrackEvent_VolumeFade = Symbol(
        [0x62E8], [0x2072758], None, "DseTrackEvent_VolumeFade", "", None
    )

    DseTrackEvent_SetExpression = Symbol(
        [0x6344], [0x20727B4], None, "DseTrackEvent_SetExpression", "", None
    )

    DseTrackEvent_SetupVolumeLfo = Symbol(
        [0x63D0], [0x2072840], None, "DseTrackEvent_SetupVolumeLfo", "", None
    )

    DseTrackEvent_SetupVolumeLfoEnvelope = Symbol(
        [0x642C], [0x207289C], None, "DseTrackEvent_SetupVolumeLfoEnvelope", "", None
    )

    DseTrackEvent_UseVolumeLfo = Symbol(
        [0x6454], [0x20728C4], None, "DseTrackEvent_UseVolumeLfo", "", None
    )

    DseTrackEvent_SetPan = Symbol(
        [0x647C], [0x20728EC], None, "DseTrackEvent_SetPan", "", None
    )

    DseTrackEvent_PanDelta = Symbol(
        [0x64FC], [0x207296C], None, "DseTrackEvent_PanDelta", "", None
    )

    DseTrackEvent_PanFade = Symbol(
        [0x6590], [0x2072A00], None, "DseTrackEvent_PanFade", "", None
    )

    DseTrackEvent_SetupPanLfo = Symbol(
        [0x65EC], [0x2072A5C], None, "DseTrackEvent_SetupPanLfo", "", None
    )

    DseTrackEvent_SetupPanLfoEnvelope = Symbol(
        [0x6648], [0x2072AB8], None, "DseTrackEvent_SetupPanLfoEnvelope", "", None
    )

    DseTrackEvent_UsePanLfo = Symbol(
        [0x6670], [0x2072AE0], None, "DseTrackEvent_UsePanLfo", "", None
    )

    DseTrackEvent_SetupLfo = Symbol(
        [0x6698], [0x2072B08], None, "DseTrackEvent_SetupLfo", "", None
    )

    DseTrackEvent_SetupLfoEnvelope = Symbol(
        [0x66F0], [0x2072B60], None, "DseTrackEvent_SetupLfoEnvelope", "", None
    )

    DseTrackEvent_SetLfoParameter = Symbol(
        [0x6724], [0x2072B94], None, "DseTrackEvent_SetLfoParameter", "", None
    )

    DseTrackEvent_UseLfo = Symbol(
        [0x6860], [0x2072CD0], None, "DseTrackEvent_UseLfo", "", None
    )

    DseTrackEvent_Signal = Symbol(
        [0x6894], [0x2072D04], None, "DseTrackEvent_Signal", "", None
    )

    DseTrackEvent_Dummy2Bytes2 = Symbol(
        [0x68C4], [0x2072D34], None, "DseTrackEvent_Dummy2Bytes2", "", None
    )

    DseSynth_Reset = Symbol([0x7130], [0x20735A0], None, "DseSynth_Reset", "", None)

    DseSynth_AllocateNew = Symbol(
        [0x71A8], [0x2073618], None, "DseSynth_AllocateNew", "", None
    )

    DseSynth_Unload = Symbol([0x7278], [0x20736E8], None, "DseSynth_Unload", "", None)

    DseSynth_ClearHeldNotes = Symbol(
        [0x72E4], [0x2073754], None, "DseSynth_ClearHeldNotes", "", None
    )

    DseSynth_ResetAndSetBankAndSequence = Symbol(
        [0x7380], [0x20737F0], None, "DseSynth_ResetAndSetBankAndSequence", "", None
    )

    DseSynth_StopChannels = Symbol(
        [0x73A8], [0x2073818], None, "DseSynth_StopChannels", "", None
    )

    DseSynth_ResetAllVoiceTimersAndVolumes = Symbol(
        [0x73D4], [0x2073844], None, "DseSynth_ResetAllVoiceTimersAndVolumes", "", None
    )

    DseSynth_RestoreHeldNotes = Symbol(
        [0x742C], [0x207389C], None, "DseSynth_RestoreHeldNotes", "", None
    )

    DseSynth_SetGlobalVolumeIndex = Symbol(
        [0x7494], [0x2073904], None, "DseSynth_SetGlobalVolumeIndex", "", None
    )

    DseSynth_SetBend = Symbol([0x757C], [0x20739EC], None, "DseSynth_SetBend", "", None)

    DseSynth_SetVolume = Symbol(
        [0x7610], [0x2073A80], None, "DseSynth_SetVolume", "", None
    )

    DseSynth_SetPan = Symbol([0x76E0], [0x2073B50], None, "DseSynth_SetPan", "", None)

    DseSynth_SetBankAndSequence = Symbol(
        [0x7774], [0x2073BE4], None, "DseSynth_SetBankAndSequence", "", None
    )

    DseChannel_Init = Symbol([0x7804], [0x2073C74], None, "DseChannel_Init", "", None)

    DseChannel_DeallocateVoices = Symbol(
        [0x79B8], [0x2073E28], None, "DseChannel_DeallocateVoices", "", None
    )

    DseChannel_ResetTimerAndVolumeForVoices = Symbol(
        [0x7A3C], [0x2073EAC], None, "DseChannel_ResetTimerAndVolumeForVoices", "", None
    )

    DseChannel_SetBank = Symbol(
        [0x7AB8], [0x2073F28], None, "DseChannel_SetBank", "", None
    )

    DseChannel_SetInstrument = Symbol(
        [0x7AF0], [0x2073F60], None, "DseChannel_SetInstrument", "", None
    )

    DseChannel_SetLfoConstEnvelopeLevel = Symbol(
        [0x7B84], [0x2073FF4], None, "DseChannel_SetLfoConstEnvelopeLevel", "", None
    )

    DseChannel_SetKeyBend = Symbol(
        [0x7BB8], [0x2074028], None, "DseChannel_SetKeyBend", "", None
    )

    DseChannel_AllocateNote = Symbol(
        [0x7C00], [0x2074070], None, "DseChannel_AllocateNote", "", None
    )

    DseChannel_ReleaseNoteInternal = Symbol(
        [0x7C90], [0x2074100], None, "DseChannel_ReleaseNoteInternal", "", None
    )

    DseChannel_ChangeNote = Symbol(
        [0x7D38], [0x20741A8], None, "DseChannel_ChangeNote", "", None
    )

    DseChannel_ReleaseNote = Symbol(
        [0x7DC8], [0x2074238], None, "DseChannel_ReleaseNote", "", None
    )

    DseVoice_PlayNote = Symbol(
        [0x7E04], [0x2074274], None, "DseVoice_PlayNote", "", None
    )

    DseVoice_ReleaseNote = Symbol(
        [0x8078], [0x20744E8], None, "DseVoice_ReleaseNote", "", None
    )

    DseVoice_UpdateParameters = Symbol(
        [0x80BC], [0x207452C], None, "DseVoice_UpdateParameters", "", None
    )

    DseVoice_ResetAll = Symbol(
        [0x8260], [0x20746D0], None, "DseVoice_ResetAll", "", None
    )

    DseVoice_ResetHW = Symbol([0x8304], [0x2074774], None, "DseVoice_ResetHW", "", None)

    UpdateChannels = Symbol(
        [0x83B4],
        [0x2074824],
        None,
        "UpdateChannels",
        "From https://projectpokemon.org/docs/mystery-dungeon-nds/procyon-studios-digital-sound-elements-r12/ and Irdkwia's notes.\n\nNo params.",
        None,
    )

    DseVoice_Cleanup = Symbol([0x84A4], [0x2074914], None, "DseVoice_Cleanup", "", None)

    DseVoice_Allocate = Symbol(
        [0x8540], [0x20749B0], None, "DseVoice_Allocate", "", None
    )

    DseVoice_Start = Symbol([0x86A8], [0x2074B18], None, "DseVoice_Start", "", None)

    DseVoice_ReleaseHeld = Symbol(
        [0x8704], [0x2074B74], None, "DseVoice_ReleaseHeld", "", None
    )

    DseVoice_Release = Symbol([0x8784], [0x2074BF4], None, "DseVoice_Release", "", None)

    DseVoice_Deallocate = Symbol(
        [0x87C8], [0x2074C38], None, "DseVoice_Deallocate", "", None
    )

    DseVoice_FlagForActivation = Symbol(
        [0x88CC], [0x2074D3C], None, "DseVoice_FlagForActivation", "", None
    )

    DseVoice_FlagForDeactivation = Symbol(
        [0x891C], [0x2074D8C], None, "DseVoice_FlagForDeactivation", "", None
    )

    DseVoice_CountNumActiveInChannel = Symbol(
        [0x8954], [0x2074DC4], None, "DseVoice_CountNumActiveInChannel", "", None
    )

    DseVoice_UpdateHardware = Symbol(
        [0x8980], [0x2074DF0], None, "DseVoice_UpdateHardware", "", None
    )

    SoundEnvelope_Reset = Symbol(
        [0x8B98],
        [0x2075008],
        None,
        "SoundEnvelope_Reset",
        "r0: Sound envelope pointer",
        None,
    )

    SoundEnvelopeParameters_Reset = Symbol(
        [0x8BAC],
        [0x207501C],
        None,
        "SoundEnvelopeParameters_Reset",
        "r0: Sound envelope parameters pointer",
        None,
    )

    SoundEnvelopeParameters_CheckValidity = Symbol(
        [0x8BC8],
        [0x2075038],
        None,
        "SoundEnvelopeParameters_CheckValidity",
        "r0: Sound envelope parameters pointer",
        None,
    )

    SoundEnvelope_SetParameters = Symbol(
        [0x8C1C],
        [0x207508C],
        None,
        "SoundEnvelope_SetParameters",
        "r0: Sound envelope pointer\nr1: Sound envelope parameters pointer",
        None,
    )

    SoundEnvelope_SetSlide = Symbol(
        [0x8C80],
        [0x20750F0],
        None,
        "SoundEnvelope_SetSlide",
        "r0: Sound envelope pointer\nr1: Target volume\nr2: Music duration lookup table index",
        None,
    )

    UpdateTrackVolumeEnvelopes = Symbol(
        [0x8D34],
        [0x20751A4],
        None,
        "UpdateTrackVolumeEnvelopes",
        "From https://projectpokemon.org/docs/mystery-dungeon-nds/procyon-studios-digital-sound-elements-r12/\n\nr0: Sound envelope pointer",
        None,
    )

    SoundEnvelope_Release = Symbol(
        [0x8E00],
        [0x2075270],
        None,
        "SoundEnvelope_Release",
        "r0: Sound envelope pointer",
        None,
    )

    SoundEnvelope_Stop = Symbol(
        [0x8E2C],
        [0x207529C],
        None,
        "SoundEnvelope_Stop",
        "r0: Sound envelope pointer",
        None,
    )

    SoundEnvelope_ForceVolume = Symbol(
        [0x8E44],
        [0x20752B4],
        None,
        "SoundEnvelope_ForceVolume",
        "r0: Sound envelope pointer\nr1: Volume",
        None,
    )

    SoundEnvelope_Stop2 = Symbol(
        [0x8E64],
        [0x20752D4],
        None,
        "SoundEnvelope_Stop2",
        "r0: Sound envelope pointer",
        None,
    )

    SoundEnvelope_Tick = Symbol(
        [0x8E7C],
        [0x20752EC],
        None,
        "SoundEnvelope_Tick",
        "r0: Sound envelope pointer\nreturn: Current volume",
        None,
    )

    SoundLfoBank_Reset = Symbol(
        [0x8FC4], [0x2075434], None, "SoundLfoBank_Reset", "r0: LFO bank pointer", None
    )

    SoundLfoBank_Set = Symbol(
        [0x8FDC],
        [0x207544C],
        None,
        "SoundLfoBank_Set",
        "r0: LFO bank pointer\nr1: LFO settings pointer\nr2: Envelope level",
        None,
    )

    SoundLfoBank_SetConstEnvelopes = Symbol(
        [0x91D4],
        [0x2075644],
        None,
        "SoundLfoBank_SetConstEnvelopes",
        "r0: LFO bank pointer\nr1: Level",
        None,
    )

    SoundLfoBank_Tick = Symbol(
        [0x9220],
        [0x2075690],
        None,
        "SoundLfoBank_Tick",
        "r0: LFO bank pointer\nreturn: New voice update flags",
        None,
    )

    SoundLfoWave_InvalidFunc = Symbol(
        [0x92D4],
        [0x2075744],
        None,
        "SoundLfoWave_InvalidFunc",
        "r0: LFO pointer\nreturn: 0",
        None,
    )

    SoundLfoWave_HalfSquareFunc = Symbol(
        [0x92E8],
        [0x2075758],
        None,
        "SoundLfoWave_HalfSquareFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_FullSquareFunc = Symbol(
        [0x9324],
        [0x2075794],
        None,
        "SoundLfoWave_FullSquareFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_HalfTriangleFunc = Symbol(
        [0x936C],
        [0x20757DC],
        None,
        "SoundLfoWave_HalfTriangleFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_FullTriangleFunc = Symbol(
        [0x93C0],
        [0x2075830],
        None,
        "SoundLfoWave_FullTriangleFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_SawFunc = Symbol(
        [0x9424],
        [0x2075894],
        None,
        "SoundLfoWave_SawFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_ReverseSawFunc = Symbol(
        [0x9460],
        [0x20758D0],
        None,
        "SoundLfoWave_ReverseSawFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_HalfNoiseFunc = Symbol(
        [0x949C],
        [0x207590C],
        None,
        "SoundLfoWave_HalfNoiseFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    SoundLfoWave_FullNoiseFunc = Symbol(
        [0x94E0],
        [0x2075950],
        None,
        "SoundLfoWave_FullNoiseFunc",
        "r0: LFO pointer\nreturn: LFO current output",
        None,
    )

    Crypto_RC4Init = Symbol([0x9648], [0x2075AB8], None, "Crypto_RC4Init", "", None)

    Mtx_LookAt = Symbol([0x9750], [0x2075BC0], None, "Mtx_LookAt", "", None)

    Mtx_OrthoW = Symbol([0x9858], [0x2075CC8], None, "Mtx_OrthoW", "", None)

    FX_Div = Symbol([0x9A60], [0x2075ED0], None, "FX_Div", "", None)

    FX_GetDivResultFx64c = Symbol(
        [0x9A70], [0x2075EE0], None, "FX_GetDivResultFx64c", "", None
    )

    FX_GetDivResult = Symbol([0x9A94], [0x2075F04], None, "FX_GetDivResult", "", None)

    FX_InvAsync = Symbol([0x9ACC], [0x2075F3C], None, "FX_InvAsync", "", None)

    FX_DivAsync = Symbol([0x9AFC], [0x2075F6C], None, "FX_DivAsync", "", None)

    FX_DivS32 = Symbol([0x9B24], [0x2075F94], None, "FX_DivS32", "", None)

    FX_ModS32 = Symbol([0x9B60], [0x2075FD0], None, "FX_ModS32", "", None)

    Vec_DotProduct = Symbol([0x9B9C], [0x207600C], None, "Vec_DotProduct", "", None)

    Vec_CrossProduct = Symbol([0x9BD8], [0x2076048], None, "Vec_CrossProduct", "", None)

    Vec_Normalize = Symbol([0x9C5C], [0x20760CC], None, "Vec_Normalize", "", None)

    Vec_Distance = Symbol([0x9D74], [0x20761E4], None, "Vec_Distance", "", None)

    FX_Atan2Idx = Symbol([0x9DF0], [0x2076260], None, "FX_Atan2Idx", "", None)

    GX_Init = Symbol([0x9F9C], [0x207640C], None, "GX_Init", "", None)

    GX_HBlankIntr = Symbol([0xA0E8], [0x2076558], None, "GX_HBlankIntr", "", None)

    GX_VBlankIntr = Symbol([0xA110], [0x2076580], None, "GX_VBlankIntr", "", None)

    GX_DispOff = Symbol([0xA144], [0x20765B4], None, "GX_DispOff", "", None)

    GX_DispOn = Symbol([0xA180], [0x20765F0], None, "GX_DispOn", "", None)

    GX_SetGraphicsMode = Symbol(
        [0xA1C8], [0x2076638], None, "GX_SetGraphicsMode", "", None
    )

    Gxs_SetGraphicsMode = Symbol(
        [0xA230], [0x20766A0], None, "Gxs_SetGraphicsMode", "", None
    )

    GXx_SetMasterBrightness = Symbol(
        [0xA24C], [0x20766BC], None, "GXx_SetMasterBrightness", "", None
    )

    GX_InitGxState = Symbol([0xA274], [0x20766E4], None, "GX_InitGxState", "", None)

    EnableVramBanksInSetDontSave = Symbol(
        [0xA2D4],
        [0x2076744],
        None,
        "EnableVramBanksInSetDontSave",
        "Enable the VRAM bank marked in the input set, but don’t mark them as enabled in ENABLED_VRAM_BANKS\n\nr0: vram_banks_set",
        None,
    )

    GX_SetBankForBg = Symbol([0xA38C], [0x20767FC], None, "GX_SetBankForBg", "", None)

    GX_SetBankForObj = Symbol([0xA61C], [0x2076A8C], None, "GX_SetBankForObj", "", None)

    GX_SetBankForBgExtPltt = Symbol(
        [0xA76C], [0x2076BDC], None, "GX_SetBankForBgExtPltt", "", None
    )

    GX_SetBankForObjExtPltt = Symbol(
        [0xA86C], [0x2076CDC], None, "GX_SetBankForObjExtPltt", "", None
    )

    GX_SetBankForTex = Symbol([0xA918], [0x2076D88], None, "GX_SetBankForTex", "", None)

    GX_SetBankForTexPltt = Symbol(
        [0xAAF0], [0x2076F60], None, "GX_SetBankForTexPltt", "", None
    )

    GX_SetBankForClearImage = Symbol(
        [0xABD8], [0x2077048], None, "GX_SetBankForClearImage", "", None
    )

    GX_SetBankForArm7 = Symbol(
        [0xAD0C], [0x207717C], None, "GX_SetBankForArm7", "", None
    )

    GX_SetBankForLcdc = Symbol(
        [0xADB8], [0x2077228], None, "GX_SetBankForLcdc", "", None
    )

    GX_SetBankForSubBg = Symbol(
        [0xADD8], [0x2077248], None, "GX_SetBankForSubBg", "", None
    )

    GX_SetBankForSubObj = Symbol(
        [0xAE80], [0x20772F0], None, "GX_SetBankForSubObj", "", None
    )

    GX_SetBankForSubBgExtPltt = Symbol(
        [0xAEF0], [0x2077360], None, "GX_SetBankForSubBgExtPltt", "", None
    )

    GX_SetBankForSubObjExtPltt = Symbol(
        [0xAF70], [0x20773E0], None, "GX_SetBankForSubObjExtPltt", "", None
    )

    EnableVramBanksInSet = Symbol(
        [0xAFF0],
        [0x2077460],
        None,
        "EnableVramBanksInSet",
        "Enable the VRAM banks in the input set. Will reset the pointed set to 0, and update ENABLED_VRAM_BANKS\n\nr0: vram_banks_set *",
        None,
    )

    GX_ResetBankForBgExtPltt = Symbol(
        [0xB024], [0x2077494], None, "GX_ResetBankForBgExtPltt", "", None
    )

    GX_ResetBankForObjExtPltt = Symbol(
        [0xB048], [0x20774B8], None, "GX_ResetBankForObjExtPltt", "", None
    )

    GX_ResetBankForTex = Symbol(
        [0xB06C], [0x20774DC], None, "GX_ResetBankForTex", "", None
    )

    GX_ResetBankForTexPltt = Symbol(
        [0xB080], [0x20774F0], None, "GX_ResetBankForTexPltt", "", None
    )

    GX_ResetBankForSubBgExtPltt = Symbol(
        [0xB094], [0x2077504], None, "GX_ResetBankForSubBgExtPltt", "", None
    )

    GX_ResetBankForSubObjExtPltt = Symbol(
        [0xB0BC], [0x207752C], None, "GX_ResetBankForSubObjExtPltt", "", None
    )

    DisableBankForX = Symbol([0xB0E4], [0x2077554], None, "DisableBankForX", "", None)

    GX_DisableBankForBg = Symbol(
        [0xB1C4], [0x2077634], None, "GX_DisableBankForBg", "", None
    )

    GX_DisableBankForObj = Symbol(
        [0xB1D8], [0x2077648], None, "GX_DisableBankForObj", "", None
    )

    GX_DisableBankForBgExtPltt = Symbol(
        [0xB1EC], [0x207765C], None, "GX_DisableBankForBgExtPltt", "", None
    )

    GX_DisableBankForObjExtPltt = Symbol(
        [0xB210], [0x2077680], None, "GX_DisableBankForObjExtPltt", "", None
    )

    GX_DisableBankForTex = Symbol(
        [0xB234], [0x20776A4], None, "GX_DisableBankForTex", "", None
    )

    GX_DisableBankForTexPltt = Symbol(
        [0xB248], [0x20776B8], None, "GX_DisableBankForTexPltt", "", None
    )

    GX_DisableBankForClearImage = Symbol(
        [0xB25C], [0x20776CC], None, "GX_DisableBankForClearImage", "", None
    )

    GX_DisableBankForArm7 = Symbol(
        [0xB270], [0x20776E0], None, "GX_DisableBankForArm7", "", None
    )

    GX_DisableBankForLcdc = Symbol(
        [0xB284], [0x20776F4], None, "GX_DisableBankForLcdc", "", None
    )

    GX_DisableBankForSubBg = Symbol(
        [0xB298], [0x2077708], None, "GX_DisableBankForSubBg", "", None
    )

    GX_DisableBankForSubObj = Symbol(
        [0xB2AC], [0x207771C], None, "GX_DisableBankForSubObj", "", None
    )

    GX_DisableBankForSubBgExtPltt = Symbol(
        [0xB2C0], [0x2077730], None, "GX_DisableBankForSubBgExtPltt", "", None
    )

    GX_DisableBankForSubObjExtPltt = Symbol(
        [0xB2E8], [0x2077758], None, "GX_DisableBankForSubObjExtPltt", "", None
    )

    G2_GetBG0ScrPtr = Symbol([0xB310], [0x2077780], None, "G2_GetBG0ScrPtr", "", None)

    G2S_GetBG0ScrPtr = Symbol([0xB344], [0x20777B4], None, "G2S_GetBG0ScrPtr", "", None)

    G2_GetBG1ScrPtr = Symbol([0xB364], [0x20777D4], None, "G2_GetBG1ScrPtr", "", None)

    G2S_GetBG1ScrPtr = Symbol([0xB398], [0x2077808], None, "G2S_GetBG1ScrPtr", "", None)

    G2_GetBG2ScrPtr = Symbol([0xB3B8], [0x2077828], None, "G2_GetBG2ScrPtr", "", None)

    G2_GetBG3ScrPtr = Symbol([0xB43C], [0x20778AC], None, "G2_GetBG3ScrPtr", "", None)

    G2_GetBG0CharPtr = Symbol([0xB4C0], [0x2077930], None, "G2_GetBG0CharPtr", "", None)

    G2S_GetBG0CharPtr = Symbol(
        [0xB4F4], [0x2077964], None, "G2S_GetBG0CharPtr", "", None
    )

    G2_GetBG1CharPtr = Symbol([0xB514], [0x2077984], None, "G2_GetBG1CharPtr", "", None)

    G2S_GetBG1CharPtr = Symbol(
        [0xB548], [0x20779B8], None, "G2S_GetBG1CharPtr", "", None
    )

    G2_GetBG2CharPtr = Symbol([0xB568], [0x20779D8], None, "G2_GetBG2CharPtr", "", None)

    G2_GetBG3CharPtr = Symbol([0xB5B8], [0x2077A28], None, "G2_GetBG3CharPtr", "", None)

    G2x_SetBlendAlpha = Symbol(
        [0xB610], [0x2077A80], None, "G2x_SetBlendAlpha", "", None
    )

    G2x_SetBlendBrightness = Symbol(
        [0xB62C], [0x2077A9C], None, "G2x_SetBlendBrightness", "", None
    )

    G2x_ChangeBlendBrightness = Symbol(
        [0xB654], [0x2077AC4], None, "G2x_ChangeBlendBrightness", "", None
    )

    G3_LoadMtx44 = Symbol([0xB698], [0x2077B08], None, "G3_LoadMtx44", "", None)

    G3_LoadMtx43 = Symbol(
        [0xB6B4],
        [0x2077B24],
        None,
        "G3_LoadMtx43",
        "Send the MTX_LOAD_4x3 geometry engine command, through a GXFIFO command. See https://problemkaputt.de/gbatek.htm#ds3dgeometrycommands and https://problemkaputt.de/gbatek.htm#ds3dmatrixloadmultiply for more information.\n\nThis pops the top of the current matrix stack (https://problemkaputt.de/gbatek.htm#ds3dmatrixstack) and sets it as the engine's 'current' matrix. It's commonly preceded by a MTX_PUSH command to populate the matrix stack with a matrix.\n\nr0: matrix_4x3 pointer",
        None,
    )

    G3_MultMtx43 = Symbol(
        [0xB6D0],
        [0x2077B40],
        None,
        "G3_MultMtx43",
        "Send the MTX_MULT_4x3 geometry engine command, through a GXFIFO command. See https://problemkaputt.de/gbatek.htm#ds3dgeometrycommands and https://problemkaputt.de/gbatek.htm#ds3dmatrixloadmultiply for more information.\n\nThis pops the top of the current matrix stack (https://problemkaputt.de/gbatek.htm#ds3dmatrixstack) and left-multiplies the engine's 'current' matrix by the new matrix. It's commonly preceded by a MTX_PUSH command to populate the matrix stack with a matrix.\n\nr0: matrix_4x3 pointer",
        None,
    )

    G3X_Init = Symbol([0xB6EC], [0x2077B5C], None, "G3X_Init", "", None)

    G3X_Reset = Symbol([0xB7F8], [0x2077C68], None, "G3X_Reset", "", None)

    G3X_ClearFifo = Symbol([0xB864], [0x2077CD4], None, "G3X_ClearFifo", "", None)

    G3X_InitMtxStack = Symbol([0xB88C], [0x2077CFC], None, "G3X_InitMtxStack", "", None)

    G3X_ResetMtxStack = Symbol(
        [0xB924], [0x2077D94], None, "G3X_ResetMtxStack", "", None
    )

    G3X_SetClearColor = Symbol(
        [0xB9B4], [0x2077E24], None, "G3X_SetClearColor", "", None
    )

    G3X_InitTable = Symbol([0xB9DC], [0x2077E4C], None, "G3X_InitTable", "", None)

    G3X_GetMtxStackLevelPV = Symbol(
        [0xBA7C], [0x2077EEC], None, "G3X_GetMtxStackLevelPV", "", None
    )

    G3X_GetMtxStackLevelPJ = Symbol(
        [0xBAAC], [0x2077F1C], None, "G3X_GetMtxStackLevelPJ", "", None
    )

    GXi_NopClearFifo128 = Symbol(
        [0xBADC], [0x2077F4C], None, "GXi_NopClearFifo128", "", None
    )

    G3i_OrthoW = Symbol([0xBB70], [0x2077FE0], None, "G3i_OrthoW", "", None)

    G3i_LookAt = Symbol([0xBBD4], [0x2078044], None, "G3i_LookAt", "", None)

    GX_LoadBgPltt = Symbol([0xBC20], [0x2078090], None, "GX_LoadBgPltt", "", None)

    Gxs_LoadBgPltt = Symbol([0xBC74], [0x20780E4], None, "Gxs_LoadBgPltt", "", None)

    GX_LoadObjPltt = Symbol([0xBCCC], [0x207813C], None, "GX_LoadObjPltt", "", None)

    Gxs_LoadObjPltt = Symbol([0xBD24], [0x2078194], None, "Gxs_LoadObjPltt", "", None)

    GX_LoadOam = Symbol([0xBD7C], [0x20781EC], None, "GX_LoadOam", "", None)

    Gxs_LoadOam = Symbol([0xBDD0], [0x2078240], None, "Gxs_LoadOam", "", None)

    GX_LoadObj = Symbol([0xBE28], [0x2078298], None, "GX_LoadObj", "", None)

    Gxs_LoadObj = Symbol([0xBE80], [0x20782F0], None, "Gxs_LoadObj", "", None)

    GX_LoadBg0Scr = Symbol([0xBED8], [0x2078348], None, "GX_LoadBg0Scr", "", None)

    GX_LoadBg1Scr = Symbol([0xBF38], [0x20783A8], None, "GX_LoadBg1Scr", "", None)

    Gxs_LoadBg1Scr = Symbol([0xBF98], [0x2078408], None, "Gxs_LoadBg1Scr", "", None)

    GX_LoadBg2Scr = Symbol([0xBFF8], [0x2078468], None, "GX_LoadBg2Scr", "", None)

    GX_LoadBg3Scr = Symbol([0xC058], [0x20784C8], None, "GX_LoadBg3Scr", "", None)

    GX_LoadBg0Char = Symbol([0xC0B8], [0x2078528], None, "GX_LoadBg0Char", "", None)

    Gxs_LoadBg0Char = Symbol([0xC118], [0x2078588], None, "Gxs_LoadBg0Char", "", None)

    GX_LoadBg1Char = Symbol([0xC178], [0x20785E8], None, "GX_LoadBg1Char", "", None)

    Gxs_LoadBg1Char = Symbol([0xC1D8], [0x2078648], None, "Gxs_LoadBg1Char", "", None)

    GX_LoadBg2Char = Symbol([0xC238], [0x20786A8], None, "GX_LoadBg2Char", "", None)

    GX_LoadBg3Char = Symbol([0xC298], [0x2078708], None, "GX_LoadBg3Char", "", None)

    GX_BeginLoadBgExtPltt = Symbol(
        [0xC2F8], [0x2078768], None, "GX_BeginLoadBgExtPltt", "", None
    )

    GX_EndLoadBgExtPltt = Symbol(
        [0xC398], [0x2078808], None, "GX_EndLoadBgExtPltt", "", None
    )

    GX_BeginLoadObjExtPltt = Symbol(
        [0xC3E0], [0x2078850], None, "GX_BeginLoadObjExtPltt", "", None
    )

    GX_EndLoadObjExtPltt = Symbol(
        [0xC428], [0x2078898], None, "GX_EndLoadObjExtPltt", "", None
    )

    Gxs_BeginLoadBgExtPltt = Symbol(
        [0xC46C], [0x20788DC], None, "Gxs_BeginLoadBgExtPltt", "", None
    )

    Gxs_EndLoadBgExtPltt = Symbol(
        [0xC484], [0x20788F4], None, "Gxs_EndLoadBgExtPltt", "", None
    )

    Gxs_BeginLoadObjExtPltt = Symbol(
        [0xC4C4], [0x2078934], None, "Gxs_BeginLoadObjExtPltt", "", None
    )

    Gxs_EndLoadObjExtPltt = Symbol(
        [0xC4DC], [0x207894C], None, "Gxs_EndLoadObjExtPltt", "", None
    )

    GX_BeginLoadTex = Symbol([0xC51C], [0x207898C], None, "GX_BeginLoadTex", "", None)

    GX_LoadTex = Symbol([0xC578], [0x20789E8], None, "GX_LoadTex", "", None)

    GX_EndLoadTex = Symbol([0xC6B8], [0x2078B28], None, "GX_EndLoadTex", "", None)

    GX_BeginLoadTexPltt = Symbol(
        [0xC704], [0x2078B74], None, "GX_BeginLoadTexPltt", "", None
    )

    GX_LoadTexPltt = Symbol([0xC738], [0x2078BA8], None, "GX_LoadTexPltt", "", None)

    GX_EndLoadTexPltt = Symbol(
        [0xC7A4], [0x2078C14], None, "GX_EndLoadTexPltt", "", None
    )

    GeomGxFifoSendMtx4x3 = Symbol(
        [0xC7E8],
        [0x2078C58],
        None,
        "GeomGxFifoSendMtx4x3",
        "Send a 4x3 matrix argument for a GXFIFO geometry engine command.\n\nThis function is used by GeomMtxLoad4x3 and GeomMtxMult4x3 to pass the matrix argument for a GXFIFO command after already having written the command code. See https://problemkaputt.de/gbatek.htm#ds3dgeometrycommands for more information.\n\nNote that the GXFIFO address is 0x4000400, but is (maybe) mirrored up to 0x400043F. This function is optimized to take advantage of this by writing 3 matrix entries at a time using ldmia and stmia instructions.\n\nr0: matrix_4x3 pointer\nr1: GXFIFO pointer",
        None,
    )

    GX_SendFifo64B = Symbol([0xC80C], [0x2078C7C], None, "GX_SendFifo64B", "", None)

    OS_GetLockID = Symbol([0xCF54], [0x20793C4], None, "OS_GetLockID", "", None)

    IncrementThreadCount = Symbol(
        [0xD078],
        [0x20794E8],
        None,
        "IncrementThreadCount",
        "Increments thread_info::thread_count by 1 and returns the new value.\n\nreturn: New thread count",
        None,
    )

    InsertThreadIntoList = Symbol(
        [0xD1C0],
        [0x2079630],
        None,
        "InsertThreadIntoList",
        "Inserts a new thread into the linked thread list (see thread_info::thread_list_head).\n\nThe thread is inserted in sorted order.\n\nr0: Thread to insert",
        None,
    )

    StartThread = Symbol(
        [0xD488],
        [0x20798F8],
        None,
        "StartThread",
        "Called to start a new thread.\n\nInitializes the specified thread struct and some values on its stack area.\n\nr0: Struct of the thread to init\nr1: Pointer to the function to run on this thread\nr2: Pointer to a thread struct. Sometimes equal to r0. Sometimes null.\nr3: Pointer to the stack area for this thread. Not all the space is usable. See thread::usable_stack_pointer for more info.\nstack[0]: Stack size\nstack[1]: (?) Used to sort threads on a list",
        None,
    )

    ThreadExit = Symbol(
        [0xD584],
        [0x20799F4],
        None,
        "ThreadExit",
        "Function called by threads on exit.\n\nBase functions that contain an infinite loop that is not supposed to return and that have their stacks in main RAM have this function as their return address.\n\nNo params.",
        None,
    )

    SetThreadField0xB4 = Symbol(
        [0xDBA4],
        [0x207A014],
        None,
        "SetThreadField0xB4",
        "Sets the given thread's field_0xB4 to the specified value.\n\nr0: Thread\nr1: Value to set",
        None,
    )

    InitThread = Symbol(
        [0xDBAC],
        [0x207A01C],
        None,
        "InitThread",
        "Initializes some fields of the given thread struct.\n\nMost notably, thread::flags, thread::function_address_plus_4, thread::stack_pointer_minus_4 and thread::usable_stack_pointer. Also initializes a few more fields with a value of 0.\nthread::flags is initialized to 0x1F, unless the address of the function is odd (???), in which case it's initialized to 0x3F.\n\nr0: Pointer to the thread to initialize\nr1: Pointer to the function the thread will run\nr2: Pointer to the start of the thread's stack area - 4",
        None,
    )

    GetTimer0Control = Symbol(
        [0xEE0C],
        [0x207B27C],
        None,
        "GetTimer0Control",
        "Returns the value of the control register for hardware timer 0\n\nreturn: Value of the control register",
        None,
    )

    ClearIrqFlag = Symbol(
        [0xF6F8],
        [0x207BB68],
        None,
        "ClearIrqFlag",
        "Enables processor interrupts by clearing the i flag in the program status register (cpsr).\n\nreturn: Old value of cpsr & 0x80 (0x80 if interrupts were disabled, 0x0 if they were already enabled)",
        None,
    )

    EnableIrqFlag = Symbol(
        [0xF70C],
        [0x207BB7C],
        None,
        "EnableIrqFlag",
        "Disables processor interrupts by setting the i flag in the program status register (cpsr).\n\nreturn: Old value of cpsr & 0x80 (0x80 if interrupts were already disabled, 0x0 if they were enabled)",
        None,
    )

    SetIrqFlag = Symbol(
        [0xF720],
        [0x207BB90],
        None,
        "SetIrqFlag",
        "Sets the value of the processor's interrupt flag according to the specified parameter.\n\nr0: Value to set the flag to (0x80 to set it, which disables interrupts; 0x0 to unset it, which enables interrupts)\nreturn: Old value of cpsr & 0x80 (0x80 if interrupts were disabled, 0x0 if they were enabled)",
        None,
    )

    EnableIrqFiqFlags = Symbol(
        [0xF738],
        [0x207BBA8],
        None,
        "EnableIrqFiqFlags",
        "Disables processor all interrupts (both standard and fast) by setting the i and f flags in the program status register (cpsr).\n\nreturn: Old value of cpsr & 0xC0 (contains the previous values of the i and f flags)",
        None,
    )

    SetIrqFiqFlags = Symbol(
        [0xF74C],
        [0x207BBBC],
        None,
        "SetIrqFiqFlags",
        "Sets the value of the processor's interrupt flags (i and f) according to the specified parameter.\n\nr0: Value to set the flags to (0xC0 to set both flags, 0x80 to set the i flag and clear the f flag, 0x40 to set the f flag and clear the i flag and 0x0 to clear both flags)\nreturn: Old value of cpsr & 0xC0 (contains the previous values of the i and f flags)",
        None,
    )

    GetIrqFlag = Symbol(
        [0xF764],
        [0x207BBD4],
        None,
        "GetIrqFlag",
        "Gets the current value of the processor's interrupt request (i) flag\n\nreturn: cpsr & 0x80 (0x80 if interrupts are disabled, 0x0 if they are enabled)",
        None,
    )

    GetProcessorMode = Symbol(
        [0xF770],
        [0x207BBE0],
        None,
        "GetProcessorMode",
        "Gets the processor's current operating mode.\n\nSee https://problemkaputt.de/gbatek.htm#armcpuflagsconditionfieldcond\n\nreturn: cpsr & 0x1f (the cpsr mode bits M4-M0)",
        None,
    )

    CountLeadingZeros = Symbol(
        [0xF9B4],
        [0x207BE24],
        None,
        "CountLeadingZeros",
        "Counts the number of leading zeros in a 32-bit integer.\n\nr0: x\nreturn: clz(x)",
        None,
    )

    WaitForever2 = Symbol(
        [0xFB48],
        [0x207BFB8],
        None,
        "WaitForever2",
        "Calls EnableIrqFlag and WaitForInterrupt in an infinite loop.\n\nThis is called on fatal errors to hang the program indefinitely.\n\nNo params.",
        None,
    )

    WaitForInterrupt = Symbol(
        [0xFB58],
        [0x207BFC8],
        None,
        "WaitForInterrupt",
        "Presumably blocks until the program receives an interrupt.\n\nThis just calls (in Ghidra terminology) coproc_moveto_Wait_for_interrupt(0). See https://en.wikipedia.org/wiki/ARM_architecture_family#Coprocessors.\n\nNo params.",
        None,
    )

    ArrayFill16 = Symbol(
        [0x101E0],
        [0x207C650],
        None,
        "ArrayFill16",
        "Fills an array of 16-bit values with a given value.\n\nr0: value\nr1: ptr\nr2: len (# bytes)",
        None,
    )

    ArrayCopy16 = Symbol(
        [0x10208],
        [0x207C678],
        None,
        "ArrayCopy16",
        "Copies an array of 16-bit values to another array of 16-bit values.\n\nThis is essentially an alternate implementation of Memcpy16, but with a different parameter order.\n\nr0: src\nr1: dest\nr2: len (# bytes)",
        None,
    )

    ArrayFill32 = Symbol(
        [0x1023C],
        [0x207C6AC],
        None,
        "ArrayFill32",
        "Fills an array of 32-bit values with a given value.\n\nThis is essentially an alternate implementation of Memset32, but with a different parameter order.\n\nr0: value\nr1: ptr\nr2: len (# bytes)",
        None,
    )

    ArrayCopy32 = Symbol(
        [0x10258],
        [0x207C6C8],
        None,
        "ArrayCopy32",
        "Copies an array of 32-bit values to another array of 32-bit values.\n\nThis is essentially an alternate implementation of Memcpy32, but with a different parameter order.\n\nr0: src\nr1: dest\nr2: len (# bytes)",
        None,
    )

    ArrayFill32Fast = Symbol(
        [0x10280],
        [0x207C6F0],
        None,
        "ArrayFill32Fast",
        "Does the same thing as ArrayFill32, except the implementation uses an unrolled loop that sets 8 values per iteration, taking advantage of the stmia instruction.\n\nr0: value\nr1: ptr\nr2: len (# bytes)",
        None,
    )

    ArrayCopy32Fast = Symbol(
        [0x102DC],
        [0x207C74C],
        None,
        "ArrayCopy32Fast",
        "Does the same thing as ArrayCopy32, except the implementation uses an unrolled loop that copies 8 values per iteration, taking advantage of the ldmia/stmia instructions.\n\nr0: src\nr1: dest\nr2: len (# bytes)",
        None,
    )

    MemsetFast = Symbol(
        [0x10334],
        [0x207C7A4],
        None,
        "MemsetFast",
        "A semi-optimized implementation of the memset(3) C library function.\n\nThis function was probably manually implemented by the developers, or was included as part of a library other than libc (the Nitro SDK probably?). See memset for what's probably the real libc function.\n\nThis function is optimized to set values in 4-byte chunks, properly dealing with pointer alignment. However, unlike the libc memset, there are no loop unrolling optimizations.\n\nr0: ptr\nr1: value\nr2: len (# bytes)",
        None,
    )

    MemcpyFast = Symbol(
        [0x103F0],
        [0x207C860],
        None,
        "MemcpyFast",
        "Copies bytes from one buffer to another, similar to memcpy(3). Note that the source/destination buffer parameters swapped relative to the standard memcpy.\n\nThis function was probably manually implemented by the developers, or was included as part of a library other than libc (the Nitro SDK probably?). See memcpy for what's probably the real libc function.\n\nThis function is optimized to copy values in 4-byte chunks, properly dealing with pointer alignment.\n\nr0: src\nr1: dest\nr2: n (# bytes)",
        None,
    )

    AtomicExchange = Symbol(
        [0x10570],
        [0x207C9E0],
        None,
        "AtomicExchange",
        "Atomically replaces a pointer's pointee with a desired value, and returns the previous value.\n\nThis function is just a single swp instruction.\n\nr0: desired value\nr1: ptr\nreturn: previous value",
        None,
    )

    FileInit = Symbol(
        [0x1330C],
        [0x207F77C],
        None,
        "FileInit",
        "Initializes a file_stream structure for file I/O.\n\nThis function must always be called before opening a file.\n\nr0: file_stream pointer",
        None,
    )

    GetOverlayInfo = Symbol(
        [0x13BC4],
        [0x2080034],
        None,
        "GetOverlayInfo",
        "Returns the y9.bin entry for the specified overlay\n\nr0: [output] Overlay info struct\nr1: ?\nr2: Overlay ID\nreturn: True if the entry could be loaded successfully?",
        None,
    )

    LoadOverlayInternal = Symbol(
        [0x13CC0],
        [0x2080130],
        None,
        "LoadOverlayInternal",
        "Called by LoadOverlay to load an overlay into RAM given its info struct\n\nr0: Overlay info struct\nReturn: True if the overlay was loaded successfully?",
        None,
    )

    InitOverlay = Symbol(
        [0x13DE4],
        [0x2080254],
        None,
        "InitOverlay",
        "Performs overlay initialization right after loading an overlay with LoadOverlayInternal.\n\nThis function is responsible for jumping to all the pointers located in the overlay's static init array, among other things.\n\nr0: Overlay info struct",
        None,
    )

    abs = Symbol(
        [0x1A484],
        [0x20868F4],
        None,
        "abs",
        "Takes the absolute value of an integer.\n\nr0: x\nreturn: abs(x)",
        None,
    )

    mbtowc = Symbol(
        [0x1B0E4],
        [0x2087554],
        None,
        "mbtowc",
        "The mbtowc(3) C library function.\n\nr0: pwc\nr1: s\nr2: n\nreturn: number of consumed bytes, or -1 on failure",
        None,
    )

    TryAssignByte = Symbol(
        [0x1B11C],
        [0x208758C],
        None,
        "TryAssignByte",
        "Assign a byte to the target of a pointer if the pointer is non-null.\n\nr0: pointer\nr1: value\nreturn: true on success, false on failure",
        None,
    )

    TryAssignByteWrapper = Symbol(
        [0x1B130],
        [0x20875A0],
        None,
        "TryAssignByteWrapper",
        "Wrapper around TryAssignByte.\n\nAccesses the TryAssignByte function with a weird chain of pointer dereferences.\n\nr0: pointer\nr1: value\nreturn: true on success, false on failure",
        None,
    )

    wcstombs = Symbol(
        [0x1B14C],
        [0x20875BC],
        None,
        "wcstombs",
        "The wcstombs(3) C library function.\n\nr0: dest\nr1: src\nr2: n\nreturn: characters converted",
        None,
    )

    memcpy = Symbol(
        [0x1B1C4],
        [0x2087634],
        None,
        "memcpy",
        "The memcpy(3) C library function.\n\nr0: dest\nr1: src\nr2: n\nreturn: dest",
        None,
    )

    memmove = Symbol(
        [0x1B1E4],
        [0x2087654],
        None,
        "memmove",
        "The memmove(3) C library function.\n\nThe implementation is nearly the same as memcpy, but it copies bytes from back to front if src < dst.\n\nr0: dest\nr1: src\nr2: n\nreturn: dest",
        None,
    )

    memset = Symbol(
        [0x1B230],
        [0x20876A0],
        None,
        "memset",
        "The memset(3) C library function.\n\nThis is just a wrapper around memset_internal that returns the pointer at the end.\n\nr0: s\nr1: c (int, but must be a single-byte value)\nr2: n\nreturn: s",
        None,
    )

    memchr = Symbol(
        [0x1B244],
        [0x20876B4],
        None,
        "memchr",
        "The memchr(3) C library function.\n\nr0: s\nr1: c\nr2: n\nreturn: pointer to first occurrence of c in s, or a null pointer if no match",
        None,
    )

    memcmp = Symbol(
        [0x1B270],
        [0x20876E0],
        None,
        "memcmp",
        "The memcmp(3) C library function.\n\nr0: s1\nr1: s2\nr2: n\nreturn: comparison value",
        None,
    )

    memset_internal = Symbol(
        [0x1B2B0],
        [0x2087720],
        None,
        "memset_internal",
        "The actual memory-setting implementation for the memset(3) C library function.\n\nThis function is optimized to set bytes in 4-byte chunks for n >= 32, correctly handling any unaligned bytes at the front/back. In this case, it also further optimizes by unrolling a for loop to set 8 4-byte values at once (effectively a 32-byte chunk).\n\nr0: s\nr1: c (int, but must be a single-byte value)\nr2: n",
        None,
    )

    __vsprintf_internal_slice = Symbol(
        [0x1CB9C],
        [0x208900C],
        None,
        "__vsprintf_internal_slice",
        "This is what implements the bulk of __vsprintf_internal.\n\nThe __vsprintf_internal in the modern-day version of glibc relies on __vfprintf_internal; this function has a slightly different interface, but it serves a similar role.\n\nr0: function pointer to append to the string being built (__vsprintf_internal uses TryAppendToSlice)\nr1: string buffer slice\nr2: format\nr3: ap\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    TryAppendToSlice = Symbol(
        [0x1D3C0],
        [0x2089830],
        None,
        "TryAppendToSlice",
        "Best-effort append the given data to a slice. If the slice's capacity is reached, any remaining data will be truncated.\n\nr0: slice pointer\nr1: buffer of data to append\nr2: number of bytes in the data buffer\nreturn: true",
        None,
    )

    __vsprintf_internal = Symbol(
        [0x1D404],
        [0x2089874],
        None,
        "__vsprintf_internal",
        "This is what implements vsprintf. It's akin to __vsprintf_internal in the modern-day version of glibc (in fact, it's probably an older version of this).\n\nr0: str\nr1: maxlen (vsprintf passes UINT32_MAX for this)\nr2: format\nr3: ap\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    vsprintf = Symbol(
        [0x1D46C],
        [0x20898DC],
        None,
        "vsprintf",
        "The vsprintf(3) C library function.\n\nr0: str\nr1: format\nr2: ap\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    snprintf = Symbol(
        [0x1D484],
        [0x20898F4],
        None,
        "snprintf",
        "The snprintf(3) C library function.\n\nThis calls __vsprintf_internal directly, so it's presumably the real snprintf.\n\nr0: str\nr1: n\nr2: format\n...: variadic\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    sprintf = Symbol(
        [0x1D4AC],
        [0x208991C],
        None,
        "sprintf",
        "The sprintf(3) C library function.\n\nThis calls __vsprintf_internal directly, so it's presumably the real sprintf.\n\nr0: str\nr1: format\n...: variadic\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    strlen = Symbol(
        [0x1D5A0],
        [0x2089A10],
        None,
        "strlen",
        "The strlen(3) C library function.\n\nr0: s\nreturn: length of s",
        None,
    )

    strcpy = Symbol(
        [0x1D5BC],
        [0x2089A2C],
        None,
        "strcpy",
        "The strcpy(3) C library function.\n\nThis function is optimized to copy characters in aligned 4-byte chunks if possible, correctly handling any unaligned bytes at the front/back.\n\nr0: dest\nr1: src\nreturn: dest",
        None,
    )

    strncpy = Symbol(
        [0x1D684],
        [0x2089AF4],
        None,
        "strncpy",
        "The strncpy(3) C library function.\n\nr0: dest\nr1: src\nr2: n\nreturn: dest",
        None,
    )

    strcat = Symbol(
        [0x1D6D4],
        [0x2089B44],
        None,
        "strcat",
        "The strcat(3) C library function.\n\nr0: dest\nr1: src\nreturn: dest",
        None,
    )

    strncat = Symbol(
        [0x1D704],
        [0x2089B74],
        None,
        "strncat",
        "The strncat(3) C library function.\n\nr0: dest\nr1: src\nr2: n\nreturn: dest",
        None,
    )

    strcmp = Symbol(
        [0x1D754],
        [0x2089BC4],
        None,
        "strcmp",
        "The strcmp(3) C library function.\n\nSimilarly to strcpy, this function is optimized to compare characters in aligned 4-byte chunks if possible.\n\nr0: s1\nr1: s2\nreturn: comparison value",
        None,
    )

    strncmp = Symbol(
        [0x1D868],
        [0x2089CD8],
        None,
        "strncmp",
        "The strncmp(3) C library function.\n\nr0: s1\nr1: s2\nr2: n\nreturn: comparison value",
        None,
    )

    strchr = Symbol(
        [0x1D89C],
        [0x2089D0C],
        None,
        "strchr",
        "The strchr(3) C library function.\n\nr0: string\nr1: c\nreturn: pointer to the located byte c, or null pointer if no match",
        None,
    )

    strcspn = Symbol(
        [0x1D8D8],
        [0x2089D48],
        None,
        "strcspn",
        "The strcspn(3) C library function.\n\nr0: string\nr1: stopset\nreturn: offset of the first character in string within stopset",
        None,
    )

    strstr = Symbol(
        [0x1D998],
        [0x2089E08],
        None,
        "strstr",
        "The strstr(3) C library function.\n\nr0: haystack\nr1: needle\nreturn: pointer into haystack where needle starts, or null pointer if no match",
        None,
    )

    wcslen = Symbol(
        [0x1F310],
        [0x208B780],
        None,
        "wcslen",
        "The wcslen(3) C library function.\n\nr0: ws\nreturn: length of ws",
        None,
    )

    _dadd = Symbol(
        [0x21DF0],
        [0x208E260],
        None,
        "_dadd",
        "Implements the addition operator for IEEE 754 double-precision floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __adddf3 in libgcc.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a + b",
        None,
    )

    _d2f = Symbol(
        [0x22108],
        [0x208E578],
        None,
        "_d2f",
        "Implements the double to float cast operator for IEEE 754 floating-point numbers.\n\nAnalogous to __truncdfsf2 in libgcc.\n\nr0: double (low bits)\nr1: double (high bits)\nreturn: (float)double",
        None,
    )

    _ll_ufrom_d = Symbol(
        [0x2220C],
        [0x208E67C],
        None,
        "_ll_ufrom_d",
        "Implements the double to unsigned long long cast operation for IEEE 754 floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __fixunsdfti in libgcc.\n\nr0: double (low bits)\nr1: double (high bits)\nreturn: (unsigned long long)double",
        None,
    )

    _dflt = Symbol(
        [0x22298],
        [0x208E708],
        None,
        "_dflt",
        "Implements the int to double cast operation for IEEE 754 floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __floatsidf in libgcc.\n\nr0: int\nreturn: (double)int",
        None,
    )

    _dfltu = Symbol(
        [0x222D8],
        [0x208E748],
        None,
        "_dfltu",
        "Implements the unsigned int to double cast operation for IEEE 754 floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __floatunsidf in libgcc.\n\nr0: uint\nreturn: (double)uint",
        None,
    )

    _dmul = Symbol(
        [0x22314],
        [0x208E784],
        None,
        "_dmul",
        "Implements the multiplication operator for IEEE 754 double-precision floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __muldf3 in libgcc.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a * b",
        None,
    )

    _dsqrt = Symbol(
        [0x22678],
        [0x208EAE8],
        None,
        "_dsqrt",
        "Analogous to the sqrt(3) C library function.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nr0: x (low bits)\nr1: x (high bits)\nreturn: sqrt(x)",
        None,
    )

    _dsub = Symbol(
        [0x2282C],
        [0x208EC9C],
        None,
        "_dsub",
        "Implements the subtraction operator for IEEE 754 double-precision floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __subdf3 in libgcc.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a - b",
        None,
    )

    _fadd = Symbol(
        [0x22BE0],
        [0x208F050],
        None,
        "_fadd",
        "Implements the addition operator for IEEE 754 floating-point numbers.\n\nAnalogous to __addsf3 in libgcc.\n\nr0: a\nr1: b\nreturn: a + b",
        None,
    )

    _dgeq = Symbol(
        [0x22E04],
        [0x208F274],
        None,
        "_dgeq",
        "Implements the >= operator for IEEE 754 double-precision floating-point numbers.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a >= b",
        None,
    )

    _dleq = Symbol(
        [0x22E9C],
        [0x208F30C],
        None,
        "_dleq",
        "Implements the <= operator for IEEE 754 double-precision floating-point numbers.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a <= b",
        None,
    )

    _dls = Symbol(
        [0x22F40],
        [0x208F3B0],
        None,
        "_dls",
        "Implements the < operator for IEEE 754 double-precision floating-point numbers.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a < b",
        None,
    )

    _deq = Symbol(
        [0x22FDC],
        [0x208F44C],
        None,
        "_deq",
        "Implements the == operator for IEEE 754 double-precision floating-point numbers.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a == b",
        None,
    )

    _dneq = Symbol(
        [0x23068],
        [0x208F4D8],
        None,
        "_dneq",
        "Implements the != operator for IEEE 754 double-precision floating-point numbers.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a != b",
        None,
    )

    _fls = Symbol(
        [0x230F4],
        [0x208F564],
        None,
        "_fls",
        "Implements the < operator for IEEE 754 floating-point numbers.\n\nr0: a\nr1: b\nreturn: a < b",
        None,
    )

    _fdiv = Symbol(
        [0x2315C],
        [0x208F5CC],
        None,
        "_fdiv",
        "Implements the division operator for IEEE 754 floating-point numbers.\n\nAnalogous to __divsf3 in libgcc.\n\nr0: dividend\nr1: divisor\nreturn: dividend / divisor",
        None,
    )

    _f2d = Symbol(
        [0x23514],
        [0x208F984],
        None,
        "_f2d",
        "Implements the float to double cast operation for IEEE 754 floating-point numbers.\n\nAnalogous to __extendsfdf2 in libgcc.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nr0: float\nreturn: (double)float",
        None,
    )

    _ffix = Symbol(
        [0x23598],
        [0x208FA08],
        None,
        "_ffix",
        "Implements the float to int cast operation for IEEE 754 floating-point numbers. The output saturates if the input is out of the representable range for the int type.\n\nAnalogous to __fixsfsi in libgcc.\n\nr0: float\nreturn: (int)float",
        None,
    )

    _fflt = Symbol(
        [0x235CC],
        [0x208FA3C],
        None,
        "_fflt",
        "Implements the int to float cast operation for IEEE 754 floating-point numbers.\n\nAnalogous to __floatsisf in libgcc.\n\nr0: int\nreturn: (float)int",
        None,
    )

    _ffltu = Symbol(
        [0x23614],
        [0x208FA84],
        None,
        "_ffltu",
        "Implements the unsigned int to float cast operation for IEEE 754 floating-point numbers.\n\nAnalogous to __floatunsisf in libgcc.\n\nr0: uint\nreturn: (float)uint",
        None,
    )

    _fmul = Symbol(
        [0x2365C],
        [0x208FACC],
        None,
        "_fmul",
        "Implements the multiplication operator for IEEE 754 floating-point numbers.\n\nAnalogous to __mulsf3 in libgcc.\n\nr0: a\nr1: b\nreturn: a * b",
        None,
    )

    sqrtf = Symbol(
        [0x2383C],
        [0x208FCAC],
        None,
        "sqrtf",
        "The sqrtf(3) C library function.\n\nr0: x\nreturn: sqrt(x)",
        None,
    )

    _fsub = Symbol(
        [0x2392C],
        [0x208FD9C],
        None,
        "_fsub",
        "Implements the subtraction operator for IEEE 754 floating-point numbers.\n\nAnalogous to __subsf3 in libgcc.\n\nr0: a\nr1: b\nreturn: a - b",
        None,
    )

    _ll_mod = Symbol(
        [0x23BA4],
        [0x2090014],
        None,
        "_ll_mod",
        "Implements the modulus operator for signed long longs.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __modti3 in libgcc.\n\nr0: dividend (low bits)\nr1: dividend (high bits)\nr2: divisor (low bits)\nr3: divisor (high bits)\nreturn: dividend % divisor",
        None,
    )

    _ll_sdiv = Symbol(
        [0x23BB4],
        [0x2090024],
        None,
        "_ll_sdiv",
        "Implements the division operator for signed long longs.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __divti3 in libgcc.\n\nr0: dividend (low bits)\nr1: dividend (high bits)\nr2: divisor (low bits)\nr3: divisor (high bits)\nreturn: dividend / divisor",
        None,
    )

    _ll_udiv = Symbol(
        [0x23D64],
        [0x20901D4],
        None,
        "_ll_udiv",
        "Implements the division operator for unsigned long longs.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __udivti3 in libgcc.\n\nr0: dividend (low bits)\nr1: dividend (high bits)\nr2: divisor (low bits)\nr3: divisor (high bits)\nreturn: dividend / divisor",
        None,
    )

    _ull_mod = Symbol(
        [0x23D70],
        [0x20901E0],
        None,
        "_ull_mod",
        "Implements the modulus operator for unsigned long longs.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __umodti3 in libgcc.\n\nr0: dividend (low bits)\nr1: dividend (high bits)\nr2: divisor (low bits)\nr3: divisor (high bits)\nreturn: dividend % divisor",
        None,
    )

    _ll_mul = Symbol(
        [0x23DAC],
        [0x209021C],
        None,
        "_ll_mul",
        "Implements the multiplication operator for signed long longs.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __multi3 in libgcc.\n\nr0: a (low bits)\nr1: a (high bits)\nr2: b (low bits)\nr3: b (high bits)\nreturn: a * b",
        None,
    )

    _s32_div_f = Symbol(
        [0x23DCC],
        [0x209023C],
        None,
        "_s32_div_f",
        "Implements the division operator for signed ints.\n\nAnalogous to __divsi3 in libgcc.\n\nThe return value is a 64-bit integer, with the quotient (dividend / divisor) in the lower 32 bits and the remainder (dividend % divisor) in the upper 32 bits. In accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return), this means that the quotient is returned in r0 and the remainder is returned in r1.\n\nr0: dividend\nr1: divisor\nreturn: (quotient) | (remainder << 32)",
        None,
    )

    _u32_div_f = Symbol(
        [0x23FD8],
        [0x2090448],
        None,
        "_u32_div_f",
        "Implements the division operator for unsigned ints.\n\nAnalogous to __udivsi3 in libgcc.\n\nThe return value is a 64-bit integer, with the quotient (dividend / divisor) in the lower 32 bits and the remainder (dividend % divisor) in the upper 32 bits. In accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return), this means that the quotient is returned in r0 and the remainder is returned in r1.\nNote: This function falls through to _u32_div_not_0_f.\n\nr0: dividend\nr1: divisor\nreturn: (quotient) | (remainder << 32)",
        None,
    )

    _u32_div_not_0_f = Symbol(
        [0x23FE0],
        [0x2090450],
        None,
        "_u32_div_not_0_f",
        "Subsidiary function to _u32_div_f. Skips the initial check for divisor == 0.\n\nThe return value is a 64-bit integer, with the quotient (dividend / divisor) in the lower 32 bits and the remainder (dividend % divisor) in the upper 32 bits. In accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return), this means that the quotient is returned in r0 and the remainder is returned in r1.\nThis function appears to only be called internally.\n\nr0: dividend\nr1: divisor\nreturn: (quotient) | (remainder << 32)",
        None,
    )

    _drdiv = Symbol(
        [0x241BC],
        [0x209062C],
        None,
        "_drdiv",
        "The same as _ddiv, but with the parameters reversed.\n\nThis simply swaps the first and second parameters, then falls through to _ddiv.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nr0: divisor (low bits)\nr1: divisor (high bits)\nr2: dividend (low bits)\nr3: dividend (high bits)\nreturn: dividend / divisor",
        None,
    )

    _ddiv = Symbol(
        [0x241D4],
        [0x2090644],
        None,
        "_ddiv",
        "Implements the division operator for IEEE 754 double-precision floating-point numbers.\n\nThe result is returned in r0 and r1, in accordance with the Procedure Call Standard for the Arm Architecture (see https://github.com/ARM-software/abi-aa/blob/60a8eb8c55e999d74dac5e368fc9d7e36e38dda4/aapcs32/aapcs32.rst#result-return).\n\nAnalogous to __divdf3 in libgcc.\n\nr0: dividend (low bits)\nr1: dividend (high bits)\nr2: divisor (low bits)\nr3: divisor (high bits)\nreturn: dividend / divisor",
        None,
    )

    _fp_init = Symbol(
        [0x24718],
        [0x2090B88],
        None,
        "_fp_init",
        "Meant to do set up for floating point calculations? Does nothing.\n\nNo params.",
        None,
    )

    DseUtil_GetRandomNumber = _Deprecated(
        "DseUtil_GetRandomNumber", SoundUtil_GetRandomNumber
    )

    __addsf3 = _Deprecated("__addsf3", _fadd)

    __divsf3 = _Deprecated("__divsf3", _fdiv)

    __extendsfdf2 = _Deprecated("__extendsfdf2", _f2d)

    __fixsfsi = _Deprecated("__fixsfsi", _ffix)

    __floatsisf = _Deprecated("__floatsisf", _fflt)

    __floatunsisf = _Deprecated("__floatunsisf", _ffltu)

    __mulsf3 = _Deprecated("__mulsf3", _fmul)

    __subsf3 = _Deprecated("__subsf3", _fsub)

    __divsi3 = _Deprecated("__divsi3", _s32_div_f)

    __udivsi3 = _Deprecated("__udivsi3", _u32_div_f)

    __udivsi3_no_zero_check = _Deprecated("__udivsi3_no_zero_check", _u32_div_not_0_f)


class EuLibsData:

    pass


class EuLibsSection:
    name = "libs"
    description = "System libraries linked to the main ARM9 binary.\n\nThis includes code from common NDS system libraries like the Nitro SDK (which contains NDS-specific functionality as well as utilities akin to libc and libgcc).\n\nWhere the library region starts and ends is a guess, but there appear to be fairly sharp boundaries. The function directly before it calls functions at lower memory addresses outside of the region, while all functions in the region only call other functions within the region. The bytes after the region seem to be the start of a global data region, used by both the libraries and the rest of ARM9."
    loadaddress = 0x206C470
    length = 0x247FC
    functions = EuLibsFunctions
    data = EuLibsData


class EuMove_effectsFunctions:

    DoMoveDamage = Symbol(
        [0x0, 0x4744, 0x5AF4, 0x7FA0],
        [0x2326828, 0x232AF6C, 0x232C31C, 0x232E7C8],
        None,
        "DoMoveDamage",
        "Move effect: Deal damage.\nRelevant moves: Many!\n\nThis just wraps DealDamage with a multiplier of 1 (i.e., the fixed-point number 0x100).\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveIronTail = Symbol(
        [0x24],
        [0x232684C],
        None,
        "DoMoveIronTail",
        "Move effect: Iron Tail\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageMultihitUntilMiss = Symbol(
        [0xA4],
        [0x23268CC],
        None,
        "DoMoveDamageMultihitUntilMiss",
        "Move effect: Deal multihit damage until a strike misses\nRelevant moves: Ice Ball, Rollout\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveYawn = Symbol(
        [0x104],
        [0x232692C],
        None,
        "DoMoveYawn",
        "Move effect: Yawn\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSleep = Symbol(
        [0x140],
        [0x2326968],
        None,
        "DoMoveSleep",
        "Move effect: Put target enemies to sleep\nRelevant moves: Lovely Kiss, Sing, Spore, Grasswhistle, Hypnosis, Sleep Powder, Dark Void\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveNightmare = Symbol(
        [0x17C],
        [0x23269A4],
        None,
        "DoMoveNightmare",
        "Move effect: Nightmare\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMorningSun = Symbol(
        [0x1B4],
        [0x23269DC],
        None,
        "DoMoveMorningSun",
        "Move effect: Morning Sun\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveVitalThrow = Symbol(
        [0x1F4],
        [0x2326A1C],
        None,
        "DoMoveVitalThrow",
        "Move effect: Vital Throw\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDig = Symbol(
        [0x204],
        [0x2326A2C],
        None,
        "DoMoveDig",
        "Move effect: Dig\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSweetScent = Symbol(
        [0x2C8],
        [0x2326AF0],
        None,
        "DoMoveSweetScent",
        "Move effect: Sweet Scent\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCharm = Symbol(
        [0x2E8],
        [0x2326B10],
        None,
        "DoMoveCharm",
        "Move effect: Charm\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRainDance = Symbol(
        [0x310],
        [0x2326B38],
        None,
        "DoMoveRainDance",
        "Move effect: Rain Dance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHail = Symbol(
        [0x36C],
        [0x2326B94],
        None,
        "DoMoveHail",
        "Move effect: Hail\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHealStatus = Symbol(
        [0x3C8],
        [0x2326BF0],
        None,
        "DoMoveHealStatus",
        "Move effect: Heal the team's status conditions\nRelevant moves: Aromatherapy, Heal Bell, Refresh\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBubble = Symbol(
        [0x3E0],
        [0x2326C08],
        None,
        "DoMoveBubble",
        "Move effect: Bubble\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEncore = Symbol(
        [0x44C],
        [0x2326C74],
        None,
        "DoMoveEncore",
        "Move effect: Encore\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRage = Symbol(
        [0x460],
        [0x2326C88],
        None,
        "DoMoveRage",
        "Move effect: Rage\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSuperFang = Symbol(
        [0x4A4],
        [0x2326CCC],
        None,
        "DoMoveSuperFang",
        "Move effect: Super Fang\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePainSplit = Symbol(
        [0x55C],
        [0x2326D84],
        None,
        "DoMovePainSplit",
        "Move effect: Pain Split\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTorment = Symbol(
        [0x648],
        [0x2326E70],
        None,
        "DoMoveTorment",
        "Move effect: Torment\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveStringShot = Symbol(
        [0x790],
        [0x2326FB8],
        None,
        "DoMoveStringShot",
        "Move effect: String Shot\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSwagger = Symbol(
        [0x7A8],
        [0x2326FD0],
        None,
        "DoMoveSwagger",
        "Move effect: Swagger\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSnore = Symbol(
        [0x7E4],
        [0x232700C],
        None,
        "DoMoveSnore",
        "Move effect: Snore\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveScreech = Symbol(
        [0x888],
        [0x23270B0],
        None,
        "DoMoveScreech",
        "Move effect: Screech\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageCringe30 = Symbol(
        [0x8B0],
        [0x23270D8],
        None,
        "DoMoveDamageCringe30",
        "Move effect: Deal damage with a 30% chance (ROCK_SLIDE_CRINGE_CHANCE) of inflicting the cringe status on the defender.\nRelevant moves: Rock Slide, Astonish, Iron Head, Dark Pulse, Air Slash, Zen Headbutt, Dragon Rush\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveWeatherBall = Symbol(
        [0x91C],
        [0x2327144],
        None,
        "DoMoveWeatherBall",
        "Move effect: Weather Ball\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWhirlpool = Symbol(
        [0x990],
        [0x23271B8],
        None,
        "DoMoveWhirlpool",
        "Move effect: Whirlpool\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFakeTears = Symbol(
        [0xA18],
        [0x2327240],
        None,
        "DoMoveFakeTears",
        "Move effect: Fake Tears\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSpite = Symbol(
        [0xA4C],
        [0x2327274],
        None,
        "DoMoveSpite",
        "Move effect: Spite\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFocusEnergy = Symbol(
        [0xAFC],
        [0x2327324],
        None,
        "DoMoveFocusEnergy",
        "Move effect: Focus Energy\nRelevant moves: Focus Energy, MOVE_TAG_0x1AC\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSmokescreen = Symbol(
        [0xB0C],
        [0x2327334],
        None,
        "DoMoveSmokescreen",
        "Move effect: Smokescreen\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMirrorMove = Symbol(
        [0xB48],
        [0x2327370],
        None,
        "DoMoveMirrorMove",
        "Move effect: Mirror Move\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveOverheat = Symbol(
        [0xB6C],
        [0x2327394],
        None,
        "DoMoveOverheat",
        "Move effect: Overheat\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAuroraBeam = Symbol(
        [0xBD0],
        [0x23273F8],
        None,
        "DoMoveAuroraBeam",
        "Move effect: Aurora Beam\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMemento = Symbol(
        [0xC4C],
        [0x2327474],
        None,
        "DoMoveMemento",
        "Move effect: Memento\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveOctazooka = Symbol(
        [0xCB4],
        [0x23274DC],
        None,
        "DoMoveOctazooka",
        "Move effect: Octazooka\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFlatter = Symbol(
        [0xD28],
        [0x2327550],
        None,
        "DoMoveFlatter",
        "Move effect: Flatter\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWillOWisp = Symbol(
        [0xD64],
        [0x232758C],
        None,
        "DoMoveWillOWisp",
        "Move effect: Will-O-Wisp\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveReturn = Symbol(
        [0xE00],
        [0x2327628],
        None,
        "DoMoveReturn",
        "Move effect: Return\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGrudge = Symbol(
        [0xEE4],
        [0x232770C],
        None,
        "DoMoveGrudge",
        "Move effect: Grudge\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCounter = Symbol(
        [0xEF4],
        [0x232771C],
        None,
        "DoMoveCounter",
        "Move effect: Give the user the Counter status\nRelevant moves: Pursuit, Counter, Payback\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageBurn10FlameWheel = Symbol(
        [0xF08],
        [0x2327730],
        None,
        "DoMoveDamageBurn10FlameWheel",
        "Move effect: Deal damage with a 10% chance (FLAME_WHEEL_BURN_CHANCE) of burning the defender.\nRelevant moves: Flame Wheel, Lava Plume\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageBurn10 = Symbol(
        [0xF90],
        [0x23277B8],
        None,
        "DoMoveDamageBurn10",
        "Move effect: Deal damage with a 10% chance (FLAMETHROWER_BURN_CHANCE) of burning the defender.\nRelevant moves: Flamethrower, Fire Blast, Heat Wave, Ember, Fire Punch\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveExpose = Symbol(
        [0x1018],
        [0x2327840],
        None,
        "DoMoveExpose",
        "Move effect: Expose all Ghost-type enemies, and reset evasion boosts\nRelevant moves: Odor Sleuth, Foresight\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDoubleTeam = Symbol(
        [0x1044],
        [0x232786C],
        None,
        "DoMoveDoubleTeam",
        "Move effect: Double Team\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGust = Symbol(
        [0x1060],
        [0x2327888],
        None,
        "DoMoveGust",
        "Move effect: Gust\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBoostDefense1 = Symbol(
        [0x10A0],
        [0x23278C8],
        None,
        "DoMoveBoostDefense1",
        "Move effect: Boost the user's defense by one stage\nRelevant moves: Harden, Withdraw\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveParalyze = Symbol(
        [0x10C0, 0x2474, 0x5678],
        [0x23278E8, 0x2328C9C, 0x232BEA0],
        None,
        "DoMoveParalyze",
        "Move effect: Paralyze the defender if possible\nRelevant moves: Disable, Stun Spore, Glare\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBoostAttack1 = Symbol(
        [0x10D8],
        [0x2327900],
        None,
        "DoMoveBoostAttack1",
        "Move effect: Boost the user's attack by one stage\nRelevant moves: Sharpen, Howl, Meditate\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRazorWind = Symbol(
        [0x10F8],
        [0x2327920],
        None,
        "DoMoveRazorWind",
        "Move effect: Razor Wind\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBide = Symbol(
        [0x1188],
        [0x23279B0],
        None,
        "DoMoveBide",
        "Move effect: Give the user the Bide status\nRelevant moves: Bide, Revenge, Avalanche\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBideUnleash = Symbol(
        [0x11CC],
        [0x23279F4],
        None,
        "DoMoveBideUnleash",
        "Move effect: Unleashes the Bide status\nRelevant moves: Bide (unleashing), Revenge (unleashing), Avalanche (unleashing)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCrunch = Symbol(
        [0x1274],
        [0x2327A9C],
        None,
        "DoMoveCrunch",
        "Move effect: Deal damage with a 20% chance (CRUNCH_LOWER_DEFENSE_CHANCE) of lowering the defender's defense.\nRelevant moves: Crunch, Shadow Ball via Nature Power\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveDamageCringe20 = Symbol(
        [0x12F4],
        [0x2327B1C],
        None,
        "DoMoveDamageCringe20",
        "Move effect: Deal damage with a 20% chance (BITE_CRINGE_CHANCE) of inflicting the cringe status on the defender.\nRelevant moves: Bite, Needle Arm, Stomp, Rolling Kick\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageParalyze20 = Symbol(
        [0x1360],
        [0x2327B88],
        None,
        "DoMoveDamageParalyze20",
        "Move effect: Deal damage with a 20% chance (THUNDER_PARALYZE_CHANCE) of paralyzing the defender.\nRelevant moves: Thunder, ThunderPunch, Force Palm, Discharge\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveEndeavor = Symbol(
        [0x13CC],
        [0x2327BF4],
        None,
        "DoMoveEndeavor",
        "Move effect: Endeavor\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFacade = Symbol(
        [0x148C],
        [0x2327CB4],
        None,
        "DoMoveFacade",
        "Move effect: Facade\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageLowerSpeed20 = Symbol(
        [0x14CC],
        [0x2327CF4],
        None,
        "DoMoveDamageLowerSpeed20",
        "Move effect: Deal damage with a 20% chance (CONSTRICT_LOWER_SPEED_CHANCE) of lowering the defender's speed.\nRelevant moves: Constrict, Bubblebeam\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveBrickBreak = Symbol(
        [0x1538],
        [0x2327D60],
        None,
        "DoMoveBrickBreak",
        "Move effect: Brick Break\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageLowerSpeed100 = Symbol(
        [0x15A8],
        [0x2327DD0],
        None,
        "DoMoveDamageLowerSpeed100",
        "Move effect: Deal damage and lower the defender's speed.\nRelevant moves: Rock Tomb, Icy Wind, Mud Shot\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFocusPunch = Symbol(
        [0x160C],
        [0x2327E34],
        None,
        "DoMoveFocusPunch",
        "Move effect: Focus Punch\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageDrain = Symbol(
        [0x1698],
        [0x2327EC0],
        None,
        "DoMoveDamageDrain",
        "Move effect: Deal draining damage, healing the attacker by a proportion of the damage dealt.\nRelevant moves: Giga Drain, Leech Life, Mega Drain, Drain Punch\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveReversal = Symbol(
        [0x17D8],
        [0x2328000],
        None,
        "DoMoveReversal",
        "Move effect: Deal damage with a higher multiplier the lower the attacker's HP is.\nRelevant moves: Reversal, Flail\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSmellingSalt = Symbol(
        [0x188C],
        [0x23280B4],
        None,
        "DoMoveSmellingSalt",
        "Move effect: SmellingSalt\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMetalSound = Symbol(
        [0x18F4],
        [0x232811C],
        None,
        "DoMoveMetalSound",
        "Move effect: Metal Sound\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTickle = Symbol(
        [0x1928],
        [0x2328150],
        None,
        "DoMoveTickle",
        "Move effect: Tickle\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveShadowHold = Symbol(
        [0x1984],
        [0x23281AC],
        None,
        "DoMoveShadowHold",
        "Move effect: Inflict the Shadow Hold status on the defender\nRelevant moves: Spider Web, Mean Look\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHaze = Symbol(
        [0x1998],
        [0x23281C0],
        None,
        "DoMoveHaze",
        "Move effect: Haze\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageMultihitFatigue = Symbol(
        [0x19AC],
        [0x23281D4],
        None,
        "DoMoveDamageMultihitFatigue",
        "Move effect: Deal multihit damage, then confuse the attacker\nRelevant moves: Outrage, Petal Dance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageWeightDependent = Symbol(
        [0x19F8],
        [0x2328220],
        None,
        "DoMoveDamageWeightDependent",
        "Move effect: Deal damage, multiplied by a weight-dependent factor.\nRelevant moves: Low Kick, Grass Knot\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveDamageBoostAllStats = Symbol(
        [0x1A44],
        [0x232826C],
        None,
        "DoMoveDamageBoostAllStats",
        "Move effect: Deal damage, with a 20% (SILVER_WIND_BOOST_CHANCE) to boost the user's attack, special attack, defense, special defense, and speed.\nRelevant moves: Silver Wind, AncientPower, Ominous Wind\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSynthesis = Symbol(
        [0x1B28],
        [0x2328350],
        None,
        "DoMoveSynthesis",
        "Move effect: Synthesis\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBoostSpeed1 = Symbol(
        [0x1B68],
        [0x2328390],
        None,
        "DoMoveBoostSpeed1",
        "Move effect: Boost the team's movement speed by one stage\nRelevant moves: Agility, Speed Boost (item effect), MOVE_TAG_0x1AA, Tailwind\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRapidSpin = Symbol(
        [0x1B80],
        [0x23283A8],
        None,
        "DoMoveRapidSpin",
        "Move effect: Rapid Spin\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSureShot = Symbol(
        [0x1BEC],
        [0x2328414],
        None,
        "DoMoveSureShot",
        "Move effect: Give the user the Sure-Shot status\nRelevant moves: Mind Reader, Lock-On\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCosmicPower = Symbol(
        [0x1C24],
        [0x232844C],
        None,
        "DoMoveCosmicPower",
        "Move effect: Cosmic Power\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSkyAttack = Symbol(
        [0x1C68],
        [0x2328490],
        None,
        "DoMoveSkyAttack",
        "Move effect: Sky Attack\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageFreeze15 = Symbol(
        [0x1D34],
        [0x232855C],
        None,
        "DoMoveDamageFreeze15",
        "Move effect: Deal damage with a 15% chance (POWDER_SNOW_FREEZE_CHANCE) of freezing the defender.\nRelevant moves: Powder Snow, Blizzard, Ice Punch, Ice Beam\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveMeteorMash = Symbol(
        [0x1D9C],
        [0x23285C4],
        None,
        "DoMoveMeteorMash",
        "Move effect: Meteor Mash\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEndure = Symbol(
        [0x1E24],
        [0x232864C],
        None,
        "DoMoveEndure",
        "Move effect: Endure\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLowerSpeed1 = Symbol(
        [0x1E34],
        [0x232865C],
        None,
        "DoMoveLowerSpeed1",
        "Move effect: Lower the defender's defense by one stage\nRelevant moves: Scary Face, Cotton Spore\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageConfuse10 = Symbol(
        [0x1E4C],
        [0x2328674],
        None,
        "DoMoveDamageConfuse10",
        "Move effect: Deal damage with a 10% chance (PSYBEAM_CONFUSE_CHANCE) of confusing the defender.\nRelevant moves: Psybeam, Signal Beam, Confusion, Chatter, Rock Climb\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePsywave = Symbol(
        [0x1EB8],
        [0x23286E0],
        None,
        "DoMovePsywave",
        "Move effect: Psywave\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageLowerDefensiveStatVariable = Symbol(
        [0x1F1C],
        [0x2328744],
        None,
        "DoMoveDamageLowerDefensiveStatVariable",
        "Move effect: Deal damage with some chance of lowering one of the defender's defensive stats.\nRelevant moves: Psychic, Acid, Seed Flare, Earth Power, Bug Buzz, Flash Cannon\n\nNote that this move effect handler has a slightly different parameter list than all the others. Which defensive stat is lowered, the chance of lowering, and the number of stages to lower are all specified as arguments by the caller.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: stat index for the defensive stat to lower\nstack[0]: number of defensive stat stages to lower\nstack[1]: percentage chance of lowering the defensive stat\nstack[2]: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePsychoBoost = Symbol(
        [0x1FA4],
        [0x23287CC],
        None,
        "DoMovePsychoBoost",
        "Move effect: Psycho Boost\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveUproar = Symbol(
        [0x2014],
        [0x232883C],
        None,
        "DoMoveUproar",
        "Move effect: Uproar\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWaterSpout = Symbol(
        [0x2024],
        [0x232884C],
        None,
        "DoMoveWaterSpout",
        "Move effect: Water Spout\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePsychUp = Symbol(
        [0x20D8],
        [0x2328900],
        None,
        "DoMovePsychUp",
        "Move effect: Psych Up\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageWithRecoil = Symbol(
        [0x2178],
        [0x23289A0],
        None,
        "DoMoveDamageWithRecoil",
        "Move effect: Deals damage, inflicting recoil damage on the attacker.\nRelevant moves: Submission, Take Down, Volt Tackle, Wood Hammer, Brave Bird\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: bool, whether or not damage was dealt",
        None,
    )

    EntityIsValidMoveEffects = Symbol(
        [0x2250, 0x461C, 0x6748, 0x8468],
        [0x2328A78, 0x232AE44, 0x232CF70, 0x232EC90],
        None,
        "EntityIsValidMoveEffects",
        "See overlay29.yml::EntityIsValid",
        None,
    )

    DoMoveRecoverHp = Symbol(
        [0x2274],
        [0x2328A9C],
        None,
        "DoMoveRecoverHp",
        "Move effect: Recover 50% of the user's max HP\nRelevant moves: Recover, Slack Off\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEarthquake = Symbol(
        [0x22B8],
        [0x2328AE0],
        None,
        "DoMoveEarthquake",
        "Move effect: Earthquake\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    GetNaturePowerVariant = Symbol(
        [0x2318],
        [0x2328B40],
        None,
        "GetNaturePowerVariant",
        "Gets the nature power variant for the current dungeon, based on the tileset ID.\n\nreturn: nature power variant",
        None,
    )

    DoMoveNaturePower = Symbol(
        [0x2354],
        [0x2328B7C],
        None,
        "DoMoveNaturePower",
        "Move effect: Nature Power\n\nr0: attacker pointer\nr1: defender pointer\nr2: move (unused)\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageParalyze10 = Symbol(
        [0x23B0],
        [0x2328BD8],
        None,
        "DoMoveDamageParalyze10",
        "Move effect: Deal damage with a 10% chance (LICK_PARALZYE_CHANCE) of paralyzing the defender.\nRelevant moves: Lick, Spark, Body Slam, DragonBreath\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSelfdestruct = Symbol(
        [0x241C],
        [0x2328C44],
        None,
        "DoMoveSelfdestruct",
        "Move effect: Selfdestruct\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveShadowBall = Symbol(
        [0x248C],
        [0x2328CB4],
        None,
        "DoMoveShadowBall",
        "Move effect: Shadow Ball\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCharge = Symbol(
        [0x250C],
        [0x2328D34],
        None,
        "DoMoveCharge",
        "Move effect: Charge\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveThunderbolt = Symbol(
        [0x256C],
        [0x2328D94],
        None,
        "DoMoveThunderbolt",
        "Move effect: Thunderbolt\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMist = Symbol(
        [0x25D8],
        [0x2328E00],
        None,
        "DoMoveMist",
        "Move effect: Mist\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFissure = Symbol(
        [0x25E8],
        [0x2328E10],
        None,
        "DoMoveFissure",
        "Move effect: Fissure\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageCringe10 = Symbol(
        [0x2700],
        [0x2328F28],
        None,
        "DoMoveDamageCringe10",
        "Move effect: Deal damage with a 10% chance (EXTRASENSORY_CRINGE_CHANCE) to inflict the cringe status on the defender.\nRelevant moves: Extrasensory, Hyper Fang, Bone Club\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSafeguard = Symbol(
        [0x276C],
        [0x2328F94],
        None,
        "DoMoveSafeguard",
        "Move effect: Safeguard\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAbsorb = Symbol(
        [0x277C],
        [0x2328FA4],
        None,
        "DoMoveAbsorb",
        "Move effect: Absorb\n\nThis is essentially identical to DoMoveDamageDrain, except the ordering of the instructions is slightly different enough to introduce subtle variations in functionality.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DefenderAbilityIsActiveMoveEffects = Symbol(
        [0x2878, 0x4158, 0x6018, 0x8038],
        [0x23290A0, 0x232A980, 0x232C840, 0x232E860],
        None,
        "DefenderAbilityIsActiveMoveEffects",
        "See overlay29.yml::DefenderAbilityIsActive",
        None,
    )

    DoMoveSkillSwap = Symbol(
        [0x28DC],
        [0x2329104],
        None,
        "DoMoveSkillSwap",
        "Move effect: Skill Swap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSketch = Symbol(
        [0x29D8],
        [0x2329200],
        None,
        "DoMoveSketch",
        "Move effect: Sketch\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHeadbutt = Symbol(
        [0x2B08],
        [0x2329330],
        None,
        "DoMoveHeadbutt",
        "Move effect: Headbutt\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDoubleEdge = Symbol(
        [0x2B74],
        [0x232939C],
        None,
        "DoMoveDoubleEdge",
        "Move effect: Double-Edge\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSandstorm = Symbol(
        [0x2C3C],
        [0x2329464],
        None,
        "DoMoveSandstorm",
        "Move effect: Sandstorm\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLowerAccuracy1 = Symbol(
        [0x2C98],
        [0x23294C0],
        None,
        "DoMoveLowerAccuracy1",
        "Move effect: Lower the defender's accuracy by one stage\nRelevant moves: Sand-Attack, Kinesis, Flash\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamagePoison40 = Symbol(
        [0x2CB8],
        [0x23294E0],
        None,
        "DoMoveDamagePoison40",
        "Move effect: Deal damage with a 40% chance (SMOG_POISON_CHANCE) of poisoning the defender.\nRelevant moves: Smog, Cross Poison, Gunk Shot, Poison Jab\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveGrowth = Symbol(
        [0x2D24],
        [0x232954C],
        None,
        "DoMoveGrowth",
        "Move effect: Growth\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSacredFire = Symbol(
        [0x2D44],
        [0x232956C],
        None,
        "DoMoveSacredFire",
        "Move effect: Sacred Fire\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveOhko = Symbol(
        [0x2DCC],
        [0x23295F4],
        None,
        "DoMoveOhko",
        "Move effect: Possibly one-hit KO the defender\nRelevant moves: Sheer Cold, Guillotine\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSolarBeam = Symbol(
        [0x2EB8],
        [0x23296E0],
        None,
        "DoMoveSolarBeam",
        "Move effect: SolarBeam\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSonicBoom = Symbol(
        [0x2F88],
        [0x23297B0],
        None,
        "DoMoveSonicBoom",
        "Move effect: SonicBoom\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFly = Symbol(
        [0x3028],
        [0x2329850],
        None,
        "DoMoveFly",
        "Move effect: Fly\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveExplosion = Symbol(
        [0x30B8],
        [0x23298E0],
        None,
        "DoMoveExplosion",
        "Move effect: Explosion\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDive = Symbol(
        [0x3110],
        [0x2329938],
        None,
        "DoMoveDive",
        "Move effect: Dive\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWaterfall = Symbol(
        [0x31D8],
        [0x2329A00],
        None,
        "DoMoveWaterfall",
        "Move effect: Waterfall\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageLowerAccuracy40 = Symbol(
        [0x3244],
        [0x2329A6C],
        None,
        "DoMoveDamageLowerAccuracy40",
        "Move effect: Deal damage with a 40% chance (MUDDY_WATER_LOWER_ACCURACY_CHANCE) of lowering the defender's accuracy.\nRelevant moves: Muddy Water, Mud Bomb, Mirror Shot\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMoveStockpile = Symbol(
        [0x32B8],
        [0x2329AE0],
        None,
        "DoMoveStockpile",
        "Move effect: Stockpile\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTwister = Symbol(
        [0x3310],
        [0x2329B38],
        None,
        "DoMoveTwister",
        "Move effect: Twister\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTwineedle = Symbol(
        [0x33A0],
        [0x2329BC8],
        None,
        "DoMoveTwineedle",
        "Move effect: Twineedle\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRecoverHpTeam = Symbol(
        [0x3438],
        [0x2329C60],
        None,
        "DoMoveRecoverHpTeam",
        "Move effect: Recover 25% HP for all team members\nRelevant moves: Softboiled, Milk Drink\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMinimize = Symbol(
        [0x3480],
        [0x2329CA8],
        None,
        "DoMoveMinimize",
        "Move effect: Minimize\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSeismicToss = Symbol(
        [0x349C],
        [0x2329CC4],
        None,
        "DoMoveSeismicToss",
        "Move effect: Seismic Toss\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveConfuse = Symbol(
        [0x3610],
        [0x2329E38],
        None,
        "DoMoveConfuse",
        "Move effect: Confuse target enemies if possible.\nRelevant moves: Confuse Ray, Supersonic, Sweet Kiss, Teeter Dance, Totter (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTaunt = Symbol(
        [0x3628],
        [0x2329E50],
        None,
        "DoMoveTaunt",
        "Move effect: Taunt\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMoonlight = Symbol(
        [0x363C],
        [0x2329E64],
        None,
        "DoMoveMoonlight",
        "Move effect: Moonlight\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHornDrill = Symbol(
        [0x367C],
        [0x2329EA4],
        None,
        "DoMoveHornDrill",
        "Move effect: Horn Drill\n\nThis is exactly the same as DoMoveOhko, except there's a call to SubstitutePlaceholderStringTags at the end.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSwordsDance = Symbol(
        [0x3778],
        [0x2329FA0],
        None,
        "DoMoveSwordsDance",
        "Move effect: Swords Dance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveConversion = Symbol(
        [0x3798],
        [0x2329FC0],
        None,
        "DoMoveConversion",
        "Move effect: Conversion\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveConversion2 = Symbol(
        [0x38A8],
        [0x232A0D0],
        None,
        "DoMoveConversion2",
        "Move effect: Conversion 2\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHelpingHand = Symbol(
        [0x38B8],
        [0x232A0E0],
        None,
        "DoMoveHelpingHand",
        "Move effect: Helping Hand\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBoostDefense2 = Symbol(
        [0x391C],
        [0x232A144],
        None,
        "DoMoveBoostDefense2",
        "Move effect: Boost the defender's defense stat by two stages\nRelevant moves: Iron Defense, Acid Armor, Barrier\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWarp = Symbol(
        [0x393C],
        [0x232A164],
        None,
        "DoMoveWarp",
        "Move effect: Warp the target to another tile on the floor\nRelevant moves: Teleport, Warp (item effect), MOVE_TAG_0x1A8\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveThundershock = Symbol(
        [0x3954],
        [0x232A17C],
        None,
        "DoMoveThundershock",
        "Move effect: Thundershock\n\nThis is identical to DoMoveDamageParalyze10, except it uses a different data symbol for the paralysis chance (but it's still 10%).\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveThunderWave = Symbol(
        [0x39C0],
        [0x232A1E8],
        None,
        "DoMoveThunderWave",
        "Move effect: Thunder Wave\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveZapCannon = Symbol(
        [0x3A34],
        [0x232A25C],
        None,
        "DoMoveZapCannon",
        "Move effect: Zap Cannon\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBlock = Symbol(
        [0x3A98],
        [0x232A2C0],
        None,
        "DoMoveBlock",
        "Move effect: Block\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePoison = Symbol(
        [0x3AAC],
        [0x232A2D4],
        None,
        "DoMovePoison",
        "Move effect: Poison the defender if possible\nRelevant moves: Poison Gas, PoisonPowder\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveToxic = Symbol(
        [0x3AC4],
        [0x232A2EC],
        None,
        "DoMoveToxic",
        "Move effect: Toxic\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePoisonFang = Symbol(
        [0x3ADC],
        [0x232A304],
        None,
        "DoMovePoisonFang",
        "Move effect: Poison Fang\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamagePoison18 = Symbol(
        [0x3B48],
        [0x232A370],
        None,
        "DoMoveDamagePoison18",
        "Move effect: Deal damage with an 18% chance (POISON_STING_POISON_CHANCE) to poison the defender.\nRelevant moves: Poison Sting, Sludge, Sludge Bomb\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveJumpKick = Symbol(
        [0x3BB4],
        [0x232A3DC],
        None,
        "DoMoveJumpKick",
        "Move effect: Jump Kick\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBounce = Symbol(
        [0x3CE0],
        [0x232A508],
        None,
        "DoMoveBounce",
        "Move effect: Bounce\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHiJumpKick = Symbol(
        [0x3DAC],
        [0x232A5D4],
        None,
        "DoMoveHiJumpKick",
        "Move effect: Hi Jump Kick\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTriAttack = Symbol(
        [0x3ED8],
        [0x232A700],
        None,
        "DoMoveTriAttack",
        "Move effect: Tri Attack\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSwapItems = Symbol(
        [0x3F94],
        [0x232A7BC],
        None,
        "DoMoveSwapItems",
        "Move effect: Swaps the held items of the attacker and defender.\nRelevant moves: Trick, Switcheroo\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTripleKick = Symbol(
        [0x41BC],
        [0x232A9E4],
        None,
        "DoMoveTripleKick",
        "Move effect: Triple Kick\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSport = Symbol(
        [0x41F8],
        [0x232AA20],
        None,
        "DoMoveSport",
        "Move effect: Activate the relevant sport condition (Mud Sport, Water Sport) on the floor\nRelevant moves: Mud Sport, Water Sport\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMudSlap = Symbol(
        [0x4224],
        [0x232AA4C],
        None,
        "DoMoveMudSlap",
        "Move effect: Mud-Slap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageStealItem = Symbol(
        [0x4290],
        [0x232AAB8],
        None,
        "DoMoveDamageStealItem",
        "Move effect: Deal damage and steal the defender's item if possible.\nRelevant moves: Thief, Covet\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAmnesia = Symbol(
        [0x429C],
        [0x232AAC4],
        None,
        "DoMoveAmnesia",
        "Move effect: Amnesia\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveNightShade = Symbol(
        [0x42BC],
        [0x232AAE4],
        None,
        "DoMoveNightShade",
        "Move effect: Night Shade\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGrowl = Symbol(
        [0x435C],
        [0x232AB84],
        None,
        "DoMoveGrowl",
        "Move effect: Growl\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSurf = Symbol(
        [0x438C],
        [0x232ABB4],
        None,
        "DoMoveSurf",
        "Move effect: Surf\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRolePlay = Symbol(
        [0x43CC],
        [0x232ABF4],
        None,
        "DoMoveRolePlay",
        "Move effect: Role Play\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSunnyDay = Symbol(
        [0x4464],
        [0x232AC8C],
        None,
        "DoMoveSunnyDay",
        "Move effect: Sunny Day\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLowerDefense1 = Symbol(
        [0x44C0],
        [0x232ACE8],
        None,
        "DoMoveLowerDefense1",
        "Move effect: Lower the defender's defense by one stage\nRelevant moves: Tail Whip, Leer\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWish = Symbol(
        [0x44F0],
        [0x232AD18],
        None,
        "DoMoveWish",
        "Move effect: Wish\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFakeOut = Symbol(
        [0x4500],
        [0x232AD28],
        None,
        "DoMoveFakeOut",
        "Move effect: Fake Out\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSleepTalk = Symbol(
        [0x456C],
        [0x232AD94],
        None,
        "DoMoveSleepTalk",
        "Move effect: Sleep Talk\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePayDay = Symbol(
        [0x4584],
        [0x232ADAC],
        None,
        "DoMovePayDay",
        "Move effect: Pay Day\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAssist = Symbol(
        [0x4640],
        [0x232AE68],
        None,
        "DoMoveAssist",
        "Move effect: Assist\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRest = Symbol(
        [0x4658],
        [0x232AE80],
        None,
        "DoMoveRest",
        "Move effect: Rest\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveIngrain = Symbol(
        [0x46C4],
        [0x232AEEC],
        None,
        "DoMoveIngrain",
        "Move effect: Ingrain\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSwallow = Symbol(
        [0x46D4],
        [0x232AEFC],
        None,
        "DoMoveSwallow",
        "Move effect: Swallow\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCurse = Symbol(
        [0x472C],
        [0x232AF54],
        None,
        "DoMoveCurse",
        "Move effect: Curse\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSuperpower = Symbol(
        [0x4768],
        [0x232AF90],
        None,
        "DoMoveSuperpower",
        "Move effect: Superpower\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSteelWing = Symbol(
        [0x47F0],
        [0x232B018],
        None,
        "DoMoveSteelWing",
        "Move effect: Steel Wing\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSpitUp = Symbol(
        [0x4884],
        [0x232B0AC],
        None,
        "DoMoveSpitUp",
        "Move effect: Spit Up\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDynamicPunch = Symbol(
        [0x48CC],
        [0x232B0F4],
        None,
        "DoMoveDynamicPunch",
        "Move effect: DynamicPunch\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveKnockOff = Symbol(
        [0x4930],
        [0x232B158],
        None,
        "DoMoveKnockOff",
        "Move effect: Knock Off\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSplash = Symbol(
        [0x4B30],
        [0x232B358],
        None,
        "DoMoveSplash",
        "Move effect: Splash\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSetDamage = Symbol(
        [0x4E88],
        [0x232B6B0],
        None,
        "DoMoveSetDamage",
        "Move effect: Give the user the Set Damage status\nRelevant moves: Doom Desire, Future Sight\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBellyDrum = Symbol(
        [0x4E98],
        [0x232B6C0],
        None,
        "DoMoveBellyDrum",
        "Move effect: Belly Drum\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLightScreen = Symbol(
        [0x4F4C],
        [0x232B774],
        None,
        "DoMoveLightScreen",
        "Move effect: Light Screen\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSecretPower = Symbol(
        [0x4F5C],
        [0x232B784],
        None,
        "DoMoveSecretPower",
        "Move effect: Secret Power\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageConfuse30 = Symbol(
        [0x5134],
        [0x232B95C],
        None,
        "DoMoveDamageConfuse30",
        "Move effect: Deal damage with a 30% chance (DIZZY_PUNCH_CONFUSE_CHANCE) to confuse the defender.\nRelevant moves: Dizzy Punch, Water Pulse\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBulkUp = Symbol(
        [0x51A0],
        [0x232B9C8],
        None,
        "DoMoveBulkUp",
        "Move effect: Bulk Up\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePause = Symbol(
        [0x51E4],
        [0x232BA0C],
        None,
        "DoMovePause",
        "Move effect: Inflicts the Paused status on the defender\nRelevant moves: Imprison, Observer (item effect), MOVE_TAG_0x1AD\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFeatherDance = Symbol(
        [0x5234],
        [0x232BA5C],
        None,
        "DoMoveFeatherDance",
        "Move effect: FeatherDance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBeatUp = Symbol(
        [0x5268],
        [0x232BA90],
        None,
        "DoMoveBeatUp",
        "Move effect: Beat Up\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBlastBurn = Symbol(
        [0x535C],
        [0x232BB84],
        None,
        "DoMoveBlastBurn",
        "Move effect: Blast Burn\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCrushClaw = Symbol(
        [0x53A8],
        [0x232BBD0],
        None,
        "DoMoveCrushClaw",
        "Move effect: Crush Claw\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBlazeKick = Symbol(
        [0x5428],
        [0x232BC50],
        None,
        "DoMoveBlazeKick",
        "Move effect: Blaze Kick\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePresent = Symbol(
        [0x54B0],
        [0x232BCD8],
        None,
        "DoMovePresent",
        "Move effect: Present\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEruption = Symbol(
        [0x55AC],
        [0x232BDD4],
        None,
        "DoMoveEruption",
        "Move effect: Eruption\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTransform = Symbol(
        [0x5690],
        [0x232BEB8],
        None,
        "DoMoveTransform",
        "Move effect: Transform\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePoisonTail = Symbol(
        [0x56D8],
        [0x232BF00],
        None,
        "DoMovePoisonTail",
        "Move effect: Poison Tail\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBlowback = Symbol(
        [0x5744],
        [0x232BF6C],
        None,
        "DoMoveBlowback",
        "Move effect: Blows the defender back\nRelevant moves: Whirlwind, Roar, Blowback (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCamouflage = Symbol(
        [0x575C],
        [0x232BF84],
        None,
        "DoMoveCamouflage",
        "Move effect: Camouflage\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTailGlow = Symbol(
        [0x580C],
        [0x232C034],
        None,
        "DoMoveTailGlow",
        "Move effect: Tail Glow\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageConstrict10 = Symbol(
        [0x582C],
        [0x232C054],
        None,
        "DoMoveDamageConstrict10",
        "Move effect: Deal damage with a 10% (WHIRLPOOL_CONSTRICT_CHANCE) chance to constrict, and with a damage multiplier dependent on the move used.\nRelevant moves: Clamp, Bind, Sand Tomb, Fire Spin, Magma Storm\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DoMovePerishSong = Symbol(
        [0x58E8],
        [0x232C110],
        None,
        "DoMovePerishSong",
        "Move effect: Perish Song\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWrap = Symbol(
        [0x58FC],
        [0x232C124],
        None,
        "DoMoveWrap",
        "Move effect: Wrap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSpikes = Symbol(
        [0x590C],
        [0x232C134],
        None,
        "DoMoveSpikes",
        "Move effect: Spikes\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMagnitude = Symbol(
        [0x597C],
        [0x232C1A4],
        None,
        "DoMoveMagnitude",
        "Move effect: Magnitude\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMagicCoat = Symbol(
        [0x5A04],
        [0x232C22C],
        None,
        "DoMoveMagicCoat",
        "Move effect: Magic Coat\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveProtect = Symbol(
        [0x5A14],
        [0x232C23C],
        None,
        "DoMoveProtect",
        "Move effect: Try to give the user the Protect status\nRelevant moves: Protect, Detect\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDefenseCurl = Symbol(
        [0x5A24],
        [0x232C24C],
        None,
        "DoMoveDefenseCurl",
        "Move effect: Defense Curl\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDecoy = Symbol(
        [0x5A44],
        [0x232C26C],
        None,
        "DoMoveDecoy",
        "Move effect: Inflict the Decoy status on the target\nRelevant moves: Follow Me, Substitute, Decoy Maker (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMistBall = Symbol(
        [0x5A64],
        [0x232C28C],
        None,
        "DoMoveMistBall",
        "Move effect: Mist Ball\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDestinyBond = Symbol(
        [0x5AE4],
        [0x232C30C],
        None,
        "DoMoveDestinyBond",
        "Move effect: Destiny Bond\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMirrorCoat = Symbol(
        [0x5B18],
        [0x232C340],
        None,
        "DoMoveMirrorCoat",
        "Move effect: Mirror Coat\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCalmMind = Symbol(
        [0x5B28],
        [0x232C350],
        None,
        "DoMoveCalmMind",
        "Move effect: Calm Mind\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHiddenPower = Symbol(
        [0x5B6C],
        [0x232C394],
        None,
        "DoMoveHiddenPower",
        "Move effect: Hidden Power\n\nThis is exactly the same as DoMoveDamage (both are wrappers around DealDamage), except this function always returns true.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMetalClaw = Symbol(
        [0x5B84],
        [0x232C3AC],
        None,
        "DoMoveMetalClaw",
        "Move effect: Metal Claw\n\n Note that this move effect handler has a slightly different parameter list than all the others. Which offensive stat is boosted is specified by the caller.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: stat index for the offensive stat to boost\nstack[0]: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAttract = Symbol(
        [0x5C18],
        [0x232C440],
        None,
        "DoMoveAttract",
        "Move effect: Attract\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCopycat = Symbol(
        [0x5C8C],
        [0x232C4B4],
        None,
        "DoMoveCopycat",
        "Move effect: The attacker uses the move last used by enemy it's facing.\nRelevant moves: Mimic, Copycat\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFrustration = Symbol(
        [0x5D94],
        [0x232C5BC],
        None,
        "DoMoveFrustration",
        "Move effect: Frustration\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLeechSeed = Symbol(
        [0x5E7C],
        [0x232C6A4],
        None,
        "DoMoveLeechSeed",
        "Move effect: Leech Seed\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMetronome = Symbol(
        [0x5EAC],
        [0x232C6D4],
        None,
        "DoMoveMetronome",
        "Move effect: Metronome\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDreamEater = Symbol(
        [0x5F0C],
        [0x232C734],
        None,
        "DoMoveDreamEater",
        "Move effect: Dream Eater\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSnatch = Symbol(
        [0x607C],
        [0x232C8A4],
        None,
        "DoMoveSnatch",
        "Move effect: Snatch\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRecycle = Symbol(
        [0x608C],
        [0x232C8B4],
        None,
        "DoMoveRecycle",
        "Move effect: Recycle\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveReflect = Symbol(
        [0x61C0],
        [0x232C9E8],
        None,
        "DoMoveReflect",
        "Move effect: Reflect\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDragonRage = Symbol(
        [0x61D0],
        [0x232C9F8],
        None,
        "DoMoveDragonRage",
        "Move effect: Dragon Rage\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDragonDance = Symbol(
        [0x6270],
        [0x232CA98],
        None,
        "DoMoveDragonDance",
        "Move effect: Dragon Dance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSkullBash = Symbol(
        [0x62AC],
        [0x232CAD4],
        None,
        "DoMoveSkullBash",
        "Move effect: Skull Bash\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageLowerSpecialDefense50 = Symbol(
        [0x633C],
        [0x232CB64],
        None,
        "DoMoveDamageLowerSpecialDefense50",
        "Move effect: Deal damage with a 50% (LUSTER_PURGE_LOWER_SPECIAL_DEFENSE_CHANCE) chance to lower special defense.\nRelevant moves: Luster Purge, Energy Ball, Focus Blast\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveStruggle = Symbol(
        [0x63EC],
        [0x232CC14],
        None,
        "DoMoveStruggle",
        "Move effect: Struggle\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRockSmash = Symbol(
        [0x64C4],
        [0x232CCEC],
        None,
        "DoMoveRockSmash",
        "Move effect: Rock Smash\nRelevant moves: Rock Smash, MOVE_UNNAMED_0x169\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSeeTrap = Symbol(
        [0x6548],
        [0x232CD70],
        None,
        "DoMoveSeeTrap",
        "Move effect: See-Trap (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTakeaway = Symbol(
        [0x6558],
        [0x232CD80],
        None,
        "DoMoveTakeaway",
        "Move effect: Takeaway (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRebound = Symbol(
        [0x676C],
        [0x232CF94],
        None,
        "DoMoveRebound",
        "Move effect: Rebound (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSwitchPositions = Symbol(
        [0x6780],
        [0x232CFA8],
        None,
        "DoMoveSwitchPositions",
        "Move effect: Switches the user's position with positions of other monsters in the room.\nRelevant moves: Baton Pass, Switcher (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveStayAway = Symbol(
        [0x67A8],
        [0x232CFD0],
        None,
        "DoMoveStayAway",
        "Move effect: Stay Away (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCleanse = Symbol(
        [0x67C0],
        [0x232CFE8],
        None,
        "DoMoveCleanse",
        "Move effect: Cleanse (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSiesta = Symbol(
        [0x68FC],
        [0x232D124],
        None,
        "DoMoveSiesta",
        "Move effect: Siesta (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTwoEdge = Symbol(
        [0x6938],
        [0x232D160],
        None,
        "DoMoveTwoEdge",
        "Move effect: Two-Edge (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveNoMove = Symbol(
        [0x6A60],
        [0x232D288],
        None,
        "DoMoveNoMove",
        "Move effect: No-Move (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveScan = Symbol(
        [0x6A74],
        [0x232D29C],
        None,
        "DoMoveScan",
        "Move effect: Scan (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePowerEars = Symbol(
        [0x6A84],
        [0x232D2AC],
        None,
        "DoMovePowerEars",
        "Move effect: Power-Ears (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTransfer = Symbol(
        [0x6A94],
        [0x232D2BC],
        None,
        "DoMoveTransfer",
        "Move effect: Transfer (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSlowDown = Symbol(
        [0x6C5C],
        [0x232D484],
        None,
        "DoMoveSlowDown",
        "Move effect: Slow Down (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSearchlight = Symbol(
        [0x6C74],
        [0x232D49C],
        None,
        "DoMoveSearchlight",
        "Move effect: Searchlight (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePetrify = Symbol(
        [0x6C84],
        [0x232D4AC],
        None,
        "DoMovePetrify",
        "Move effect: Petrifies the target\nRelevant moves: Petrify (item effect), MOVE_TAG_0x1A9\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePounce = Symbol(
        [0x6C94],
        [0x232D4BC],
        None,
        "DoMovePounce",
        "Move effect: Pounce (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTrawl = Symbol(
        [0x6CA8],
        [0x232D4D0],
        None,
        "DoMoveTrawl",
        "Move effect: Trawl (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEscape = Symbol(
        [0x6CB8],
        [0x232D4E0],
        None,
        "DoMoveEscape",
        "Move effect: Escape (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDrought = Symbol(
        [0x6D50],
        [0x232D578],
        None,
        "DoMoveDrought",
        "Move effect: Drought (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTrapBuster = Symbol(
        [0x6D60],
        [0x232D588],
        None,
        "DoMoveTrapBuster",
        "Move effect: Trap Buster (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWildCall = Symbol(
        [0x6F0C],
        [0x232D734],
        None,
        "DoMoveWildCall",
        "Move effect: Wild Call (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveInvisify = Symbol(
        [0x6FD8],
        [0x232D800],
        None,
        "DoMoveInvisify",
        "Move effect: Invisify (item effect)\n\nThis function sets r1 = r0 before calling TryInvisify, so the effect will always be applied to the user regardless of the move settings.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveOneShot = Symbol(
        [0x6FEC],
        [0x232D814],
        None,
        "DoMoveOneShot",
        "Move effect: One-Shot (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHpGauge = Symbol(
        [0x7088],
        [0x232D8B0],
        None,
        "DoMoveHpGauge",
        "Move effect: HP Gauge (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveVacuumCut = Symbol(
        [0x7098],
        [0x232D8C0],
        None,
        "DoMoveVacuumCut",
        "Move effect: Vacuum Cut\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveReviver = Symbol(
        [0x70C4],
        [0x232D8EC],
        None,
        "DoMoveReviver",
        "Move effect: Reviver (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveShocker = Symbol(
        [0x70DC],
        [0x232D904],
        None,
        "DoMoveShocker",
        "Move effect: Shocker (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEcho = Symbol(
        [0x70F4],
        [0x232D91C],
        None,
        "DoMoveEcho",
        "Move effect: Echo (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFamish = Symbol(
        [0x719C],
        [0x232D9C4],
        None,
        "DoMoveFamish",
        "Move effect: Famish (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveOneRoom = Symbol(
        [0x71BC],
        [0x232D9E4],
        None,
        "DoMoveOneRoom",
        "Move effect: One-Room (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFillIn = Symbol(
        [0x71CC],
        [0x232D9F4],
        None,
        "DoMoveFillIn",
        "Move effect: Fill-In (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTrapper = Symbol(
        [0x7338],
        [0x232DB60],
        None,
        "DoMoveTrapper",
        "Move effect: Trapper (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveItemize = Symbol(
        [0x7390],
        [0x232DBB8],
        None,
        "DoMoveItemize",
        "Move effect: Itemize (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHurl = Symbol(
        [0x7424],
        [0x232DC4C],
        None,
        "DoMoveHurl",
        "Move effect: Hurls the target\nRelevant moves: Strength, Hurl (item effect), Fling\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMobile = Symbol(
        [0x7434],
        [0x232DC5C],
        None,
        "DoMoveMobile",
        "Move effect: Mobile (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveSeeStairs = Symbol(
        [0x7444],
        [0x232DC6C],
        None,
        "DoMoveSeeStairs",
        "Move effect: See Stairs (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLongToss = Symbol(
        [0x7454],
        [0x232DC7C],
        None,
        "DoMoveLongToss",
        "Move effect: Long Toss (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePierce = Symbol(
        [0x7464],
        [0x232DC8C],
        None,
        "DoMovePierce",
        "Move effect: Pierce (item effect)\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHammerArm = Symbol(
        [0x7474],
        [0x232DC9C],
        None,
        "DoMoveHammerArm",
        "Move effect: Hammer Arm\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAquaRing = Symbol(
        [0x74B8],
        [0x232DCE0],
        None,
        "DoMoveAquaRing",
        "Move effect: Aqua Ring\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGastroAcid = Symbol(
        [0x74C8],
        [0x232DCF0],
        None,
        "DoMoveGastroAcid",
        "Move effect: Gastro Acid\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHealingWish = Symbol(
        [0x74E0],
        [0x232DD08],
        None,
        "DoMoveHealingWish",
        "Move effect: Healing Wish\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCloseCombat = Symbol(
        [0x7530],
        [0x232DD58],
        None,
        "DoMoveCloseCombat",
        "Move effect: Close Combat\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLuckyChant = Symbol(
        [0x75B0],
        [0x232DDD8],
        None,
        "DoMoveLuckyChant",
        "Move effect: Lucky Chant\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGuardSwap = Symbol(
        [0x75C0],
        [0x232DDE8],
        None,
        "DoMoveGuardSwap",
        "Move effect: Guard Swap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHealOrder = Symbol(
        [0x7620],
        [0x232DE48],
        None,
        "DoMoveHealOrder",
        "Move effect: Heal Order\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHealBlock = Symbol(
        [0x7648],
        [0x232DE70],
        None,
        "DoMoveHealBlock",
        "Move effect: Heal Block\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveThunderFang = Symbol(
        [0x7660],
        [0x232DE88],
        None,
        "DoMoveThunderFang",
        "Move effect: Thunder Fang\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDefog = Symbol(
        [0x76F4],
        [0x232DF1C],
        None,
        "DoMoveDefog",
        "Move effect: Defog\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTrumpCard = Symbol(
        [0x77A8],
        [0x232DFD0],
        None,
        "DoMoveTrumpCard",
        "Move effect: Trump Card\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveIceFang = Symbol(
        [0x7868],
        [0x232E090],
        None,
        "DoMoveIceFang",
        "Move effect: Ice Fang\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePsychoShift = Symbol(
        [0x78F8],
        [0x232E120],
        None,
        "DoMovePsychoShift",
        "Move effect: Psycho Shift\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveEmbargo = Symbol(
        [0x7918],
        [0x232E140],
        None,
        "DoMoveEmbargo",
        "Move effect: Embargo\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveBrine = Symbol(
        [0x7930],
        [0x232E158],
        None,
        "DoMoveBrine",
        "Move effect: Deal damage, with a 2x multiplier if the defender is at or below half HP.\nRelevant moves: Brine, Assurance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveNaturalGift = Symbol(
        [0x7980],
        [0x232E1A8],
        None,
        "DoMoveNaturalGift",
        "Move effect: Natural Gift\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGyroBall = Symbol(
        [0x7A40],
        [0x232E268],
        None,
        "DoMoveGyroBall",
        "Move effect: Gyro Ball\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveShadowForce = Symbol(
        [0x7AA8],
        [0x232E2D0],
        None,
        "DoMoveShadowForce",
        "Move effect: Shadow Force\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveGravity = Symbol(
        [0x7B44],
        [0x232E36C],
        None,
        "DoMoveGravity",
        "Move effect: Gravity\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveStealthRock = Symbol(
        [0x7B54],
        [0x232E37C],
        None,
        "DoMoveStealthRock",
        "Move effect: Stealth Rock\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveChargeBeam = Symbol(
        [0x7BC4],
        [0x232E3EC],
        None,
        "DoMoveChargeBeam",
        "Move effect: Charge Beam\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageEatItem = Symbol(
        [0x7C2C],
        [0x232E454],
        None,
        "DoMoveDamageEatItem",
        "Move effect: Deals damage, and eats any beneficial items the defender is holding.\nRelevant moves: Pluck, Bug Bite\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveAcupressure = Symbol(
        [0x7CE8],
        [0x232E510],
        None,
        "DoMoveAcupressure",
        "Move effect: Acupressure\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMagnetRise = Symbol(
        [0x7E6C],
        [0x232E694],
        None,
        "DoMoveMagnetRise",
        "Move effect: Magnet Rise\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveToxicSpikes = Symbol(
        [0x7E7C],
        [0x232E6A4],
        None,
        "DoMoveToxicSpikes",
        "Move effect: Toxic Spikes\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLastResort = Symbol(
        [0x7EEC],
        [0x232E714],
        None,
        "DoMoveLastResort",
        "Move effect: Last Resort\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTrickRoom = Symbol(
        [0x7F90],
        [0x232E7B8],
        None,
        "DoMoveTrickRoom",
        "Move effect: Trick Room\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWorrySeed = Symbol(
        [0x7FC4],
        [0x232E7EC],
        None,
        "DoMoveWorrySeed",
        "Move effect: Worry Seed\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDamageHpDependent = Symbol(
        [0x809C],
        [0x232E8C4],
        None,
        "DoMoveDamageHpDependent",
        "Move effect: Deal damage, with a multiplier dependent on the defender's current HP.\nRelevant moves: Wring Out, Crush Grip\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHeartSwap = Symbol(
        [0x8150],
        [0x232E978],
        None,
        "DoMoveHeartSwap",
        "Move effect: Heart Swap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRoost = Symbol(
        [0x81E0],
        [0x232EA08],
        None,
        "DoMoveRoost",
        "Move effect: Roost\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePowerSwap = Symbol(
        [0x829C],
        [0x232EAC4],
        None,
        "DoMovePowerSwap",
        "Move effect: Power Swap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMovePowerTrick = Symbol(
        [0x82FC],
        [0x232EB24],
        None,
        "DoMovePowerTrick",
        "Move effect: Power Trick\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFeint = Symbol(
        [0x8310],
        [0x232EB38],
        None,
        "DoMoveFeint",
        "Move effect: Feint\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFlareBlitz = Symbol(
        [0x8348],
        [0x232EB70],
        None,
        "DoMoveFlareBlitz",
        "Move effect: Flare Blitz\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDefendOrder = Symbol(
        [0x848C],
        [0x232ECB4],
        None,
        "DoMoveDefendOrder",
        "Move effect: Defend Order\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveFireFang = Symbol(
        [0x84D0],
        [0x232ECF8],
        None,
        "DoMoveFireFang",
        "Move effect: Fire Fang\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLunarDance = Symbol(
        [0x8580],
        [0x232EDA8],
        None,
        "DoMoveLunarDance",
        "Move effect: Lunar Dance\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMiracleEye = Symbol(
        [0x85E8],
        [0x232EE10],
        None,
        "DoMoveMiracleEye",
        "Move effect: Miracle Eye\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveWakeUpSlap = Symbol(
        [0x8618],
        [0x232EE40],
        None,
        "DoMoveWakeUpSlap",
        "Move effect: Wake-Up Slap\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveMetalBurst = Symbol(
        [0x86A4],
        [0x232EECC],
        None,
        "DoMoveMetalBurst",
        "Move effect: Metal Burst\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveHeadSmash = Symbol(
        [0x86B8],
        [0x232EEE0],
        None,
        "DoMoveHeadSmash",
        "Move effect: Head Smash\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveCaptivate = Symbol(
        [0x8778],
        [0x232EFA0],
        None,
        "DoMoveCaptivate",
        "Move effect: Captivate\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveLeafStorm = Symbol(
        [0x883C],
        [0x232F064],
        None,
        "DoMoveLeafStorm",
        "Move effect: Leaf Storm\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveDracoMeteor = Symbol(
        [0x8894],
        [0x232F0BC],
        None,
        "DoMoveDracoMeteor",
        "Move effect: Draco Meteor\n\nNote that this move effect handler has an extra parameter that can be used to disable the special attack drop.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nr4: disable special attack drop\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveRockPolish = Symbol(
        [0x88F8],
        [0x232F120],
        None,
        "DoMoveRockPolish",
        "Move effect: Rock Polish\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveNastyPlot = Symbol(
        [0x892C],
        [0x232F154],
        None,
        "DoMoveNastyPlot",
        "Move effect: Nasty Plot\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTag0x1AB = Symbol(
        [0x894C],
        [0x232F174],
        None,
        "DoMoveTag0x1AB",
        "Move effect: MOVE_TAG_0x1AB\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTag0x1A6 = Symbol(
        [0x8968],
        [0x232F190],
        None,
        "DoMoveTag0x1A6",
        "Move effect: MOVE_TAG_0x1A6\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )

    DoMoveTag0x1A7 = Symbol(
        [0x89AC],
        [0x232F1D4],
        None,
        "DoMoveTag0x1A7",
        "Move effect: MOVE_TAG_0x1A7\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether the move was successfully used",
        None,
    )


class EuMove_effectsData:

    MAX_HP_CAP_MOVE_EFFECTS = Symbol(
        None,
        None,
        None,
        "MAX_HP_CAP_MOVE_EFFECTS",
        "See overlay29.yml::MAX_HP_CAP",
        "int32_t",
    )

    LUNAR_DANCE_PP_RESTORATION = Symbol(
        None,
        None,
        None,
        "LUNAR_DANCE_PP_RESTORATION",
        "The amount of PP restored by Lunar Dance (999).",
        "int32_t",
    )


class EuMove_effectsSection:
    name = "move_effects"
    description = "Move effect handlers for individual moves, called by ExecuteMoveEffect (and also the Metronome and Nature Power tables).\n\nThis subregion contains only the move effect handlers themselves, and not necessarily all the utility functions used by the move effect handlers (such as the damage calculation functions). These supporting utilities are in the main overlay29 block."
    loadaddress = 0x2326828
    length = 0x8A24
    functions = EuMove_effectsFunctions
    data = EuMove_effectsData


class EuOverlay0Functions:

    pass


class EuOverlay0Data:

    TOP_MENU_MUSIC_ID = Symbol(
        [0x15F4],
        [0x22BE9B4],
        None,
        "TOP_MENU_MUSIC_ID",
        "Music ID to play in the top menu.",
        "struct data_processing_instruction",
    )


class EuOverlay0Section:
    name = "overlay0"
    description = "Likely contains supporting data and code related to the top menu.\n\nThis is loaded together with overlay 1 while in the top menu. Since it's in overlay group 2 (together with overlay 10, which is another 'data' overlay), this overlay probably plays a similar role. It mentions several files from the BACK folder that are known backgrounds for the top menu."
    loadaddress = 0x22BD3C0
    length = 0x60880
    functions = EuOverlay0Functions
    data = EuOverlay0Data


class EuOverlay1Functions:

    CreateMainMenus = Symbol(
        [0x7B88],
        [0x23318C8],
        None,
        "CreateMainMenus",
        "Prepares the top menu and sub menu, adding the different options that compose them.\n\nContains multiple calls to AddMainMenuOption and AddSubMenuOption. Some of them are conditionally executed depending on which options should be unlocked.\n\nNo params.",
        None,
    )

    AddMainMenuOption = Symbol(
        [0x7FFC],
        [0x2331D3C],
        None,
        "AddMainMenuOption",
        "Adds an option to the top menu.\n\nThis function is called for each one of the options in the top menu. It loops the MAIN_MENU data field, if the specified action ID does not exist there, the option won't be added.\n\nr0: Action ID\nr1: True if the option should be enabled, false otherwise",
        None,
    )

    AddSubMenuOption = Symbol(
        [0x80D4],
        [0x2331E14],
        None,
        "AddSubMenuOption",
        "Adds an option to the 'Other' submenu on the top menu.\n\nThis function is called for each one of the options in the submenu. It loops the SUBMENU data field, if the specified action ID does not exist there, the option won't be added.\n\nr0: Action ID\nr1: True if the option should be enabled, false otherwise",
        None,
    )

    ProcessContinueScreenContents = Symbol(
        [0x9998],
        [0x23336D8],
        None,
        "ProcessContinueScreenContents",
        "Fetches the required data and creates all the strings to display the contents shown in the window\nwhen choosing continue in the main menu.\n\nr0: undefined4",
        None,
    )


class EuOverlay1Data:

    PRINTS_STRINGS = Symbol(
        [0x11B38],
        [0x233B878],
        0x1E8,
        "PRINTS_STRINGS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    PRINTS_STRUCT = Symbol(
        [0x11D20],
        [0x233BA60],
        0x1F0,
        "PRINTS_STRUCT",
        "62*0x8\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    MAIN_MENU_WINDOW_PARAMS_1 = Symbol(
        [0x11F24],
        [0x233BC64],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_WINDOW_PARAMS_2 = Symbol(
        [0x11F34],
        [0x233BC74],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_WINDOW_PARAMS_3 = Symbol(
        [0x11F44],
        [0x233BC84],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_WINDOW_PARAMS_4 = Symbol(
        [0x11F54],
        [0x233BC94],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    CONTINUE_CHOICE = Symbol([0x11F74], [0x233BCB4], 0x20, "CONTINUE_CHOICE", "", "")

    SUBMENU = Symbol([0x11F94], [0x233BCD4], 0x48, "SUBMENU", "", "")

    MAIN_MENU = Symbol([0x11FDC], [0x233BD1C], 0xA0, "MAIN_MENU", "", "")

    MAIN_MENU_WINDOW_PARAMS_5 = Symbol(
        [0x12128],
        [0x233BE68],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_WINDOW_PARAMS_6 = Symbol(
        [0x12138],
        [0x233BE78],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_WINDOW_PARAMS_7 = Symbol(
        [0x12148],
        [0x233BE88],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_ITEMS_CONFIRM = Symbol(
        [0x12158],
        [0x233BE98],
        0x18,
        "MAIN_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    MAIN_MENU_WINDOW_PARAMS_8 = Symbol(
        [0x121DC],
        [0x233BF1C],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_MENU_WINDOW_PARAMS_9 = Symbol(
        [0x121FC],
        [0x233BF3C],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_DEBUG_MENU_ITEMS_1 = Symbol(
        [0x1221C],
        [0x233BF5C],
        0x60,
        "MAIN_DEBUG_MENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[12]",
    )

    MAIN_MENU_WINDOW_PARAMS_10 = Symbol(
        [0x1227C],
        [0x233BFBC],
        0x10,
        "MAIN_MENU_WINDOW_PARAMS_10",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    MAIN_DEBUG_MENU_ITEMS_2 = Symbol(
        [0x1229C],
        [0x233BFDC],
        0x38,
        "MAIN_DEBUG_MENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[7]",
    )


class EuOverlay1Section:
    name = "overlay1"
    description = "Likely controls the top menu.\n\nThis is loaded together with overlay 0 while in the top menu. Since it's in overlay group 1 (together with other 'main' overlays like overlay 11 and overlay 29), this is probably the controller.\n\nSeems to contain code related to Wi-Fi rescue. It mentions several files from the GROUND and BACK folders."
    loadaddress = 0x2329D40
    length = 0x12C80
    functions = EuOverlay1Functions
    data = EuOverlay1Data


class EuOverlay10Functions:

    CreateInventoryMenu = Symbol(
        [0x0],
        [0x22BD3C0],
        None,
        "CreateInventoryMenu",
        "Creates a window containing a menu for inventory management. Also see struct inventory_menu.\n\nThis is used for the Treasure Bag menu, the item information/price window in dungeon Kecleon shops, and possibly other things.\n\nIf window_params is NULL, INVENTORY_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: some function pointer?\nstack[0]: ?\nstack[1]: total number of items\nstack[2]: number of items per page\nstack[3]: ?\nreturn: window_id",
        None,
    )

    SetInventoryMenuState0 = Symbol(
        [0x24C],
        [0x22BD60C],
        None,
        "SetInventoryMenuState0",
        "Sets an inventory menu to state 0.\n\nr0: window_id",
        None,
    )

    SetInventoryMenuState6 = Symbol(
        [0x260],
        [0x22BD620],
        None,
        "SetInventoryMenuState6",
        "Sets an inventory menu to state 6.\n\nr0: window_id",
        None,
    )

    CloseInventoryMenu = Symbol(
        [0x274],
        [0x22BD634],
        None,
        "CloseInventoryMenu",
        "Closes a window created with CreateInventoryMenu.\n\nr0: window_id",
        None,
    )

    IsInventoryMenuActive = Symbol(
        [0x2E8],
        [0x22BD6A8],
        None,
        "IsInventoryMenuActive",
        "This is a guess.\n\nChecks if the state of an inventory menu is something other than 7 or 8\n\nr0: window_id\nreturn: bool",
        None,
    )

    CheckInventoryMenuField0x1A0 = Symbol(
        [0x308],
        [0x22BD6C8],
        None,
        "CheckInventoryMenuField0x1A0",
        "Checks if inventory_menu::field_0x1a0 is 0.\n\nr0: window_id\nreturn: bool",
        None,
    )

    PopInventoryMenuField0x1A3 = Symbol(
        [0x3D8],
        [0x22BD798],
        None,
        "PopInventoryMenuField0x1A3",
        "Sets inventory_menu::field_0x1a3 to 0 and returns the old value.\n\nr0: window_id\nreturn: old value",
        None,
    )

    UpdateInventoryMenu = Symbol(
        [0x3F4],
        [0x22BD7B4],
        None,
        "UpdateInventoryMenu",
        "Window update function for inventory menus.\n\nr0: window pointer",
        None,
    )

    IsInventoryMenuState3 = Symbol(
        [0x8F4],
        [0x22BDCB4],
        None,
        "IsInventoryMenuState3",
        "Checks if an inventory menu has a state value of 3.\n\nr0: window_id\nreturn: bool",
        None,
    )

    SprintfStatic = Symbol(
        [0x9CC, 0x4DD4],
        [0x22BDD8C, 0x22C2194],
        None,
        "SprintfStatic",
        "Statically defined copy of sprintf(3) in overlay 10. See arm9.yml for more information.\n\nr0: str\nr1: format\n...: variadic\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    GetEffectAnimationField0x19 = Symbol(
        [0x1434],
        [0x22BE7F4],
        None,
        "GetEffectAnimationField0x19",
        "Calls GetEffectAnimation and returns field 0x19.\n\nr0: anim_id\nreturn: GetEffectAnimation(anim_id)->field_0x19.",
        None,
    )

    AnimationHasMoreFrames = Symbol(
        [0x2E84],
        [0x22C0244],
        None,
        "AnimationHasMoreFrames",
        "Just a guess. This is called in a loop in PlayEffectAnimation, and the output controls whether or not AdvanceFrame continues to be called.\nIf the current effect animation's is_non_blocking field is set, the function will return false the very first time it is called.\n\nr0: ?\nreturn: whether or not the animation still has more frames left?",
        None,
    )

    GetEffectAnimation = Symbol(
        [0x3420],
        [0x22C07E0],
        None,
        "GetEffectAnimation",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: anim_id\nreturn: effect animation pointer",
        None,
    )

    GetMoveAnimation = Symbol(
        [0x3434],
        [0x22C07F4],
        None,
        "GetMoveAnimation",
        "Get the move animation corresponding to the given move ID.\n\nr0: move_id\nreturn: move animation pointer",
        None,
    )

    GetSpecialMonsterMoveAnimation = Symbol(
        [0x3448],
        [0x22C0808],
        None,
        "GetSpecialMonsterMoveAnimation",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: ent_id\nreturn: special monster move animation pointer",
        None,
    )

    GetTrapAnimation = Symbol(
        [0x345C],
        [0x22C081C],
        None,
        "GetTrapAnimation",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: trap_id\nreturn: trap animation",
        None,
    )

    GetItemAnimation1 = Symbol(
        [0x3470],
        [0x22C0830],
        None,
        "GetItemAnimation1",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_id\nreturn: first field of the item animation info",
        None,
    )

    GetItemAnimation2 = Symbol(
        [0x3484],
        [0x22C0844],
        None,
        "GetItemAnimation2",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: item_id\nreturn: second field of the item animation info",
        None,
    )

    GetMoveAnimationSpeed = Symbol(
        [0x3498],
        [0x22C0858],
        None,
        "GetMoveAnimationSpeed",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: move_id\nreturn: anim_ent_ptr (This might be a mistake? It seems to be an integer, not a pointer)",
        None,
    )

    DrawTeamStats = Symbol(
        [0x3F68],
        [0x22C1328],
        None,
        "DrawTeamStats",
        "Handles creating the windows, sprites, etc. for the team stats top screen display.\n\nr0: undefined4\nr1: int\nr2: undefined4\nr3: uint32_t\nreturn: undefined4",
        None,
    )

    UpdateTeamStats = Symbol(
        [0x4260],
        [0x22C1620],
        None,
        "UpdateTeamStats",
        "Handles updating the team stats top screen display.\n\nNo params.",
        None,
    )

    FreeTeamStats = Symbol(
        [0x4934],
        [0x22C1CF4],
        None,
        "FreeTeamStats",
        "Handles the procedure to close the team stats top screen display.\n\nFirst it deletes the sprites, then it closes the portrait boxes and then the text boxes containing the stats for all 4 team members.\n\nreturn: always 1, seems unused",
        None,
    )

    FreeMapAndTeam = Symbol(
        [0x4C64],
        [0x22C2024],
        None,
        "FreeMapAndTeam",
        "Handles the procedure to close the map and team top screen display.\n\nreturn: always 1, seems unused",
        None,
    )

    ProcessTeamStatsLvHp = Symbol(
        [0x4CD4],
        [0x22C2094],
        None,
        "ProcessTeamStatsLvHp",
        "Appears to populate the Lv./HP row in the 'Team stats' top screen.\n\nr0: index of some kind",
        None,
    )

    ProcessTeamStatsNameGender = Symbol(
        [0x4DFC],
        [0x22C21BC],
        None,
        "ProcessTeamStatsNameGender",
        "Appears to populate the name/gender row in the 'Team stats' top screen.\n\nr0: index of some kind",
        None,
    )

    IsBackgroundTileset = Symbol(
        [0x5B0C],
        [0x22C2ECC],
        None,
        "IsBackgroundTileset",
        "Given a tileset ID, returns whether it's a background or a regular tileset\n\nIn particular, returns r0 >= 0xAA\n\nr0: Tileset ID\nreturn: True if the tileset ID corresponds to a background, false if it corresponds to a regular tileset",
        None,
    )

    InitTilesetBuffer = Symbol(
        [0x5C54],
        [0x22C3014],
        None,
        "InitTilesetBuffer",
        "Initializes a buffer that contains data related to tilesets (such as dungeon::unknown_file_buffer_0x102A8).\n\nCalls AllocAndLoadFileInPack and DecompressAtNormalVeneer.\n\nr0: Pointer to the buffer to init\nr1: Tileset ID\nr2: Memory allocation flags",
        None,
    )

    MainGame = Symbol(
        [0x5E24],
        [0x22C31E4],
        None,
        "MainGame",
        "Contains several functions that handle switching between ground and dungeon mode. It also handles other situations, like what happens right after exiting a dungeon.\n\nThe function doesn't get called until the player selects the option to resume a saved game and doesn't return until the player returns to the main menu.\n\nr0: End condition code? Seems to control what tasks get run and what transition happens when the dungeon ends\nreturn: return code?",
        None,
    )


class EuOverlay10Data:

    INVENTORY_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x792C],
        [0x22C4CEC],
        None,
        "INVENTORY_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an inventory_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateInventoryMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateInventoryMenu.",
        "struct window_params",
    )

    FIRST_DUNGEON_WITH_MONSTER_HOUSE_TRAPS = Symbol(
        [0x79A4],
        [0x22C4D64],
        0x1,
        "FIRST_DUNGEON_WITH_MONSTER_HOUSE_TRAPS",
        "The first dungeon that can have extra traps spawn in Monster Houses, Dark Hill\n\ntype: struct dungeon_id_8",
        "struct dungeon_id_8",
    )

    BAD_POISON_DAMAGE_COOLDOWN = Symbol(
        [0x79AC],
        [0x22C4D6C],
        0x2,
        "BAD_POISON_DAMAGE_COOLDOWN",
        "The number of turns between passive bad poison (toxic) damage.",
        "int16_t",
    )

    PROTEIN_STAT_BOOST = Symbol(
        [0x79B8],
        [0x22C4D78],
        0x2,
        "PROTEIN_STAT_BOOST",
        "The permanent attack boost from ingesting a Protein.",
        "int16_t",
    )

    WATERFALL_CRINGE_CHANCE = Symbol(
        [0x79BC],
        [0x22C4D7C],
        None,
        "WATERFALL_CRINGE_CHANCE",
        "The chance of Waterfall inflicting the cringe status, as a percentage (30%).",
        "int16_t",
    )

    AURORA_BEAM_LOWER_ATTACK_CHANCE = Symbol(
        [0x79C0],
        [0x22C4D80],
        None,
        "AURORA_BEAM_LOWER_ATTACK_CHANCE",
        "The chance of Aurora Beam halving attack, as a percentage (60%).",
        "int16_t",
    )

    SPAWN_CAP_NO_MONSTER_HOUSE = Symbol(
        [0x79C8],
        [0x22C4D88],
        0x2,
        "SPAWN_CAP_NO_MONSTER_HOUSE",
        "The maximum number of enemies that can spawn on a floor without a monster house (15).",
        "int16_t",
    )

    OREN_BERRY_DAMAGE = Symbol(
        [0x79D0],
        [0x22C4D90],
        0x2,
        "OREN_BERRY_DAMAGE",
        "Damage dealt by eating an Oren Berry.",
        "int16_t",
    )

    IRON_TAIL_LOWER_DEFENSE_CHANCE = Symbol(
        [0x79D8],
        [0x22C4D98],
        None,
        "IRON_TAIL_LOWER_DEFENSE_CHANCE",
        "The chance of Iron Tail lowering defense, as a percentage (30%).",
        "int16_t",
    )

    TWINEEDLE_POISON_CHANCE = Symbol(
        [0x79DC],
        [0x22C4D9C],
        None,
        "TWINEEDLE_POISON_CHANCE",
        "The chance of Twineedle poisoning, as a percentage (20%).",
        "int16_t",
    )

    EXTRASENSORY_CRINGE_CHANCE = Symbol(
        [0x79E0],
        [0x22C4DA0],
        None,
        "EXTRASENSORY_CRINGE_CHANCE",
        "The chance of Extrasensory (and others, see DoMoveDamageCringe10) inflicting the cringe status, as a percentage (10%).",
        "int16_t",
    )

    ROCK_SLIDE_CRINGE_CHANCE = Symbol(
        [0x79E4],
        [0x22C4DA4],
        None,
        "ROCK_SLIDE_CRINGE_CHANCE",
        "The chance of Rock Slide (and others, see DoMoveDamageCringe30) inflicting the cringe status, as a percentage (30%)",
        "int16_t",
    )

    CRUNCH_LOWER_DEFENSE_CHANCE = Symbol(
        [0x79E8],
        [0x22C4DA8],
        None,
        "CRUNCH_LOWER_DEFENSE_CHANCE",
        "The chance of Crunch (and others, see DoMoveDamageLowerDef20) lowering defense, as a percentage (20%).",
        "int16_t",
    )

    FOREWARN_FORCED_MISS_CHANCE = Symbol(
        [0x7A00],
        [0x22C4DC0],
        None,
        "FOREWARN_FORCED_MISS_CHANCE",
        "The chance of Forewarn forcing a move to miss, as a percentage (20%).",
        "int16_t",
    )

    UNOWN_STONE_DROP_CHANCE = Symbol(
        [0x7A0C],
        [0x22C4DCC],
        0x2,
        "UNOWN_STONE_DROP_CHANCE",
        "The chance of an Unown dropping an Unown stone, as a percentage (33%).",
        "int16_t",
    )

    SITRUS_BERRY_HP_RESTORATION = Symbol(
        [0x7A10],
        [0x22C4DD0],
        0x2,
        "SITRUS_BERRY_HP_RESTORATION",
        "The amount of HP restored by eating a Sitrus Berry.",
        "int16_t",
    )

    MUDDY_WATER_LOWER_ACCURACY_CHANCE = Symbol(
        [0x7A1C],
        [0x22C4DDC],
        None,
        "MUDDY_WATER_LOWER_ACCURACY_CHANCE",
        "The chance of Muddy Water (and others, see DoMoveDamageLowerAccuracy40) lowering accuracy, as a percentage (40%).",
        "int16_t",
    )

    SILVER_WIND_BOOST_CHANCE = Symbol(
        [0x7A20],
        [0x22C4DE0],
        None,
        "SILVER_WIND_BOOST_CHANCE",
        "The chance of Silver Wind (and others, see DoMoveDamageBoostAllStats) boosting all stats, as a percentage (20%).",
        "int16_t",
    )

    POISON_TAIL_POISON_CHANCE = Symbol(
        [0x7A24],
        [0x22C4DE4],
        None,
        "POISON_TAIL_POISON_CHANCE",
        "The chance of Poison Tail poisoning, as a percentage (10%).",
        "int16_t",
    )

    THUNDERSHOCK_PARALYZE_CHANCE = Symbol(
        [0x7A28],
        [0x22C4DE8],
        None,
        "THUNDERSHOCK_PARALYZE_CHANCE",
        "The chance of Thundershock paralyzing, as a percentage (10%).",
        "int16_t",
    )

    BOUNCE_PARALYZE_CHANCE = Symbol(
        [0x7A2C],
        [0x22C4DEC],
        None,
        "BOUNCE_PARALYZE_CHANCE",
        "The chance of Bounce paralyzing, as a percentage (30%)",
        "int16_t",
    )

    HEADBUTT_CRINGE_CHANCE = Symbol(
        [0x7A30],
        [0x22C4DF0],
        None,
        "HEADBUTT_CRINGE_CHANCE",
        "The chance of Headbutt inflicting the cringe status, as a percentage (25%).",
        "int16_t",
    )

    FIRE_FANG_CRINGE_CHANCE = Symbol(
        [0x7A34],
        [0x22C4DF4],
        None,
        "FIRE_FANG_CRINGE_CHANCE",
        "The chance of Fire Fang inflicting the cringe status, as a percentage (25%).",
        "int16_t",
    )

    SACRED_FIRE_BURN_CHANCE = Symbol(
        [0x7A38],
        [0x22C4DF8],
        None,
        "SACRED_FIRE_BURN_CHANCE",
        "The chance of Sacred Fire burning, as a percentage (50%).",
        "int16_t",
    )

    WHIRLPOOL_CONSTRICTION_CHANCE = Symbol(
        [0x7A3C],
        [0x22C4DFC],
        None,
        "WHIRLPOOL_CONSTRICTION_CHANCE",
        "The chance of Whirlpool inflicting the constriction status, as a percentage (10%).",
        "int16_t",
    )

    EXP_ELITE_EXP_BOOST = Symbol(
        [0x7A40],
        [0x22C4E00],
        0x2,
        "EXP_ELITE_EXP_BOOST",
        "The percentage increase in experience from the Exp. Elite IQ skill",
        "int16_t",
    )

    MONSTER_HOUSE_MAX_NON_MONSTER_SPAWNS = Symbol(
        [0x7A44],
        [0x22C4E04],
        0x2,
        "MONSTER_HOUSE_MAX_NON_MONSTER_SPAWNS",
        "The maximum number of extra non-monster spawns (items/traps) in a Monster House, 7",
        "int16_t",
    )

    HEAL_ORDER_HP_RESTORATION = Symbol(
        [0x7A50],
        [0x22C4E10],
        None,
        "HEAL_ORDER_HP_RESTORATION",
        "The amount of HP restored by Heal Order (40).",
        "int16_t",
    )

    STEEL_WING_BOOST_DEFENSE_CHANCE = Symbol(
        [0x7A5C],
        [0x22C4E1C],
        None,
        "STEEL_WING_BOOST_DEFENSE_CHANCE",
        "The chance of Steel Wing boosting defense, as a percentage (20%).",
        "int16_t",
    )

    GOLD_THORN_POWER = Symbol(
        [0x7A68],
        [0x22C4E28],
        0x2,
        "GOLD_THORN_POWER",
        "Attack power for Golden Thorns.",
        "int16_t",
    )

    BURN_DAMAGE = Symbol(
        [0x7A6C],
        [0x22C4E2C],
        None,
        "BURN_DAMAGE",
        "Damage dealt by the burn status condition.",
        "int16_t",
    )

    POISON_DAMAGE = Symbol(
        [0x7A70],
        [0x22C4E30],
        None,
        "POISON_DAMAGE",
        "Damage dealt by the poison status condition.",
        "int16_t",
    )

    SPAWN_COOLDOWN = Symbol(
        [0x7A74],
        [0x22C4E34],
        0x2,
        "SPAWN_COOLDOWN",
        "The number of turns between enemy spawns under normal conditions.",
        "int16_t",
    )

    MIST_BALL_LOWER_SPECIAL_ATTACK_CHANCE = Symbol(
        [0x7A78],
        [0x22C4E38],
        None,
        "MIST_BALL_LOWER_SPECIAL_ATTACK_CHANCE",
        "The chance of Mist Ball lowering special attack, as a percentage (50%).",
        "int16_t",
    )

    CHARGE_BEAM_BOOST_SPECIAL_ATTACK_CHANCE = Symbol(
        [0x7A88],
        [0x22C4E48],
        None,
        "CHARGE_BEAM_BOOST_SPECIAL_ATTACK_CHANCE",
        "The chance of Charge Beam boosting special attack, as a percentage (40%).",
        "int16_t",
    )

    ORAN_BERRY_FULL_HP_BOOST = Symbol(
        [0x7A8C],
        [0x22C4E4C],
        0x2,
        "ORAN_BERRY_FULL_HP_BOOST",
        "The permanent HP boost from eating an Oran Berry at full HP (0).",
        "int16_t",
    )

    LIFE_SEED_HP_BOOST = Symbol(
        [0x7A90],
        [0x22C4E50],
        0x2,
        "LIFE_SEED_HP_BOOST",
        "The permanent HP boost from eating a Life Seed.",
        "int16_t",
    )

    OCTAZOOKA_LOWER_ACCURACY_CHANCE = Symbol(
        [0x7A98],
        [0x22C4E58],
        None,
        "OCTAZOOKA_LOWER_ACCURACY_CHANCE",
        "The chance of Octazooka lowering accuracy, as a percentage (60%).",
        "int16_t",
    )

    LUSTER_PURGE_LOWER_SPECIAL_DEFENSE_CHANCE = Symbol(
        [0x7AA4],
        [0x22C4E64],
        None,
        "LUSTER_PURGE_LOWER_SPECIAL_DEFENSE_CHANCE",
        "The chance of Luster Purge (and others, see DoMoveDamageLowerSpecialDefense50) lowering special defense, as a percentage (50%).",
        "int16_t",
    )

    SUPER_LUCK_CRIT_RATE_BOOST = Symbol(
        [0x7AA8],
        [0x22C4E68],
        None,
        "SUPER_LUCK_CRIT_RATE_BOOST",
        "The critical hit rate (additive) boost from Super Luck, 10%.",
        "int16_t",
    )

    CONSTRICT_LOWER_SPEED_CHANCE = Symbol(
        [0x7AAC],
        [0x22C4E6C],
        None,
        "CONSTRICT_LOWER_SPEED_CHANCE",
        "The chance of Constrict (and others, see DoMoveDamageLowerSpeed20) lowering speed, as a percentage (20%).",
        "int16_t",
    )

    ICE_FANG_FREEZE_CHANCE = Symbol(
        [0x7AB0],
        [0x22C4E70],
        None,
        "ICE_FANG_FREEZE_CHANCE",
        "The chance of Ice Fang freezing, as a percentage (15%).",
        "int16_t",
    )

    SMOG_POISON_CHANCE = Symbol(
        [0x7AB4],
        [0x22C4E74],
        None,
        "SMOG_POISON_CHANCE",
        "The chance of Smog (and others, see DoMoveDamagePoison40) poisoning, as a percentage (40%).",
        "int16_t",
    )

    LICK_PARALYZE_CHANCE = Symbol(
        [0x7AC0],
        [0x22C4E80],
        None,
        "LICK_PARALYZE_CHANCE",
        "The chance of Lick (and others, see DoMoveDamageParalyze10) paralyzing, as a percentage (10%).",
        "int16_t",
    )

    THUNDER_FANG_PARALYZE_CHANCE = Symbol(
        [0x7AC4],
        [0x22C4E84],
        None,
        "THUNDER_FANG_PARALYZE_CHANCE",
        "The chance of Thunder Fang paralyzing, as a percentage (10%).",
        "int16_t",
    )

    BITE_CRINGE_CHANCE = Symbol(
        [0x7ACC],
        [0x22C4E8C],
        None,
        "BITE_CRINGE_CHANCE",
        "The chance of Bite (and others, see DoMoveDamageCringe20) inflicting the cringe status, as a percentage (20%)",
        "int16_t",
    )

    SKY_ATTACK_CRINGE_CHANCE = Symbol(
        [0x7AD0],
        [0x22C4E90],
        None,
        "SKY_ATTACK_CRINGE_CHANCE",
        "The chance of Sky Attack inflicting the cringe status, as a percentage (25%).",
        "int16_t",
    )

    ICE_FANG_CRINGE_CHANCE = Symbol(
        [0x7AD4],
        [0x22C4E94],
        None,
        "ICE_FANG_CRINGE_CHANCE",
        "The chance of Ice Fang inflicting the cringe status, as a percentage (25%).",
        "int16_t",
    )

    BLAZE_KICK_BURN_CHANCE = Symbol(
        [0x7AD8],
        [0x22C4E98],
        None,
        "BLAZE_KICK_BURN_CHANCE",
        "The chance of Blaze Kick burning, as a percentage (10%).",
        "int16_t",
    )

    FLAMETHROWER_BURN_CHANCE = Symbol(
        [0x7ADC],
        [0x22C4E9C],
        None,
        "FLAMETHROWER_BURN_CHANCE",
        "The chance of Flamethrower (and others, see DoMoveDamageBurn10) burning, as a percentage (10%).",
        "int16_t",
    )

    DIZZY_PUNCH_CONFUSE_CHANCE = Symbol(
        [0x7AE0],
        [0x22C4EA0],
        None,
        "DIZZY_PUNCH_CONFUSE_CHANCE",
        "The chance of Dizzy Punch (and others, see DoMoveDamageConfuse30) confusing, as a percentage (30%).",
        "int16_t",
    )

    SECRET_POWER_EFFECT_CHANCE = Symbol(
        [0x7AE4],
        [0x22C4EA4],
        None,
        "SECRET_POWER_EFFECT_CHANCE",
        "The chance of Secret Power inflicting an effect, as a percentage (30%).",
        "int16_t",
    )

    METAL_CLAW_BOOST_ATTACK_CHANCE = Symbol(
        [0x7AEC],
        [0x22C4EAC],
        None,
        "METAL_CLAW_BOOST_ATTACK_CHANCE",
        "The chance of Metal Claw boosting attack, as a percentage (20%).",
        "int16_t",
    )

    TECHNICIAN_MOVE_POWER_THRESHOLD = Symbol(
        [0x7AF4],
        [0x22C4EB4],
        None,
        "TECHNICIAN_MOVE_POWER_THRESHOLD",
        "The move power threshold for Technician (4). Moves whose base power doesn't exceed this value will receive a 50% damage boost.",
        "int16_t",
    )

    SONICBOOM_FIXED_DAMAGE = Symbol(
        [0x7B00],
        [0x22C4EC0],
        None,
        "SONICBOOM_FIXED_DAMAGE",
        "The amount of fixed damage dealt by SonicBoom (20).",
        "int16_t",
    )

    RAIN_ABILITY_BONUS_REGEN = Symbol(
        [0x7B10],
        [0x22C4ED0],
        None,
        "RAIN_ABILITY_BONUS_REGEN",
        "The passive bonus health regen given when the weather is rain for the abilities rain dish and dry skin.",
        "int16_t",
    )

    LEECH_SEED_HP_DRAIN = Symbol(
        [0x7B20],
        [0x22C4EE0],
        None,
        "LEECH_SEED_HP_DRAIN",
        "The amount of health drained by leech seed status.",
        "int16_t",
    )

    EXCLUSIVE_ITEM_EXP_BOOST = Symbol(
        [0x7B24],
        [0x22C4EE4],
        0x2,
        "EXCLUSIVE_ITEM_EXP_BOOST",
        "The percentage increase in experience from exp-boosting exclusive items.",
        "int16_t",
    )

    AFTERMATH_CHANCE = Symbol(
        [0x7B2C],
        [0x22C4EEC],
        0x2,
        "AFTERMATH_CHANCE",
        "The chance of the Aftermath ability activating, as a percentage (50%).",
        "int16_t",
    )

    SET_DAMAGE_STATUS_DAMAGE = Symbol(
        [0x7B30],
        [0x22C4EF0],
        None,
        "SET_DAMAGE_STATUS_DAMAGE",
        "The fixed amount of damage dealt when the Set Damage status condition is active (30).",
        "int16_t",
    )

    INTIMIDATOR_ACTIVATION_CHANCE = Symbol(
        [0x7B50],
        [0x22C4F10],
        0x2,
        "INTIMIDATOR_ACTIVATION_CHANCE",
        "The percentage chance that Intimidator will activate.",
        "int16_t",
    )

    TYPE_ADVANTAGE_MASTER_CRIT_RATE = Symbol(
        [0x7B78],
        [0x22C4F38],
        None,
        "TYPE_ADVANTAGE_MASTER_CRIT_RATE",
        "The flat critical hit rate with Type-Advantage Master, 40%.",
        "int16_t",
    )

    ORAN_BERRY_HP_RESTORATION = Symbol(
        [0x7B84],
        [0x22C4F44],
        0x2,
        "ORAN_BERRY_HP_RESTORATION",
        "The amount of HP restored by eating a Oran Berry.",
        "int16_t",
    )

    SITRUS_BERRY_FULL_HP_BOOST = Symbol(
        [0x7B8C],
        [0x22C4F4C],
        0x2,
        "SITRUS_BERRY_FULL_HP_BOOST",
        "The permanent HP boost from eating a Sitrus Berry at full HP.",
        "int16_t",
    )

    SNORE_CRINGE_CHANCE = Symbol(
        [0x7B98],
        [0x22C4F58],
        None,
        "SNORE_CRINGE_CHANCE",
        "The chance of Snore inflicting the cringe status, as a percentage (30%).",
        "int16_t",
    )

    METEOR_MASH_BOOST_ATTACK_CHANCE = Symbol(
        [0x7B9C],
        [0x22C4F5C],
        None,
        "METEOR_MASH_BOOST_ATTACK_CHANCE",
        "The chance of Meteor Mash boosting attack, as a percentage (20%).",
        "int16_t",
    )

    CRUSH_CLAW_LOWER_DEFENSE_CHANCE = Symbol(
        [0x7BA0],
        [0x22C4F60],
        None,
        "CRUSH_CLAW_LOWER_DEFENSE_CHANCE",
        "The chance of Crush Claw lowering defense, as a percentage (50%).",
        "int16_t",
    )

    BURN_DAMAGE_COOLDOWN = Symbol(
        [0x7BA8],
        [0x22C4F68],
        0x2,
        "BURN_DAMAGE_COOLDOWN",
        "The number of turns between passive burn damage.",
        "int16_t",
    )

    SHADOW_BALL_LOWER_SPECIAL_DEFENSE_CHANCE = Symbol(
        [0x7BB4],
        [0x22C4F74],
        None,
        "SHADOW_BALL_LOWER_SPECIAL_DEFENSE_CHANCE",
        "The chance of Shadow Ball lowering special defense, as a percentage (20%).",
        "int16_t",
    )

    STICK_POWER = Symbol(
        [0x7BBC], [0x22C4F7C], 0x2, "STICK_POWER", "Attack power for Sticks.", "int16_t"
    )

    BUBBLE_LOWER_SPEED_CHANCE = Symbol(
        [0x7BC4],
        [0x22C4F84],
        None,
        "BUBBLE_LOWER_SPEED_CHANCE",
        "The chance of Bubble lowering speed, as a percentage (10%).",
        "int16_t",
    )

    ICE_BODY_BONUS_REGEN = Symbol(
        [0x7BC8],
        [0x22C4F88],
        0x2,
        "ICE_BODY_BONUS_REGEN",
        "The passive bonus health regen given when the weather is hail for the ability ice body.",
        "int16_t",
    )

    POWDER_SNOW_FREEZE_CHANCE = Symbol(
        [0x7BCC],
        [0x22C4F8C],
        None,
        "POWDER_SNOW_FREEZE_CHANCE",
        "The chance of Powder Snow (and others, see DoMoveDamageFreeze15) freezing, as a percentage (15%).",
        "int16_t",
    )

    POISON_STING_POISON_CHANCE = Symbol(
        [0x7BD4],
        [0x22C4F94],
        None,
        "POISON_STING_POISON_CHANCE",
        "The chance of Poison Sting (and others, see DoMoveDamagePoison18) poisoning, as a percentage (18%).",
        "int16_t",
    )

    SPAWN_COOLDOWN_THIEF_ALERT = Symbol(
        [0x7BD8],
        [0x22C4F98],
        0x2,
        "SPAWN_COOLDOWN_THIEF_ALERT",
        "The number of turns between enemy spawns when the Thief Alert condition is active.",
        "int16_t",
    )

    POISON_FANG_POISON_CHANCE = Symbol(
        [0x7BDC],
        [0x22C4F9C],
        None,
        "POISON_FANG_POISON_CHANCE",
        "The chance of Poison Fang poisoning, as a percentage (30%).",
        "int16_t",
    )

    WEATHER_MOVE_TURN_COUNT = Symbol(
        [0x7BEC],
        [0x22C4FAC],
        None,
        "WEATHER_MOVE_TURN_COUNT",
        "The number of turns the moves rain dance, hail, sandstorm, sunny day and defog change the weather for. (3000)",
        "int16_t",
    )

    THUNDER_PARALYZE_CHANCE = Symbol(
        [0x7BF0],
        [0x22C4FB0],
        None,
        "THUNDER_PARALYZE_CHANCE",
        "The chance of Thunder (and others, see DoMoveDamageParalyze20) paralyzing, as a percentage (20%)",
        "int16_t",
    )

    THUNDERBOLT_PARALYZE_CHANCE = Symbol(
        [0x7BF4],
        [0x22C4FB4],
        None,
        "THUNDERBOLT_PARALYZE_CHANCE",
        "The chance of Thunderbolt paralyzing, as a percentage (15%).",
        "int16_t",
    )

    MONSTER_HOUSE_MAX_MONSTER_SPAWNS = Symbol(
        [0x7BF8],
        [0x22C4FB8],
        0x2,
        "MONSTER_HOUSE_MAX_MONSTER_SPAWNS",
        "The maximum number of monster spawns in a Monster House, 30, but multiplied by 2/3 for some reason (so the actual maximum is 45)",
        "int16_t",
    )

    TWISTER_CRINGE_CHANCE = Symbol(
        [0x7C00],
        [0x22C4FC0],
        None,
        "TWISTER_CRINGE_CHANCE",
        "The chance of Twister inflicting the cringe status, as a percentage (10%).",
        "int16_t",
    )

    SPEED_BOOST_TURNS = Symbol(
        [0x7C04],
        [0x22C4FC4],
        0x2,
        "SPEED_BOOST_TURNS",
        "Number of turns (250) after which Speed Boost will trigger and increase speed by one stage.",
        "int16_t",
    )

    FAKE_OUT_CRINGE_CHANCE = Symbol(
        [0x7C08],
        [0x22C4FC8],
        None,
        "FAKE_OUT_CRINGE_CHANCE",
        "The chance of Fake Out inflicting the cringe status, as a percentage (35%).",
        "int16_t",
    )

    THUNDER_FANG_CRINGE_CHANCE = Symbol(
        [0x7C10],
        [0x22C4FD0],
        None,
        "THUNDER_FANG_CRINGE_CHANCE",
        "The chance of Thunder Fang inflicting the cringe status, as a percentage (25%).",
        "int16_t",
    )

    FLARE_BLITZ_BURN_CHANCE = Symbol(
        [0x7C1C],
        [0x22C4FDC],
        None,
        "FLARE_BLITZ_BURN_CHANCE",
        "The chance of Flare Blitz burning, as a percentage (25%). This value is also used for the Fire Fang burn chance.",
        "int16_t",
    )

    FLAME_WHEEL_BURN_CHANCE = Symbol(
        [0x7C20],
        [0x22C4FE0],
        None,
        "FLAME_WHEEL_BURN_CHANCE",
        "The chance of Flame Wheel (and others, see DoMoveDamageBurn10FlameWheel) burning, as a percentage (10%).",
        "int16_t",
    )

    PSYBEAM_CONFUSE_CHANCE = Symbol(
        [0x7C28],
        [0x22C4FE8],
        None,
        "PSYBEAM_CONFUSE_CHANCE",
        "The chance of Psybeam (and others, see DoMoveDamageConfuse10) confusing, as a percentage (10%).",
        "int16_t",
    )

    TRI_ATTACK_STATUS_CHANCE = Symbol(
        [0x7C2C],
        [0x22C4FEC],
        None,
        "TRI_ATTACK_STATUS_CHANCE",
        "The chance of Tri Attack inflicting any status condition, as a percentage (20%).",
        "int16_t",
    )

    MIRACLE_CHEST_EXP_BOOST = Symbol(
        [0x7C30],
        [0x22C4FF0],
        0x2,
        "MIRACLE_CHEST_EXP_BOOST",
        "The percentage increase in experience from the Miracle Chest item",
        "int16_t",
    )

    WONDER_CHEST_EXP_BOOST = Symbol(
        [0x7C34],
        [0x22C4FF4],
        0x2,
        "WONDER_CHEST_EXP_BOOST",
        "The percentage increase in experience from the Wonder Chest item",
        "int16_t",
    )

    SPAWN_CAP_WITH_MONSTER_HOUSE = Symbol(
        [0x7C3C],
        [0x22C4FFC],
        0x2,
        "SPAWN_CAP_WITH_MONSTER_HOUSE",
        "The maximum number of enemies that can spawn on a floor with a monster house, not counting those in the monster house (4).",
        "int16_t",
    )

    POISON_DAMAGE_COOLDOWN = Symbol(
        [0x7C40],
        [0x22C5000],
        0x2,
        "POISON_DAMAGE_COOLDOWN",
        "The number of turns between passive poison damage.",
        "int16_t",
    )

    LEECH_SEED_DAMAGE_COOLDOWN = Symbol(
        [0x7C44],
        [0x22C5004],
        None,
        "LEECH_SEED_DAMAGE_COOLDOWN",
        "The number of turns between leech seed health drain.",
        "int16_t",
    )

    THROWN_ITEM_HIT_CHANCE = Symbol(
        [0x7C48],
        [0x22C5008],
        0x2,
        "THROWN_ITEM_HIT_CHANCE",
        "Chance of a hurled item hitting the target (90%).",
        "int16_t",
    )

    GEO_PEBBLE_DAMAGE = Symbol(
        [0x7C4C],
        [0x22C500C],
        0x2,
        "GEO_PEBBLE_DAMAGE",
        "Damage dealt by Geo Pebbles.",
        "int16_t",
    )

    GRAVELEROCK_DAMAGE = Symbol(
        [0x7C50],
        [0x22C5010],
        0x2,
        "GRAVELEROCK_DAMAGE",
        "Damage dealt by Gravelerocks.",
        "int16_t",
    )

    RARE_FOSSIL_DAMAGE = Symbol(
        [0x7C54],
        [0x22C5014],
        0x2,
        "RARE_FOSSIL_DAMAGE",
        "Damage dealt by Rare Fossils.",
        "int16_t",
    )

    GINSENG_CHANCE_3 = Symbol(
        [0x7C58],
        [0x22C5018],
        0x2,
        "GINSENG_CHANCE_3",
        "The percentage chance for Ginseng to boost a move's power by 3 (12%).",
        "int16_t",
    )

    ZINC_STAT_BOOST = Symbol(
        [0x7C5C],
        [0x22C501C],
        0x2,
        "ZINC_STAT_BOOST",
        "The permanent special defense boost from ingesting a Zinc.",
        "int16_t",
    )

    IRON_STAT_BOOST = Symbol(
        [0x7C60],
        [0x22C5020],
        0x2,
        "IRON_STAT_BOOST",
        "The permanent defense boost from ingesting an Iron.",
        "int16_t",
    )

    CALCIUM_STAT_BOOST = Symbol(
        [0x7C64],
        [0x22C5024],
        0x2,
        "CALCIUM_STAT_BOOST",
        "The permanent special attack boost from ingesting a Calcium.",
        "int16_t",
    )

    WISH_BONUS_REGEN = Symbol(
        [0x7C68],
        [0x22C5028],
        None,
        "WISH_BONUS_REGEN",
        "The passive bonus regen given by the wish status condition.",
        "int16_t",
    )

    DRAGON_RAGE_FIXED_DAMAGE = Symbol(
        [0x7C6C],
        [0x22C502C],
        None,
        "DRAGON_RAGE_FIXED_DAMAGE",
        "The amount of fixed damage dealt by Dragon Rage (30).",
        "int16_t",
    )

    CORSOLA_TWIG_POWER = Symbol(
        [0x7C70],
        [0x22C5030],
        0x2,
        "CORSOLA_TWIG_POWER",
        "Attack power for Corsola Twigs.",
        "int16_t",
    )

    CACNEA_SPIKE_POWER = Symbol(
        [0x7C74],
        [0x22C5034],
        0x2,
        "CACNEA_SPIKE_POWER",
        "Attack power for Cacnea Spikes.",
        "int16_t",
    )

    GOLD_FANG_POWER = Symbol(
        [0x7C78],
        [0x22C5038],
        0x2,
        "GOLD_FANG_POWER",
        "Attack power for Gold Fangs.",
        "int16_t",
    )

    SILVER_SPIKE_POWER = Symbol(
        [0x7C7C],
        [0x22C503C],
        0x2,
        "SILVER_SPIKE_POWER",
        "Attack power for Silver Spikes.",
        "int16_t",
    )

    IRON_THORN_POWER = Symbol(
        [0x7C80],
        [0x22C5040],
        0x2,
        "IRON_THORN_POWER",
        "Attack power for Iron Thorns.",
        "int16_t",
    )

    SCOPE_LENS_CRIT_RATE_BOOST = Symbol(
        [0x7C88],
        [0x22C5048],
        None,
        "SCOPE_LENS_CRIT_RATE_BOOST",
        "The critical hit rate (additive) boost from the Scope Lens/Patsy Band items and the Sharpshooter IQ skill, 15%.",
        "int16_t",
    )

    HEALING_WISH_HP_RESTORATION = Symbol(
        [0x7C8C],
        [0x22C504C],
        None,
        "HEALING_WISH_HP_RESTORATION",
        "The amount of HP restored by Healing Wish (999). This also applies to Lunar Dance.",
        "int16_t",
    )

    ME_FIRST_MULTIPLIER = Symbol(
        [0x7CA8],
        [0x22C5068],
        None,
        "ME_FIRST_MULTIPLIER",
        "The damage multiplier applied to attacks copied by Me First, as a fixed-point number with 8 fraction bits (1.5).",
        "fx32_8",
    )

    FACADE_DAMAGE_MULTIPLIER = Symbol(
        [0x7CB0],
        [0x22C5070],
        None,
        "FACADE_DAMAGE_MULTIPLIER",
        "The Facade damage multiplier for users with a status condition, as a binary fixed-point number with 8 fraction bits (0x200 -> 2x).",
        "fx32_8",
    )

    IMPRISON_TURN_RANGE = Symbol(
        [0x7CB4],
        [0x22C5074],
        None,
        "IMPRISON_TURN_RANGE",
        "The turn range for the Paused status inflicted by Imprison, [3, 6).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    SLEEP_TURN_RANGE = Symbol(
        [0x7CB8],
        [0x22C5078],
        0x4,
        "SLEEP_TURN_RANGE",
        "Appears to control the range of turns for which the sleep condition can last.\n\nThe first two bytes are the low value of the range, and the later two bytes are the high value.",
        "int16_t[2]",
    )

    NIGHTMARE_TURN_RANGE = Symbol(
        [0x7CBC],
        [0x22C507C],
        None,
        "NIGHTMARE_TURN_RANGE",
        "The turn range for the Nightmare status inflicted by Nightmare, [4, 8).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    BURN_DAMAGE_MULTIPLIER = Symbol(
        [0x7CDC],
        [0x22C509C],
        None,
        "BURN_DAMAGE_MULTIPLIER",
        "The extra damage multiplier for moves when the attacker is burned, as a fixed-point number with 8 fraction bits (the raw value is 0xCC, which is close to 0.8).\n\nUnlike in the main series, this multiplier is applied regardless of whether the move being used is physical or special.",
        "fx32_8",
    )

    REST_TURN_RANGE = Symbol(
        [0x7CE0],
        [0x22C50A0],
        None,
        "REST_TURN_RANGE",
        "The turn range for the Napping status inflicted by Rest, [1, 4).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    MATCHUP_SUPER_EFFECTIVE_MULTIPLIER_ERRATIC_PLAYER = Symbol(
        [0x7CE4],
        [0x22C50A4],
        None,
        "MATCHUP_SUPER_EFFECTIVE_MULTIPLIER_ERRATIC_PLAYER",
        "The damage multiplier corresponding to MATCHUP_SUPER_EFFECTIVE when Erratic Player is active, as a fixed-point number with 8 fraction bits (the raw value is 0x1B3, the closest possible representation of 1.7).",
        "fx32_8",
    )

    MATCHUP_IMMUNE_MULTIPLIER = Symbol(
        [0x7CF0],
        [0x22C50B0],
        None,
        "MATCHUP_IMMUNE_MULTIPLIER",
        "The damage multiplier corresponding to MATCHUP_IMMUNE, as a fixed-point number with 8 fraction bits (0.5).",
        "fx32_8",
    )

    SPORT_CONDITION_TURN_RANGE = Symbol(
        [0x7D24],
        [0x22C50E4],
        None,
        "SPORT_CONDITION_TURN_RANGE",
        "The turn range for the sport conditions activated by Mud Sport and Water Sport, [10, 12).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    SURE_SHOT_TURN_RANGE = Symbol(
        [0x7D30],
        [0x22C50F0],
        None,
        "SURE_SHOT_TURN_RANGE",
        "The turn range for the Sure Shot status inflicted by Mind Reader and Lock-On, [10, 12).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    DETECT_BAND_MOVE_ACCURACY_DROP = Symbol(
        [0x7D40],
        [0x22C5100],
        None,
        "DETECT_BAND_MOVE_ACCURACY_DROP",
        "The (subtractive) move accuracy drop induced on an attacker if the defender is wearing a Detect Band (30).",
        "int",
    )

    TINTED_LENS_MULTIPLIER = Symbol(
        [0x7D58],
        [0x22C5118],
        None,
        "TINTED_LENS_MULTIPLIER",
        "The extra damage multiplier for not-very-effective moves when Tinted Lens is active, as a fixed-point number with 8 fraction bits (the raw value is 0x133, the closest possible representation of 1.2).",
        "fx32_8",
    )

    SMOKESCREEN_TURN_RANGE = Symbol(
        [0x7D5C],
        [0x22C511C],
        None,
        "SMOKESCREEN_TURN_RANGE",
        "The turn range for the Whiffer status inflicted by Smokescreen, [1, 4).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    PERISH_SONG_TURN_RANGE = Symbol(
        [0x7D68],
        [0x22C5128],
        0x4,
        "PERISH_SONG_TURN_RANGE",
        "The turn range for the status inflicted by Perish Song, [3, 3).\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    SHADOW_FORCE_DAMAGE_MULTIPLIER = Symbol(
        [0x7D74],
        [0x22C5134],
        None,
        "SHADOW_FORCE_DAMAGE_MULTIPLIER",
        "The damage multiplier for Shadow Force, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    DIG_DAMAGE_MULTIPLIER = Symbol(
        [0x7D7C],
        [0x22C513C],
        None,
        "DIG_DAMAGE_MULTIPLIER",
        "The damage multiplier for Dig, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    DIVE_DAMAGE_MULTIPLIER = Symbol(
        [0x7D80],
        [0x22C5140],
        None,
        "DIVE_DAMAGE_MULTIPLIER",
        "The damage multiplier for Dive, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    BOUNCE_DAMAGE_MULTIPLIER = Symbol(
        [0x7D84],
        [0x22C5144],
        None,
        "BOUNCE_DAMAGE_MULTIPLIER",
        "The damage multiplier for Bounce, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    POWER_PITCHER_DAMAGE_MULTIPLIER = Symbol(
        [0x7D90],
        [0x22C5150],
        0x4,
        "POWER_PITCHER_DAMAGE_MULTIPLIER",
        "The multiplier for projectile damage from Power Pitcher (1.5), as a binary fixed-point number (8 fraction bits)",
        "fx32_8",
    )

    QUICK_DODGER_MOVE_ACCURACY_DROP = Symbol(
        [0x7DA0],
        [0x22C5160],
        None,
        "QUICK_DODGER_MOVE_ACCURACY_DROP",
        "The (subtractive) move accuracy drop induced on an attacker if the defender has the Quick Dodger IQ skill (10).",
        "int",
    )

    MATCHUP_NOT_VERY_EFFECTIVE_MULTIPLIER = Symbol(
        [0x7DA8],
        [0x22C5168],
        None,
        "MATCHUP_NOT_VERY_EFFECTIVE_MULTIPLIER",
        "The damage multiplier corresponding to MATCHUP_NOT_VERY_EFFECTIVE, as a fixed-point number with 8 fraction bits (the raw value is 0x1B4, the closest possible representation of 1/√2).",
        "fx32_8",
    )

    MATCHUP_SUPER_EFFECTIVE_MULTIPLIER = Symbol(
        [0x7DB0],
        [0x22C5170],
        None,
        "MATCHUP_SUPER_EFFECTIVE_MULTIPLIER",
        "The damage multiplier corresponding to MATCHUP_SUPER_EFFECTIVE, as a fixed-point number with 8 fraction bits (the raw value is 0x166, the closest possible representation of 1.4).",
        "fx32_8",
    )

    MATCHUP_NEUTRAL_MULTIPLIER = Symbol(
        [0x7DB4],
        [0x22C5174],
        None,
        "MATCHUP_NEUTRAL_MULTIPLIER",
        "The damage multiplier corresponding to MATCHUP_NEUTRAL, as a fixed-point number with 8 fraction bits (1).",
        "fx32_8",
    )

    MATCHUP_IMMUNE_MULTIPLIER_ERRATIC_PLAYER = Symbol(
        [0x7DB8],
        [0x22C5178],
        None,
        "MATCHUP_IMMUNE_MULTIPLIER_ERRATIC_PLAYER",
        "The damage multiplier corresponding to MATCHUP_IMMUNE when Erratic Player is active, as a fixed-point number with 8 fraction bits (0.25).",
        "fx32_8",
    )

    MATCHUP_NOT_VERY_EFFECTIVE_MULTIPLIER_ERRATIC_PLAYER = Symbol(
        [0x7DBC],
        [0x22C517C],
        None,
        "MATCHUP_NOT_VERY_EFFECTIVE_MULTIPLIER_ERRATIC_PLAYER",
        "The damage multiplier corresponding to MATCHUP_NOT_VERY_EFFECTIVE when Erratic Player is active, as a fixed-point number with 8 fraction bits (0.5).",
        "fx32_8",
    )

    MATCHUP_NEUTRAL_MULTIPLIER_ERRATIC_PLAYER = Symbol(
        [0x7DC4],
        [0x22C5184],
        None,
        "MATCHUP_NEUTRAL_MULTIPLIER_ERRATIC_PLAYER",
        "The damage multiplier corresponding to MATCHUP_NEUTRAL when Erratic Player is active, as a fixed-point number with 8 fraction bits (1).",
        "fx32_8",
    )

    AIR_BLADE_DAMAGE_MULTIPLIER = Symbol(
        [0x7DDC],
        [0x22C519C],
        0x4,
        "AIR_BLADE_DAMAGE_MULTIPLIER",
        "The multiplier for damage from the Air Blade (1.5), as a binary fixed-point number (8 fraction bits)",
        "fx32_8",
    )

    KECLEON_SHOP_BOOST_CHANCE_MULTIPLIER = Symbol(
        [0x7DE4],
        [0x22C51A4],
        None,
        "KECLEON_SHOP_BOOST_CHANCE_MULTIPLIER",
        "The boosted kecleon shop spawn chance multiplier (~1.2) as a binary fixed-point number (8 fraction bits).",
        "fx32_8",
    )

    HIDDEN_STAIRS_SPAWN_CHANCE_MULTIPLIER = Symbol(
        [0x7DE8],
        [0x22C51A8],
        0x4,
        "HIDDEN_STAIRS_SPAWN_CHANCE_MULTIPLIER",
        "The hidden stairs spawn chance multiplier (~1.2) as a binary fixed-point number (8 fraction bits), if applicable. See ShouldBoostHiddenStairsSpawnChance in overlay 29.",
        "fx32_8",
    )

    YAWN_TURN_RANGE = Symbol(
        [0x7DF8],
        [0x22C51B8],
        None,
        "YAWN_TURN_RANGE",
        "The turn range for the Yawning status inflicted by Yawn, [2, 2].\n\ntype: int16_t[2]",
        "int16_t[2]",
    )

    SPEED_BOOST_TURN_RANGE = Symbol(
        [0x7E20],
        [0x22C51E0],
        0x4,
        "SPEED_BOOST_TURN_RANGE",
        "Appears to control the range of turns for which a speed boost can last.\n\nThe first two bytes are the low value of the range, and the later two bytes are the high value.",
        "int16_t[2]",
    )

    SOLARBEAM_DAMAGE_MULTIPLIER = Symbol(
        [0x7E3C],
        [0x22C51FC],
        None,
        "SOLARBEAM_DAMAGE_MULTIPLIER",
        "The default damage multiplier for SolarBeam, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    SKY_ATTACK_DAMAGE_MULTIPLIER = Symbol(
        [0x7E40],
        [0x22C5200],
        None,
        "SKY_ATTACK_DAMAGE_MULTIPLIER",
        "The damage multiplier for Sky Attack, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    RAZOR_WIND_DAMAGE_MULTIPLIER = Symbol(
        [0x7E48],
        [0x22C5208],
        None,
        "RAZOR_WIND_DAMAGE_MULTIPLIER",
        "The damage multiplier for Razor Wind, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    FOCUS_PUNCH_DAMAGE_MULTIPLIER = Symbol(
        [0x7E4C],
        [0x22C520C],
        None,
        "FOCUS_PUNCH_DAMAGE_MULTIPLIER",
        "The damage multiplier for Focus Punch, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    SKULL_BASH_DAMAGE_MULTIPLIER = Symbol(
        [0x7E54],
        [0x22C5214],
        None,
        "SKULL_BASH_DAMAGE_MULTIPLIER",
        "The damage multiplier for Skull Bash, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    FLY_DAMAGE_MULTIPLIER = Symbol(
        [0x7E58],
        [0x22C5218],
        None,
        "FLY_DAMAGE_MULTIPLIER",
        "The damage multiplier for Fly, as a fixed-point number with 8 fraction bits (2).",
        "fx32_8",
    )

    WEATHER_BALL_TYPE_TABLE = Symbol(
        [0x7E74],
        [0x22C5234],
        None,
        "WEATHER_BALL_TYPE_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding Weather Ball type.\n\ntype: struct type_id_8[8]",
        "struct type_id_8[8]",
    )

    LAST_RESORT_DAMAGE_MULT_TABLE = Symbol(
        [0x7EDC],
        [0x22C529C],
        None,
        "LAST_RESORT_DAMAGE_MULT_TABLE",
        "Table of damage multipliers for Last Resort for different numbers of moves out of PP, where each entry is a binary fixed-point number with 8 fraction bits.\n\nIf n is the number of moves out of PP not counting Last Resort itself, the table is indexed by (n - 1).\n\ntype: int[4]",
        "fx32_8[4]",
    )

    SYNTHESIS_HP_RESTORATION_TABLE = Symbol(
        [0x7EEC],
        [0x22C52AC],
        None,
        "SYNTHESIS_HP_RESTORATION_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding HP restoration value for Synthesis.\n\ntype: int16_t[8]",
        "int16_t[8]",
    )

    ROOST_HP_RESTORATION_TABLE = Symbol(
        [0x7EFC],
        [0x22C52BC],
        None,
        "ROOST_HP_RESTORATION_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding HP restoration value for Roost.\n\nEvery entry in this table is 40.\n\ntype: int16_t[8]",
        "int16_t[8]",
    )

    MOONLIGHT_HP_RESTORATION_TABLE = Symbol(
        [0x7F0C],
        [0x22C52CC],
        None,
        "MOONLIGHT_HP_RESTORATION_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding HP restoration value for Moonlight.\n\ntype: int16_t[8]",
        "int16_t[8]",
    )

    MORNING_SUN_HP_RESTORATION_TABLE = Symbol(
        [0x7F1C],
        [0x22C52DC],
        None,
        "MORNING_SUN_HP_RESTORATION_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding HP restoration value for Morning Sun.\n\ntype: int16_t[8]",
        "int16_t[8]",
    )

    REVERSAL_DAMAGE_MULT_TABLE = Symbol(
        [0x7F2C],
        [0x22C52EC],
        None,
        "REVERSAL_DAMAGE_MULT_TABLE",
        "Table of damage multipliers for Reversal/Flail at different HP ranges, where each entry is a binary fixed-point number with 8 fraction bits.\n\ntype: int[4]",
        "fx32_8[4]",
    )

    WATER_SPOUT_DAMAGE_MULT_TABLE = Symbol(
        [0x7F3C],
        [0x22C52FC],
        None,
        "WATER_SPOUT_DAMAGE_MULT_TABLE",
        "Table of damage multipliers for Water Spout at different HP ranges, where each entry is a binary fixed-point number with 8 fraction bits.\n\ntype: int[4]",
        "fx32_8[4]",
    )

    WRING_OUT_DAMAGE_MULT_TABLE = Symbol(
        [0x7F4C],
        [0x22C530C],
        None,
        "WRING_OUT_DAMAGE_MULT_TABLE",
        "Table of damage multipliers for Wring Out/Crush Grip at different HP ranges, where each entry is a binary fixed-point number with 8 fraction bits.\n\ntype: int[4]",
        "fx32_8[4]",
    )

    ERUPTION_DAMAGE_MULT_TABLE = Symbol(
        [0x7F5C],
        [0x22C531C],
        None,
        "ERUPTION_DAMAGE_MULT_TABLE",
        "Table of damage multipliers for Eruption at different HP ranges, where each entry is a binary fixed-point number with 8 fraction bits.\n\ntype: int[4]",
        "fx32_8[4]",
    )

    WEATHER_BALL_DAMAGE_MULT_TABLE = Symbol(
        [0x80EC],
        [0x22C54AC],
        None,
        "WEATHER_BALL_DAMAGE_MULT_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding Weather Ball damage multiplier, where each entry is a binary fixed-point number with 8 fraction bits.\n\ntype: int[8]",
        "fx32_8[8]",
    )

    EAT_ITEM_EFFECT_IGNORE_LIST = Symbol(
        [0x810C],
        [0x22C54CC],
        0x48,
        "EAT_ITEM_EFFECT_IGNORE_LIST",
        "List of item IDs that should be ignored by the ShouldTryEatItem function. The last entry is null.",
        "struct item_id_16[36]",
    )

    CASTFORM_WEATHER_ATTRIBUTE_TABLE = Symbol(
        [0x8204],
        [0x22C55C4],
        0x30,
        "CASTFORM_WEATHER_ATTRIBUTE_TABLE",
        "Maps each weather type (by index, see enum weather_id) to the corresponding Castform type and form.\n\ntype: struct castform_weather_attributes[8]",
        "struct castform_weather_attributes[8]",
    )

    BAD_POISON_DAMAGE_TABLE = Symbol(
        [0x8234],
        [0x22C55F4],
        None,
        "BAD_POISON_DAMAGE_TABLE",
        "Table for how much damage each tick of badly poisoned should deal. The table is filled with 0x0006, but could use different values for each entry.",
        "int16_t[30]",
    )

    TYPE_MATCHUP_COMBINATOR_TABLE = Symbol(
        [0x82AC],
        [0x22C566C],
        None,
        "TYPE_MATCHUP_COMBINATOR_TABLE",
        "Table of type matchup combinations.\n\nEach row corresponds to a single type matchup that results from combining two individual type matchups together. For example, combining MATCHUP_NOT_VERY_EFFECTIVE with MATCHUP_SUPER_EFFECTIVE results in MATCHUP_NEUTRAL.\n\ntype: struct type_matchup_combinator_table",
        "struct type_matchup_combinator_table",
    )

    OFFENSIVE_STAT_STAGE_MULTIPLIERS = Symbol(
        [0x8330],
        [0x22C56F0],
        0x54,
        "OFFENSIVE_STAT_STAGE_MULTIPLIERS",
        "Table of multipliers for offensive stats (attack/special attack) for each stage 0-20, as binary fixed-point numbers (8 fraction bits)",
        "fx32_8[21]",
    )

    DEFENSIVE_STAT_STAGE_MULTIPLIERS = Symbol(
        [0x8384],
        [0x22C5744],
        0x54,
        "DEFENSIVE_STAT_STAGE_MULTIPLIERS",
        "Table of multipliers for defensive stats (defense/special defense) for each stage 0-20, as binary fixed-point numbers (8 fraction bits)",
        "fx32_8[21]",
    )

    NATURE_POWER_TABLE = Symbol(
        [0x83D8],
        [0x22C5798],
        0x78,
        "NATURE_POWER_TABLE",
        "Maps enum nature_power_variant to the associated move ID and effect handler.\n\ntype: struct wildcard_move_desc[15]",
        "struct wildcard_move_desc[15]",
    )

    APPLES_AND_BERRIES_ITEM_IDS = Symbol(
        [0x8450],
        [0x22C5810],
        0x84,
        "APPLES_AND_BERRIES_ITEM_IDS",
        "Table of item IDs for Apples and Berries, which trigger the exclusive item effect EXCLUSIVE_EFF_RECOVER_HP_FROM_APPLES_AND_BERRIES.\n\ntype: struct item_id_16[66]",
        "struct item_id_16[66]",
    )

    RECRUITMENT_LEVEL_BOOST_TABLE = Symbol(
        [0x85FC],
        [0x22C59BC],
        0xCC,
        "RECRUITMENT_LEVEL_BOOST_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: int16_t[102]",
        "int16_t[102]",
    )

    NATURAL_GIFT_ITEM_TABLE = Symbol(
        [0x86C8],
        [0x22C5A88],
        0xCC,
        "NATURAL_GIFT_ITEM_TABLE",
        "Maps items to their type and base power if used with Natural Gift.\n\nAny item not listed in this table explicitly will be Normal type with a base power of 1 when used with Natural Gift.\n\ntype: struct natural_gift_item_info[34]",
        "struct natural_gift_item_info[34]",
    )

    RANDOM_MUSIC_ID_TABLE = Symbol(
        [0x8794],
        [0x22C5B54],
        0xF0,
        "RANDOM_MUSIC_ID_TABLE",
        "Table of music IDs for dungeons with a random assortment of music tracks.\n\nThis is a table with 30 rows, each with 4 2-byte music IDs. Each row contains the possible music IDs for a given group, from which the music track will be selected randomly.\n\ntype: struct music_id_16[30][4]",
        "struct music_id_16[30][4]",
    )

    SHOP_ITEM_CHANCES = Symbol(
        [0x8884],
        [0x22C5C44],
        0x120,
        "SHOP_ITEM_CHANCES",
        "8 * 6 * 3 * 0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "int16_t[144]",
    )

    MALE_ACCURACY_STAGE_MULTIPLIERS = Symbol(
        [0x89A4],
        [0x22C5D64],
        0x54,
        "MALE_ACCURACY_STAGE_MULTIPLIERS",
        "Table of multipliers for the accuracy stat for males for each stage 0-20, as binary fixed-point numbers (8 fraction bits)",
        "fx32_8[21]",
    )

    MALE_EVASION_STAGE_MULTIPLIERS = Symbol(
        [0x89F8],
        [0x22C5DB8],
        0x54,
        "MALE_EVASION_STAGE_MULTIPLIERS",
        "Table of multipliers for the evasion stat for males for each stage 0-20, as binary fixed-point numbers (8 fraction bits)",
        "fx32_8[21]",
    )

    FEMALE_ACCURACY_STAGE_MULTIPLIERS = Symbol(
        [0x8A4C],
        [0x22C5E0C],
        0x54,
        "FEMALE_ACCURACY_STAGE_MULTIPLIERS",
        "Table of multipliers for the accuracy stat for females for each stage 0-20, as binary fixed-point numbers (8 fraction bits)",
        "fx32_8[21]",
    )

    FEMALE_EVASION_STAGE_MULTIPLIERS = Symbol(
        [0x8AA0],
        [0x22C5E60],
        0x54,
        "FEMALE_EVASION_STAGE_MULTIPLIERS",
        "Table of multipliers for the evasion stat for females for each stage 0-20, as binary fixed-point numbers (8 fraction bits)",
        "fx32_8[21]",
    )

    MUSIC_ID_TABLE = Symbol(
        [0x8AF4],
        [0x22C5EB4],
        0x154,
        "MUSIC_ID_TABLE",
        "List of music IDs used in dungeons with a single music track.\n\nThis is an array of 170 2-byte music IDs, and is indexed into by the music value in the floor properties struct for a given floor. Music IDs with the highest bit set (0x8000) are indexes into the RANDOM_MUSIC_ID_TABLE.\n\ntype: struct music_id_16[170] (or not a music ID if the highest bit is set)",
        "struct music_id_16[170]",
    )

    TYPE_MATCHUP_TABLE = Symbol(
        [0x8C48],
        [0x22C6008],
        0x288,
        "TYPE_MATCHUP_TABLE",
        "Table of type matchups.\n\nEach row corresponds to the type matchups of a specific attack type, with each entry within the row specifying the type's effectiveness against a target type.\n\ntype: struct type_matchup_table",
        "struct type_matchup_table",
    )

    FIXED_ROOM_MONSTER_SPAWN_STATS_TABLE = Symbol(
        [0x8ED0],
        [0x22C6290],
        0x4A4,
        "FIXED_ROOM_MONSTER_SPAWN_STATS_TABLE",
        "Table of stats for monsters that can spawn in fixed rooms, pointed into by the FIXED_ROOM_MONSTER_SPAWN_TABLE.\n\nThis is an array of 99 12-byte entries containing stat spreads for one monster entry each.\n\ntype: struct fixed_room_monster_spawn_stats_entry[99]",
        "struct fixed_room_monster_spawn_stats_entry[99]",
    )

    METRONOME_TABLE = Symbol(
        [0x9374],
        [0x22C6734],
        0x540,
        "METRONOME_TABLE",
        "Something to do with the moves that Metronome can turn into.\n\ntype: struct wildcard_move_desc[168]",
        "struct wildcard_move_desc[168]",
    )

    TILESET_PROPERTIES = Symbol(
        [0x98B4],
        [0x22C6C74],
        0x954,
        "TILESET_PROPERTIES",
        "type: struct tileset_property[199]",
        "struct tileset_property[199]",
    )

    FIXED_ROOM_PROPERTIES_TABLE = Symbol(
        [0xA208],
        [0x22C75C8],
        0xC00,
        "FIXED_ROOM_PROPERTIES_TABLE",
        "Table of properties for fixed rooms.\n\nThis is an array of 256 12-byte entries containing properties for a given fixed room ID.\n\nSee the struct definitions and Frostbyte's dungeon data document for more info.\n\ntype: struct fixed_room_properties_entry[256]",
        "struct fixed_room_properties_entry[256]",
    )

    TRAP_ANIMATION_INFO = Symbol(
        [0xAFE8],
        [0x22C83A8],
        0x34,
        "TRAP_ANIMATION_INFO",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct trap_animation[26]",
        "struct trap_animation[26]",
    )

    ITEM_ANIMATION_INFO = Symbol(
        [0xB01C],
        [0x22C83DC],
        0x15E0,
        "ITEM_ANIMATION_INFO",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct item_animation[1400]",
        "struct item_animation[1400]",
    )

    MOVE_ANIMATION_INFO = Symbol(
        [0xC5FC],
        [0x22C99BC],
        0x34C8,
        "MOVE_ANIMATION_INFO",
        "type: struct move_animation[563]",
        "struct move_animation[563]",
    )

    EFFECT_ANIMATION_INFO = Symbol(
        [0xFAC4],
        [0x22CCE84],
        0x4C90,
        "EFFECT_ANIMATION_INFO",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct effect_animation[700]",
        "struct effect_animation[700]",
    )

    SPECIAL_MONSTER_MOVE_ANIMATION_INFO = Symbol(
        [0x14754],
        [0x22D1B14],
        0xADF4,
        "SPECIAL_MONSTER_MOVE_ANIMATION_INFO",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct special_monster_move_animation[7422]",
        "struct special_monster_move_animation[7422]",
    )

    DEFEAT_ITEM_LOSS_CHANCE = Symbol(
        [0x61A0],
        [0x22C3560],
        None,
        "DEFEAT_ITEM_LOSS_CHANCE",
        "Chance of losing each individual bag item after being defeated in a dungeon (50%).",
        "struct data_processing_instruction",
    )


class EuOverlay10Section:
    name = "overlay10"
    description = "Appears to be used both during ground mode and dungeon mode. With dungeon mode, whereas overlay 29 contains the main dungeon engine, this overlay seems to contain routines and data for dungeon mechanics."
    loadaddress = 0x22BD3C0
    length = 0x1F7A0
    functions = EuOverlay10Functions
    data = EuOverlay10Data


class EuOverlay11Functions:

    UnlockScriptingLock = Symbol(
        [0xEF0],
        [0x22DDA70],
        None,
        "UnlockScriptingLock",
        "Unlocks a scripting lock.\n\nSets the corresponding byte to 1 on LOCK_NOTIFY_ARRAY to signal that the scripting engine should handle the unlock. Also sets a global unlock flag, used to tell the scripting engine that the state of locks have changed and they should be checked again.\n\nr0: ID of the lock to unlock",
        None,
    )

    FuncThatCallsRunNextOpcode = Symbol(
        [0xF24],
        [0x22DDAA4],
        None,
        "FuncThatCallsRunNextOpcode",
        "Called up to 16 times per frame. Exact purpose unknown.\n\nr0: Looks like a pointer to some struct containing data about the current state of scripting engine",
        None,
    )

    RunNextOpcode = Symbol(
        [0x1B24],
        [0x22DE6A4],
        None,
        "RunNextOpcode",
        "Runs the next scripting opcode.\n\nContains a switch statement based on the opcode ([r0+1C]).\n\nr0: Looks like a pointer to some struct containing data about the current state of scripting engine",
        None,
    )

    HandleUnlocks = Symbol(
        [0x8110],
        [0x22E4C90],
        None,
        "HandleUnlocks",
        "Checks if a script unlock happened by reading entries from LOCK_NOTIFY_ARRAY and handles the ones that were set.\n\nIf the global unlock flag is not set, returns immediately. If it is, the function loops LOCK_NOTIFY_ARRAY, checking for true values. If it finds one, resets it back to 0 and handles the unlock.\n\nNo params.",
        None,
    )

    LoadFileFromRomVeneer = Symbol(
        [0x849C],
        [0x22E501C],
        None,
        "LoadFileFromRomVeneer",
        "Likely a linker-generated veneer for LoadFileFromRom.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: [output] pointer to an IO struct {ptr, len}\nr1: file path string pointer\nr2: flags",
        None,
    )

    SsbLoad2 = Symbol([0x84BC], [0x22E503C], None, "SsbLoad2", "", None)

    ScriptParamToInt = Symbol(
        [0x866C],
        [0x22E51EC],
        None,
        "ScriptParamToInt",
        "Converts the given opcode parameter to a signed integer.\n\nThe parameter will be returned unchanged unless one of its two most significant bits (0x8000 and 0x4000) are set, in which case both bits will be cleared and the original value will be modified according to the following two rules:\n- If the 0x4000 bit is set (sign bit), the value will be set to -16384 + value.\n- If the 0x8000 bit is set (fixed-point flag), the value will be set to value / 256, rounded down.\nBoth rules can be applied, in the same order as listed, if both conditions are met.\n\nr0: Parameter to convert\nreturn: The input parameter, as a signed integer",
        None,
    )

    ScriptParamToFixedPoint16 = Symbol(
        [0x86A0],
        [0x22E5220],
        None,
        "ScriptParamToFixedPoint16",
        "Converts the given opcode parameter to a 16-bit signed fixed-point number with 8 fraction bits.\n\nThe resulting number is encoded as (value) * 256, with the last byte acting as a fraction byte capable of representing multiples of 1/256.\n\nThe parameter will either be returned unchanged or modified depending on which of its two most significant bits (0x8000 and 0x4000) are set. Both bits are unset before running the operations listed below:\n- If the 0x4000 bit is set (sign bit), the value will be set to -16384 + value.\n- If the 0x8000 bit is set (fixed-point flag), the raw value is interpreted as being fixed-point already, and nothing else happens. Otherwise, it's assumed to be a normal integer and is converted to fixed-point by left-shifting it by 8 (moving the integer part to its proper place).\nBoth rules can be applied, in the same order as listed, if both conditions are met.\n\nr0: Parameter to convert\nreturn: The input parameter, as a 16-bit signed fixed-point number with 8 fraction bits",
        None,
    )

    StationLoadHanger = Symbol(
        [0x8994], [0x22E5514], None, "StationLoadHanger", "", None
    )

    ScriptStationLoadTalk = Symbol(
        [0x91A4], [0x22E5D24], None, "ScriptStationLoadTalk", "", None
    )

    SsbLoad1 = Symbol([0x9B10], [0x22E6690], None, "SsbLoad1", "", None)

    ScriptSpecialProcessCall = Symbol(
        [0xAED8],
        [0x22E7A58],
        None,
        "ScriptSpecialProcessCall",
        "Processes calls to the OPCODE_PROCESS_SPECIAL script opcode.\n\nr0: some struct containing a callback of some sort, only used for special process ID 18\nr1: special process ID\nr2: first argument, if relevant? Probably corresponds to the second parameter of OPCODE_PROCESS_SPECIAL\nr3: second argument, if relevant? Probably corresponds to the third parameter of OPCODE_PROCESS_SPECIAL\nreturn: return value of the special process if it has one, otherwise 0",
        None,
    )

    GetCoroutineInfo = Symbol(
        [0xBD78],
        [0x22E88F8],
        None,
        "GetCoroutineInfo",
        "Returns information about a coroutine in unionall\n\nIt's used by the CallCommon code to pull the data required to call the coroutine, so maybe the function returns data required to call a coroutine instead of info about the coroutine itself.\n\nr0: [output] Coroutine info\nr1: Coroutine ID\nreturn: True if the coroutine is valid? It's false only if the coroutine's offset is 0.",
        None,
    )

    GetSpecialRecruitmentSpecies = Symbol(
        [0xBDFC],
        [0x22E897C],
        None,
        "GetSpecialRecruitmentSpecies",
        "Returns an entry from RECRUITMENT_TABLE_SPECIES.\n\nNote: This indexes without doing bounds checking.\n\nr0: index into RECRUITMENT_TABLE_SPECIES\nreturn: enum monster_id",
        None,
    )

    PrepareMenuAcceptTeamMember = Symbol(
        [0xBE40],
        [0x22E89C0],
        None,
        "PrepareMenuAcceptTeamMember",
        "Implements SPECIAL_PROC_PREPARE_MENU_ACCEPT_TEAM_MEMBER (see ScriptSpecialProcessCall).\n\nr0: index into RECRUITMENT_TABLE_SPECIES",
        None,
    )

    InitRandomNpcJobs = Symbol(
        [0xBEE4],
        [0x22E8A64],
        None,
        "InitRandomNpcJobs",
        "Implements SPECIAL_PROC_INIT_RANDOM_NPC_JOBS (see ScriptSpecialProcessCall).\n\nr0: job type? 0 is a random NPC job, 1 is a bottle mission\nr1: ?",
        None,
    )

    GetRandomNpcJobType = Symbol(
        [0xBF7C],
        [0x22E8AFC],
        None,
        "GetRandomNpcJobType",
        "Implements SPECIAL_PROC_GET_RANDOM_NPC_JOB_TYPE (see ScriptSpecialProcessCall).\n\nreturn: job type?",
        None,
    )

    GetRandomNpcJobSubtype = Symbol(
        [0xBF94],
        [0x22E8B14],
        None,
        "GetRandomNpcJobSubtype",
        "Implements SPECIAL_PROC_GET_RANDOM_NPC_JOB_SUBTYPE (see ScriptSpecialProcessCall).\n\nreturn: job subtype?",
        None,
    )

    GetRandomNpcJobStillAvailable = Symbol(
        [0xBFB0],
        [0x22E8B30],
        None,
        "GetRandomNpcJobStillAvailable",
        "Implements SPECIAL_PROC_GET_RANDOM_NPC_JOB_STILL_AVAILABLE (see ScriptSpecialProcessCall).\n\nreturn: bool",
        None,
    )

    AcceptRandomNpcJob = Symbol(
        [0xC018],
        [0x22E8B98],
        None,
        "AcceptRandomNpcJob",
        "Implements SPECIAL_PROC_ACCEPT_RANDOM_NPC_JOB (see ScriptSpecialProcessCall).\n\nreturn: bool",
        None,
    )

    GroundMainLoop = Symbol(
        [0xC534],
        [0x22E90B4],
        None,
        "GroundMainLoop",
        "Appears to be the main loop for ground mode.\n\nBased on debug print statements and general code structure, it seems contain a core loop, and dispatches to various functions in response to different events.\n\nr0: mode, which is stored globally and used in switch statements for dispatch\nreturn: return code",
        None,
    )

    GetAllocArenaGround = Symbol(
        [0xD11C],
        [0x22E9C9C],
        None,
        "GetAllocArenaGround",
        "The GetAllocArena function used for ground mode. See SetMemAllocatorParams for more information.\n\nFor (flags & 0xFF):\n  8, 15, 16: GROUND_MEMORY_ARENA_1\n  14: GROUND_MEMORY_ARENA_2\n  other: null (default arena)\n\nr0: initial memory arena pointer, or null\nr1: flags (see MemAlloc)\nreturn: memory arena pointer, or null",
        None,
    )

    GetFreeArenaGround = Symbol(
        [0xD180],
        [0x22E9D00],
        None,
        "GetFreeArenaGround",
        "The GetFreeArena function used for ground mode. See SetMemAllocatorParams for more information.\n\nr0: initial memory arena pointer, or null\nr1: pointer to free\nreturn: memory arena pointer, or null",
        None,
    )

    GroundMainReturnDungeon = Symbol(
        [0xD1D4],
        [0x22E9D54],
        None,
        "GroundMainReturnDungeon",
        "Implements SPECIAL_PROC_RETURN_DUNGEON (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    GroundMainNextDay = Symbol(
        [0xD1F8],
        [0x22E9D78],
        None,
        "GroundMainNextDay",
        "Implements SPECIAL_PROC_NEXT_DAY (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    JumpToTitleScreen = Symbol(
        [0xD39C],
        [0x22E9F1C],
        None,
        "JumpToTitleScreen",
        "Implements SPECIAL_PROC_JUMP_TO_TITLE_SCREEN and SPECIAL_PROC_0x1A (see ScriptSpecialProcessCall).\n\nr0: int, argument value for SPECIAL_PROC_JUMP_TO_TITLE_SCREEN and -1 for SPECIAL_PROC_0x1A\nreturn: bool (but note that the special process ignores this and always returns 0)",
        None,
    )

    ReturnToTitleScreen = Symbol(
        [0xD454],
        [0x22E9FD4],
        None,
        "ReturnToTitleScreen",
        "Implements SPECIAL_PROC_RETURN_TO_TITLE_SCREEN (see ScriptSpecialProcessCall).\n\nr0: fade duration\nreturn: bool (but note that the special process ignores this and always returns 0)",
        None,
    )

    ScriptSpecialProcess0x16 = Symbol(
        [0xD4B4],
        [0x22EA034],
        None,
        "ScriptSpecialProcess0x16",
        "Implements SPECIAL_PROC_0x16 (see ScriptSpecialProcessCall).\n\nr0: bool",
        None,
    )

    IsScreenFadeInProgress = Symbol(
        [0xDD38],
        [0x22EA8B8],
        None,
        "IsScreenFadeInProgress",
        "Used for example in the handler functions of the top screen types in ground mode to check whether the top screen fade is complete or not.\n\nreturn: True if the top screen is still fading, false if it's done fading.",
        None,
    )

    LoadBackgroundAttributes = Symbol(
        [0xF900],
        [0x22EC480],
        None,
        "LoadBackgroundAttributes",
        "Open and read an entry from the MAP_BG/bg_list.dat\n\nDocumentation on this format can be found here:\nhttps://github.com/SkyTemple/skytemple-files/tree/55b3017631a8a1b0f106111ef91a901dc394c6df/skytemple_files/graphics/bg_list_dat\n\nr0: [output] The entry\nr1: background ID",
        None,
    )

    LoadMapType10 = Symbol(
        [0x10AE4],
        [0x22ED664],
        None,
        "LoadMapType10",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: [output] buffer_ptr\nr1: map_id\nr2: dungeon_info_str\nr3: additional_info",
        None,
    )

    LoadMapType11 = Symbol(
        [0x11004],
        [0x22EDB84],
        None,
        "LoadMapType11",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: [output] buffer_ptr\nr1: map_id\nr2: dungeon_info_str\nr3: additional_info",
        None,
    )

    GetSpecialLayoutBackground = Symbol(
        [0x15380],
        [0x22F1F00],
        None,
        "GetSpecialLayoutBackground",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: bg_id\nr1: dungeon_info_str\nr2: additional_info\nr3: copy_fixed_room_layout",
        None,
    )

    SetAnimDataFields = Symbol(
        [0x1863C],
        [0x22F51BC],
        None,
        "SetAnimDataFields",
        "Sets some fields on the animation struct?\n\nr0: animation pointer\nr1: ?",
        None,
    )

    SetAnimDataFieldsWrapper = Symbol(
        [0x1877C],
        [0x22F52FC],
        None,
        "SetAnimDataFieldsWrapper",
        "Calls SetAnimDataFields with the second argument right-shifted by 16.",
        None,
    )

    InitAnimDataFromOtherAnimData = Symbol(
        [0x18A84],
        [0x22F5604],
        None,
        "InitAnimDataFromOtherAnimData",
        "Appears to partially copy some animation data into another animation struct, plus doing extra initialization on the destination struct.\n\nr0: dst\nr1: src",
        None,
    )

    SetAnimDataFields2 = Symbol(
        [0x19108],
        [0x22F5C88],
        None,
        "SetAnimDataFields2",
        "Sets some fields on the animation struct, based on the params?\n\nr0: animation pointer\nr1: flags\nr2: ?",
        None,
    )

    GetIdleAnimationType = Symbol(
        [0x19B70],
        [0x22F66F0],
        None,
        "GetIdleAnimationType",
        "Given a monster species, returns the type of idle animation it should have.\n\nPossible values are 'freeze animation #0' (0x300), 'loop animation #7' (0x807) and 'freeze animation #7' (0x307).\n\nr0: Monster ID\nr1: (?) Could contain data about the animation the monster is currently playing\nreturn: Animation data",
        None,
    )

    LoadObjectAnimData = Symbol(
        [0x1AC80],
        [0x22F7800],
        None,
        "LoadObjectAnimData",
        "Loads the animation (WAN) data for a given object index?\n\nr0: animation pointer\nr1: object index\nr2: flags",
        None,
    )

    InitAnimDataFromOtherAnimDataVeneer = Symbol(
        [0x1AD28],
        [0x22F78A8],
        None,
        "InitAnimDataFromOtherAnimDataVeneer",
        "Likely a linker-generated veneer for InitAnimDataFromOtherAnimData.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: dst\nr1: src",
        None,
    )

    AnimRelatedFunction = Symbol(
        [0x1AD34, 0x1AE84],
        [0x22F78B4, 0x22F7A04],
        None,
        "AnimRelatedFunction",
        "Does more stuff related to animations...probably?\n\nr0: animation pointer?\nothers: ?",
        None,
    )

    AllocAndInitPartnerFollowDataAndLiveActorList = Symbol(
        [0x1BADC],
        [0x22F865C],
        None,
        "AllocAndInitPartnerFollowDataAndLiveActorList",
        "Allocate and initialize the partner follow data and the live actor list (in GROUND_STATE_PTRS)\n\nNo params.",
        None,
    )

    InitPartnerFollowDataAndLiveActorList = Symbol(
        [0x1BB38],
        [0x22F86B8],
        None,
        "InitPartnerFollowDataAndLiveActorList",
        "Initialize the partner follow data and the live actor list (in GROUND_STATE_PTRS, doesn’t perform the allocation of the structures)\n\nNo params.",
        None,
    )

    DeleteLiveActor = Symbol(
        [0x1C398],
        [0x22F8F18],
        None,
        "DeleteLiveActor",
        "Remove the actor from the overworld actor list (in GROUND_STATE_PTRS)\n\nr0: the index of the actor in the live actor list",
        None,
    )

    ChangeActorAnimation = Symbol(
        [0x1D1E8],
        [0x22F9D68],
        None,
        "ChangeActorAnimation",
        "Used by the SetAnimation opcode to change the animation of an actor.\n\nIt's responsible for breaking down the SetAnimation parameter and determining which animation to play and which flags to set.\n\nr0: ?\nr1: SetAnimation parameter",
        None,
    )

    InitPartnerFollowData = Symbol(
        [0x1F848],
        [0x22FC3C8],
        None,
        "InitPartnerFollowData",
        "Initialize the partner follow data structure, without allocating it (in GROUND_STATE_PTRS)\n\nNo params.",
        None,
    )

    GetDirectionLiveActor = Symbol(
        [0x20FC8],
        [0x22FDB48],
        None,
        "GetDirectionLiveActor",
        "Put the direction of the actor in the destination\n\nr0: live actor\nr1: destination address (1 byte)",
        None,
    )

    SetDirectionLiveActor = Symbol(
        [0x20FD8],
        [0x22FDB58],
        None,
        "SetDirectionLiveActor",
        "Store the direction in the actor structure\n-1 input is ignored\nUnsure if this change the animation\n\nr0: live actor\nr1: direction",
        None,
    )

    CreateTeamInfoBox = Symbol(
        [0x22CB4],
        [0x22FF834],
        None,
        "CreateTeamInfoBox",
        "Creates a window containing team information (rank and money carried) for the top-level menu in ground mode. Also see struct team_info_box.\n\nThe new window will always default to TEAM_INFO_BOX_DEFAULT_WINDOW_PARAMS.\n\nreturn: window_id",
        None,
    )

    CloseTeamInfoBox = Symbol(
        [0x22D6C],
        [0x22FF8EC],
        None,
        "CloseTeamInfoBox",
        "Closes a window created with CreateTeamInfoBox.\n\nr0: window_id",
        None,
    )

    IsTeamInfoBoxActive = Symbol(
        [0x22DA4],
        [0x22FF924],
        None,
        "IsTeamInfoBoxActive",
        "This is a guess.\n\nChecks if the state of a team info box is not 5.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateTeamInfoBox = Symbol(
        [0x22DC4],
        [0x22FF944],
        None,
        "UpdateTeamInfoBox",
        "Window update function for team info boxes.\n\nr0: window pointer",
        None,
    )

    CreateTopGroundMenu = Symbol(
        [0x24BA4],
        [0x2301724],
        None,
        "CreateTopGroundMenu",
        "Creates a parent menu (containing Items, Team, etc.) and two other windows upon pressing X in the overworld.\n\nreturn: always 1",
        None,
    )

    CloseTopGroundMenu = Symbol(
        [0x24D10],
        [0x2301890],
        None,
        "CloseTopGroundMenu",
        "Closes the three windows created by CreateOverworldMenu.\n\nNo params.",
        None,
    )

    UpdateTopGroundMenu = Symbol(
        [0x24D6C],
        [0x23018EC],
        None,
        "UpdateTopGroundMenu",
        "Window update function for the top-level ground mode menu.\n\nreturn: status code",
        None,
    )

    IsBagNotEmpty = Symbol(
        [0x288E0],
        [0x2305460],
        None,
        "IsBagNotEmpty",
        "Checks if the bag has at least one valid item. Notably used in CreateTopGroundMenu to decide if the 'Items' option should be enabled.\n\nreturn: bool",
        None,
    )

    SprintfStatic = Symbol(
        [0x2CCE8],
        [0x2309868],
        None,
        "SprintfStatic",
        "Statically defined copy of sprintf(3) in overlay 11. See arm9.yml for more information.\n\nr0: str\nr1: format\n...: variadic\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    GetExclusiveItemRequirements = Symbol(
        [0x2ED54],
        [0x230B8D4],
        None,
        "GetExclusiveItemRequirements",
        "Used to calculate the items required to get a certain exclusive item in the swap shop.\n\nr0: ?\nr1: ?",
        None,
    )

    HandleControlsTopScreenGround = Symbol(
        [0x32434],
        [0x230EFB4],
        None,
        "HandleControlsTopScreenGround",
        "Handles the controls top screen display in the overworld.\n\nFor some reason the implementation seems considerably jankier in ground mode. In dungeon mode there's this structure for the top screen that has handlers for creating, updating and closing the various top screen layouts in a sort of polymorphic way. Here there's just a separate function for every layout that gets called every frame and seems to have a switch-case to handle everything about it.\n\nNo params.",
        None,
    )

    GetDungeonMapPos = Symbol(
        [0x32B64],
        [0x230F6E4],
        None,
        "GetDungeonMapPos",
        "Checks if a dungeon should be displayed on the map and the position where it should be displayed if so.\n\nr0: [Output] Buffer where the coordinates of the map marker will be stored. The coordinates are shifted 8 bits to the left, so they are probably fixed-point numbers instead of integers.\nr1: Dungeon ID\nreturn: True if the dungeon should be displayed on the map, false otherwise.",
        None,
    )

    WorldMapSetMode = Symbol(
        [0x32E20],
        [0x230F9A0],
        None,
        "WorldMapSetMode",
        "Function called by the script function 'worldmap_SetMode'\nDefine the mode of the world map, which can among other things be used to decide if the player character should appear on the world map\nThe mode is set even if no world map is set\n\nr0: world map mode",
        None,
    )

    WorldMapSetCamera = Symbol(
        [0x32EE0],
        [0x230FA60],
        None,
        "WorldMapSetCamera",
        "Function called with the script function 'worldmap_SetCamera'.\nSet the map marker the world map should try to center on (while still ensuring it doesn't go over the background border)\nHas no effect if no map is currently set\n\nr0: map marker id",
        None,
    )

    StatusUpdate = Symbol(
        [0x378F8],
        [0x2314478],
        None,
        "StatusUpdate",
        "Implements SPECIAL_PROC_STATUS_UPDATE (see ScriptSpecialProcessCall).\n\nNo params.",
        None,
    )

    HandleTeamStatsGround = Symbol(
        [0x3793C],
        [0x23144BC],
        None,
        "HandleTeamStatsGround",
        "Handles the team stats top screen display in the overworld.\n\nFor some reason the implementation seems considerably jankier in ground mode. In dungeon mode there's this structure for the top screen that has handlers for creating, updating and closing the various top screen layouts in a sort of polymorphic way. Here there's just a separate function for every layout that gets called every frame and seems to have a switch-case to handle everything about it.\n\nNo params.",
        None,
    )

    ProcessScriptParam = _Deprecated("ProcessScriptParam", ScriptParamToInt)


class EuOverlay11Data:

    OVERLAY11_UNKNOWN_TABLE__NA_2316A38 = Symbol(
        None,
        None,
        None,
        "OVERLAY11_UNKNOWN_TABLE__NA_2316A38",
        "Multiple entries are pointers to the string 'script.c'\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: undefined4[40]",
        "",
    )

    SCRIPT_COMMAND_PARSING_DATA = Symbol(
        [0x3A938],
        [0x23174B8],
        None,
        "SCRIPT_COMMAND_PARSING_DATA",
        "Used by ScriptCommandParsing somehow",
        "undefined[32]",
    )

    SCRIPT_OP_CODE_NAMES = Symbol(
        [0x3A958],
        [0x23174D8],
        None,
        "SCRIPT_OP_CODE_NAMES",
        "Opcode name strings pointed to by entries in SCRIPT_OP_CODES (script_opcode::name)",
        "char[0]",
    )

    SCRIPT_OP_CODES = Symbol(
        [0x3C470],
        [0x2318FF0],
        0xBF8,
        "SCRIPT_OP_CODES",
        "Table of opcodes for the script engine. There are 383 8-byte entries.\n\nThese opcodes underpin the various ExplorerScript functions you can call in the SkyTemple SSB debugger.\n\ntype: struct script_opcode_table",
        "struct script_opcode_table",
    )

    OVERLAY11_DEBUG_STRINGS = Symbol(
        [0x3D068],
        [0x2319BE8],
        None,
        "OVERLAY11_DEBUG_STRINGS",
        "Strings used with various debug printing functions throughout the overlay",
        "char[0]",
    )

    C_ROUTINE_NAMES = Symbol(
        [0x3D94C],
        [0x231A4CC],
        None,
        "C_ROUTINE_NAMES",
        "Common routine name strings pointed to by entries in C_ROUTINES (common_routine::name)",
        "char[0]",
    )

    C_ROUTINES = Symbol(
        [0x40688],
        [0x231D208],
        None,
        "C_ROUTINES",
        "Common routines used within the unionall.ssb script (the master script). There are 701 8-byte entries.\n\nThese routines underpin the ExplorerScript coroutines you can call in the SkyTemple SSB debugger.\n\ntype: struct common_routine_table",
        "struct common_routine_table",
    )

    GROUND_WEATHER_TABLE = Symbol(
        [0x41C70],
        [0x231E7F0],
        None,
        "GROUND_WEATHER_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct ground_weather_entry[12]",
        "struct ground_weather_entry[12]",
    )

    GROUND_WAN_FILES_TABLE = Symbol(
        [0x41CA0],
        [0x231E820],
        0x10BC,
        "GROUND_WAN_FILES_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: char[343][12]",
        "char[343][12]",
    )

    OBJECTS = Symbol(
        [0x42D5C],
        [0x231F8DC],
        0x1AAC,
        "OBJECTS",
        "Table of objects for the script engine, which can be placed in scenes. There are a version-dependent number of 12-byte entries.\n\ntype: struct script_object[length / 12]",
        "struct script_object[0]",
    )

    RECRUITMENT_TABLE_LOCATIONS = Symbol(
        [0x44844],
        [0x23213C4],
        0x16,
        "RECRUITMENT_TABLE_LOCATIONS",
        "Table of dungeon IDs corresponding to entries in RECRUITMENT_TABLE_SPECIES.\n\ntype: struct dungeon_id_16[22]",
        "struct dungeon_id_16[22]",
    )

    RECRUITMENT_TABLE_LEVELS = Symbol(
        [0x4485C],
        [0x23213DC],
        0x2C,
        "RECRUITMENT_TABLE_LEVELS",
        "Table of levels for recruited Pokémon, corresponding to entries in RECRUITMENT_TABLE_SPECIES.\n\ntype: int16_t[22]",
        "int16_t[22]",
    )

    RECRUITMENT_TABLE_SPECIES = Symbol(
        [0x44888],
        [0x2321408],
        0x2C,
        "RECRUITMENT_TABLE_SPECIES",
        "Table of Pokémon recruited at special locations, such as at the ends of certain dungeons (e.g., Dialga or the Seven Treasures legendaries) or during a cutscene (e.g., Cresselia and Manaphy).\n\nInterestingly, this includes both Heatran genders. It also includes Darkrai for some reason?\n\ntype: struct monster_id_16[22]",
        "struct monster_id_16[22]",
    )

    LEVEL_TILEMAP_LIST = Symbol(
        [0x44CDC],
        [0x232185C],
        0x288,
        "LEVEL_TILEMAP_LIST",
        "Irdkwia's notes: FIXED_FLOOR_GROUND_ASSOCIATION\n\ntype: struct level_tilemap_list_entry[81]",
        "struct level_tilemap_list_entry[81]",
    )

    SETANIMATION_TABLE = Symbol(
        [0x4587C],
        [0x23223FC],
        0xA8,
        "SETANIMATION_TABLE",
        "Table that associates the parameter of the SetAnimation scripting opcode to animation data.\n\nThe first entry is unused and has a value of 0xFFFF.",
        "struct animation_data[84]",
    )

    TEAM_INFO_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x4640C],
        [0x2322F8C],
        None,
        "TEAM_INFO_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a team_info_box.",
        "struct window_params",
    )

    OVERLAY11_OVERLAY_LOAD_TABLE = Symbol(
        [0x4701C],
        [0x2323B9C],
        0x150,
        "OVERLAY11_OVERLAY_LOAD_TABLE",
        "The overlays that can be loaded while this one is loaded.\n\nEach entry is 16 bytes, consisting of:\n- overlay group ID (see arm9.yml or enum overlay_group_id in the C headers for a mapping between group ID and overlay number)\n- function pointer to entry point\n- function pointer to destructor\n- possibly function pointer to frame-update function?\n\ntype: struct overlay_load_entry[21]",
        "struct overlay_load_entry[21]",
    )

    UNIONALL_RAM_ADDRESS = Symbol(
        [0x48C64], [0x23257E4], None, "UNIONALL_RAM_ADDRESS", "[Runtime]", ""
    )

    GROUND_STATE_MAP = Symbol(
        [0x48C80], [0x2325800], None, "GROUND_STATE_MAP", "[Runtime]", ""
    )

    GROUND_STATE_WEATHER = Symbol(
        [0x48C8C],
        [0x232580C],
        None,
        "GROUND_STATE_WEATHER",
        "[Runtime] Same structure format as GROUND_STATE_MAP",
        "",
    )

    GROUND_STATE_PTRS = Symbol(
        [0x48CB4],
        [0x2325834],
        0x18,
        "GROUND_STATE_PTRS",
        "Host pointers to multiple structure used for performing an overworld scene\n\ntype: struct main_ground_data",
        "struct main_ground_data",
    )

    WORLD_MAP_MODE = Symbol(
        [0x48DA4],
        [0x2325924],
        0x4,
        "WORLD_MAP_MODE",
        "The current world map",
        "uint32_t",
    )


class EuOverlay11Section:
    name = "overlay11"
    description = "The script engine.\n\nThis is the 'main' overlay of ground mode. The script engine is what runs the ground mode scripts contained in the SCRIPT folder, which are written in a custom scripting language. These scripts encode things like cutscenes, screen transitions, ground mode events, and tons of other things related to ground mode."
    loadaddress = 0x22DCB80
    length = 0x48E40
    functions = EuOverlay11Functions
    data = EuOverlay11Data


class EuOverlay12Functions:

    pass


class EuOverlay12Data:

    pass


class EuOverlay12Section:
    name = "overlay12"
    description = "Unused; all zeroes."
    loadaddress = 0x238AC80
    length = 0x20
    functions = EuOverlay12Functions
    data = EuOverlay12Data


class EuOverlay13Functions:

    EntryOverlay13 = Symbol(
        [0x0],
        [0x238AC80],
        None,
        "EntryOverlay13",
        "Main function of this overlay.\n\nNote: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    ExitOverlay13 = Symbol(
        [0x50],
        [0x238ACD0],
        None,
        "ExitOverlay13",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    Overlay13SwitchFunctionNa238A1C8 = Symbol(
        [0x88],
        [0x238AD08],
        None,
        "Overlay13SwitchFunctionNa238A1C8",
        "Handles the 'return' value from MENU_PERSONALITY_TEST called by scripts. \n\nreturn: int?",
        None,
    )

    Overlay13SwitchFunctionNa238A574 = Symbol(
        [0x434],
        [0x238B0B4],
        None,
        "Overlay13SwitchFunctionNa238A574",
        "Handles the menus and dialogue boxes associated with the personality quiz.\n\nNo params.",
        None,
    )

    GetPersonality = Symbol(
        [0x1C68],
        [0x238C8E8],
        None,
        "GetPersonality",
        "Returns the personality obtained after answering all the questions.\n\nThe value to return is determined by checking the points obtained for each the personalities and returning the one with the highest amount of points.\n\nreturn: Personality (0-15)",
        None,
    )

    GetOptionStringFromID = Symbol(
        [0x1CB0],
        [0x238C930],
        None,
        "GetOptionStringFromID",
        "Note: unverified, ported from Irdkwia's notes. The first parameter and the return value point to the same string (which is passed directly into PreprocessString as the first argument), so I'm not sure why they're named differently... Seems like a mistake?\n\nr0: menu_id\nr1: option_id\nreturn: process",
        None,
    )

    WaitForNextStep = Symbol(
        [0x1D0C],
        [0x238C98C],
        None,
        "WaitForNextStep",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: switch_case",
        None,
    )


class EuOverlay13Data:

    QUIZ_BORDER_COLOR_TABLE = Symbol(
        [0x1ED0],
        [0x238CB50],
        0x4,
        "QUIZ_BORDER_COLOR_TABLE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    PORTRAIT_ATTRIBUTES = Symbol(
        [0x1ED4],
        [0x238CB54],
        0x8,
        "PORTRAIT_ATTRIBUTES",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    QUIZ_MALE_FEMALE_BOOST_TABLE = Symbol(
        [0x1EDC],
        [0x238CB5C],
        0x8,
        "QUIZ_MALE_FEMALE_BOOST_TABLE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY13_UNKNOWN_STRUCT__NA_238C024 = Symbol(
        [0x1EE4],
        [0x238CB64],
        0x10,
        "OVERLAY13_UNKNOWN_STRUCT__NA_238C024",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    QUIZ_WINDOW_PARAMS_1 = Symbol(
        [0x1EF4],
        [0x238CB74],
        0x10,
        "QUIZ_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    QUIZ_WINDOW_PARAMS_2 = Symbol(
        [0x1F04],
        [0x238CB84],
        0x10,
        "QUIZ_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    QUIZ_WINDOW_PARAMS_3 = Symbol(
        [0x1F14],
        [0x238CB94],
        0x10,
        "QUIZ_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    QUIZ_WINDOW_PARAMS_4 = Symbol(
        [0x1F24],
        [0x238CBA4],
        0x10,
        "QUIZ_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    QUIZ_MENU_ITEMS_1 = Symbol(
        [0x1F34],
        [0x238CBB4],
        0x18,
        "QUIZ_MENU_ITEMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[3]",
    )

    STARTERS_PARTNER_IDS = Symbol(
        [0x1F4C],
        [0x238CBCC],
        0x2A,
        "STARTERS_PARTNER_IDS",
        "type: struct monster_id_16[21]",
        "struct monster_id_16[21]",
    )

    STARTERS_HERO_IDS = Symbol(
        [0x1F78],
        [0x238CBF8],
        0x40,
        "STARTERS_HERO_IDS",
        "type: struct monster_id_16[32]",
        "struct monster_id_16[32]",
    )

    STARTERS_TYPE_INCOMPATIBILITY_TABLE = Symbol(
        [0x1FB8],
        [0x238CC38],
        0x54,
        "STARTERS_TYPE_INCOMPATIBILITY_TABLE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    STARTERS_STRINGS = Symbol(
        [0x200C],
        [0x238CC8C],
        0x60,
        "STARTERS_STRINGS",
        "Irdkwia's notes: InsightsStringIDs",
        "uint16_t[48]",
    )

    QUIZ_QUESTION_STRINGS = Symbol(
        [0x206C],
        [0x238CCEC],
        0x84,
        "QUIZ_QUESTION_STRINGS",
        "0x2 * (66 questions)",
        "uint16_t[66]",
    )

    QUIZ_ANSWER_STRINGS = Symbol(
        [0x20F0],
        [0x238CD70],
        0x160,
        "QUIZ_ANSWER_STRINGS",
        "0x2 * (175 answers + null-terminator)",
        "uint16_t[176]",
    )

    QUIZ_ANSWER_POINTS = Symbol(
        [0x2250],
        [0x238CED0],
        0xAE0,
        "QUIZ_ANSWER_POINTS",
        "0x10 * (174 answers?)\n\nNote: unverified, ported from Irdkwia's notes",
        "struct quiz_answer_points_entry[174]",
    )

    OVERLAY13_RESERVED_SPACE = Symbol(
        [0x2D50],
        [0x238D9D0],
        0x10,
        "OVERLAY13_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY13_UNKNOWN_POINTER__NA_238CEA0 = Symbol(
        [0x2D60],
        [0x238D9E0],
        0x4,
        "OVERLAY13_UNKNOWN_POINTER__NA_238CEA0",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY13_UNKNOWN_POINTER__NA_238CEA4 = Symbol(
        [0x2D64],
        [0x238D9E4],
        0x4,
        "OVERLAY13_UNKNOWN_POINTER__NA_238CEA4",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY13_UNKNOWN_POINTER__NA_238CEA8 = Symbol(
        [0x2D68],
        [0x238D9E8],
        0x4,
        "OVERLAY13_UNKNOWN_POINTER__NA_238CEA8",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    QUIZ_WINDOW_PARAMS_5 = Symbol(
        [0x2D6C],
        [0x238D9EC],
        0x10,
        "QUIZ_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    QUIZ_WINDOW_PARAMS_6 = Symbol(
        [0x2D7C],
        [0x238D9FC],
        0x10,
        "QUIZ_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    QUIZ_DEBUG_MENU_ITEMS = Symbol(
        [0x2D8C],
        [0x238DA0C],
        0x48,
        "QUIZ_DEBUG_MENU_ITEMS",
        "Note: unverified, ported from Irdkwia's notes",
        "struct simple_menu_id_item[9]",
    )

    OVERLAY13_UNKNOWN_STRUCT__NA_238CF14 = Symbol(
        [0x2DD4],
        [0x238DA54],
        0x10,
        "OVERLAY13_UNKNOWN_STRUCT__NA_238CF14",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    QUIZ_QUESTION_ANSWER_ASSOCIATIONS = Symbol(
        [0x2DE4],
        [0x238DA64],
        0x84,
        "QUIZ_QUESTION_ANSWER_ASSOCIATIONS",
        "0x2 * (66 questions)\n\nNote: unverified, ported from Irdkwia's notes",
        "uint16_t[66]",
    )


class EuOverlay13Section:
    name = "overlay13"
    description = "Controls the personality test, including the available partners and playable Pokémon. The actual personality test questions are stored in the MESSAGE folder."
    loadaddress = 0x238AC80
    length = 0x2E80
    functions = EuOverlay13Functions
    data = EuOverlay13Data


class EuOverlay14Functions:

    SentrySetupState = Symbol(
        [0x0],
        [0x238AC80],
        None,
        "SentrySetupState",
        "Allocates and initializes the sentry duty struct.\n\nPossibly the entrypoint of this overlay?\n\nr0: controls initial game state? If 2, the minigame starts in state 4 rather than state 6.\nreturn: always 1",
        None,
    )

    SentryUpdateDisplay = Symbol(
        [0xCBC],
        [0x238B93C],
        None,
        "SentryUpdateDisplay",
        "Seems to update various parts of the display, such as the round number.\n\nNo params.",
        None,
    )

    SentrySetExitingState = Symbol(
        [0x1598],
        [0x238C218],
        None,
        "SentrySetExitingState",
        "Sets the completion state to exiting, triggering the minigame to run its exit sequence.\n\nNo params.",
        None,
    )

    SentryRunState = Symbol(
        [0x16BC],
        [0x238C33C],
        None,
        "SentryRunState",
        "Run the minigame according to the current game state, or handle the transition to a new state if one has been set.\n\nThe game is implemented using the state machine programming pattern. This function appears to contain the top-level code for running a single 'turn' of the state machine, although presumably there's a higher level game engine that's calling this function in a loop somewhere.\n\nreturn: return code for the engine driving the minigame? Seems like 1 to keep going and 4 to stop",
        None,
    )

    SentrySetStateIntermediate = Symbol(
        [0x2088],
        [0x238CD08],
        None,
        "SentrySetStateIntermediate",
        "Queues up a new intermediate game state to transition to, where the transition handler will be called immediately by SentryRunState after the current state handler has returned.\n\nr0: new state",
        None,
    )

    SentryState0 = Symbol(
        [0x20A8], [0x238CD28], None, "SentryState0", "No params.", None
    )

    SentryState1 = Symbol(
        [0x20CC], [0x238CD4C], None, "SentryState1", "No params.", None
    )

    SentryState2 = Symbol(
        [0x2124], [0x238CDA4], None, "SentryState2", "No params.", None
    )

    SentryState3 = Symbol(
        [0x2148], [0x238CDC8], None, "SentryState3", "No params.", None
    )

    SentryState4 = Symbol(
        [0x2270], [0x238CEF0], None, "SentryState4", "No params.", None
    )

    SentryStateExit = Symbol(
        [0x2294],
        [0x238CF14],
        None,
        "SentryStateExit",
        "State 0x5: Exit (wraps SentrySetExitingState).\n\nNo params.",
        None,
    )

    SentryState6 = Symbol(
        [0x22A0], [0x238CF20], None, "SentryState6", "No params.", None
    )

    SentryState7 = Symbol(
        [0x22C4],
        [0x238CF44],
        None,
        "SentryState7",
        "This state corresponds to when Loudred tells you the instructions for the minigame (STRING_ID_SENTRY_INSTRUCTIONS).\n\nNo params.",
        None,
    )

    SentryState8 = Symbol(
        [0x22DC], [0x238CF5C], None, "SentryState8", "No params.", None
    )

    SentryState9 = Symbol(
        [0x2300], [0x238CF80], None, "SentryState9", "No params.", None
    )

    SentryStateA = Symbol(
        [0x2324],
        [0x238CFA4],
        None,
        "SentryStateA",
        "This state corresponds to when Loudred alerts you that someone is coming (STRING_ID_SENTRY_HERE_COMES).\n\nNo params.",
        None,
    )

    SentryStateB = Symbol(
        [0x233C], [0x238CFBC], None, "SentryStateB", "No params.", None
    )

    SentryStateGenerateChoices = Symbol(
        [0x2354],
        [0x238CFD4],
        None,
        "SentryStateGenerateChoices",
        "State 0xC: Generate the four choices for a round.\n\nNo params.",
        None,
    )

    SentryStateGetUserChoice = Symbol(
        [0x2954],
        [0x238D5D4],
        None,
        "SentryStateGetUserChoice",
        "State 0xD: Wait for the player to select an answer.\n\nNo params.",
        None,
    )

    SentryStateFinalizeRound = Symbol(
        [0x2E84],
        [0x238DB04],
        None,
        "SentryStateFinalizeRound",
        "State 0xE: Deal with the bookkeeping after the player has made a final choice for the round.\n\nThis includes things like incrementing the round counter. It also appears to check the final point count on the last round to determine the player's overall performance.\n\nNo params.",
        None,
    )

    SentryStateF = Symbol(
        [0x31C8], [0x238DE48], None, "SentryStateF", "No params.", None
    )

    SentryState10 = Symbol(
        [0x31E0], [0x238DE60], None, "SentryState10", "No params.", None
    )

    SentryState11 = Symbol(
        [0x3258],
        [0x238DED8],
        None,
        "SentryState11",
        "This state corresponds to when the partner tells you to try again after the player makes a wrong selection for the first time (STRING_ID_SENTRY_TRY_AGAIN).\n\nNo params.",
        None,
    )

    SentryState12 = Symbol(
        [0x3270], [0x238DEF0], None, "SentryState12", "No params.", None
    )

    SentryState13 = Symbol(
        [0x32A8],
        [0x238DF28],
        None,
        "SentryState13",
        "This state corresponds to when Loudred tells you that you're out of time (STRING_ID_SENTRY_OUT_OF_TIME).\n\nNo params.",
        None,
    )

    SentryState14 = Symbol(
        [0x32D0],
        [0x238DF50],
        None,
        "SentryState14",
        "This state corresponds to when the player is shouting their guess (STRING_ID_SENTRY_FOOTPRINT_IS_6EE), and when Loudred tells the visitor to come in (STRING_ID_SENTRY_COME_IN_6EF).\n\nNo params.",
        None,
    )

    SentryState15 = Symbol(
        [0x32E8], [0x238DF68], None, "SentryState15", "No params.", None
    )

    SentryState16 = Symbol(
        [0x3328], [0x238DFA8], None, "SentryState16", "No params.", None
    )

    SentryState17 = Symbol(
        [0x3380],
        [0x238E000],
        None,
        "SentryState17",
        "This state corresponds to when Loudred tells the player that they chose the wrong answer (STRING_ID_SENTRY_WRONG, STRING_ID_SENTRY_BUCK_UP).\n\nNo params.",
        None,
    )

    SentryState18 = Symbol(
        [0x33F8], [0x238E078], None, "SentryState18", "No params.", None
    )

    SentryState19 = Symbol(
        [0x3430],
        [0x238E0B0],
        None,
        "SentryState19",
        "This state seems to be similar to state 0x14, when the player is shouting their guess (STRING_ID_SENTRY_FOOTPRINT_IS_6EC), and when Loudred tells the visitor to come in (STRING_ID_SENTRY_COME_IN_6ED), but used in a different context (different state transitions to and from this state).\n\nNo params.",
        None,
    )

    SentryState1A = Symbol(
        [0x3448], [0x238E0C8], None, "SentryState1A", "No params.", None
    )

    SentryStateFinalizePoints = Symbol(
        [0x3488],
        [0x238E108],
        None,
        "SentryStateFinalizePoints",
        "State 0x1B: Apply any modifiers to the player's point total, such as granting 2000 bonus points for 100% correctness.\n\nNo params.",
        None,
    )

    SentryState1C = Symbol(
        [0x3518],
        [0x238E198],
        None,
        "SentryState1C",
        "This state corresponds to when Loudred tells the player that they chose the correct answer ('Yep! Looks like you're right!').\n\nNo params.",
        None,
    )

    SentryState1D = Symbol(
        [0x355C], [0x238E1DC], None, "SentryState1D", "No params.", None
    )

    SentryState1E = Symbol(
        [0x35C0],
        [0x238E240],
        None,
        "SentryState1E",
        "This state corresponds to one of the possible dialogue options when you've finished all the rounds (STRING_ID_SENTRY_KEEP_YOU_WAITING, STRING_ID_SENTRY_THATLL_DO_IT).\n\nNo params.",
        None,
    )

    SentryState1F = Symbol(
        [0x35D8], [0x238E258], None, "SentryState1F", "No params.", None
    )

    SentryState20 = Symbol(
        [0x3654],
        [0x238E2D4],
        None,
        "SentryState20",
        "This state corresponds to one of the possible dialogue options when you've finished all the rounds (STRING_ID_SENTRY_NO_MORE_VISITORS, STRING_ID_SENTRY_THATS_ALL).\n\nNo params.",
        None,
    )

    SentryState21 = Symbol(
        [0x366C], [0x238E2EC], None, "SentryState21", "No params.", None
    )


class EuOverlay14Data:

    SENTRY_DUTY_STRUCT_SIZE = Symbol(
        None,
        None,
        None,
        "SENTRY_DUTY_STRUCT_SIZE",
        "Number of bytes in the sentry duty struct (14548).",
        "uint32_t",
    )

    SENTRY_LOUDRED_MONSTER_ID = Symbol(
        None,
        None,
        None,
        "SENTRY_LOUDRED_MONSTER_ID",
        "Monster ID for Loudred, used as the speaker ID for dialogue.",
        "enum monster_id",
    )

    STRING_ID_SENTRY_TOP_SESSIONS = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_TOP_SESSIONS",
        "String ID 0x6D9:\n Here are the rankings for the\ntop sentry sessions.",
        "int",
    )

    STRING_ID_SENTRY_INSTRUCTIONS = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_INSTRUCTIONS",
        "String ID 0x6D8:\n Look at the footprint on the top\nscreen, OK? Then identify the Pokémon![C]\n You can get only [CS:V]two wrong[CR], OK?\n[partner] will keep an eye on things!",
        "int",
    )

    STRING_ID_SENTRY_HERE_COMES = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_HERE_COMES",
        "String ID 0x6DA:\n Here comes a Pokémon! Check\nits footprint and tell me what it is!",
        "int",
    )

    STRING_ID_SENTRY_WHOSE_FOOTPRINT = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_WHOSE_FOOTPRINT",
        "String ID 0x6DB:\n Whose footprint is this?[W:60]",
        "int",
    )

    STRING_ID_SENTRY_TRY_AGAIN = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_TRY_AGAIN",
        "String ID 0x6EB:\n Huh? I don't think so. Try again!",
        "int",
    )

    STRING_ID_SENTRY_OUT_OF_TIME = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_OUT_OF_TIME",
        "String ID 0x6DC:\n [se_play:0][W:30]Out of time! Pick up the pace![W:75]",
        "int",
    )

    STRING_ID_SENTRY_FOOTPRINT_IS_6EE = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_FOOTPRINT_IS_6EE",
        "String ID 0x6EE:\n The footprint is [kind:]'s!\nThe footprint is [kind:]'s![W:60]",
        "int",
    )

    STRING_ID_SENTRY_COME_IN_6EF = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_COME_IN_6EF",
        "String ID 0x6EF:\n Heard ya! Come in, visitor![W:30]",
        "int",
    )

    STRING_ID_SENTRY_WRONG = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_WRONG",
        "String ID 0x6F1:\n ......[se_play:0][W:30]Huh?! Looks wrong to me![W:50]",
        "int",
    )

    STRING_ID_SENTRY_BUCK_UP = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_BUCK_UP",
        "String ID 0x6F2 (and also used as Loudred's speaker ID after subtracting 0x5B0):\n The correct answer is\n[kind:]! Buck up! And snap to it![se_play:0][W:120]",
        "int",
    )

    STRING_ID_SENTRY_FOOTPRINT_IS_6EC = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_FOOTPRINT_IS_6EC",
        "String ID 0x6EC:\n The footprint is [kind:]'s!\nThe footprint is [kind:]'s![W:60]",
        "int",
    )

    STRING_ID_SENTRY_COME_IN_6ED = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_COME_IN_6ED",
        "String ID 0x6ED:\n Heard ya! Come in, visitor![W:30]",
        "int",
    )

    STRING_ID_SENTRY_KEEP_YOU_WAITING = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_KEEP_YOU_WAITING",
        "String ID 0x6F3:\n [se_play:0]Sorry to keep you waiting.",
        "int",
    )

    STRING_ID_SENTRY_THATLL_DO_IT = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_THATLL_DO_IT",
        "String ID 0x6F4:\n [partner] and [hero]![C]\n That'll do it! Now get back here!",
        "int",
    )

    SENTRY_CHATOT_MONSTER_ID = Symbol(
        None,
        None,
        None,
        "SENTRY_CHATOT_MONSTER_ID",
        "Monster ID for Chatot, used as the speaker ID for dialogue.",
        "enum monster_id",
    )

    STRING_ID_SENTRY_NO_MORE_VISITORS = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_NO_MORE_VISITORS",
        "String ID 0x6F5:\n [se_play:0]No more visitors! No more\nvisitors! ♪",
        "int",
    )

    STRING_ID_SENTRY_THATS_ALL = Symbol(
        None,
        None,
        None,
        "STRING_ID_SENTRY_THATS_ALL",
        "String ID 0x6F6:\n OK, got that![C]\n Hey, [partner] and\n[hero]![C]\n That's all for today! Now get\nback here!",
        "int",
    )

    SENTRY_GROVYLE_MONSTER_ID = Symbol(
        None,
        None,
        None,
        "SENTRY_GROVYLE_MONSTER_ID",
        "Monster ID for Grovyle, which appears to be explicitly excluded when generating species choices.",
        "enum monster_id",
    )

    SENTRY_DEBUG_MENU_ITEMS = Symbol(
        [0x39C0],
        [0x238E640],
        0x48,
        "SENTRY_DEBUG_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[9]",
    )

    SENTRY_DUTY_PTR = Symbol(
        [0x3AA0],
        [0x238E720],
        None,
        "SENTRY_DUTY_PTR",
        "Pointer to the SENTRY_DUTY_STRUCT.",
        "struct sentry_duty*",
    )

    SENTRY_DUTY_STATE_HANDLER_TABLE = Symbol(
        [0x3AB4],
        [0x238E734],
        None,
        "SENTRY_DUTY_STATE_HANDLER_TABLE",
        "Null-terminated table of handler functions for the different states in the state machine. See SentryRunState.\n\ntype: state_handler_fn_t[35]",
        "state_handler_fn_t[35]",
    )


class EuOverlay14Section:
    name = "overlay14"
    description = "Runs the sentry duty minigame."
    loadaddress = 0x238AC80
    length = 0x3B40
    functions = EuOverlay14Functions
    data = EuOverlay14Data


class EuOverlay15Functions:

    pass


class EuOverlay15Data:

    BANK_MAIN_MENU_ITEMS = Symbol(
        [0xF40],
        [0x238BBC0],
        0x28,
        "BANK_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[5]",
    )

    BANK_WINDOW_PARAMS_1 = Symbol(
        None,
        None,
        None,
        "BANK_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BANK_WINDOW_PARAMS_2 = Symbol(
        [0xF78],
        [0x238BBF8],
        0x10,
        "BANK_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BANK_WINDOW_PARAMS_3 = Symbol(
        [0xF88],
        [0x238BC08],
        0x10,
        "BANK_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BANK_WINDOW_PARAMS_4 = Symbol(
        [0xF98],
        [0x238BC18],
        0x10,
        "BANK_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BANK_WINDOW_PARAMS_5 = Symbol(
        None,
        None,
        None,
        "BANK_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY15_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY15_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY15_UNKNOWN_POINTER__NA_238B180 = Symbol(
        [0x1060],
        [0x238BCE0],
        None,
        "OVERLAY15_UNKNOWN_POINTER__NA_238B180",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay15Section:
    name = "overlay15"
    description = "Controls the Duskull Bank."
    loadaddress = 0x238AC80
    length = 0x1080
    functions = EuOverlay15Functions
    data = EuOverlay15Data


class EuOverlay16Functions:

    pass


class EuOverlay16Data:

    EVO_MENU_ITEMS_CONFIRM = Symbol(
        [0x2BCC],
        [0x238D84C],
        0x18,
        "EVO_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    EVO_SUBMENU_ITEMS = Symbol(
        [0x2BE4],
        [0x238D864],
        0x20,
        "EVO_SUBMENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    EVO_MAIN_MENU_ITEMS = Symbol(
        [0x2C04],
        [0x238D884],
        0x20,
        "EVO_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    EVO_MENU_STRING_IDS = Symbol(
        None,
        None,
        None,
        "EVO_MENU_STRING_IDS",
        "26*0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "uint16_t[26]",
    )

    EVO_WINDOW_PARAMS_1 = Symbol(
        None,
        None,
        None,
        "EVO_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    EVO_WINDOW_PARAMS_2 = Symbol(
        None,
        None,
        None,
        "EVO_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    EVO_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "EVO_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    EVO_WINDOW_PARAMS_4 = Symbol(
        [0x2C88],
        [0x238D908],
        0x10,
        "EVO_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    EVO_WINDOW_PARAMS_5 = Symbol(
        [0x2C98],
        [0x238D918],
        0x10,
        "EVO_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    EVO_WINDOW_PARAMS_6 = Symbol(
        [0x2CA8],
        [0x238D928],
        0x10,
        "EVO_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    EVO_WINDOW_PARAMS_7 = Symbol(
        None,
        None,
        None,
        "EVO_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY16_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY16_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY16_UNKNOWN_POINTER__NA_238CE40 = Symbol(
        [0x2D00],
        [0x238D980],
        None,
        "OVERLAY16_UNKNOWN_POINTER__NA_238CE40",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY16_UNKNOWN_POINTER__NA_238CE58 = Symbol(
        None,
        None,
        None,
        "OVERLAY16_UNKNOWN_POINTER__NA_238CE58",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay16Section:
    name = "overlay16"
    description = "Controls Luminous Spring."
    loadaddress = 0x238AC80
    length = 0x2D20
    functions = EuOverlay16Functions
    data = EuOverlay16Data


class EuOverlay17Functions:

    pass


class EuOverlay17Data:

    ASSEMBLY_WINDOW_PARAMS_1 = Symbol(
        [0x19F4],
        [0x238C674],
        0x10,
        "ASSEMBLY_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    ASSEMBLY_WINDOW_PARAMS_2 = Symbol(
        [0x1A04],
        [0x238C684],
        0x10,
        "ASSEMBLY_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    ASSEMBLY_WINDOW_PARAMS_3 = Symbol(
        [0x1A14],
        [0x238C694],
        0x10,
        "ASSEMBLY_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    ASSEMBLY_WINDOW_PARAMS_4 = Symbol(
        [0x1A24],
        [0x238C6A4],
        0x10,
        "ASSEMBLY_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    ASSEMBLY_WINDOW_PARAMS_5 = Symbol(
        [0x1A34],
        [0x238C6B4],
        0x10,
        "ASSEMBLY_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    ASSEMBLY_MENU_ITEMS_CONFIRM = Symbol(
        [0x1A44],
        [0x238C6C4],
        0x18,
        "ASSEMBLY_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    ASSEMBLY_MAIN_MENU_ITEMS_1 = Symbol(
        [0x1A5C],
        [0x238C6DC],
        0x18,
        "ASSEMBLY_MAIN_MENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[3]",
    )

    ASSEMBLY_MAIN_MENU_ITEMS_2 = Symbol(
        [0x1A74],
        [0x238C6F4],
        0x20,
        "ASSEMBLY_MAIN_MENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    ASSEMBLY_SUBMENU_ITEMS_1 = Symbol(
        [0x1A94],
        [0x238C714],
        0x28,
        "ASSEMBLY_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[5]",
    )

    ASSEMBLY_SUBMENU_ITEMS_2 = Symbol(
        [0x1ABC],
        [0x238C73C],
        0x30,
        "ASSEMBLY_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[6]",
    )

    ASSEMBLY_SUBMENU_ITEMS_3 = Symbol(
        [0x1AEC],
        [0x238C76C],
        0x30,
        "ASSEMBLY_SUBMENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[6]",
    )

    ASSEMBLY_SUBMENU_ITEMS_4 = Symbol(
        [0x1B1C],
        [0x238C79C],
        0x38,
        "ASSEMBLY_SUBMENU_ITEMS_4",
        "",
        "struct simple_menu_id_item[7]",
    )

    ASSEMBLY_SUBMENU_ITEMS_5 = Symbol(
        [0x1B54],
        [0x238C7D4],
        0x38,
        "ASSEMBLY_SUBMENU_ITEMS_5",
        "",
        "struct simple_menu_id_item[7]",
    )

    ASSEMBLY_SUBMENU_ITEMS_6 = Symbol(
        [0x1B8C],
        [0x238C80C],
        0x38,
        "ASSEMBLY_SUBMENU_ITEMS_6",
        "",
        "struct simple_menu_id_item[7]",
    )

    ASSEMBLY_SUBMENU_ITEMS_7 = Symbol(
        [0x1BC4],
        [0x238C844],
        0x40,
        "ASSEMBLY_SUBMENU_ITEMS_7",
        "",
        "struct simple_menu_id_item[8]",
    )

    OVERLAY17_FUNCTION_POINTER_TABLE = Symbol(
        [0x1C04],
        [0x238C884],
        None,
        "OVERLAY17_FUNCTION_POINTER_TABLE",
        "Note: unverified, ported from Irdkwia's notes",
        "void*[42]",
    )

    OVERLAY17_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY17_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY17_UNKNOWN_POINTER__NA_238BE00 = Symbol(
        [0x1CC0],
        [0x238C940],
        None,
        "OVERLAY17_UNKNOWN_POINTER__NA_238BE00",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY17_UNKNOWN_POINTER__NA_238BE04 = Symbol(
        None,
        None,
        None,
        "OVERLAY17_UNKNOWN_POINTER__NA_238BE04",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY17_UNKNOWN_POINTER__NA_238BE08 = Symbol(
        None,
        None,
        None,
        "OVERLAY17_UNKNOWN_POINTER__NA_238BE08",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay17Section:
    name = "overlay17"
    description = "Controls the Chimecho Assembly."
    loadaddress = 0x238AC80
    length = 0x1CE0
    functions = EuOverlay17Functions
    data = EuOverlay17Data


class EuOverlay18Functions:

    pass


class EuOverlay18Data:

    LINK_SHOP_WINDOW_PARAMS_1 = Symbol(
        [0x3130],
        [0x238DDB0],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_2 = Symbol(
        [0x3140],
        [0x238DDC0],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_3 = Symbol(
        [0x3150],
        [0x238DDD0],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_4 = Symbol(
        [0x3160],
        [0x238DDE0],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_5 = Symbol(
        [0x3170],
        [0x238DDF0],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_6 = Symbol(
        [0x3180],
        [0x238DE00],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_7 = Symbol(
        [0x3190],
        [0x238DE10],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_8 = Symbol(
        [0x31A0],
        [0x238DE20],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_9 = Symbol(
        [0x31B0],
        [0x238DE30],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_10 = Symbol(
        [0x31C0],
        [0x238DE40],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_10",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_WINDOW_PARAMS_11 = Symbol(
        [0x31D0],
        [0x238DE50],
        0x10,
        "LINK_SHOP_WINDOW_PARAMS_11",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    LINK_SHOP_MENU_ITEMS_CONFIRM = Symbol(
        [0x31E0],
        [0x238DE60],
        0x18,
        "LINK_SHOP_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    LINK_SHOP_SUBMENU_ITEMS_1 = Symbol(
        [0x31F8],
        [0x238DE78],
        0x20,
        "LINK_SHOP_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    LINK_SHOP_SUBMENU_ITEMS_2 = Symbol(
        [0x3218],
        [0x238DE98],
        0x20,
        "LINK_SHOP_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    LINK_SHOP_MAIN_MENU_ITEMS = Symbol(
        [0x3238],
        [0x238DEB8],
        0x20,
        "LINK_SHOP_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    LINK_SHOP_SUBMENU_ITEMS_3 = Symbol(
        [0x3258],
        [0x238DED8],
        0x28,
        "LINK_SHOP_SUBMENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[5]",
    )

    LINK_SHOP_SUBMENU_ITEMS_4 = Symbol(
        [0x3280],
        [0x238DF00],
        0x30,
        "LINK_SHOP_SUBMENU_ITEMS_4",
        "",
        "struct simple_menu_id_item[6]",
    )

    LINK_SHOP_SUBMENU_ITEMS_5 = Symbol(
        [0x32B0],
        [0x238DF30],
        0x48,
        "LINK_SHOP_SUBMENU_ITEMS_5",
        "",
        "struct simple_menu_id_item[9]",
    )

    LINK_SHOP_SUBMENU_ITEMS_6 = Symbol(
        [0x32F8],
        [0x238DF78],
        0x48,
        "LINK_SHOP_SUBMENU_ITEMS_6",
        "",
        "struct simple_menu_id_item[9]",
    )

    LINK_SHOP_SUBMENU_ITEMS_7 = Symbol(
        [0x3340],
        [0x238DFC0],
        0x48,
        "LINK_SHOP_SUBMENU_ITEMS_7",
        "",
        "struct simple_menu_id_item[9]",
    )

    OVERLAY18_FUNCTION_POINTER_TABLE = Symbol(
        [0x3388],
        [0x238E008],
        None,
        "OVERLAY18_FUNCTION_POINTER_TABLE",
        "Note: unverified, ported from Irdkwia's notes",
        "void*[76]",
    )

    OVERLAY18_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY18_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY18_UNKNOWN_POINTER__NA_238D620 = Symbol(
        [0x34E0],
        [0x238E160],
        None,
        "OVERLAY18_UNKNOWN_POINTER__NA_238D620",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY18_UNKNOWN_POINTER__NA_238D624 = Symbol(
        None,
        None,
        None,
        "OVERLAY18_UNKNOWN_POINTER__NA_238D624",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY18_UNKNOWN_POINTER__NA_238D628 = Symbol(
        None,
        None,
        None,
        "OVERLAY18_UNKNOWN_POINTER__NA_238D628",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay18Section:
    name = "overlay18"
    description = "Controls the Electivire Link Shop."
    loadaddress = 0x238AC80
    length = 0x3500
    functions = EuOverlay18Functions
    data = EuOverlay18Data


class EuOverlay19Functions:

    GetBarItem = Symbol(
        [0x0],
        [0x238AC80],
        None,
        "GetBarItem",
        "Gets the struct bar_item from BAR_AVAILABLE_ITEMS with the specified item ID.\n\nr0: item ID\nreturn: struct bar_item*",
        None,
    )

    GetRecruitableMonsterAll = Symbol(
        [0x84],
        [0x238AD04],
        None,
        "GetRecruitableMonsterAll",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: int?",
        None,
    )

    GetRecruitableMonsterList = Symbol(
        [0x134],
        [0x238ADB4],
        None,
        "GetRecruitableMonsterList",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: int?",
        None,
    )

    GetRecruitableMonsterListRestricted = Symbol(
        [0x1DC],
        [0x238AE5C],
        None,
        "GetRecruitableMonsterListRestricted",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: int?",
        None,
    )


class EuOverlay19Data:

    OVERLAY19_UNKNOWN_TABLE__NA_238DAE0 = Symbol(
        [0x3994],
        [0x238E614],
        None,
        "OVERLAY19_UNKNOWN_TABLE__NA_238DAE0",
        "4*0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    BAR_UNLOCKABLE_DUNGEONS_TABLE = Symbol(
        [0x399C],
        [0x238E61C],
        None,
        "BAR_UNLOCKABLE_DUNGEONS_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct dungeon_id_16[6]",
        "struct dungeon_id_16[6]",
    )

    BAR_RECRUITABLE_MONSTER_TABLE = Symbol(
        [0x39A8],
        [0x238E628],
        None,
        "BAR_RECRUITABLE_MONSTER_TABLE",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct monster_id_16[108]",
        "struct monster_id_16[108]",
    )

    BAR_AVAILABLE_ITEMS = Symbol(
        [0x3A80],
        [0x238E700],
        None,
        "BAR_AVAILABLE_ITEMS",
        "Note: unverified, ported from Irdkwia's notes\n\ntype: struct bar_item[66]",
        "struct bar_item[66]",
    )

    OVERLAY19_UNKNOWN_STRING_IDS__NA_238E178 = Symbol(
        [0x402C],
        [0x238ECAC],
        None,
        "OVERLAY19_UNKNOWN_STRING_IDS__NA_238E178",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY19_UNKNOWN_STRUCT__NA_238E1A4 = Symbol(
        [0x4058],
        [0x238ECD8],
        None,
        "OVERLAY19_UNKNOWN_STRUCT__NA_238E1A4",
        "5*0x8\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY19_UNKNOWN_STRING_IDS__NA_238E1CC = Symbol(
        [0x4080],
        [0x238ED00],
        None,
        "OVERLAY19_UNKNOWN_STRING_IDS__NA_238E1CC",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    BAR_WINDOW_PARAMS_1 = Symbol(
        [0x408C],
        [0x238ED0C],
        0x10,
        "BAR_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BAR_WINDOW_PARAMS_2 = Symbol(
        [0x409C],
        [0x238ED1C],
        0x10,
        "BAR_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BAR_WINDOW_PARAMS_3 = Symbol(
        [0x40AC],
        [0x238ED2C],
        0x10,
        "BAR_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    BAR_MENU_ITEMS_CONFIRM_1 = Symbol(
        [0x40BC],
        [0x238ED3C],
        0x18,
        "BAR_MENU_ITEMS_CONFIRM_1",
        "",
        "struct simple_menu_id_item[3]",
    )

    BAR_MENU_ITEMS_CONFIRM_2 = Symbol(
        [0x40D4],
        [0x238ED54],
        0x18,
        "BAR_MENU_ITEMS_CONFIRM_2",
        "",
        "struct simple_menu_id_item[3]",
    )

    OVERLAY19_UNKNOWN_STRING_IDS__NA_238E238 = Symbol(
        [0x40EC],
        [0x238ED6C],
        None,
        "OVERLAY19_UNKNOWN_STRING_IDS__NA_238E238",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    BAR_MAIN_MENU_ITEMS = Symbol(
        [0x4104],
        [0x238ED84],
        0x20,
        "BAR_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    BAR_SUBMENU_ITEMS_1 = Symbol(
        [0x4124],
        [0x238EDA4],
        0x20,
        "BAR_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    BAR_SUBMENU_ITEMS_2 = Symbol(
        [0x4144],
        [0x238EDC4],
        0x30,
        "BAR_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[6]",
    )

    OVERLAY19_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY19_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY19_UNKNOWN_POINTER__NA_238E360 = Symbol(
        [0x4200],
        [0x238EE80],
        None,
        "OVERLAY19_UNKNOWN_POINTER__NA_238E360",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY19_UNKNOWN_POINTER__NA_238E364 = Symbol(
        None,
        None,
        None,
        "OVERLAY19_UNKNOWN_POINTER__NA_238E364",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay19Section:
    name = "overlay19"
    description = "Controls Spinda's Juice Bar."
    loadaddress = 0x238AC80
    length = 0x4220
    functions = EuOverlay19Functions
    data = EuOverlay19Data


class EuOverlay2Functions:

    pass


class EuOverlay2Data:

    pass


class EuOverlay2Section:
    name = "overlay2"
    description = "Controls the Nintendo WFC Settings interface, accessed from the top menu (Other > Nintendo WFC > Nintendo WFC Settings). Presumably contains code for Nintendo Wi-Fi setup."
    loadaddress = 0x2329D40
    length = 0x2AFC0
    functions = EuOverlay2Functions
    data = EuOverlay2Data


class EuOverlay20Functions:

    pass


class EuOverlay20Data:

    OVERLAY20_UNKNOWN_POINTER__NA_238CF7C = Symbol(
        [0x2E3C],
        [0x238DABC],
        None,
        "OVERLAY20_UNKNOWN_POINTER__NA_238CF7C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    RECYCLE_MENU_ITEMS_CONFIRM_1 = Symbol(
        [0x2E44],
        [0x238DAC4],
        0x18,
        "RECYCLE_MENU_ITEMS_CONFIRM_1",
        "",
        "struct simple_menu_id_item[3]",
    )

    RECYCLE_MENU_ITEMS_CONFIRM_2 = Symbol(
        [0x2E5C],
        [0x238DADC],
        0x18,
        "RECYCLE_MENU_ITEMS_CONFIRM_2",
        "",
        "struct simple_menu_id_item[3]",
    )

    RECYCLE_SUBMENU_ITEMS_1 = Symbol(
        [0x2E74],
        [0x238DAF4],
        0x18,
        "RECYCLE_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[3]",
    )

    RECYCLE_SUBMENU_ITEMS_2 = Symbol(
        [0x2E8C],
        [0x238DB0C],
        0x20,
        "RECYCLE_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    RECYCLE_MAIN_MENU_ITEMS_1 = Symbol(
        [0x2EAC],
        [0x238DB2C],
        0x28,
        "RECYCLE_MAIN_MENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[5]",
    )

    OVERLAY20_UNKNOWN_TABLE__NA_238D014 = Symbol(
        [0x2ED4],
        [0x238DB54],
        None,
        "OVERLAY20_UNKNOWN_TABLE__NA_238D014",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    RECYCLE_WINDOW_PARAMS_1 = Symbol(
        [0x2EE8],
        [0x238DB68],
        0x10,
        "RECYCLE_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_2 = Symbol(
        [0x2EF8],
        [0x238DB78],
        0x10,
        "RECYCLE_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_3 = Symbol(
        [0x2F08],
        [0x238DB88],
        0x10,
        "RECYCLE_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_4 = Symbol(
        [0x2F18],
        [0x238DB98],
        0x10,
        "RECYCLE_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_5 = Symbol(
        [0x2F28],
        [0x238DBA8],
        0x10,
        "RECYCLE_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_6 = Symbol(
        [0x2F38],
        [0x238DBB8],
        0x10,
        "RECYCLE_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_MAIN_MENU_ITEMS_2 = Symbol(
        [0x2F48],
        [0x238DBC8],
        0x20,
        "RECYCLE_MAIN_MENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    RECYCLE_WINDOW_PARAMS_7 = Symbol(
        [0x2F68],
        [0x238DBE8],
        0x10,
        "RECYCLE_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_8 = Symbol(
        [0x2F78],
        [0x238DBF8],
        0x10,
        "RECYCLE_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_9 = Symbol(
        [0x2F88],
        [0x238DC08],
        0x10,
        "RECYCLE_WINDOW_PARAMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_10 = Symbol(
        [0x2F98],
        [0x238DC18],
        0x10,
        "RECYCLE_WINDOW_PARAMS_10",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_WINDOW_PARAMS_11 = Symbol(
        [0x2FA8],
        [0x238DC28],
        0x10,
        "RECYCLE_WINDOW_PARAMS_11",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    RECYCLE_MAIN_MENU_ITEMS_3 = Symbol(
        [0x2FB8],
        [0x238DC38],
        0x18,
        "RECYCLE_MAIN_MENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[3]",
    )

    OVERLAY20_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY20_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY20_UNKNOWN_POINTER__NA_238D120 = Symbol(
        [0x2FE0],
        [0x238DC60],
        None,
        "OVERLAY20_UNKNOWN_POINTER__NA_238D120",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY20_UNKNOWN_POINTER__NA_238D124 = Symbol(
        [0x2FE4],
        [0x238DC64],
        None,
        "OVERLAY20_UNKNOWN_POINTER__NA_238D124",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY20_UNKNOWN_POINTER__NA_238D128 = Symbol(
        [0x2FE8],
        [0x238DC68],
        None,
        "OVERLAY20_UNKNOWN_POINTER__NA_238D128",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY20_UNKNOWN_POINTER__NA_238D12C = Symbol(
        [0x2FEC],
        [0x238DC6C],
        None,
        "OVERLAY20_UNKNOWN_POINTER__NA_238D12C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay20Section:
    name = "overlay20"
    description = "Controls the Recycle Shop."
    loadaddress = 0x238AC80
    length = 0x3000
    functions = EuOverlay20Functions
    data = EuOverlay20Data


class EuOverlay21Functions:

    pass


class EuOverlay21Data:

    SWAP_SHOP_WINDOW_PARAMS_1 = Symbol(
        [0x28E8],
        [0x238D568],
        0x10,
        "SWAP_SHOP_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_MENU_ITEMS_CONFIRM = Symbol(
        [0x28F8],
        [0x238D578],
        0x18,
        "SWAP_SHOP_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    SWAP_SHOP_SUBMENU_ITEMS_1 = Symbol(
        [0x2910],
        [0x238D590],
        0x18,
        "SWAP_SHOP_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[3]",
    )

    SWAP_SHOP_SUBMENU_ITEMS_2 = Symbol(
        [0x2928],
        [0x238D5A8],
        0x20,
        "SWAP_SHOP_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    SWAP_SHOP_MAIN_MENU_ITEMS_1 = Symbol(
        [0x2948],
        [0x238D5C8],
        0x20,
        "SWAP_SHOP_MAIN_MENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    SWAP_SHOP_MAIN_MENU_ITEMS_2 = Symbol(
        [0x2968],
        [0x238D5E8],
        0x28,
        "SWAP_SHOP_MAIN_MENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[5]",
    )

    SWAP_SHOP_SUBMENU_ITEMS_3 = Symbol(
        [0x2990],
        [0x238D610],
        0x30,
        "SWAP_SHOP_SUBMENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[6]",
    )

    OVERLAY21_UNKNOWN_STRING_IDS = Symbol(
        None,
        None,
        None,
        "OVERLAY21_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    SWAP_SHOP_WINDOW_PARAMS_2 = Symbol(
        None,
        None,
        None,
        "SWAP_SHOP_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "SWAP_SHOP_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_4 = Symbol(
        None,
        None,
        None,
        "SWAP_SHOP_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_5 = Symbol(
        [0x2A28],
        [0x238D6A8],
        0x10,
        "SWAP_SHOP_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_6 = Symbol(
        [0x2A38],
        [0x238D6B8],
        0x10,
        "SWAP_SHOP_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_7 = Symbol(
        [0x2A48],
        [0x238D6C8],
        0x10,
        "SWAP_SHOP_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_8 = Symbol(
        [0x2A58],
        [0x238D6D8],
        0x10,
        "SWAP_SHOP_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SWAP_SHOP_WINDOW_PARAMS_9 = Symbol(
        [0x2A68],
        [0x238D6E8],
        0x10,
        "SWAP_SHOP_WINDOW_PARAMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY21_JP_STRING = Symbol(
        [0x2DDC], [0x238DA5C], None, "OVERLAY21_JP_STRING", "合成：", ""
    )

    OVERLAY21_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY21_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY21_UNKNOWN_POINTER__NA_238CF40 = Symbol(
        [0x2E00],
        [0x238DA80],
        None,
        "OVERLAY21_UNKNOWN_POINTER__NA_238CF40",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY21_UNKNOWN_POINTER__NA_238CF44 = Symbol(
        None,
        None,
        None,
        "OVERLAY21_UNKNOWN_POINTER__NA_238CF44",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay21Section:
    name = "overlay21"
    description = "Controls the Croagunk Swap Shop."
    loadaddress = 0x238AC80
    length = 0x2E20
    functions = EuOverlay21Functions
    data = EuOverlay21Data


class EuOverlay22Functions:

    pass


class EuOverlay22Data:

    SHOP_WINDOW_PARAMS_1 = Symbol(
        [0x46DC],
        [0x238F35C],
        0x10,
        "SHOP_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_2 = Symbol(
        [0x46FC],
        [0x238F37C],
        0x10,
        "SHOP_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY22_UNKNOWN_STRUCT__NA_238E85C = Symbol(
        [0x471C],
        [0x238F39C],
        None,
        "OVERLAY22_UNKNOWN_STRUCT__NA_238E85C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    SHOP_MENU_ITEMS_CONFIRM = Symbol(
        [0x4728],
        [0x238F3A8],
        0x18,
        "SHOP_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    SHOP_MAIN_MENU_ITEMS_1 = Symbol(
        [0x4740],
        [0x238F3C0],
        0x20,
        "SHOP_MAIN_MENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    SHOP_MAIN_MENU_ITEMS_2 = Symbol(
        [0x4760],
        [0x238F3E0],
        0x20,
        "SHOP_MAIN_MENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    SHOP_MAIN_MENU_ITEMS_3 = Symbol(
        [0x4780],
        [0x238F400],
        0x30,
        "SHOP_MAIN_MENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[6]",
    )

    OVERLAY22_UNKNOWN_STRING_IDS = Symbol(
        [0x47B0],
        [0x238F430],
        None,
        "OVERLAY22_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    SHOP_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "SHOP_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_4 = Symbol(
        None,
        None,
        None,
        "SHOP_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_5 = Symbol(
        None,
        None,
        None,
        "SHOP_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_6 = Symbol(
        [0x4840],
        [0x238F4C0],
        0x10,
        "SHOP_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_7 = Symbol(
        [0x4850],
        [0x238F4D0],
        0x10,
        "SHOP_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_8 = Symbol(
        [0x4860],
        [0x238F4E0],
        0x10,
        "SHOP_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_9 = Symbol(
        [0x4870],
        [0x238F4F0],
        0x10,
        "SHOP_WINDOW_PARAMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    SHOP_WINDOW_PARAMS_10 = Symbol(
        [0x4880],
        [0x238F500],
        0x10,
        "SHOP_WINDOW_PARAMS_10",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY22_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY22_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY22_UNKNOWN_POINTER__NA_238EC60 = Symbol(
        [0x4B20],
        [0x238F7A0],
        None,
        "OVERLAY22_UNKNOWN_POINTER__NA_238EC60",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY22_UNKNOWN_POINTER__NA_238EC64 = Symbol(
        None,
        None,
        None,
        "OVERLAY22_UNKNOWN_POINTER__NA_238EC64",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY22_UNKNOWN_POINTER__NA_238EC68 = Symbol(
        [0x4B28],
        [0x238F7A8],
        None,
        "OVERLAY22_UNKNOWN_POINTER__NA_238EC68",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY22_UNKNOWN_POINTER__NA_238EC6C = Symbol(
        None,
        None,
        None,
        "OVERLAY22_UNKNOWN_POINTER__NA_238EC6C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY22_UNKNOWN_POINTER__NA_238EC70 = Symbol(
        [0x4B30],
        [0x238F7B0],
        None,
        "OVERLAY22_UNKNOWN_POINTER__NA_238EC70",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay22Section:
    name = "overlay22"
    description = "Controls the Kecleon Shop in Treasure Town."
    loadaddress = 0x238AC80
    length = 0x4B40
    functions = EuOverlay22Functions
    data = EuOverlay22Data


class EuOverlay23Functions:

    pass


class EuOverlay23Data:

    OVERLAY23_UNKNOWN_VALUE__NA_238D2E8 = Symbol(
        [0x31A8],
        [0x238DE28],
        None,
        "OVERLAY23_UNKNOWN_VALUE__NA_238D2E8",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY23_UNKNOWN_VALUE__NA_238D2EC = Symbol(
        [0x31AC],
        [0x238DE2C],
        None,
        "OVERLAY23_UNKNOWN_VALUE__NA_238D2EC",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY23_UNKNOWN_STRUCT__NA_238D2F0 = Symbol(
        [0x31B0],
        [0x238DE30],
        None,
        "OVERLAY23_UNKNOWN_STRUCT__NA_238D2F0",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    STORAGE_MENU_ITEMS_CONFIRM = Symbol(
        [0x31BC],
        [0x238DE3C],
        0x18,
        "STORAGE_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    STORAGE_MAIN_MENU_ITEMS_1 = Symbol(
        [0x31D4],
        [0x238DE54],
        0x20,
        "STORAGE_MAIN_MENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    STORAGE_MAIN_MENU_ITEMS_2 = Symbol(
        [0x31F4],
        [0x238DE74],
        0x20,
        "STORAGE_MAIN_MENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    STORAGE_MAIN_MENU_ITEMS_3 = Symbol(
        [0x3214],
        [0x238DE94],
        0x20,
        "STORAGE_MAIN_MENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[4]",
    )

    STORAGE_MAIN_MENU_ITEMS_4 = Symbol(
        [0x3234],
        [0x238DEB4],
        0x28,
        "STORAGE_MAIN_MENU_ITEMS_4",
        "",
        "struct simple_menu_id_item[5]",
    )

    OVERLAY23_UNKNOWN_STRING_IDS = Symbol(
        None,
        None,
        None,
        "OVERLAY23_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    STORAGE_WINDOW_PARAMS_1 = Symbol(
        None,
        None,
        None,
        "STORAGE_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_2 = Symbol(
        None,
        None,
        None,
        "STORAGE_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "STORAGE_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_4 = Symbol(
        [0x32B8],
        [0x238DF38],
        0x10,
        "STORAGE_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_5 = Symbol(
        [0x32C8],
        [0x238DF48],
        0x10,
        "STORAGE_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_6 = Symbol(
        [0x32D8],
        [0x238DF58],
        0x10,
        "STORAGE_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_7 = Symbol(
        [0x32E8],
        [0x238DF68],
        0x10,
        "STORAGE_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    STORAGE_WINDOW_PARAMS_8 = Symbol(
        [0x32F8],
        [0x238DF78],
        0x10,
        "STORAGE_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY23_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY23_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY23_UNKNOWN_POINTER__NA_238D8A0 = Symbol(
        [0x3760],
        [0x238E3E0],
        None,
        "OVERLAY23_UNKNOWN_POINTER__NA_238D8A0",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay23Section:
    name = "overlay23"
    description = (
        "Controls Kangaskhan Storage (both in Treasure Town and via Kangaskhan Rocks)."
    )
    loadaddress = 0x238AC80
    length = 0x3780
    functions = EuOverlay23Functions
    data = EuOverlay23Data


class EuOverlay24Functions:

    pass


class EuOverlay24Data:

    OVERLAY24_UNKNOWN_STRUCT__NA_238C508 = Symbol(
        [0x23C8],
        [0x238D048],
        None,
        "OVERLAY24_UNKNOWN_STRUCT__NA_238C508",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY24_UNKNOWN_STRUCT__NA_238C514 = Symbol(
        [0x23D4],
        [0x238D054],
        None,
        "OVERLAY24_UNKNOWN_STRUCT__NA_238C514",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DAYCARE_MENU_ITEMS_CONFIRM = Symbol(
        [0x23E0],
        [0x238D060],
        0x18,
        "DAYCARE_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    DAYCARE_MAIN_MENU_ITEMS = Symbol(
        [0x23F8],
        [0x238D078],
        0x20,
        "DAYCARE_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    OVERLAY24_UNKNOWN_STRING_IDS = Symbol(
        None,
        None,
        None,
        "OVERLAY24_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DAYCARE_WINDOW_PARAMS_1 = Symbol(
        None,
        None,
        None,
        "DAYCARE_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DAYCARE_WINDOW_PARAMS_2 = Symbol(
        None,
        None,
        None,
        "DAYCARE_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DAYCARE_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "DAYCARE_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DAYCARE_WINDOW_PARAMS_4 = Symbol(
        [0x2480],
        [0x238D100],
        0x10,
        "DAYCARE_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DAYCARE_WINDOW_PARAMS_5 = Symbol(
        None,
        None,
        None,
        "DAYCARE_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY24_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY24_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY24_UNKNOWN_POINTER__NA_238C600 = Symbol(
        [0x24C0],
        [0x238D140],
        None,
        "OVERLAY24_UNKNOWN_POINTER__NA_238C600",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay24Section:
    name = "overlay24"
    description = "Controls the Chansey Day Care."
    loadaddress = 0x238AC80
    length = 0x24E0
    functions = EuOverlay24Functions
    data = EuOverlay24Data


class EuOverlay25Functions:

    pass


class EuOverlay25Data:

    OVERLAY25_UNKNOWN_STRUCT__NA_238B498 = Symbol(
        [0x1358],
        [0x238BFD8],
        None,
        "OVERLAY25_UNKNOWN_STRUCT__NA_238B498",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    APPRAISAL_WINDOW_PARAMS_1 = Symbol(
        [0x1364],
        [0x238BFE4],
        0x10,
        "APPRAISAL_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_MENU_ITEMS_CONFIRM = Symbol(
        [0x1374],
        [0x238BFF4],
        0x18,
        "APPRAISAL_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    APPRAISAL_MAIN_MENU_ITEMS = Symbol(
        [0x138C],
        [0x238C00C],
        0x20,
        "APPRAISAL_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    APPRAISAL_SUBMENU_ITEMS = Symbol(
        [0x13AC],
        [0x238C02C],
        0x20,
        "APPRAISAL_SUBMENU_ITEMS",
        "",
        "struct simple_menu_id_item[4]",
    )

    OVERLAY25_UNKNOWN_STRING_IDS = Symbol(
        None,
        None,
        None,
        "OVERLAY25_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    APPRAISAL_WINDOW_PARAMS_2 = Symbol(
        None,
        None,
        None,
        "APPRAISAL_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "APPRAISAL_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_WINDOW_PARAMS_4 = Symbol(
        None,
        None,
        None,
        "APPRAISAL_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_WINDOW_PARAMS_5 = Symbol(
        [0x1424],
        [0x238C0A4],
        0x10,
        "APPRAISAL_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_WINDOW_PARAMS_6 = Symbol(
        [0x1434],
        [0x238C0B4],
        0x10,
        "APPRAISAL_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_WINDOW_PARAMS_7 = Symbol(
        [0x1444],
        [0x238C0C4],
        0x10,
        "APPRAISAL_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    APPRAISAL_WINDOW_PARAMS_8 = Symbol(
        [0x1454],
        [0x238C0D4],
        0x10,
        "APPRAISAL_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY25_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY25_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY25_UNKNOWN_POINTER__NA_238B5E0 = Symbol(
        [0x14A0],
        [0x238C120],
        None,
        "OVERLAY25_UNKNOWN_POINTER__NA_238B5E0",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay25Section:
    name = "overlay25"
    description = "Controls Xatu Appraisal."
    loadaddress = 0x238AC80
    length = 0x14C0
    functions = EuOverlay25Functions
    data = EuOverlay25Data


class EuOverlay26Functions:

    pass


class EuOverlay26Data:

    OVERLAY26_UNKNOWN_TABLE__NA_238AE20 = Symbol(
        [0xCE0],
        [0x238B960],
        None,
        "OVERLAY26_UNKNOWN_TABLE__NA_238AE20",
        "0x6 + 11*0xC + 0x2\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY26_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY26_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY26_UNKNOWN_POINTER__NA_238AF60 = Symbol(
        [0xE20],
        [0x238BAA0],
        None,
        "OVERLAY26_UNKNOWN_POINTER__NA_238AF60",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY26_UNKNOWN_POINTER__NA_238AF64 = Symbol(
        [0xE24],
        [0x238BAA4],
        None,
        "OVERLAY26_UNKNOWN_POINTER__NA_238AF64",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY26_UNKNOWN_POINTER__NA_238AF68 = Symbol(
        [0xE28],
        [0x238BAA8],
        None,
        "OVERLAY26_UNKNOWN_POINTER__NA_238AF68",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY26_UNKNOWN_POINTER__NA_238AF6C = Symbol(
        [0xE2C],
        [0x238BAAC],
        None,
        "OVERLAY26_UNKNOWN_POINTER__NA_238AF6C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY26_UNKNOWN_POINTER5__NA_238AF70 = Symbol(
        [0xE30],
        [0x238BAB0],
        None,
        "OVERLAY26_UNKNOWN_POINTER5__NA_238AF70",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay26Section:
    name = "overlay26"
    description = "Related to mission completion. It's loaded when the dungeon completion summary is shown upon exiting a dungeon, and during the cutscenes where you collect mission rewards from clients."
    loadaddress = 0x238AC80
    length = 0xE40
    functions = EuOverlay26Functions
    data = EuOverlay26Data


class EuOverlay27Functions:

    pass


class EuOverlay27Data:

    OVERLAY27_UNKNOWN_VALUE__NA_238C948 = Symbol(
        [0x2808],
        [0x238D488],
        None,
        "OVERLAY27_UNKNOWN_VALUE__NA_238C948",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY27_UNKNOWN_VALUE__NA_238C94C = Symbol(
        [0x280C],
        [0x238D48C],
        None,
        "OVERLAY27_UNKNOWN_VALUE__NA_238C94C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY27_UNKNOWN_STRUCT__NA_238C950 = Symbol(
        [0x2810],
        [0x238D490],
        None,
        "OVERLAY27_UNKNOWN_STRUCT__NA_238C950",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DISCARD_ITEMS_MENU_ITEMS_CONFIRM = Symbol(
        [0x281C],
        [0x238D49C],
        0x18,
        "DISCARD_ITEMS_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    DISCARD_ITEMS_SUBMENU_ITEMS_1 = Symbol(
        [0x2834],
        [0x238D4B4],
        0x20,
        "DISCARD_ITEMS_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    DISCARD_ITEMS_SUBMENU_ITEMS_2 = Symbol(
        [0x2854],
        [0x238D4D4],
        0x20,
        "DISCARD_ITEMS_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    DISCARD_ITEMS_MAIN_MENU_ITEMS = Symbol(
        [0x2874],
        [0x238D4F4],
        0x28,
        "DISCARD_ITEMS_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[5]",
    )

    OVERLAY27_UNKNOWN_STRING_IDS = Symbol(
        None,
        None,
        None,
        "OVERLAY27_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DISCARD_WINDOW_PARAMS_1 = Symbol(
        None,
        None,
        None,
        "DISCARD_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_2 = Symbol(
        None,
        None,
        None,
        "DISCARD_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_3 = Symbol(
        None,
        None,
        None,
        "DISCARD_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_4 = Symbol(
        None,
        None,
        None,
        "DISCARD_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_5 = Symbol(
        [0x290C],
        [0x238D58C],
        0x10,
        "DISCARD_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_6 = Symbol(
        [0x291C],
        [0x238D59C],
        0x10,
        "DISCARD_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_7 = Symbol(
        [0x292C],
        [0x238D5AC],
        0x10,
        "DISCARD_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DISCARD_WINDOW_PARAMS_8 = Symbol(
        None,
        None,
        None,
        "DISCARD_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY27_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY27_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY27_UNKNOWN_POINTER__NA_238CE80 = Symbol(
        [0x2D40],
        [0x238D9C0],
        None,
        "OVERLAY27_UNKNOWN_POINTER__NA_238CE80",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY27_UNKNOWN_POINTER__NA_238CE84 = Symbol(
        [0x2D44],
        [0x238D9C4],
        None,
        "OVERLAY27_UNKNOWN_POINTER__NA_238CE84",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay27Section:
    name = "overlay27"
    description = "Controls the special episode item discard menu."
    loadaddress = 0x238AC80
    length = 0x2D60
    functions = EuOverlay27Functions
    data = EuOverlay27Data


class EuOverlay28Functions:

    pass


class EuOverlay28Data:

    pass


class EuOverlay28Section:
    name = "overlay28"
    description = "Controls the staff credits sequence."
    loadaddress = 0x238AC80
    length = 0xC60
    functions = EuOverlay28Functions
    data = EuOverlay28Data


class EuOverlay29Functions:

    GetWeatherColorTable = Symbol(
        [0x23E0],
        [0x22DEF60],
        None,
        "GetWeatherColorTable",
        "Gets a pointer to the floor's color table given the current weather.\n\nThe returned table contains 1024 color entries.\n\nr0: Weather ID\nreturn: color table pointer",
        None,
    )

    DungeonAlloc = Symbol(
        [0x281C],
        [0x22DF39C],
        None,
        "DungeonAlloc",
        "Allocates a new dungeon struct.\n\nThis updates the master dungeon pointer and returns a copy of that pointer.\n\nreturn: pointer to a newly allocated dungeon struct",
        None,
    )

    GetDungeonPtrMaster = Symbol(
        [0x2840],
        [0x22DF3C0],
        None,
        "GetDungeonPtrMaster",
        "Returns the master dungeon pointer (a global, see DUNGEON_PTR_MASTER).\n\nreturn: pointer to a newly allocated dungeon struct",
        None,
    )

    DungeonZInit = Symbol(
        [0x2850],
        [0x22DF3D0],
        None,
        "DungeonZInit",
        "Zero-initializes the dungeon struct pointed to by the master dungeon pointer.\n\nNo params.",
        None,
    )

    DungeonFree = Symbol(
        [0x2870],
        [0x22DF3F0],
        None,
        "DungeonFree",
        "Frees the dungeons struct pointer to by the master dungeon pointer, and nullifies the pointer.\n\nNo params.",
        None,
    )

    RunDungeon = Symbol(
        [0x2CF8],
        [0x22DF878],
        None,
        "RunDungeon",
        "Called at the start of a dungeon. Initializes the dungeon struct from specified dungeon data. Includes a loop that does not break until the dungeon is cleared, and another one inside it that runs until the current floor ends.\n\nr0: Pointer to the struct containing info used to initialize the dungeon. See type dungeon_init for details.\nr1: Pointer to the dungeon data struct that will be used during the dungeon.",
        None,
    )

    EntityIsValid = Symbol(
        [
            0x4114,
            0x57DC,
            0x5DC7,
            0x7118,
            0x75E8,
            0xD424,
            0x10438,
            0x10BF0,
            0x12178,
            0x135D4,
            0x143C4,
            0x190C8,
            0x1A0E0,
            0x1B19C,
            0x20818,
            0x22338,
            0x23F90,
            0x268E4,
            0x28664,
            0x29438,
            0x29AB0,
            0x2BDA4,
            0x2C128,
            0x2CE68,
            0x327E4,
            0x32EFC,
            0x34EF0,
            0x35794,
            0x38FF8,
            0x3CC14,
            0x3CD2C,
            0x3DE6C,
            0x3F074,
            0x40AB0,
            0x42CC0,
            0x43458,
            0x43AE4,
            0x44064,
            0x4464C,
            0x45320,
            0x49508,
            0x52700,
            0x57E6C,
            0x58F98,
            0x5BCF8,
            0x68B5C,
            0x69704,
            0x6BC24,
            0x6D8FC,
            0x71E50,
            0x72CA0,
        ],
        [
            0x22E0C94,
            0x22E235C,
            0x22E2947,
            0x22E3C98,
            0x22E4168,
            0x22E9FA4,
            0x22ECFB8,
            0x22ED770,
            0x22EECF8,
            0x22F0154,
            0x22F0F44,
            0x22F5C48,
            0x22F6C60,
            0x22F7D1C,
            0x22FD398,
            0x22FEEB8,
            0x2300B10,
            0x2303464,
            0x23051E4,
            0x2305FB8,
            0x2306630,
            0x2308924,
            0x2308CA8,
            0x23099E8,
            0x230F364,
            0x230FA7C,
            0x2311A70,
            0x2312314,
            0x2315B78,
            0x2319794,
            0x23198AC,
            0x231A9EC,
            0x231BBF4,
            0x231D630,
            0x231F840,
            0x231FFD8,
            0x2320664,
            0x2320BE4,
            0x23211CC,
            0x2321EA0,
            0x2326088,
            0x232F280,
            0x23349EC,
            0x2335B18,
            0x2338878,
            0x23456DC,
            0x2346284,
            0x23487A4,
            0x234A47C,
            0x234E9D0,
            0x234F820,
        ],
        None,
        "EntityIsValid",
        "Checks if an entity pointer points to a valid entity (not entity type 0, which represents no entity).\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    GetFloorType = Symbol(
        [0x4170],
        [0x22E0CF0],
        None,
        "GetFloorType",
        "Get the current floor type.\n\nFloor types:\n  0 appears to mean the current floor is 'normal'\n  1 means the current floor is a fixed floor with warp zones enabled\n  2 means the current floor has a rescue point\n\nreturn: floor type",
        None,
    )

    TryForcedLoss = Symbol(
        [0x43E0],
        [0x22E0F60],
        None,
        "TryForcedLoss",
        "Attempts to trigger a forced loss of the type specified in dungeon::forced_loss_reason.\n\nr0: if true, the function will not check for the end of the floor condition and will skip other (unknown) actions in case of forced loss.\nreturn: true if the forced loss happens, false otherwise",
        None,
    )

    IsBossFight = Symbol(
        [0x4624],
        [0x22E11A4],
        None,
        "IsBossFight",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: fixed_room_id\nreturn: bool",
        None,
    )

    IsCurrentFixedRoomBossFight = Symbol(
        [0x4640],
        [0x22E11C0],
        None,
        "IsCurrentFixedRoomBossFight",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: bool",
        None,
    )

    IsMarowakTrainingMaze = Symbol(
        [0x4660],
        [0x22E11E0],
        None,
        "IsMarowakTrainingMaze",
        "Check if the current dungeon is one of the training mazes in Marowak Dojo (this excludes Final Maze).\n\nreturn: bool",
        None,
    )

    FixedRoomIsSubstituteRoom = Symbol(
        [0x468C],
        [0x22E120C],
        None,
        "FixedRoomIsSubstituteRoom",
        "Checks if the current fixed room is the 'substitute room' (ID 0x6E).\n\nreturn: bool",
        None,
    )

    StoryRestrictionsEnabled = Symbol(
        [0x46E8],
        [0x22E1268],
        None,
        "StoryRestrictionsEnabled",
        "Returns true if certain special restrictions are enabled.\n\nIf true, you will get kicked out of the dungeon if a team member that passes the arm9::JoinedAtRangeCheck2 check faints.\n\nreturn: !dungeon::nonstory_flag || dungeon::hidden_land_flag",
        None,
    )

    GetScenarioBalanceVeneer = Symbol(
        [0x471C],
        [0x22E129C],
        None,
        "GetScenarioBalanceVeneer",
        "Likely a linker-generated veneer for GetScenarioBalance.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-",
        None,
    )

    FadeToBlack = Symbol(
        [0x4728],
        [0x22E12A8],
        None,
        "FadeToBlack",
        "Fades the screen to black across several frames.\n\nNo params.",
        None,
    )

    CheckTouchscreenArea = Symbol(
        [0x4A78],
        [0x22E15F8],
        None,
        "CheckTouchscreenArea",
        "Checks if the currently pressed touchscreen position is within the specified area.\n\nr0: Area lower X coordinate\nr1: Area lower Y coordinate\nr2: Area upper X coordinate\nr3: Area upper Y coordinate\nreturn: True if the specified area contains the currently pressed touchscreen position, false otherwise.",
        None,
    )

    GetTrapInfo = Symbol(
        [0x53C8],
        [0x22E1F48],
        None,
        "GetTrapInfo",
        "Given a trap entity, returns the pointer to the trap info struct it contains.\n\nr0: Entity pointer\nreturn: Trap data pointer",
        None,
    )

    GetItemInfo = Symbol(
        [0x53D0],
        [0x22E1F50],
        None,
        "GetItemInfo",
        "Given an item entity, returns the pointer to the item info struct it contains.\n\nr0: Entity pointer\nreturn: Item data pointer",
        None,
    )

    GetTileAtEntity = Symbol(
        [0x53E8],
        [0x22E1F68],
        None,
        "GetTileAtEntity",
        "Returns a pointer to the tile where an entity is located.\n\nr0: pointer to entity\nreturns: pointer to tile",
        None,
    )

    UpdateEntityPixelPos = Symbol(
        [0x5800],
        [0x22E2380],
        None,
        "UpdateEntityPixelPos",
        "Updates an entity's pixel_pos field using the specified pixel_position struct, or its own pos field if it's null.\n\nr0: Entity pointer\nr1: Pixel position to use, or null to use the entity's own position",
        None,
    )

    SetEntityPixelPosXY = Symbol(
        [0x5844],
        [0x22E23C4],
        None,
        "SetEntityPixelPosXY",
        "r0: Entity pointer\nr1: x\nr2: y",
        None,
    )

    IncrementEntityPixelPosXY = Symbol(
        [0x5850],
        [0x22E23D0],
        None,
        "IncrementEntityPixelPosXY",
        "r0: Entity pointer\nr1: x\nr2: y",
        None,
    )

    CreateEnemyEntity = Symbol(
        [0x5E80],
        [0x22E2A00],
        None,
        "CreateEnemyEntity",
        "Creates and initializes the entity struct of a newly spawned enemy monster. Fails if there's 16 enemies on the floor already.\n\nIt could also be used to spawn fixed room allies, since those share their slots on the entity list.\n\nr0: Monster ID\nreturn: Pointer to the newly initialized entity, or null if the entity couldn't be initialized",
        None,
    )

    SpawnTrap = Symbol(
        [0x6020],
        [0x22E2BA0],
        None,
        "SpawnTrap",
        "Spawns a trap on the floor. Fails if there are more than 64 traps already on the floor.\n\nThis modifies the appropriate fields on the dungeon struct, initializing new entries in the entity table and the trap info list.\n\nr0: trap ID\nr1: position\nr2: team (see struct trap::team)\nr3: flags (see struct trap::team)\nreturn: entity pointer for the newly added trap, or null on failure",
        None,
    )

    SpawnItemEntity = Symbol(
        [0x60D4],
        [0x22E2C54],
        None,
        "SpawnItemEntity",
        "Spawns a blank item entity on the floor. Fails if there are more than 64 items already on the floor.\n\nThis initializes a new entry in the entity table and points it to the corresponding slot in the item info list.\n\nr0: position\nreturn: entity pointer for the newly added item, or null on failure",
        None,
    )

    ShouldMinimapDisplayEntity = Symbol(
        [0x6258],
        [0x22E2DD8],
        None,
        "ShouldMinimapDisplayEntity",
        "Checks if a given entity should be displayed on the minimap\n\nr0: Entity pointer\nreturn: True if the entity should be displayed on the minimap",
        None,
    )

    ShouldDisplayEntity = Symbol(
        [0x6334],
        [0x22E2EB4],
        None,
        "ShouldDisplayEntity",
        "Checks if an entity should be displayed or not.\n\nFor example, it returns false if the entity is an invisible enemy.\nAlso used to determine if messages that involve a certain entity should be displayed or suppressed.\n\nr0: Entity pointer\nr1: (?) Seems to be 1 for monsters and 0 for items.\nreturn: True if the entity and its associated messages should be displayed, false if they shouldn't.",
        None,
    )

    ShouldDisplayEntityWrapper = Symbol(
        [0x64EC],
        [0x22E306C],
        None,
        "ShouldDisplayEntityWrapper",
        "Calls ShouldDisplayEntity with r1 = 0\n\nr0: Entity pointer\nreturn: True if the entity and its associated messages should be displayed, false if they shouldn't.",
        None,
    )

    CanSeeTarget = Symbol(
        [0x650C],
        [0x22E308C],
        None,
        "CanSeeTarget",
        "Checks if a given monster can see another monster.\n\nCalls IsPositionActuallyInSight. Also checks if the user is blinded, if the target is invisible, etc.\nThis function is almost the same as CanTargetEntity, the only difference is that the latter calls IsPositionInSight instead.\n\nr0: User entity pointer\nr1: Target entity pointer\nreturn: True if the user can see the target, false otherwise",
        None,
    )

    CanTargetEntity = Symbol(
        [0x65D0],
        [0x22E3150],
        None,
        "CanTargetEntity",
        "Checks if a monster can target another entity when controlled by the AI.\nMore specifically, it checks if the target is invisible, if the user can see invisible monsters, if the user is blinded and if the target position is in sight from the position of the user (this last check is done by calling IsPositionInSight with the user's and the target's position).\nThis function is almost the same as CanSeeTarget, the only difference is that the latter calls IsPositionActuallyInSight instead.\n\nr0: User entity pointer\nr1: Target entity pointer\nreturn: True if the user can target the target, false otherwise",
        None,
    )

    CanTargetPosition = Symbol(
        [0x6714],
        [0x22E3294],
        None,
        "CanTargetPosition",
        "Checks if a monster can target a position. This function just calls IsPositionInSight using the position of the user as the origin.\n\nr0: Entity pointer\nr1: Target position\nreturn: True if the specified monster can target the target position, false otherwise.",
        None,
    )

    PopulateActiveMonsterPtrs = Symbol(
        [0x6738],
        [0x22E32B8],
        None,
        "PopulateActiveMonsterPtrs",
        "Populates active_monster_ptrs with all valid monsters in the monster_slot_headers array.\n\nNo params.",
        None,
    )

    GetTeamMemberIndex = Symbol(
        [0x67F8],
        [0x22E3378],
        None,
        "GetTeamMemberIndex",
        "Given a pointer to an entity, returns its index on the entity list, or null if the entity can't be found on the first 4 slots of the list.\n\nr0: Pointer to the entity to find\nreturn: Index of the specified entity on the entity list, or null if it's not on the first 4 slots.",
        None,
    )

    SubstitutePlaceholderStringTags = Symbol(
        [0x6898],
        [0x22E3418],
        None,
        "SubstitutePlaceholderStringTags",
        "Replaces instances of a given placeholder tag by the string representation of the given entity.\n\nFrom the eos-move-effects docs (which are somewhat nebulous): 'Replaces the string at StringID [r0] by the string representation of the target [r1] (aka its name). Any message with the string manipulator '[string:StringID]' will use that string'.\n\nThe game uses various placeholder tags in its strings, which you can read about here: https://textbox.skytemple.org/.\n\nr0: string ID (unclear what this means)\nr1: entity pointer\nr2: ?",
        None,
    )

    UpdateMapSurveyorFlag = Symbol(
        [0x6BDC],
        [0x22E375C],
        None,
        "UpdateMapSurveyorFlag",
        "Sets the Map Surveyor flag in the dungeon struct to true if a team member has Map Surveyor, sets it to false otherwise.\n\nThis function has two variants: in the EU ROM, it will return true if the flag was changed. The NA version will return the new value of the flag instead.\n\nreturn: bool",
        None,
    )

    PointCameraToMonster = Symbol(
        [0x6C84],
        [0x22E3804],
        None,
        "PointCameraToMonster",
        "Points the camera to the specified monster.\n\nr0: Entity pointer\nr1: ?",
        None,
    )

    UpdateCamera = Symbol(
        [0x6CF4],
        [0x22E3874],
        None,
        "UpdateCamera",
        "Called every frame. Sets the camera to the right coordinates depending on the monster it points to.\n\nIt also takes care of updating the minimap, checking which elements should be shown on it, as well as whether the screen should be black due to the blinker status.\n\nr0: ?",
        None,
    )

    ItemIsActive = Symbol(
        [
            0x713C,
            0x12148,
            0x197D0,
            0x23744,
            0x26578,
            0x2BDC8,
            0x2E8D0,
            0x3246C,
            0x33704,
            0x34F14,
            0x35AD8,
            0x3901C,
            0x6BBD0,
        ],
        [
            0x22E3CBC,
            0x22EECC8,
            0x22F6350,
            0x23002C4,
            0x23030F8,
            0x2308948,
            0x230B450,
            0x230EFEC,
            0x2310284,
            0x2311A94,
            0x2312658,
            0x2315B9C,
            0x2348750,
        ],
        None,
        "ItemIsActive",
        "Checks if a monster is holding a certain item that isn't disabled by Klutz.\n\nr0: entity pointer\nr1: item ID\nreturn: bool",
        None,
    )

    GetVisibilityRange = Symbol(
        [0x716C],
        [0x22E3CEC],
        None,
        "GetVisibilityRange",
        "Returns dungeon::display_data::visibility_range. If the visibility range is 0, returns 2 instead.\n\nreturn: Visibility range of the current floor, or 2 if the visibility is 0.",
        None,
    )

    RevealWholeFloor = Symbol(
        [0x7260],
        [0x22E3DE0],
        None,
        "RevealWholeFloor",
        "Sets the luminous state for the floor and marks all the tiles on the floor as revealed.\n\nMore specifically, sets dungeon::display_data::luminous to 1, sets visibility_flags::f_revealed for all tiles on the floor, calls UpdateCamera, UpdateTrapsVisibility, UpdateMinimap and logs the message 'It became brighter on the floor!'.\n\nr0: Pointer to the entity who revealed the floor",
        None,
    )

    PlayEffectAnimationEntity = Symbol(
        [0x7414],
        [0x22E3F94],
        None,
        "PlayEffectAnimationEntity",
        "Just a guess. This appears to be paired often with GetEffectAnimationField0x19, and also has calls AnimationHasMoreFrames in a loop alongside AdvanceFrame(66) calls.\n\nThe third parameter skips the loop entirely. It seems like in this case the function might just preload some animation frames for later use??\n\nr0: entity pointer\nr1: Effect ID\nr2: appears to be a flag for actually running the animation now? If this is 0, the AdvanceFrame loop is skipped entirely.\nothers: ?\nreturn: status code, or maybe the number of frames or something? Either way, -1 seems to indicate the animation being finished or something?",
        None,
    )

    PlayEffectAnimationPos = Symbol(
        [0x760C],
        [0x22E418C],
        None,
        "PlayEffectAnimationPos",
        "Takes a position struct in r0 and converts it to a pixel position struct before calling PlayEffectAnimationPixelPos\n\nr0: Position where the effect should be played\nr1: Effect ID\nr2: Unknown flag (same as the one in PlayEffectAnimationEntity)\nreturn: Result of call to PlayEffectAnimationPixelPos",
        None,
    )

    PlayEffectAnimationPixelPos = Symbol(
        [0x7650],
        [0x22E41D0],
        None,
        "PlayEffectAnimationPixelPos",
        "Seems like a variant of PlayEffectAnimationEntity that uses pixel coordinates as its first parameter instead of an entity pointer.\n\nr0: Pixel position where the effect should be played\nr1: Effect ID\nr2: Unknown flag (same as the one in PlayEffectAnimationEntity)\nreturn: Same as PlayEffectAnimationEntity",
        None,
    )

    AnimationDelayOrSomething = Symbol(
        [0x7710],
        [0x22E4290],
        None,
        "AnimationDelayOrSomething",
        "Called whenever most (all?) animations are played. Does not return until the animation is over.\n\nMight wait until the animation is done? Contains several loops that call AdvanceFrame.\n\nr0: ?",
        None,
    )

    UpdateStatusIconFlags = Symbol(
        [0x78E4],
        [0x22E4464],
        None,
        "UpdateStatusIconFlags",
        "Sets a monster's status_icon_flags bitfield according to its current status effects. Does not affect a Sudowoodo in the 'permanent sleep' state (statuses::sleep == 0x7F).\n\nSome of the status effect in monster::statuses are used as an index to access an array, where every group of 8 bytes represents a bitmask. All masks are added in a bitwise OR and then stored in monster::status_icon.\n\nAlso sets icon flags for statuses::exposed, statuses::grudge, critical HP and lowered stats with explicit checks, and applies the effect of the Identifier Orb (see dungeon::identify_orb_flag).\n\nr0: entity pointer",
        None,
    )

    PlayEffectAnimation0x171Full = Symbol(
        [0x7E48],
        [0x22E49C8],
        None,
        "PlayEffectAnimation0x171Full",
        "Just a guess. Calls PlayEffectAnimation with data from animation ID 0x171, with the third parameter of PlayEffectAnimation set to true.\n\nr0: entity pointer",
        None,
    )

    PlayEffectAnimation0x171 = Symbol(
        [0x7E9C],
        [0x22E4A1C],
        None,
        "PlayEffectAnimation0x171",
        "Just a guess. Calls PlayEffectAnimation with data from animation ID 0x171.\n\nr0: entity pointer",
        None,
    )

    ShowPpRestoreEffect = Symbol(
        [0x8794],
        [0x22E5314],
        None,
        "ShowPpRestoreEffect",
        "Displays the graphical effect on a monster that just recovered PP.\n\nr0: entity pointer",
        None,
    )

    ShouldDisplayEntityAdvanced = Symbol(
        [0x9D00],
        [0x22E6880],
        None,
        "ShouldDisplayEntityAdvanced",
        "Returns whether or not the entity should be displayed, using the same checks as ShouldDisplayEntity except also checking whether it is visible and whether the camera entity is blinded.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    PlayEffectAnimation0x1A9 = Symbol(
        [0x9F60, 0x9FAC, 0x9FF8, 0xA044, 0xA2F4, 0xA340],
        [0x22E6AE0, 0x22E6B2C, 0x22E6B78, 0x22E6BC4, 0x22E6E74, 0x22E6EC0],
        None,
        "PlayEffectAnimation0x1A9",
        "Just a guess. Calls PlayEffectAnimation with data from animation ID 0x1A9.\n\nr0: entity pointer",
        None,
    )

    PlayEffectAnimation0x18E = Symbol(
        [0xA208],
        [0x22E6D88],
        None,
        "PlayEffectAnimation0x18E",
        "Just a guess. Calls PlayEffectAnimation with data from animation ID 0x18E.\n\nr0: entity pointer",
        None,
    )

    LoadMappaFileAttributes = Symbol(
        [0xADEC],
        [0x22E796C],
        None,
        "LoadMappaFileAttributes",
        "Note: unverified, ported from Irdkwia's notes\n\nThis function processes the monster spawn list of the current floor, checking which species can spawn, capping the amount of spawnable species on the floor to 14, randomly choosing which 14 species will spawn and ensuring that the sprite size of all the species combined does not exceed the maximum of 0x58000 bytes (352 KB). Kecleon and the Decoy are always included in the random selection.\nThe function also processes the floor's item spawn lists. When loading fixed rooms from the hidden staircase, the game forces the number of spawnable species to 0.\n\nr0: quick_saved\nr1: disable_monsters\nr2: special_process",
        None,
    )

    GetItemIdToSpawn = Symbol(
        [0xB8F4],
        [0x22E8474],
        None,
        "GetItemIdToSpawn",
        "Randomly picks an item to spawn using one of the floor's item spawn lists and returns its ID.\n\nIf the function fails to properly choose an item (due to, for example, a corrupted item list), ITEM_POKE is returned.\n\nr0: Which item list to use\nreturn: Item ID",
        None,
    )

    CopySpawnEntriesMaster = Symbol(
        [0xBA18],
        [0x22E8598],
        None,
        "CopySpawnEntriesMaster",
        "Copies the array at spawn_entries_master, starting from offset, to spawn_entries and returns the number of elements copied.\n\nr0: [output] Size 16 monster_spawn_entry array\nr1: Offset (always 0 in practice)\nreturn: int",
        None,
    )

    MonsterSpawnListPartialCopy = Symbol(
        [0xBA90],
        [0x22E8610],
        None,
        "MonsterSpawnListPartialCopy",
        "Copies all entries in the floor's monster spawn list that have a sprite size >= 6 to the specified buffer.\n\nThe parameter in r1 can be used to specify how many entries are already present in the buffer. Entries added by this function will be placed after those, and the total returned in r1 will account for existing entries as well.\n\nr0: [output] Buffer where the result will be stored\nr1: Current amount of entries in the buffer\nreturn: New amount of entries in the buffer",
        None,
    )

    IsOnMonsterSpawnList = Symbol(
        [0xBB7C],
        [0x22E86FC],
        None,
        "IsOnMonsterSpawnList",
        "Returns true if the specified monster is included in the floor's monster spawn list (the modified list after a maximum of 14 different species were chosen, not the raw list read from the mappa file).\n\nr0: Monster ID\nreturn: bool",
        None,
    )

    GetMonsterIdToSpawn = Symbol(
        [0xBBD0],
        [0x22E8750],
        None,
        "GetMonsterIdToSpawn",
        "Randomly picks a monster to spawn using the floor's monster spawn list and returns its ID.\n\nr0: the spawn weight to use (0 for normal, 1 for monster house)\nreturn: monster ID",
        None,
    )

    GetMonsterLevelToSpawn = Symbol(
        [0xBC88],
        [0x22E8808],
        None,
        "GetMonsterLevelToSpawn",
        "Get the level of the monster to be spawned, given its id.\n\nr0: monster ID\nreturn: Level of the monster to be spawned, or 1 if the specified ID can't be found on the floor's spawn table.",
        None,
    )

    AllocTopScreenStatus = Symbol(
        [0xBCF4],
        [0x22E8874],
        None,
        "AllocTopScreenStatus",
        "Allocates and initializes the top_screen_status struct when entering dungeon mode.\n\nNo params.",
        None,
    )

    FreeTopScreenStatus = Symbol(
        [0xBD74],
        [0x22E88F4],
        None,
        "FreeTopScreenStatus",
        "Gets called when leaving dungeon mode, calls FreeTopScreen and then also frees the allocated memory to the top_screen_status struct.\n\nNo params.",
        None,
    )

    InitializeTeamStats = Symbol(
        [0xBF60],
        [0x22E8AE0],
        None,
        "InitializeTeamStats",
        "Initializes the team stats top screen.\n\nreturn: always 1, seems unused",
        None,
    )

    UpdateTeamStatsWrapper = Symbol(
        [0xBFC0],
        [0x22E8B40],
        None,
        "UpdateTeamStatsWrapper",
        "Contains a check and calls UpdateTeamStats in overlay10.\n\nreturn: always 1, seems unused",
        None,
    )

    FreeTeamStatsWrapper = Symbol(
        [0xC018],
        [0x22E8B98],
        None,
        "FreeTeamStatsWrapper",
        "Calls a function that calls FreeTeamStats in overlay10.\n\nreturn: always 1, seems unused",
        None,
    )

    AssignTopScreenHandlers = Symbol(
        [0xC4F8],
        [0x22E9078],
        None,
        "AssignTopScreenHandlers",
        "Sets the handler functions of the top screen type.\n\nr0: Array where the handler function pointers get written to.\nr1: init_func\nr2: update_func\nr3: ?\nstack[0]: free_func",
        None,
    )

    HandleTopScreenFades = Symbol(
        [0xC69C],
        [0x22E921C],
        None,
        "HandleTopScreenFades",
        "Used to initialize and uninitialize the top screen in dungeon mode in conjunction with handling the fade status of the screen.\n\nFor example, when a fade out is done, it calls the necessary functions to close the top screen windows. When it starts fading in again, it re-creates all the necessary windows corresponding to the top screen type setting.\n\nNo params.",
        None,
    )

    FreeTopScreen = Symbol(
        [0xCA7C],
        [0x22E95FC],
        None,
        "FreeTopScreen",
        "Gets called twice when fading out the top screen. First it calls the free_func of the top screen type and sets the handlers to null and on the second pass it just returns.\n\nreturn: always 1, seems unused",
        None,
    )

    GetDirectionTowardsPosition = Symbol(
        [0xCE50],
        [0x22E99D0],
        None,
        "GetDirectionTowardsPosition",
        "Gets the direction in which a monster should move to go from the origin position to the target position\n\nr0: Origin position\nr1: Target position\nreturn: Direction in which to move to reach the target position from the origin position",
        None,
    )

    GetChebyshevDistance = Symbol(
        [0xCEBC],
        [0x22E9A3C],
        None,
        "GetChebyshevDistance",
        "Returns the Chebyshev distance between two positions. Calculated as max(abs(x0-x1), abs(y0-y1)).\n\nr0: Position A\nr1: Position B\nreturn: Chebyshev Distance between position A and position B",
        None,
    )

    IsPositionActuallyInSight = Symbol(
        [0xCEFC],
        [0x22E9A7C],
        None,
        "IsPositionActuallyInSight",
        "Checks if a given target position is in sight from a given origin position.\nIf the origin position is on a hallway or r2 is true, checks if both positions are within <dungeon::display_data::visibility_range> tiles of each other.\nIf the origin position is on a room, checks that the target position is within the boundaries of said room.\n\nr0: Origin position\nr1: Target position\nr2: True to assume the entity standing on the origin position has the dropeye status\nreturn: True if the target position is in sight from the origin position",
        None,
    )

    IsPositionInSight = Symbol(
        [0xCFD4],
        [0x22E9B54],
        None,
        "IsPositionInSight",
        "Checks if a given target position is in sight from a given origin position.\nThere's multiple factors that affect this check, but generally, it's true if both positions are in the same room (by checking if the target position is within the boundaries of the room where the origin position is) or within 2 tiles of each other.\n\nr0: Origin position\nr1: Target position\nr2: True to assume the entity standing on the origin position has the dropeye status\nreturn: True if the target position is in sight from the origin position",
        None,
    )

    GetLeader = Symbol(
        [0xD3B0],
        [0x22E9F30],
        None,
        "GetLeader",
        "Gets the pointer to the entity that is currently leading the team, or null if none of the first 4 entities is a valid monster with its is_team_leader flag set. It also sets LEADER_PTR to the result before returning it.\n\nreturn: Pointer to the current leader of the team or null if there's no valid leader.",
        None,
    )

    GetLeaderMonster = Symbol(
        [0xD448],
        [0x22E9FC8],
        None,
        "GetLeaderMonster",
        "Returns a pointer to the monster data of the current leader.\n\nNo params.",
        None,
    )

    FindNearbyUnoccupiedTile = Symbol(
        [0xD674],
        [0x22EA1F4],
        None,
        "FindNearbyUnoccupiedTile",
        "Searches for an unoccupied tile near some origin.\n\nA tile is considered 'unoccupied' if it's not a key door, and has no object or monster on it. In 'random room' mode, the tile must also not be in a hallway, and must not have the stairs.\n\nThe first unoccupied tile found is returned. The search order is randomized in 'random room' mode, otherwise the search order is fixed based on the input displacement array.\n\nr0: [output] position\nr1: origin position\nr2: array of displacements from the origin position to consider\nr3: number of elements in displacements array\nstack[0]: random room mode flag\nreturn: whether a tile was successfully found",
        None,
    )

    FindClosestUnoccupiedTileWithin2 = Symbol(
        [0xD820],
        [0x22EA3A0],
        None,
        "FindClosestUnoccupiedTileWithin2",
        "Searches for the closest unoccupied tile within 2 steps of the given origin.\n\nCalls FindNearbyUnoccupiedTile with DISPLACEMENTS_WITHIN_2_SMALLEST_FIRST.\n\nr0: [output] position\nr1: origin position\nr2: random room mode flag\nreturn: whether a tile was successfully found",
        None,
    )

    FindFarthestUnoccupiedTileWithin2 = Symbol(
        [0xD83C],
        [0x22EA3BC],
        None,
        "FindFarthestUnoccupiedTileWithin2",
        "Searches for the farthest unoccupied tile within 2 steps of the given origin.\n\nCalls FindNearbyUnoccupiedTile with DISPLACEMENTS_WITHIN_2_LARGEST_FIRST.\n\nr0: [output] position\nr1: origin position\nr2: random room mode flag\nreturn: whether a tile was successfully found",
        None,
    )

    FindUnoccupiedTileWithin3 = Symbol(
        [0xD858],
        [0x22EA3D8],
        None,
        "FindUnoccupiedTileWithin3",
        "Searches for an unoccupied tile within 3 steps of the given origin.\n\nCalls FindNearbyUnoccupiedTile with DISPLACEMENTS_WITHIN_3.\n\nr0: [output] position\nr1: origin position\nr2: random room mode flag\nreturn: whether a tile was successfully found",
        None,
    )

    TickStatusTurnCounter = Symbol(
        [0xD874],
        [0x22EA3F4],
        None,
        "TickStatusTurnCounter",
        "Ticks down a turn counter for a status condition. If the counter equals 0x7F, it will not be decreased.\n\nr0: pointer to the status turn counter\nreturn: new counter value",
        None,
    )

    AdvanceFrame = Symbol(
        [0xDE10],
        [0x22EA990],
        None,
        "AdvanceFrame",
        "Advances one frame. Does not return until the next frame starts.\n\nr0: ? - Unused by the function",
        None,
    )

    DisplayAnimatedNumbers = Symbol(
        [0xE548],
        [0x22EB0C8],
        None,
        "DisplayAnimatedNumbers",
        "Displays numbers or the 'MISS' text above a monster. Normally used to display damage amounts, although it also has other uses (such as showing the stockpile count).\n\nr0: Amount to display. Can be negative. 9999 displays 'MISS' instead.\nr1: Entity above which the numbers will be displayed\nr2: True to display a plus or minus sign before the numbers, false to hide it\nr3: Color of the numbers. NUMBER_COLOR_AUTO to determine it automatically.",
        None,
    )

    SetDungeonRngPreseed23Bit = Symbol(
        [0xE798],
        [0x22EB318],
        None,
        "SetDungeonRngPreseed23Bit",
        "Sets the preseed in the global dungeon PRNG state, using 23 bits from the input. See GenerateDungeonRngSeed for more information.\n\nGiven the input preseed23, the actual global preseed is set to (preseed23 & 0xFFFFFF | 1), so only bits 1-23 of the input are used.\n\nr0: preseed23",
        None,
    )

    GenerateDungeonRngSeed = Symbol(
        [0xE7B0],
        [0x22EB330],
        None,
        "GenerateDungeonRngSeed",
        "Generates a seed with which to initialize the dungeon PRNG.\n\nThe seed is calculated by starting with a different seed, the 'preseed' x0 (defaults to 1, but can be set by other functions). The preseed is iterated twice with the same recurrence relation used in the primary LCG to generate two pseudorandom 32-bit numbers x1 and x2. The output seed is then computed as\n  seed = (x1 & 0xFF0000) | (x2 >> 0x10) | 1\nThe value x1 is then saved as the new preseed.\n\nThis method of seeding the dungeon PRNG appears to be used only sometimes, depending on certain flags in the data for a given dungeon.\n\nreturn: RNG seed",
        None,
    )

    GetDungeonRngPreseed = Symbol(
        [0xE7FC],
        [0x22EB37C],
        None,
        "GetDungeonRngPreseed",
        "Gets the current preseed stored in the global dungeon PRNG state. See GenerateDungeonRngSeed for more information.\n\nreturn: current dungeon RNG preseed",
        None,
    )

    SetDungeonRngPreseed = Symbol(
        [0xE80C],
        [0x22EB38C],
        None,
        "SetDungeonRngPreseed",
        "Sets the preseed in the global dungeon PRNG state. See GenerateDungeonRngSeed for more information.\n\nr0: preseed",
        None,
    )

    InitDungeonRng = Symbol(
        [0xE81C],
        [0x22EB39C],
        None,
        "InitDungeonRng",
        "Initialize (or reinitialize) the dungeon PRNG with a given seed. The primary LCG and the five secondary LCGs are initialized jointly, and with the same seed.\n\nr0: seed",
        None,
    )

    DungeonRand16Bit = Symbol(
        [0xE850],
        [0x22EB3D0],
        None,
        "DungeonRand16Bit",
        "Computes a pseudorandom 16-bit integer using the dungeon PRNG.\n\nNote that the dungeon PRNG is only used in dungeon mode (as evidenced by these functions being in overlay 29). The game uses another lower-quality PRNG (see arm9.yml) for other needs.\n\nRandom numbers are generated with a linear congruential generator (LCG). The game actually maintains 6 separate sequences that can be used for generation: a primary LCG and 5 secondary LCGs. The generator used depends on parameters set on the global PRNG state.\n\nAll dungeon LCGs have a modulus of 2^32 and a multiplier of 1566083941 (see DUNGEON_PRNG_LCG_MULTIPLIER). The primary LCG uses an increment of 1, while the secondary LCGs use an increment of 2531011 (see DUNGEON_PRNG_LCG_INCREMENT_SECONDARY). So, for example, the primary LCG uses the recurrence relation:\n  x = (1566083941*x_prev + 1) % 2^32\n\nSince the dungeon LCGs generate 32-bit integers rather than 16-bit, the primary LCG yields 16-bit values by taking the upper 16 bits of the computed 32-bit value. The secondary LCGs yield 16-bit values by taking the lower 16 bits of the computed 32-bit value.\n\nAll of the dungeon LCGs have a hard-coded default seed of 1, but in practice the seed is set with a call to InitDungeonRng during dungeon initialization.\n\nreturn: pseudorandom int on the interval [0, 65535]",
        None,
    )

    DungeonRandInt = Symbol(
        [0xE8C8],
        [0x22EB448],
        None,
        "DungeonRandInt",
        "Compute a pseudorandom integer under a given maximum value using the dungeon PRNG.\n\nr0: high\nreturn: pseudorandom integer on the interval [0, high - 1]",
        None,
    )

    DungeonRandRange = Symbol(
        [0xE8F0],
        [0x22EB470],
        None,
        "DungeonRandRange",
        "Compute a pseudorandom value between two integers using the dungeon PRNG.\n\nIf both input integers are the same, the first is returned.\n\nr0: x\nr1: y\nreturn: pseudorandom integer on the interval [min(x, y), max(x, y) - 1], or x if x == y.",
        None,
    )

    DungeonRandOutcome = Symbol(
        [0xE950, 0xE980],
        [0x22EB4D0, 0x22EB500],
        None,
        "DungeonRandOutcome",
        "Returns the result of a possibly biased coin flip (a Bernoulli random variable) with some success probability p, using the dungeon PRNG.\n\nr0: success percentage (100*p)\nreturn: true with probability p, false with probability (1-p)",
        None,
    )

    CalcStatusDuration = Symbol(
        [0xE9B0],
        [0x22EB530],
        None,
        "CalcStatusDuration",
        "Seems to calculate the duration of a volatile status on a monster.\n\nr0: entity pointer\nr1: pointer to a turn range (an array of two shorts {lower, higher})\nr2: flag for whether or not to factor in the Self Curer IQ skill and the Natural Cure ability\nreturn: number of turns for the status condition",
        None,
    )

    DungeonRngUnsetSecondary = Symbol(
        [0xEA64],
        [0x22EB5E4],
        None,
        "DungeonRngUnsetSecondary",
        "Sets the dungeon PRNG to use the primary LCG for subsequent random number generation, and also resets the secondary LCG index back to 0.\n\nSimilar to DungeonRngSetPrimary, but DungeonRngSetPrimary doesn't modify the secondary LCG index if it was already set to something other than 0.\n\nNo params.",
        None,
    )

    DungeonRngSetSecondary = Symbol(
        [0xEA7C],
        [0x22EB5FC],
        None,
        "DungeonRngSetSecondary",
        "Sets the dungeon PRNG to use one of the 5 secondary LCGs for subsequent random number generation.\n\nr0: secondary LCG index",
        None,
    )

    DungeonRngSetPrimary = Symbol(
        [0xEA94],
        [0x22EB614],
        None,
        "DungeonRngSetPrimary",
        "Sets the dungeon PRNG to use the primary LCG for subsequent random number generation.\n\nNo params.",
        None,
    )

    MusicTableIdxToMusicId = Symbol(
        [0xEB30],
        [0x22EB6B0],
        None,
        "MusicTableIdxToMusicId",
        "Used to convert an index that refers to a MUSIC_ID_TABLE entry to a regular music ID.\n\nr0: Music table index\nreturn: Music ID",
        None,
    )

    ChangeDungeonMusic = Symbol(
        [0xEC44],
        [0x22EB7C4],
        None,
        "ChangeDungeonMusic",
        "Replace the currently playing music with the provided music\n\nr0: music ID",
        None,
    )

    TrySwitchPlace = Symbol(
        [0xEFA8],
        [0x22EBB28],
        None,
        "TrySwitchPlace",
        "The user entity attempts to switch places with the target entity (i.e. by the effect of the Switcher Orb). \n\nThe function checks for the Suction Cups ability for both the user and the target, and for the Mold Breaker ability on the user.\n\nr0: pointer to user entity\nr1: pointer to target entity",
        None,
    )

    SetLeaderActionFields = Symbol(
        [0xF1F8],
        [0x22EBD78],
        None,
        "SetLeaderActionFields",
        "Sets the leader's monster::action::action_id to the specified value.\n\nAlso sets monster::action::action_use_idx and monster::action::field_0xA to 0, as well as monster::action::field_0x10 and monster::action::field_0x12 to -1.\n\nr0: ID of the action to set",
        None,
    )

    ClearMonsterActionFields = Symbol(
        [0xF224],
        [0x22EBDA4],
        None,
        "ClearMonsterActionFields",
        "Clears the fields related to AI in the monster's data struct, setting them all to 0.\nSpecifically, monster::action::action_id, monster::action::action_use_idx and monster::action::field_0xA are cleared.\n\nr0: Pointer to the monster's action field",
        None,
    )

    SetMonsterActionFields = Symbol(
        [0xF238],
        [0x22EBDB8],
        None,
        "SetMonsterActionFields",
        "Sets some the fields related to AI in the monster's data struct.\nSpecifically, monster::action::action_id, monster::action::action_use_idx and monster::action::field_0xA. The last 2 are always set to 0.\n\nr0: Pointer to the monster's action field\nr1: Value to set monster::action::action_id to.",
        None,
    )

    SetActionPassTurnOrWalk = Symbol(
        [0xF24C],
        [0x22EBDCC],
        None,
        "SetActionPassTurnOrWalk",
        "Sets a monster's action to action::ACTION_PASS_TURN or action::ACTION_WALK, depending on the result of GetCanMoveFlag for the monster's ID.\n\nr0: Pointer to the monster's action field\nr1: Monster ID",
        None,
    )

    GetItemToUseByIndex = Symbol(
        [0xF27C],
        [0x22EBDFC],
        None,
        "GetItemToUseByIndex",
        "Returns a pointer to the item that is about to be used by a monster given its index.\n\nr0: Entity pointer\nr1: Item index\nreturn: Pointer to the item",
        None,
    )

    GetItemToUse = Symbol(
        [0xF37C],
        [0x22EBEFC],
        None,
        "GetItemToUse",
        "Returns a pointer to the item that is about to be used by a monster.\n\nr0: Entity pointer\nr1: Parameter index in monster::action_data::action_parameters. Will be used to use to determine the index of the used item.\nr2: Unused\nreturn: Pointer to the item",
        None,
    )

    GetItemAction = Symbol(
        [0xF408],
        [0x22EBF88],
        None,
        "GetItemAction",
        "Returns the action ID that corresponds to an item given its ID.\n\nThe action is based on the category of the item (see ITEM_CATEGORY_ACTIONS), unless the specified ID is 0x16B, in which case ACTION_UNK_35 is returned.\nSome items can have unexpected actions, such as thrown items, which have ACTION_NOTHING. This is done to prevent duplicate actions from being listed in the menu (since items always have a 'throw' option), since a return value of ACTION_NOTHING prevents the option from showing up in the menu.\n\nr0: Item ID\nreturn: Action ID associated with the specified item",
        None,
    )

    RemoveUsedItem = Symbol(
        [0xF43C],
        [0x22EBFBC],
        None,
        "RemoveUsedItem",
        "Removes an item from the bag or from the floor after using it\n\nr0: Pointer to the entity that used the item\nr1: Parameter index in monster::action_data::action_parameters. Will be used to use to determine the index of the used item.",
        None,
    )

    AddDungeonSubMenuOption = Symbol(
        [0xF64C],
        [0x22EC1CC],
        None,
        "AddDungeonSubMenuOption",
        "Adds an option to the list of actions that can be taken on a pokémon, item or move to the currently active sub-menu on dungeon mode (team, moves, items, etc.).\n\nr0: Action ID\nr1: True if the option should be enabled, false otherwise",
        None,
    )

    DisableDungeonSubMenuOption = Symbol(
        [0xF724],
        [0x22EC2A4],
        None,
        "DisableDungeonSubMenuOption",
        "Disables an option that was addeed to a dungeon sub-menu.\n\nr0: Action ID of the option that should be disabled",
        None,
    )

    SetActionRegularAttack = Symbol(
        [0xFA80],
        [0x22EC600],
        None,
        "SetActionRegularAttack",
        "Sets a monster's action to action::ACTION_REGULAR_ATTACK, with a specified direction.\n\nr0: Pointer to the monster's action field\nr1: Direction in which to use the move. Gets stored in monster::action::direction.",
        None,
    )

    SetActionUseMovePlayer = Symbol(
        [0xFAC8],
        [0x22EC648],
        None,
        "SetActionUseMovePlayer",
        "Sets a monster's action to action::ACTION_USE_MOVE_PLAYER, with a specified monster and move index.\n\nr0: Pointer to the monster's action field\nr1: Index of the monster that is using the move on the entity list. Gets stored in monster::action::action_use_idx.\nr2: Index of the move to use (0-3). Gets stored in monster::action::field_0xA.",
        None,
    )

    SetActionUseMoveAi = Symbol(
        [0xFAEC],
        [0x22EC66C],
        None,
        "SetActionUseMoveAi",
        "Sets a monster's action to action::ACTION_USE_MOVE_AI, with a specified direction and move index.\n\nr0: Pointer to the monster's action field\nr1: Index of the move to use (0-3). Gets stored in monster::action::action_use_idx.\nr2: Direction in which to use the move. Gets stored in monster::action::direction.",
        None,
    )

    RunFractionalTurn = Symbol(
        [0xFB38],
        [0x22EC6B8],
        None,
        "RunFractionalTurn",
        "The main function which executes the actions that take place in a fractional turn. Called in a loop by RunDungeon while IsFloorOver returns false.\n\nr0: first loop flag (true when the function is first called during a floor)",
        None,
    )

    RunLeaderTurn = Symbol(
        [0x10138],
        [0x22ECCB8],
        None,
        "RunLeaderTurn",
        "Handles the leader's turn. Includes a movement speed check that might cause it to return early if the leader isn't fast enough to act in this fractional turn. If that check (and some others) pass, the function does not return until the leader performs an action.\n\nr0: ?\nreturn: true if the leader has performed an action",
        None,
    )

    TrySpawnMonsterAndActivatePlusMinus = Symbol(
        [0x1050C],
        [0x22ED08C],
        None,
        "TrySpawnMonsterAndActivatePlusMinus",
        "Called at the beginning of RunFractionalTurn. Executed only if FRACTIONAL_TURN_SEQUENCE[fractional_turn * 2] is not 0.\n\nFirst it calls TrySpawnMonsterAndTickSpawnCounter, then tries to activate the Plus and Minus abilities for both allies and enemies, and finally calls TryForcedLoss.\n\nNo params.",
        None,
    )

    IsFloorOver = Symbol(
        [0x10618],
        [0x22ED198],
        None,
        "IsFloorOver",
        "Checks if the current floor should end, and updates dungeon::floor_loop_status if required.\nIf the player has been defeated, sets dungeon::floor_loop_status to floor_loop_status::FLOOR_LOOP_LEADER_FAINTED.\nIf dungeon::end_floor_flag is 1 or 2, sets dungeon::floor_loop_status to floor_loop_status::FLOOR_LOOP_NEXT_FLOOR.\n\nreturn: true if the current floor should end",
        None,
    )

    DecrementWindCounter = Symbol(
        [0x10978],
        [0x22ED4F8],
        None,
        "DecrementWindCounter",
        "Decrements dungeon::wind_turns and displays a wind warning message if required.\n\nNo params.",
        None,
    )

    SetForcedLossReason = Symbol(
        [0x10E38],
        [0x22ED9B8],
        None,
        "SetForcedLossReason",
        "Sets dungeon::forced_loss_reason to the specified value\n\nr0: Forced loss reason",
        None,
    )

    GetForcedLossReason = Symbol(
        [0x10E4C],
        [0x22ED9CC],
        None,
        "GetForcedLossReason",
        "Returns dungeon::forced_loss_reason\n\nreturn: forced_loss_reason",
        None,
    )

    BindTrapToTile = Symbol(
        [0x11688],
        [0x22EE208],
        None,
        "BindTrapToTile",
        "Sets the given tile's associated object to be the given trap, and sets the visibility of the trap.\n\nr0: tile pointer\nr1: entity pointer\nr2: visibility flag",
        None,
    )

    SpawnEnemyTrapAtPos = Symbol(
        [0x117A0],
        [0x22EE320],
        None,
        "SpawnEnemyTrapAtPos",
        "A convenience wrapper around SpawnTrap and BindTrapToTile. Always passes 0 for the team parameter (making it an enemy trap).\n\nr0: trap ID\nr1: x position\nr2: y position\nr3: flags\nstack[0]: visibility flag",
        None,
    )

    PrepareTrapperTrap = Symbol(
        [0x11A04],
        [0x22EE584],
        None,
        "PrepareTrapperTrap",
        "Saves the relevant information in the dungeon struct to later place a trap at the\nlocation of the entity. (Only called with trap ID 0x19 (TRAP_NONE), but could be used \nwith others).\n\nr0: entity pointer\nr1: trap ID\nr2: team (see struct trap::team)",
        None,
    )

    TrySpawnTrap = Symbol(
        [0x11AEC],
        [0x22EE66C],
        None,
        "TrySpawnTrap",
        "Checks if the a trap can be placed on the tile. If the trap ID is >= TRAP_NONE (the\nlast value for a trap), randomly select another trap (except for wonder tile). After\n30 failed attempts to select a non-wonder tile trap ID, default to chestnut trap.\nIf the checks pass, spawn the trap.\n\nr0: position\nr1: trap ID\nr2: team (see struct trap::team)\nr3: visibility flag\nreturn: true if a trap was spawned succesfully",
        None,
    )

    TrySpawnTrapperTrap = Symbol(
        [0x11C04],
        [0x22EE784],
        None,
        "TrySpawnTrapperTrap",
        "If the flag for a trapper trap is set, handles spawning a trap based upon the\ninformation inside the dungeon struct. Uses the entity for logging a message\ndepending on success or failure.\n\nr0: entity pointer\nreturn: true if a trap was spawned succesfully",
        None,
    )

    TryRemoveTrap = Symbol(
        [0x11CAC],
        [0x22EE82C],
        None,
        "TryRemoveTrap",
        "Tries to remove a trap from the tile at the passed position. It does nothing\nif there is no trap on the tile at that position.\n\nr0: position\nr1: bool update trap visibility\nreturn: whether a trap was succesfully removed or not",
        None,
    )

    TryTriggerTrap = Symbol(
        [0x11DD0],
        [0x22EE950],
        None,
        "TryTriggerTrap",
        "Called whenever a monster steps on a trap.\n\nThe function will try to trigger it. Nothing will happen if the pokémon has the same team as the trap. The attempt to trigger the trap can also fail due to IQ skills, due to the trap failing to work (random chance), etc.\n\nr0: Entity who stepped on the trap\nr1: Trap position\nr2: ?\nr3: ?",
        None,
    )

    ApplyMudTrapEffect = Symbol(
        [0x1219C],
        [0x22EED1C],
        None,
        "ApplyMudTrapEffect",
        "Randomly lowers attack, special attack, defense, or special defense of the defender by 3 stages.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyStickyTrapEffect = Symbol(
        [0x12264],
        [0x22EEDE4],
        None,
        "ApplyStickyTrapEffect",
        "If the defender is the leader, randomly try to make something in the bag sticky. Otherwise, try to make the item the monster is holding sticky.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyGrimyTrapEffect = Symbol(
        [0x12460],
        [0x22EEFE0],
        None,
        "ApplyGrimyTrapEffect",
        "If the defender is the leader, randomly try to turn food items in the toolbox into\ngrimy food. Otherwise, try to make the food item the monster is holding grimy food.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyPitfallTrapEffect = Symbol(
        [0x12654],
        [0x22EF1D4],
        None,
        "ApplyPitfallTrapEffect",
        "If the defender is the leader, end the current floor unless it has a rescue point.\nOtherwise, make the entity faint and ignore reviver seeds. If not called by a random\ntrap, break the grate on the pitfall trap.\n\nr0: attacker entity pointer\nr1: defender entity pointer\nr2: tile pointer\nr3: bool caused by random trap",
        None,
    )

    ApplySummonTrapEffect = Symbol(
        [0x127C8],
        [0x22EF348],
        None,
        "ApplySummonTrapEffect",
        "Randomly spawns 2-4 enemy monsters around the position. The entity is only used for\nlogging messages.\n\nr0: entity pointer\nr1: position",
        None,
    )

    ApplyPpZeroTrapEffect = Symbol(
        [0x12864],
        [0x22EF3E4],
        None,
        "ApplyPpZeroTrapEffect",
        "Tries to reduce the PP of one of the defender's moves to 0.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyPokemonTrapEffect = Symbol(
        [0x1294C],
        [0x22EF4CC],
        None,
        "ApplyPokemonTrapEffect",
        "Turns item in the same room as the tile at the position (usually just the entities's\nposition) into monsters. If the position is in a hallway, convert items in a 3x3 area\ncentered on the position into monsters.\n\nr0: entity pointer\nr1: position",
        None,
    )

    ApplyTripTrapEffect = Symbol(
        [0x12B60],
        [0x22EF6E0],
        None,
        "ApplyTripTrapEffect",
        "Tries to drop the defender's item and places it on the floor.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyStealthRockTrapEffect = Symbol(
        [0x12C84],
        [0x22EF804],
        None,
        "ApplyStealthRockTrapEffect",
        "Tries to apply the damage from the stealth rock trap but does nothing if the defender is a rock type.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyToxicSpikesTrapEffect = Symbol(
        [0x12D20],
        [0x22EF8A0],
        None,
        "ApplyToxicSpikesTrapEffect",
        "Tries to inflict 10 damage on the defender and then tries to poison them.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ApplyRandomTrapEffect = Symbol(
        [0x12D74],
        [0x22EF8F4],
        None,
        "ApplyRandomTrapEffect",
        "Selects a random trap that isn't a wonder tile and isn't a random trap and calls\nApplyTrapEffect on all monsters that is different from the trap's team.\n\nr0: Triggered trap\nr1: User\nr2: Target, normally same as user\nr3: Tile that contains the trap\nstack[0]: position",
        None,
    )

    ApplyGrudgeTrapEffect = Symbol(
        [0x12EA8],
        [0x22EFA28],
        None,
        "ApplyGrudgeTrapEffect",
        "Spawns several monsters around the position and gives all monsters on the floor the\ngrudge status condition.\n\nr0: entity pointer\nr1: position",
        None,
    )

    ApplyTrapEffect = Symbol(
        [0x12F88],
        [0x22EFB08],
        None,
        "ApplyTrapEffect",
        "Performs the effect of a triggered trap.\n\nThe trap's animation happens before this function is called.\n\nr0: Triggered trap\nr1: User\nr2: Target, normally same as user\nr3: Tile that contains the trap\nstack[0]: position\nstack[1]: trap ID\nstack[2]: bool caused by random trap\nreturn: True if the trap should be destroyed after the effect is applied",
        None,
    )

    RevealTrapsNearby = Symbol(
        [0x1340C],
        [0x22EFF8C],
        None,
        "RevealTrapsNearby",
        "Reveals traps within the monster's viewing range.\n\nr0: entity pointer",
        None,
    )

    ShouldRunMonsterAi = Symbol(
        [0x13820],
        [0x22F03A0],
        None,
        "ShouldRunMonsterAi",
        "Checks a monster's monster_behavior to see whether or not the monster should use AI. Only called on monsters with\na monster_behavior greater than or equal to BEHAVIOR_FIXED_ENEMY. Returns false for BEHAVIOR_FIXED_ENEMY, \nBEHAVIOR_WANDERING_ENEMY_0x8, BEHAVIOR_SECRET_BAZAAR_KIRLIA, BEHAVIOR_SECRET_BAZAAR_MIME_JR,\nBEHAVIOR_SECRET_BAZAAR_SWALOT, BEHAVIOR_SECRET_BAZAAR_LICKILICKY, and BEHAVIOR_SECRET_BAZAAR_SHEDINJA.\n\nr0: monster entity pointer\nreturn: bool",
        None,
    )

    DebugRecruitingEnabled = Symbol(
        [0x138A0],
        [0x22F0420],
        None,
        "DebugRecruitingEnabled",
        "Always returns true. Called by SpecificRecruitCheck.\n\nSeems to be a function used during development to disable recruiting. If it returns false, SpecificRecruitCheck will also return false.\n\nreturn: true",
        None,
    )

    TryActivateIqBooster = Symbol(
        [0x138A8],
        [0x22F0428],
        None,
        "TryActivateIqBooster",
        "Increases the IQ of all team members holding the IQ Booster by floor_properties::iq_booster_value amount unless the\nvalue is 0.\n\nNo params.",
        None,
    )

    IsSecretBazaarNpcBehavior = Symbol(
        [0x13938],
        [0x22F04B8],
        None,
        "IsSecretBazaarNpcBehavior",
        "Checks if a behavior ID corresponds to one of the Secret Bazaar NPCs.\n\nr0: monster behavior ID\nreturn: bool",
        None,
    )

    GetLeaderAction = Symbol(
        [0x149C0],
        [0x22F1540],
        None,
        "GetLeaderAction",
        "Returns a pointer to the action data of the current leader (field 0x4A on its monster struct).\n\nNo params.",
        None,
    )

    GetEntityTouchscreenArea = Symbol(
        [0x149E0],
        [0x22F1560],
        None,
        "GetEntityTouchscreenArea",
        "Returns the area on the touchscreen that contains the sprite of the specified entity\n\nr0: Entity pointer\nr1: [output] struct where the result should be written",
        None,
    )

    SetLeaderAction = Symbol(
        [0x14D10],
        [0x22F1890],
        None,
        "SetLeaderAction",
        "Sets the leader's action field depending on the inputs given by the player.\n\nThis function also accounts for other special situations that can force a certain action, such as when the leader is running. The function also takes care of opening the main menu when X is pressed.\nThe function generally doesn't return until the player has an action set.\n\nNo params.",
        None,
    )

    ShouldLeaderKeepRunning = Symbol(
        [0x16EC4],
        [0x22F3A44],
        None,
        "ShouldLeaderKeepRunning",
        "Determines if the leader should keep running. Returns false if the leader bumps into something, or if an action that should stop the leader takes place.\n\nreturn: True if the leader should keep running, false if it should stop.",
        None,
    )

    CheckLeaderTile = Symbol(
        [0x1746C],
        [0x22F3FEC],
        None,
        "CheckLeaderTile",
        "Checks the tile the leader just stepped on and performs any required actions, such as picking up items, triggering traps, etc.\n\nContains a switch that checks the type of the tile the leader just stepped on.\n\nNo params.",
        None,
    )

    ChangeLeader = Symbol(
        [0x17770],
        [0x22F42F0],
        None,
        "ChangeLeader",
        "Tries to change the current leader to the monster specified by dungeon::new_leader.\n\nAccounts for situations that can prevent changing leaders, such as having stolen from a Kecleon shop. If one of those situations prevents changing leaders, prints the corresponding message to the message log.\n\nNo params.",
        None,
    )

    UseSingleUseItemWrapper = Symbol(
        [0x19108],
        [0x22F5C88],
        None,
        "UseSingleUseItemWrapper",
        "Same as UseSingleUseItem, but the second parameter is determined automatically from monster::action_data::action_parameter[1]::action_use_idx.\n\nr0: User",
        None,
    )

    UseSingleUseItem = Symbol(
        [0x19134],
        [0x22F5CB4],
        None,
        "UseSingleUseItem",
        "Makes a monster use a single-use item. The item is deleted afterwards.\n\nThe item to use is determined by the user's monster::action_data::action_parameter[0].\n\nr0: User (monster who used the item)\nr1: Target (monster that consumes the item)",
        None,
    )

    UseThrowableItem = Symbol(
        [0x192F8],
        [0x22F5E78],
        None,
        "UseThrowableItem",
        "Makes a monster use a throwable item.\n\nThe item to use is determined by monster::action_data::action_parameter[0].\nIf the item's category is CATEGORY_THROWN_LINE or CATEGORY_THROWN_ARC, the game will attempt to decrement the count of the used item by 1. If it's not or there's only 1 item left, it is destroyed instead.\n\nr0: User (monster who used the item)",
        None,
    )

    ResetDamageData = Symbol(
        [0x1AC50],
        [0x22F77D0],
        None,
        "ResetDamageData",
        "Zeroes the damage data struct, which is output by the damage calculation function.\n\nr0: damage data pointer",
        None,
    )

    FreeLoadedAttackSpriteAndMore = Symbol(
        [0x1AD48],
        [0x22F78C8],
        None,
        "FreeLoadedAttackSpriteAndMore",
        "Among other things, free another data structure in the attack sprite storage area/data\n\nNo params.",
        None,
    )

    SetAndLoadCurrentAttackAnimation = Symbol(
        [0x1ADA0],
        [0x22F7920],
        None,
        "SetAndLoadCurrentAttackAnimation",
        "Load given sprite into the currently loaded attack sprite structure, replacing the previous one if already loaded.\n\nr0: pack id\nr1: file index\nreturn: sprite id in the loaded wan list",
        None,
    )

    ClearLoadedAttackSprite = Symbol(
        [0x1AE40],
        [0x22F79C0],
        None,
        "ClearLoadedAttackSprite",
        "Delete the data of the currently loaded attack sprite, if any.\nDoesn’t free the structure, which can continue to be used.\n\nNo params.",
        None,
    )

    GetLoadedAttackSpriteId = Symbol(
        [0x1AE88],
        [0x22F7A08],
        None,
        "GetLoadedAttackSpriteId",
        "Get the sprite ID (in the loaded WAN list) of the currently loaded attack sprite, or 0 if none.\n\nreturn: sprite ID",
        None,
    )

    DungeonGetTotalSpriteFileSize = Symbol(
        [0x1AEA0],
        [0x22F7A20],
        None,
        "DungeonGetTotalSpriteFileSize",
        "Checks Castform and Cherrim\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nreturn: sprite file size",
        None,
    )

    DungeonGetSpriteIndex = Symbol(
        [0x1B1C0],
        [0x22F7D40],
        None,
        "DungeonGetSpriteIndex",
        "Gets the sprite index of the specified monster on this floor\n\nr0: Monster ID\nreturn: Sprite index of the specified monster ID",
        None,
    )

    JoinedAtRangeCheck2Veneer = Symbol(
        [0x1B1E0],
        [0x22F7D60],
        None,
        "JoinedAtRangeCheck2Veneer",
        "Likely a linker-generated veneer for arm9::JoinedAtRangeCheck2.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nNo params.",
        None,
    )

    FloorNumberIsEven = Symbol(
        [0x1B1EC],
        [0x22F7D6C],
        None,
        "FloorNumberIsEven",
        "Checks if the current dungeon floor number is even (probably to determine whether an enemy spawn should be female).\n\nHas a special check to return false for Labyrinth Cave B10F (the Gabite boss fight).\n\nreturn: bool",
        None,
    )

    GetKecleonIdToSpawnByFloor = Symbol(
        [0x1B224],
        [0x22F7DA4],
        None,
        "GetKecleonIdToSpawnByFloor",
        "If the current floor number is even, returns female Kecleon's id (0x3D7), otherwise returns male Kecleon's id (0x17F).\n\nreturn: monster ID",
        None,
    )

    StoreSpriteFileIndexBothGenders = Symbol(
        [0x1B244],
        [0x22F7DC4],
        None,
        "StoreSpriteFileIndexBothGenders",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nr1: file ID",
        None,
    )

    LoadMonsterSpriteInner = Symbol(
        [0x1B30C],
        [0x22F7E8C],
        None,
        "LoadMonsterSpriteInner",
        "This is called by LoadMonsterSprite a bunch of times.\n\nr0: monster ID",
        None,
    )

    SwapMonsterWanFileIndex = Symbol(
        [0x1B40C],
        [0x22F7F8C],
        None,
        "SwapMonsterWanFileIndex",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: src_id\nr1: dst_id",
        None,
    )

    LoadMonsterSprite = Symbol(
        [0x1B48C],
        [0x22F800C],
        None,
        "LoadMonsterSprite",
        "Loads the sprite of the specified monster to use it in a dungeon.\n\nIrdkwia's notes: Handles Castform/Cherrim/Deoxys\n\nr0: monster ID\nr1: ?",
        None,
    )

    DeleteMonsterSpriteFile = Symbol(
        [0x1B5A0],
        [0x22F8120],
        None,
        "DeleteMonsterSpriteFile",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID",
        None,
    )

    DeleteAllMonsterSpriteFiles = Symbol(
        [0x1B63C],
        [0x22F81BC],
        None,
        "DeleteAllMonsterSpriteFiles",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    EuFaintCheck = Symbol(
        [0x1BD68],
        [0x22F88E8],
        None,
        "EuFaintCheck",
        "This function is exclusive to the EU ROM. Seems to perform a check to see if the monster who just fainted was a team member who should cause the minimap to be updated (or something like that, maybe related to the Map Surveyor IQ skill) and if it passes, updates the minimap.\nThe function ends by calling another 2 functions. In US ROMs, calls to EUFaintCheck are replaced by calls to those two functions. This seems to indicate that this function fixes some edge case glitch that can happen when a team member faints.\n\nr0: False if the fainted entity was a team member\nr1: True to set an unknown byte in the RAM to 1",
        None,
    )

    HandleFaint = Symbol(
        [0x1BDB8],
        [0x22F8938],
        None,
        "HandleFaint",
        "Handles a fainted pokémon (reviving does not count as fainting).\n\nr0: Fainted entity\nr1: Damage source (move ID or greater than the max move id for other causes)\nr2: Entity responsible of the fainting",
        None,
    )

    MoveMonsterToPos = Symbol(
        [0x1C47C],
        [0x22F8FFC],
        None,
        "MoveMonsterToPos",
        "Moves a monster to the target position. Used both for regular movement and special movement (like teleportation).\n\nr0: Entity pointer\nr1: X target position\nr2: Y target position\nr3: ?",
        None,
    )

    CreateMonsterSummaryFromMonster = Symbol(
        [0x1C858],
        [0x22F93D8],
        None,
        "CreateMonsterSummaryFromMonster",
        "Creates a snapshot of the condition of a monster struct in a monster_summary struct.\n\nr0: [output] monster_summary\nr1: monster",
        None,
    )

    UpdateAiTargetPos = Symbol(
        [0x1CFD0],
        [0x22F9B50],
        None,
        "UpdateAiTargetPos",
        "Given a monster, updates its target_pos field based on its current position and the direction in which it plans to attack.\n\nr0: Entity pointer",
        None,
    )

    SetMonsterTypeAndAbility = Symbol(
        [0x1D020],
        [0x22F9BA0],
        None,
        "SetMonsterTypeAndAbility",
        "Checks Forecast ability\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: target entity pointer",
        None,
    )

    TryActivateSlowStart = Symbol(
        [0x1D0C8],
        [0x22F9C48],
        None,
        "TryActivateSlowStart",
        "Runs a check over all monsters on the field for the ability Slow Start, and lowers the speed of those who have it.\n\nNo params",
        None,
    )

    TryActivateArtificialWeatherAbilities = Symbol(
        [0x1D164],
        [0x22F9CE4],
        None,
        "TryActivateArtificialWeatherAbilities",
        "Runs a check over all monsters on the field for abilities that affect the weather and changes the floor's weather accordingly.\n\nNo params",
        None,
    )

    GetMonsterApparentId = Symbol(
        [0x1D294],
        [0x22F9E14],
        None,
        "GetMonsterApparentId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: target entity pointer\nr1: current_id\nreturn: ?",
        None,
    )

    TryActivateTraceAndColorChange = Symbol(
        [0x1D37C],
        [0x22F9EFC],
        None,
        "TryActivateTraceAndColorChange",
        "Tries to activate the abilities trace and color change if possible. Called after using\na move.\n\nr0: attacker entity pointer\nr1: defender entity pointer\nr2: move pointer",
        None,
    )

    DefenderAbilityIsActive = Symbol(
        [0x1D558, 0x258B8, 0x2E834, 0x35A74, 0x46C4C, 0x568CC],
        [0x22FA0D8, 0x2302438, 0x230B3B4, 0x23125F4, 0x23237CC, 0x233344C],
        None,
        "DefenderAbilityIsActive",
        "Checks if a defender has an active ability that isn't disabled by an attacker's Mold Breaker.\n\nThere are two versions of this function, which share the same logic but have slightly different assembly. This is probably due to differences in compiler optimizations at different addresses.\n\nr0: attacker pointer\nr1: defender pointer\nr2: ability ID to check on the defender\nr3: flag for whether the attacker's ability is enabled\nreturn: bool",
        None,
    )

    IsMonster = Symbol(
        [
            0x1D5AC,
            0x2590C,
            0x2E888,
            0x33874,
            0x3C990,
            0x3E8B4,
            0x3F1F8,
            0x46CA0,
            0x714E0,
        ],
        [
            0x22FA12C,
            0x230248C,
            0x230B408,
            0x23103F4,
            0x2319510,
            0x231B434,
            0x231BD78,
            0x2323820,
            0x234E060,
        ],
        None,
        "IsMonster",
        "Checks if an entity is a monster (entity type 1).\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    TryActivateConversion2 = Symbol(
        [0x1D5D0],
        [0x22FA150],
        None,
        "TryActivateConversion2",
        "Checks for the conversion2 status and applies the type change if applicable. Called\nafter using a move.\n\nr0: attacker entity pointer\nr1: defender entity pointer\nr2: move pointer",
        None,
    )

    TryActivateTruant = Symbol(
        [0x1D67C],
        [0x22FA1FC],
        None,
        "TryActivateTruant",
        "Checks if an entity has the ability Truant, and if so tries to apply the pause status to it.\n\nr0: pointer to entity",
        None,
    )

    TryPointCameraToMonster = Symbol(
        [0x1D740],
        [0x22FA2C0],
        None,
        "TryPointCameraToMonster",
        "Attempts to place the camera on top of the specified monster.\n\nIf the camera is already on top of the specified entity, the function does nothing.\n\nr0: Entity pointer. Must be a monster, otherwise the function does nothing.\nr1: ?\nr2: ?",
        None,
    )

    RestorePpAllMovesSetFlags = Symbol(
        [0x1D900],
        [0x22FA480],
        None,
        "RestorePpAllMovesSetFlags",
        "Restores PP for all moves, clears flags move::f_consume_2_pp, move::flags2_unk5 and move::flags2_unk7, and sets flag move::f_consume_pp.\nCalled when a monster is revived.\n\nr0: pointer to entity whose moves will be restored",
        None,
    )

    CheckTeamMemberIdxVeneer = Symbol(
        [0x1DACC],
        [0x22FA64C],
        None,
        "CheckTeamMemberIdxVeneer",
        "Likely a linker-generated veneer for CheckTeamMemberIdx.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: member index\nreturn: True if the value is equal to 0x55AA or 0x5AA5",
        None,
    )

    IsMonsterIdInNormalRangeVeneer = Symbol(
        [0x1DAF4],
        [0x22FA674],
        None,
        "IsMonsterIdInNormalRangeVeneer",
        "Likely a linker-generated veneer for IsMonsterIdInNormalRange.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: monster ID\nreturn: bool",
        None,
    )

    BoostIQ = Symbol(
        [0x1DFD0],
        [0x22FAB50],
        None,
        "BoostIQ",
        "Tries to boost the target's IQ.\n\nr0: monster entity pointer\nr1: iq boost\nr2: bool suppress logs",
        None,
    )

    ShouldMonsterHeadToStairs = Symbol(
        [0x1E2BC],
        [0x22FAE3C],
        None,
        "ShouldMonsterHeadToStairs",
        "Checks if a given monster should try to reach the stairs when controlled by the AI\n\nr0: Entity pointer\nreturn: True if the monster should try to reach the stairs, false otherwise",
        None,
    )

    MewSpawnCheck = Symbol(
        [0x1E47C],
        [0x22FAFFC],
        None,
        "MewSpawnCheck",
        "If the monster id parameter is 0x97 (Mew), returns false if either dungeon::mew_cannot_spawn or the second parameter are true.\n\nCalled before spawning an enemy, appears to be checking if Mew can spawn on the current floor.\n\nr0: monster id\nr1: return false if the monster id is Mew\nreturn: bool",
        None,
    )

    TryEndStatusWithAbility = Symbol(
        [0x1E668],
        [0x22FB1E8],
        None,
        "TryEndStatusWithAbility",
        "Checks if any of the defender's active abilities would end one of their current status\nconditions. For example, if the ability Own Tempo will stop confusion.\n\nCalled after changing a monster's ability with skill swap, role play, or trace to\nremove statuses the monster should no longer be affected by.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    ExclusiveItemEffectIsActive = Symbol(
        [
            0x1EB24,
            0x23DD4,
            0x2E8AC,
            0x337A0,
            0x34F44,
            0x386CC,
            0x3D688,
            0x3E75C,
            0x47800,
            0x568A8,
            0x6BC00,
            0x6C330,
        ],
        [
            0x22FB6A4,
            0x2300954,
            0x230B42C,
            0x2310320,
            0x2311AC4,
            0x231524C,
            0x231A208,
            0x231B2DC,
            0x2324380,
            0x2333428,
            0x2348780,
            0x2348EB0,
        ],
        None,
        "ExclusiveItemEffectIsActive",
        "Checks if a monster is a team member under the effects of a certain exclusive item effect.\n\nr0: entity pointer\nr1: exclusive item effect ID\nreturn: bool",
        None,
    )

    GetTeamMemberWithIqSkill = Symbol(
        [0x1EE84],
        [0x22FBA04],
        None,
        "GetTeamMemberWithIqSkill",
        "Returns an entity pointer to the first team member which has the specified iq skill.\n\nr0: iq skill id\nreturn: pointer to entity",
        None,
    )

    TeamMemberHasEnabledIqSkill = Symbol(
        [0x1EEF0],
        [0x22FBA70],
        None,
        "TeamMemberHasEnabledIqSkill",
        "Returns true if any team member has the specified iq skill.\n\nr0: iq skill id\nreturn: bool",
        None,
    )

    TeamLeaderIqSkillIsEnabled = Symbol(
        [0x1EF0C],
        [0x22FBA8C],
        None,
        "TeamLeaderIqSkillIsEnabled",
        "Returns true the leader has the specified iq skill.\n\nr0: iq skill id\nreturn: bool",
        None,
    )

    CountMovesOutOfPp = Symbol(
        [0x1EF34],
        [0x22FBAB4],
        None,
        "CountMovesOutOfPp",
        "Returns how many of a monster's move are out of PP.\n\nr0: entity pointer\nreturn: number of moves out of PP",
        None,
    )

    HasSuperEffectiveMoveAgainstUser = Symbol(
        [0x1EF98],
        [0x22FBB18],
        None,
        "HasSuperEffectiveMoveAgainstUser",
        "Checks if the target has at least one super effective move against the user.\n\nr0: User\nr1: Target\nr2: If true, moves with a max Ginseng boost != 99 will be ignored\nreturn: True if the target has at least one super effective move against the user, false otherwise.",
        None,
    )

    TryEatItem = Symbol(
        [0x1F0A0],
        [0x22FBC20],
        None,
        "TryEatItem",
        "The user attempts to eat an item from the target.\n\nThe function tries to eat the target's held item first. If that's not possible and the target is part of the team, it attempts to eat a random edible item from the bag instead.\nFun fact: The code used to select the random bag item that will be eaten is poorly coded. As a result, there's a small chance of the first edible item in the bag being picked instead of a random one. The exact chance of this happening is (N/B)^B, where N is the amount of non-edible items in the bag and B is the total amount of items in the bag.\n\nr0: User\nr1: Target\nreturn: True if the attempt was successful",
        None,
    )

    SetDecoyAiTracker = Symbol(
        [0x1F3C4],
        [0x22FBF44],
        None,
        "SetDecoyAiTracker",
        "If there is a decoy on the floor that the entity can see, sets the entity's decoy_ai_tracker to 1 or 2,\ndepending on whether the attacker who caused the decoy status is on the team or not, respectively.\n\nr0: Entity pointer",
        None,
    )

    CheckSpawnThreshold = Symbol(
        [0x1F478],
        [0x22FBFF8],
        None,
        "CheckSpawnThreshold",
        "Checks if a given monster ID can spawn in dungeons.\n\nThe function returns true if the monster's spawn threshold value is <= SCENARIO_BALANCE_FLAG\n\nr0: monster ID\nreturn: True if the monster can spawn, false otherwise",
        None,
    )

    HasLowHealth = Symbol(
        [0x1F49C],
        [0x22FC01C],
        None,
        "HasLowHealth",
        "Checks if the entity passed is a valid monster, and if it's at low health (below 25% rounded down)\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    AreEntitiesAdjacent = Symbol(
        [0x1F504],
        [0x22FC084],
        None,
        "AreEntitiesAdjacent",
        "Checks whether two entities are adjacent or not.\n\nThe function checks all 8 possible directions.\n\nr0: First entity\nr1: Second entity\nreturn: True if both entities are adjacent, false otherwise.",
        None,
    )

    IsSpecialStoryAlly = Symbol(
        [0x1F94C],
        [0x22FC4CC],
        None,
        "IsSpecialStoryAlly",
        "Checks if a monster is a special story ally.\n\nThis is a hard-coded check that looks at the monster's 'Joined At' field. If the value is in the range [DUNGEON_JOINED_AT_BIDOOF, DUNGEON_DUMMY_0xE3], this check will return true.\n\nr0: monster pointer\nreturn: bool",
        None,
    )

    IsExperienceLocked = Symbol(
        [0x1F96C],
        [0x22FC4EC],
        None,
        "IsExperienceLocked",
        "Checks if a monster does not gain experience.\n\nThis basically just inverts IsSpecialStoryAlly, with the exception of also checking for the 'Joined At' field being DUNGEON_CLIENT (is this set for mission clients?).\n\nr0: monster pointer\nreturn: bool",
        None,
    )

    InitOtherMonsterData = Symbol(
        [0x1FCD4],
        [0x22FC854],
        None,
        "InitOtherMonsterData",
        "Initializes stats, IQ skills and moves for a given monster\n\nMight only be used when spawning fixed room monsters.\n\nr0: Entity pointer\nr1: Fixed room monster stats index\nr2: Spawn direction? (when calling this function while spawning a fixed room monster, this is the parameter value associated to the spawn action, after converting it to a direction.)",
        None,
    )

    InitEnemySpawnStats = Symbol(
        [0x1FDD4],
        [0x22FC954],
        None,
        "InitEnemySpawnStats",
        "Initializes dungeon::enemy_spawn_stats. Might do something else too.\n\nNo params.",
        None,
    )

    InitEnemyStatsAndMoves = Symbol(
        [0x200B0],
        [0x22FCC30],
        None,
        "InitEnemyStatsAndMoves",
        "Initializes the HP, Atk, Sp. Atk, Def, Sp. Def and moveset of a newly spawned enemy. Might do something else too.\n\nr0: Pointer to the monster's move list\nr1: Pointer to the monster's current HP\nr2: Pointer to the monster's offensive stats\nr3: Pointer to the monster's defensive stats",
        None,
    )

    SpawnTeam = Symbol(
        [0x20388],
        [0x22FCF08],
        None,
        "SpawnTeam",
        "Seems to initialize and spawn the team when entering a dungeon.\n\nr0: ?",
        None,
    )

    SpawnInitialMonsters = Symbol(
        [0x20BF4],
        [0x22FD774],
        None,
        "SpawnInitialMonsters",
        "Tries to spawn monsters on all the tiles marked for monster spawns. This includes normal enemies and mission targets (rescue targets, outlaws, etc.).\n\nA random initial position is selected as a starting point. Tiles are then swept over left-to-right, top-to-bottom, wrapping around when the map boundary is reached, until all tiles have been checked. The first marked tile encountered in the sweep is reserved for the mission target, but the actual spawning of the target is done last.\n\nNo params.",
        None,
    )

    SpawnMonster = Symbol(
        [0x20F00],
        [0x22FDA80],
        None,
        "SpawnMonster",
        "Spawns the given monster on a tile.\n\nr0: pointer to struct spawned_monster_data\nr1: if true, the monster cannot spawn asleep, otherwise it will randomly be asleep\nreturn: pointer to entity",
        None,
    )

    InitTeamMember = Symbol(
        [0x21230],
        [0x22FDDB0],
        None,
        "InitTeamMember",
        "Initializes a team member. Run at the start of each floor in a dungeon.\n\nr0: Monster ID\nr1: X position\nr2: Y position\nr3: Pointer to the struct containing the data of the team member to initialize\nstack[0]: ?\nstack[1]: ?\nstack[2]: ?\nstack[3]: ?\nstack[4]: ?",
        None,
    )

    InitMonster = Symbol(
        [0x21850],
        [0x22FE3D0],
        None,
        "InitMonster",
        "Initializes the monster struct within the provided entity struct.\n\nr0: ?\nr1: Pointer to the entity whose monster struct should be initialized\nr2: pointer to the entity's spawned_monster_data struct\nr3: (?) Pointer to something",
        None,
    )

    SubInitMonster = Symbol(
        [0x21C3C],
        [0x22FE7BC],
        None,
        "SubInitMonster",
        "Called by InitMonster. Initializes some fields on the monster struct.\n\nr0: pointer to monster to initialize\nr1: some flag",
        None,
    )

    MarkShopkeeperSpawn = Symbol(
        [0x22014],
        [0x22FEB94],
        None,
        "MarkShopkeeperSpawn",
        "Add a shopkeeper spawn to the list on the dungeon struct. Actual spawning is done later by SpawnShopkeepers.\n\nIf an existing entry in dungeon::shopkeeper_spawns exists with the same position, that entry is reused for the new spawn data. Otherwise, a new entry is appended to the array.\n\nr0: x position\nr1: y position\nr2: monster ID\nr3: monster behavior",
        None,
    )

    SpawnShopkeepers = Symbol(
        [0x220C8],
        [0x22FEC48],
        None,
        "SpawnShopkeepers",
        "Spawns all the shopkeepers in the dungeon struct's shopkeeper_spawns array.\n\nNo params.",
        None,
    )

    GetMaxHpAtLevel = Symbol(
        [0x22178],
        [0x22FECF8],
        None,
        "GetMaxHpAtLevel",
        "Returns the max HP of a monster given its level.\n\nr0: Monster ID\nr1: Monster level\nreturn: Max HP at the given level",
        None,
    )

    GetOffensiveStatAtLevel = Symbol(
        [0x221CC],
        [0x22FED4C],
        None,
        "GetOffensiveStatAtLevel",
        "Returns the Atk / Sp. Atk of a monster given its level, capped to 255.\n\nr0: Monster ID\nr1: Monster level\nr2: Stat index (0: Atk, 1: Sp. Atk)\nreturn: Atk / Sp. Atk at the given level",
        None,
    )

    GetDefensiveStatAtLevel = Symbol(
        [0x22234],
        [0x22FEDB4],
        None,
        "GetDefensiveStatAtLevel",
        "Returns the Def / Sp. Def of a monster given its level, capped to 255.\n\nr0: Monster ID\nr1: Monster level\nr2: Stat index (0: Def, 1: Sp. Def)\nreturn: Def / Sp. Def at the given level",
        None,
    )

    GetOutlawSpawnData = Symbol(
        [0x2229C],
        [0x22FEE1C],
        None,
        "GetOutlawSpawnData",
        "Gets outlaw spawn data for the current floor.\n\nr0: [output] Outlaw spawn data",
        None,
    )

    ExecuteMonsterAction = Symbol(
        [0x2235C],
        [0x22FEEDC],
        None,
        "ExecuteMonsterAction",
        "Executes the set action for the specified monster. Used for both AI actions and player-inputted actions. If the action is not ACTION_NOTHING, ACTION_PASS_TURN, ACTION_WALK or ACTION_UNK_4, the monster's already_acted field is set to true. Includes a switch based on the action ID that performs the action, although some of them aren't handled by said swtich.\n\nr0: Pointer to monster entity\nreturn: If the result is true, the AI is run again for the current ally, and it performs another action. This can happen up to three times.",
        None,
    )

    TryActivateFlashFireOnAllMonsters = Symbol(
        [0x23014],
        [0x22FFB94],
        None,
        "TryActivateFlashFireOnAllMonsters",
        "Checks every monster for apply_flash_fire_boost. If it's true, activates Flash Fire for the monster and sets\napply_flash_fire_boost back to false.\n\nNo params.",
        None,
    )

    HasStatusThatPreventsActing = Symbol(
        [0x23074],
        [0x22FFBF4],
        None,
        "HasStatusThatPreventsActing",
        "Returns true if the monster has any status problem that prevents it from acting\n\nr0: Entity pointer\nreturn: True if the specified monster can't act because of a status problem, false otherwise.",
        None,
    )

    GetMobilityTypeCheckSlip = Symbol(
        [0x234D8],
        [0x2300058],
        None,
        "GetMobilityTypeCheckSlip",
        "Returns the mobility type of a monster species, accounting for STATUS_SLIP.\n\nThe function also converts MOBILITY_LAVA and MOBILITY_WATER to other values if required.\n\nr0: Monster species\nr1: True if the monster can walk on water\nreturn: Mobility type",
        None,
    )

    GetMobilityTypeCheckSlipAndFloating = Symbol(
        [0x23520],
        [0x23000A0],
        None,
        "GetMobilityTypeCheckSlipAndFloating",
        "Returns the mobility type of a monster, accounting for STATUS_SLIP and the result of a call to IsFloating.\n\nr0: Entity pointer\nr1: Monster species\nreturn: Mobility type",
        None,
    )

    IsInvalidSpawnTile = Symbol(
        [0x23570],
        [0x23000F0],
        None,
        "IsInvalidSpawnTile",
        "Checks if a monster cannot spawn on the given tile for some reason.\n\nReasons include:\n- There's another monster on the tile\n- The tile is an impassable wall\n- The monster does not have the required mobility to stand on the tile\n\nr0: monster ID\nr1: tile pointer\nreturn: true means the monster CANNOT spawn on this tile",
        None,
    )

    GetMobilityTypeAfterIqSkills = Symbol(
        [0x23774],
        [0x23002F4],
        None,
        "GetMobilityTypeAfterIqSkills",
        "Modifies the given mobility type to account for All-Terrain Hiker and Absolute Mover, if the user has them.\n\nr0: Entity pointer\nr1: Mobility type\nreturn: New mobility type, after accounting for the IQ skills mentioned above",
        None,
    )

    CannotStandOnTile = Symbol(
        [0x23B48],
        [0x23006C8],
        None,
        "CannotStandOnTile",
        "Checks if a given monster cannot stand on a given tile.\n\nReasons include:\n- The coordinates of the tile are out of bounds\n- There's another monster on the tile\n- The monster does not have the required mobility to stand on the tile\n\nr0: Entity pointer\nr1: Tile pointer\nreturn: True if the monster cannot stand on the specified tile, false if it can",
        None,
    )

    CalcSpeedStage = Symbol(
        [0x23CA0],
        [0x2300820],
        None,
        "CalcSpeedStage",
        "Calculates the speed stage of a monster from its speed up/down counters. The second parameter is the weight of each counter (how many stages it will add/remove), but appears to be always 1. \nTakes modifiers into account (paralysis, snowy weather, Time Tripper). Deoxys-speed, Shaymin-sky and enemy Kecleon during a thief alert get a flat +1 always.\n\nThe calculated speed stage is both returned and saved in the monster's statuses struct.\n\nr0: pointer to entity\nr1: speed counter weight\nreturn: speed stage",
        None,
    )

    CalcSpeedStageWrapper = Symbol(
        [0x23DF8],
        [0x2300978],
        None,
        "CalcSpeedStageWrapper",
        "Calls CalcSpeedStage with a speed counter weight of 1.\n\nr0: pointer to entity\nreturn: speed stage",
        None,
    )

    GetNumberOfAttacks = Symbol(
        [0x23E08],
        [0x2300988],
        None,
        "GetNumberOfAttacks",
        "Returns the number of attacks that a monster can do in one turn (1 or 2).\n\nChecks for the abilities Swift Swim, Chlorophyll, Unburden, and for exclusive items.\n\nr0: pointer to entity\nreturns: int",
        None,
    )

    GetMonsterDisplayNameType = Symbol(
        [0x23FB4],
        [0x2300B34],
        None,
        "GetMonsterDisplayNameType",
        "Determines how the name of a monster should be displayed.\n\nr0: Entity pointer\nreturn: Display name type",
        None,
    )

    GetMonsterName = Symbol(
        [0x24010],
        [0x2300B90],
        None,
        "GetMonsterName",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: buffer\nr1: TargetInfo",
        None,
    )

    SprintfStatic = Symbol(
        [0x24174],
        [0x2300CF4],
        None,
        "SprintfStatic",
        "Statically defined copy of sprintf(3) in overlay 29. See arm9.yml for more information.\n\nr0: str\nr1: format\n...: variadic\nreturn: number of characters printed, excluding the null-terminator",
        None,
    )

    IsMonsterDrowsy = Symbol(
        [0x2435C],
        [0x2300EDC],
        None,
        "IsMonsterDrowsy",
        "Checks if a monster has the sleep, nightmare, or yawning status. Note that this excludes the napping status.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasNonvolatileNonsleepStatus = Symbol(
        [0x24390],
        [0x2300F10],
        None,
        "MonsterHasNonvolatileNonsleepStatus",
        "Checks if a monster has one of the statuses in the 'burn' group, which includes the traditionally non-volatile status conditions (except sleep) in the main series: STATUS_BURN, STATUS_POISONED, STATUS_BADLY_POISONED, STATUS_PARALYSIS, and STATUS_IDENTIFYING.\n\nSTATUS_IDENTIFYING is probably included based on enum status_id? Unless it's handled differently somehow.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasImmobilizingStatus = Symbol(
        [0x243AC],
        [0x2300F2C],
        None,
        "MonsterHasImmobilizingStatus",
        "Checks if a monster has one of the non-self-inflicted statuses in the 'freeze' group, which includes status conditions that immobilize the monster: STATUS_FROZEN, STATUS_SHADOW_HOLD, STATUS_WRAPPED, STATUS_PETRIFIED, STATUS_CONSTRICTION, and STATUS_FAMISHED.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasAttackInterferingStatus = Symbol(
        [0x243CC],
        [0x2300F4C],
        None,
        "MonsterHasAttackInterferingStatus",
        "Checks if a monster has one of the statuses in the 'cringe' group, which includes status conditions that interfere with the monster's ability to attack: STATUS_CRINGE, STATUS_CONFUSED, STATUS_PAUSED, STATUS_COWERING, STATUS_TAUNTED, STATUS_ENCORE, STATUS_INFATUATED, and STATUS_DOUBLE_SPEED.\n\nSTATUS_DOUBLE_SPEED is probably included based on enum status_id? Unless it's handled differently somehow.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasSkillInterferingStatus = Symbol(
        [0x243E8],
        [0x2300F68],
        None,
        "MonsterHasSkillInterferingStatus",
        "Checks if a monster has one of the non-self-inflicted statuses in the 'curse' group, which loosely includes status conditions that interfere with the monster's skills or ability to do things: STATUS_CURSED, STATUS_DECOY, STATUS_GASTRO_ACID, STATUS_HEAL_BLOCK, STATUS_EMBARGO.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasLeechSeedStatus = Symbol(
        [0x24434],
        [0x2300FB4],
        None,
        "MonsterHasLeechSeedStatus",
        "Checks if a monster is afflicted with Leech Seed.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasWhifferStatus = Symbol(
        [0x24450],
        [0x2300FD0],
        None,
        "MonsterHasWhifferStatus",
        "Checks if a monster has the whiffer status.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    IsMonsterVisuallyImpaired = Symbol(
        [0x2446C],
        [0x2300FEC],
        None,
        "IsMonsterVisuallyImpaired",
        "Checks if a monster's vision is impaired somehow. This includes the checks in IsBlinded, as well as STATUS_CROSS_EYED and STATUS_DROPEYE.\n\nr0: entity pointer\nr1: flag for whether to check for the held item\nreturn: bool",
        None,
    )

    IsMonsterMuzzled = Symbol(
        [0x244A8],
        [0x2301028],
        None,
        "IsMonsterMuzzled",
        "Checks if a monster has the muzzled status.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasMiracleEyeStatus = Symbol(
        [0x244C4],
        [0x2301044],
        None,
        "MonsterHasMiracleEyeStatus",
        "Checks if a monster has the Miracle Eye status.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    MonsterHasNegativeStatus = Symbol(
        [0x244E0],
        [0x2301060],
        None,
        "MonsterHasNegativeStatus",
        "Checks if a monster has any 'negative' status conditions. This includes a wide variety of non-self-inflicted statuses that could traditionally be viewed as actual 'status conditions', as well as speed being lowered and moves being sealed.\n\nr0: entity pointer\nr1: flag for whether to check for the held item (see IsMonsterVisuallyImpaired)\nreturn: bool",
        None,
    )

    IsMonsterSleeping = Symbol(
        [0x24654],
        [0x23011D4],
        None,
        "IsMonsterSleeping",
        "Checks if a monster has the sleep, nightmare, or napping status.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    CheckVariousStatuses2 = Symbol(
        [0x246C4],
        [0x2301244],
        None,
        "CheckVariousStatuses2",
        "Returns 0 if none of these conditions holds for the given entity:\nblinded (checked only if blind_check == 1),\nasleep, frozen, paused, infatuated, wrapping, wrapped, biding, petrified, or terrified.\n\nr0: Entity pointer\nr1: If true, return 1 if entity is blinded\nreturn: bool",
        None,
    )

    CheckVariousConditions = Symbol(
        [0x249EC],
        [0x230156C],
        None,
        "CheckVariousConditions",
        "Returns 0 if none of these conditions holds for the given entity: is a rescue client,\ndoesn’t gain experience (a mission client/story teammate?), is a terrified non-team-leader,\nmeets any of the conditions in CheckVariousStatuses2 (with blind_check = 0), is charging a two-turn move.\n\nr0: Entity pointer\nreturn: bool",
        None,
    )

    CheckVariousStatuses = Symbol(
        [0x24B5C],
        [0x23016DC],
        None,
        "CheckVariousStatuses",
        "Returns 0 if none of these conditions holds for the given entity: asleep, frozen, petrified, biding.\n\nr0: Entity pointer\nreturn: bool",
        None,
    )

    CanMonsterMoveInDirection = Symbol(
        [0x24D24],
        [0x23018A4],
        None,
        "CanMonsterMoveInDirection",
        "Checks if the given monster can move in the specified direction\n\nReturns false if any monster is standing on the target tile\n\nr0: Monster entity pointer\nr1: Direction to check\nreturn: bool",
        None,
    )

    GetDirectionalMobilityType = Symbol(
        [0x24DDC],
        [0x230195C],
        None,
        "GetDirectionalMobilityType",
        "Returns the mobility type of a monster, after accounting for things that could affect it.\n\nList of checks: Mobile status, Mobile Scarf, All-Terrain Hiker and Absolute Mover.\n\nIf the specified direction is DIR_NONE, direction checks are skipped. If it's not, MOBILITY_INTANGIBLE is only returned if the direction is not diagonal.\n\nr0: Monster entity pointer\nr1: Base mobility type\nr2: Direction of mobility\nreturn: Final mobility type",
        None,
    )

    IsMonsterCornered = Symbol(
        [0x24FC4],
        [0x2301B44],
        None,
        "IsMonsterCornered",
        "True if the given monster is cornered (it can't move in any direction)\n\nr0: Entity pointer\nreturn: True if the monster can't move in any direction, false otherwise.",
        None,
    )

    CanAttackInDirection = Symbol(
        [0x250E0],
        [0x2301C60],
        None,
        "CanAttackInDirection",
        "Returns whether a monster can attack in a given direction.\nThe check fails if the destination tile is impassable, contains a monster that isn't of type entity_type::ENTITY_MONSTER or if the monster can't directly move from the current tile into the destination tile.\n\nr0: Entity pointer\nr1: Direction\nreturn: True if the monster can attack into the tile adjacent to them in the specified direction, false otherwise.",
        None,
    )

    CanAiMonsterMoveInDirection = Symbol(
        [0x251A4],
        [0x2301D24],
        None,
        "CanAiMonsterMoveInDirection",
        "Checks whether an AI-controlled monster can move in the specified direction.\nAccounts for walls, other monsters on the target position and IQ skills that might prevent a monster from moving into a specific location, such as House Avoider, Trap Avoider or Lava Evader.\n\nr0: Entity pointer\nr1: Direction\nr2: [output] True if movement was not possible because there was another monster on the target tile, false otherwise.\nreturn: True if the monster can move in the specified direction, false otherwise.",
        None,
    )

    ShouldMonsterRunAway = Symbol(
        [0x25464],
        [0x2301FE4],
        None,
        "ShouldMonsterRunAway",
        "Checks if a monster should run away from other monsters\n\nr0: Entity pointer\nreturn: True if the monster should run away, false otherwise",
        None,
    )

    ShouldMonsterRunAwayVariation = Symbol(
        [0x25554],
        [0x23020D4],
        None,
        "ShouldMonsterRunAwayVariation",
        "Calls ShouldMonsterRunAway and returns its result. It also calls another function if the result was true.\n\nr0: Entity pointer\nr1: ?\nreturn: Result of the call to ShouldMonsterRunAway",
        None,
    )

    GetTreatmentBetweenMonsters = Symbol(
        [0x25608],
        [0x2302188],
        None,
        "GetTreatmentBetweenMonsters",
        "Called to check if a monster should treat another as an ally, enemy, or ignore it.\n(Examples of the 'ignore' case: target is a shopkeeper, there is a decoy on the floor, etc.)\n\nr0: Pointer to entity 1\nr1: Pointer to entity 2\nr2: If false, return TREATMENT_IGNORE if entity 2 is invisible and entity 1 cannot see invisible monsters\nr3: If true, return TREATMENT_IGNORE if entity 1 is a team member and entity 2 has the STATUS_PETRIFIED status\nreturn: Treatment that monster 1 should apply to monster 2",
        None,
    )

    SafeguardIsActive = Symbol(
        [0x257EC],
        [0x230236C],
        None,
        "SafeguardIsActive",
        "Checks if the monster is under the effect of Safeguard.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message\nreturn: bool",
        None,
    )

    LeafGuardIsActive = Symbol(
        [0x25840],
        [0x23023C0],
        None,
        "LeafGuardIsActive",
        "Checks if the monster is protected by the ability Leaf Guard.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message\nreturn: bool",
        None,
    )

    IsProtectedFromStatDrops = Symbol(
        [0x259D8],
        [0x2302558],
        None,
        "IsProtectedFromStatDrops",
        "Checks if the target monster is protected from getting their stats dropped by the user.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message\nreturn: bool",
        None,
    )

    NoGastroAcidStatus = Symbol(
        [0x25B88],
        [0x2302708],
        None,
        "NoGastroAcidStatus",
        "Checks if a monster does not have the Gastro Acid status.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    AbilityIsActive = Symbol(
        [0x25BBC],
        [0x230273C],
        None,
        "AbilityIsActive",
        "Checks if a monster has a certain ability that isn't disabled by Gastro Acid.\n\nr0: entity pointer\nr1: ability ID\nreturn: bool",
        None,
    )

    AbilityIsActiveVeneer = Symbol(
        [0x25C24],
        [0x23027A4],
        None,
        "AbilityIsActiveVeneer",
        "Likely a linker-generated veneer for AbilityIsActive.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: entity pointer\nr1: ability ID\nreturn: bool",
        None,
    )

    OtherMonsterAbilityIsActive = Symbol(
        [0x25C30],
        [0x23027B0],
        None,
        "OtherMonsterAbilityIsActive",
        "Checks if there are any other monsters on the floor besides the user that have the specified ability active, subject to the user being on the floor.\n\nIt also seems like there might be some other range or validity check, so this might not actually check ALL other monsters?\n\nr0: user entity pointer\nr1: ability ID\nreturn: bool",
        None,
    )

    LevitateIsActive = Symbol(
        [0x25CC4],
        [0x2302844],
        None,
        "LevitateIsActive",
        "Checks if a monster is levitating (has the effect of Levitate and Gravity is not active).\n\nr0: pointer to entity\nreturn: bool",
        None,
    )

    MonsterIsType = Symbol(
        [0x25CFC],
        [0x230287C],
        None,
        "MonsterIsType",
        "Checks if a monster is a given type.\n\nr0: entity pointer\nr1: type ID\nreturn: bool",
        None,
    )

    IsTypeAffectedByGravity = Symbol(
        [0x25D34],
        [0x23028B4],
        None,
        "IsTypeAffectedByGravity",
        "Checks if Gravity is active and that the given type is affected (i.e., Flying type).\n\nr0: target entity pointer (unused)\nr1: type ID\nreturn: bool",
        None,
    )

    HasTypeAffectedByGravity = Symbol(
        [0x25D58],
        [0x23028D8],
        None,
        "HasTypeAffectedByGravity",
        "Checks if Gravity is active and that the given monster is of an affected type (i.e., Flying type).\n\nr0: target entity pointer\nr1: type ID\nreturn: bool",
        None,
    )

    CanSeeInvisibleMonsters = Symbol(
        [0x25D98],
        [0x2302918],
        None,
        "CanSeeInvisibleMonsters",
        "Returns whether a certain monster can see other invisible monsters.\nTo be precise, this function returns true if the monster is holding Goggle Specs or if it has the status status::STATUS_EYEDROPS.\n\nr0: Entity pointer\nreturn: True if the monster can see invisible monsters.",
        None,
    )

    HasDropeyeStatus = Symbol(
        [0x25DFC],
        [0x230297C],
        None,
        "HasDropeyeStatus",
        "Returns whether a certain monster is under the effect of status::STATUS_DROPEYE.\n\nr0: Entity pointer\nreturn: True if the monster has dropeye status.",
        None,
    )

    IqSkillIsEnabled = Symbol(
        [0x25E2C],
        [0x23029AC],
        None,
        "IqSkillIsEnabled",
        "Checks if a monster has a certain IQ skill enabled.\n\nr0: entity pointer\nr1: IQ skill ID\nreturn: bool",
        None,
    )

    UpdateIqSkills = Symbol(
        [0x25E68],
        [0x23029E8],
        None,
        "UpdateIqSkills",
        "Updates the IQ skill flags of a monster.\n\nIf the monster is a team member, copies monster::iq_skill_menu_flags to monster::iq_skill_flags. If the monster is an enemy, enables all the IQ skills it can learn (except a few that are only enabled in enemies that have a certain amount of IQ).\nIf the monster is an enemy, it also sets its tactic to TACTIC_GO_AFTER_FOES.\nCalled after exiting the IQ skills menu or after an enemy spawns.\n\nr0: monster pointer",
        None,
    )

    GetMoveTypeForMonster = Symbol(
        [0x26128],
        [0x2302CA8],
        None,
        "GetMoveTypeForMonster",
        "Check the type of a move when used by a certain monster. Accounts for special cases such as Hidden Power, Weather Ball, the regular attack...\n\nr0: Entity pointer\nr1: Pointer to move data\nreturn: Type of the move",
        None,
    )

    GetMovePower = Symbol(
        [0x261C8],
        [0x2302D48],
        None,
        "GetMovePower",
        "Gets the power of a move, factoring in Ginseng/Space Globe boosts.\n\nr0: user pointer\nr1: move pointer\nreturn: move power",
        None,
    )

    MonsterCanThrowItems = Symbol(
        [0x26214],
        [0x2302D94],
        None,
        "MonsterCanThrowItems",
        "Returns a boolean indicating whether or not the given monster can throw items based on its monster id.\n\nr0: Monster pointer\nreturn: bool",
        None,
    )

    UpdateStateFlags = Symbol(
        [0x2626C],
        [0x2302DEC],
        None,
        "UpdateStateFlags",
        "Updates monster::state_flags and monster::prev_state_flags with new values.\n\nr0: monster pointer\nr1: bitmask for bits to update\nr2: whether to set the bits indicated by the mask to 1 or 0\nreturn: whether or not any of the masked bits changed from the previous state",
        None,
    )

    IsProtectedFromNegativeStatus = Symbol(
        [0x262DC],
        [0x2302E5C],
        None,
        "IsProtectedFromNegativeStatus",
        "Checks if the target monster is protected from getting a negative status condition.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message\nreturn: bool",
        None,
    )

    AddExpSpecial = Symbol(
        [0x263E8],
        [0x2302F68],
        None,
        "AddExpSpecial",
        "Adds to a monster's experience points, subject to experience boosting effects.\n\nThis function appears to be called only under special circumstances. Possibly when granting experience from damage (e.g., Joy Ribbon)?\n\nInterestingly, the parameter in r0 isn't actually used. This might be a compiler optimization to avoid shuffling registers, since this function might be called alongside lots of other functions that have both the attacker and defender as the first two arguments.\n\nr0: attacker pointer\nr1: defender pointer\nr2: base experience gain, before boosts",
        None,
    )

    EnemyEvolution = Symbol(
        [0x265A8],
        [0x2303128],
        None,
        "EnemyEvolution",
        "Checks if any enemies on the floor should evolve and attempts to evolve it. The\nentity pointer passed seems to get replaced by a generic placeholder entity if the\nentity pointer passed is invalid.\n\nr0: entity pointer",
        None,
    )

    LevelUpItemEffect = Symbol(
        [0x26908],
        [0x2303488],
        None,
        "LevelUpItemEffect",
        "Attempts to level up the target. Calls LevelUp with a few extra checks and messages\nfor using as an item. Used for the Joy Seed and Golden Seed.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of levels\nr3: bool message flag?\nstack[0]: bool show level up dialogue (for example 'Hey, I leveled up!' with a portrait)?",
        None,
    )

    TryDecreaseLevel = Symbol(
        [0x26E34],
        [0x23039B4],
        None,
        "TryDecreaseLevel",
        "Decrease the target monster's level if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of levels to decrease\nreturn: success flag",
        None,
    )

    LevelUp = Symbol(
        [0x26EE8],
        [0x2303A68],
        None,
        "LevelUp",
        "Attempts to level up the target. Fails if the target's level can't be raised. The show level up dialogue bool does nothing for monsters not on the team.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: bool message flag?\nr3: bool show level up dialogue (for example 'Hey, I leveled up!' with a portrait)?\nreturn: success flag",
        None,
    )

    GetMonsterMoves = Symbol(
        [0x279C4],
        [0x2304544],
        None,
        "GetMonsterMoves",
        "Determines the moveset of a newly spawned monster given its species and level.\n\nThe function loops the monster's learnset, adding moves to the list in level-up order. Once all four slots are filled up, a random existing move gets replaced to make room for the new one. This means that the monster will always have the latest move it can learn given its level.\n\nr0: [output] Pointer to move ID list (4 entries, 2 bytes each)\nr1: Monster ID\nr2: Monster level",
        None,
    )

    EvolveMonster = Symbol(
        [0x27B28],
        [0x23046A8],
        None,
        "EvolveMonster",
        "Makes the specified monster evolve into the specified species. Has a special case when\na monster evolves into Ninjask and tries to spawn a Shedinja as well.\n\nr0: user entity pointer?\nr1: target pointer to the entity to evolve\nr2: Species to evolve into",
        None,
    )

    ChangeMonsterAnimation = Symbol(
        [0x28854],
        [0x23053D4],
        None,
        "ChangeMonsterAnimation",
        "Changes the animation a monster is currently playing. Optionally changes their direction as well.\n\nDoes nothing if the provided entity is not a monster.\n\nr0: Entity pointer\nr1: ID of the animation to set\nr2: Direction to turn the monster in, or DIR_NONE to keep the current direction",
        None,
    )

    GetIdleAnimationId = Symbol(
        [0x28960],
        [0x23054E0],
        None,
        "GetIdleAnimationId",
        "Returns the animation id to be applied to a monster that is currently idling.\n\nReturns a different animation for monsters with the sleep, napping, nightmare or bide status, as well as for sudowoodo and for monsters with infinite sleep turns (0x7F).\n\nr0: pointer to entity\nreturn: animation ID",
        None,
    )

    DisplayActions = Symbol(
        [0x28E8C],
        [0x2305A0C],
        None,
        "DisplayActions",
        "Graphically displays any pending actions that have happened but haven't been shown on screen yet. All actions are displayed at the same time. For example, this delayed display system is used to display multiple monsters moving at once even though they take turns sequentially.\n\nr0: Pointer to an entity. Can be null.\nreturns: Seems to be true if there were any pending actions to display.",
        None,
    )

    CheckNonLeaderTile = Symbol(
        [0x29540],
        [0x23060C0],
        None,
        "CheckNonLeaderTile",
        "Similar to CheckLeaderTile, but for other monsters.\n\nUsed both for enemies and team members.\n\nr0: Entity pointer",
        None,
    )

    EndNegativeStatusCondition = Symbol(
        [0x29770],
        [0x23062F0],
        None,
        "EndNegativeStatusCondition",
        "Cures the target's negative status conditions. The game rarely (if not never) calls\nthis function with the bool to remove the wrapping status false.\n\nr0: pointer to user\nr1: pointer to target\nr2: bool play animation\nr3: bool log failure message\nstack[0]: bool remove wrapping status\nreturn: bool succesfully removed negative status",
        None,
    )

    EndNegativeStatusConditionWrapper = Symbol(
        [0x29AD4],
        [0x2306654],
        None,
        "EndNegativeStatusConditionWrapper",
        "Calls EndNegativeStatusCondition with remove wrapping status false.\n\nr0: pointer to user\nr1: pointer to target\nr2: bool play animation\nr3: bool log failure message\nreturn: bool succesfully removed negative status",
        None,
    )

    TransferNegativeStatusCondition = Symbol(
        [0x29AE8],
        [0x2306668],
        None,
        "TransferNegativeStatusCondition",
        "Transfers all negative status conditions the user has and gives then to the target.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    EndSleepClassStatus = Symbol(
        [0x29E88],
        [0x2306A08],
        None,
        "EndSleepClassStatus",
        "Cures the target's sleep, sleepless, nightmare, yawn or napping status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndBurnClassStatus = Symbol(
        [0x2A054],
        [0x2306BD4],
        None,
        "EndBurnClassStatus",
        "Cures the target's burned, poisoned, badly poisoned or paralysis status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndFrozenClassStatus = Symbol(
        [0x2A104],
        [0x2306C84],
        None,
        "EndFrozenClassStatus",
        "Cures the target's freeze, shadow hold, ingrain, petrified, constriction or wrap (both as user and as target) status due to the action of the user.\n\nr0: pointer to user\nr1: pointer to target\nr2: if true, the event will be printed to the log",
        None,
    )

    EndCringeClassStatus = Symbol(
        [0x2A280],
        [0x2306E00],
        None,
        "EndCringeClassStatus",
        "Cures the target's cringe, confusion, cowering, pause, taunt, encore or infatuated status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndReflectClassStatus = Symbol(
        [0x2A3A0],
        [0x2306F20],
        None,
        "EndReflectClassStatus",
        "Removes the target's reflect, safeguard, light screen, counter, magic coat, wish, protect, mirror coat, endure, mini counter?, mirror move, conversion 2, vital throw, mist, metal burst, aqua ring or lucky chant status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    TryRemoveSnatchedMonsterFromDungeonStruct = Symbol(
        [0x2A584],
        [0x2307104],
        None,
        "TryRemoveSnatchedMonsterFromDungeonStruct",
        "If the target is afflicted with snatch, change dungeon::snatch_monster and dungeon::snatch_status_unique_id back\nto NULL and 0 respectively. This function does not actually remove the status and visual flags for snatch from\nthe monster, it simply removes it from the dungeon struct. After calling, the user should ensure the monster\ndoes not still have the snatch status.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndCurseClassStatus = Symbol(
        [0x2A5D4],
        [0x2307154],
        None,
        "EndCurseClassStatus",
        "Removes the target's curse (1), decoy (2), snatch (3), gastro acid (4), heal block (5), or embargo (6) status\ndue to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target\nr2: curse class status being afflicted after (0 is the status is only being removed)\nr3: flag to log a message",
        None,
    )

    EndLeechSeedClassStatus = Symbol(
        [0x2A770],
        [0x23072F0],
        None,
        "EndLeechSeedClassStatus",
        "Cures the target's leech seed or destiny bond status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndSureShotClassStatus = Symbol(
        [0x2A7FC],
        [0x230737C],
        None,
        "EndSureShotClassStatus",
        "Removes the target's sure shot, whiffer, set damage or focus energy status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndInvisibleClassStatus = Symbol(
        [0x2A8AC],
        [0x230742C],
        None,
        "EndInvisibleClassStatus",
        "Removes the target's invisible, transformed, mobile, or slip status due to the action of the user, and prints\nthe event to the log.\n\nr0: pointer to user\nr1: pointer to target\nr2: flag to not log a message when removing slip status",
        None,
    )

    EndBlinkerClassStatus = Symbol(
        [0x2A9D4],
        [0x2307554],
        None,
        "EndBlinkerClassStatus",
        "Removes the target's blinker, cross-eyed, eyedrops, or dropeye status due to the action of the user, and\nprints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndMuzzledStatus = Symbol(
        [0x2AAA4],
        [0x2307624],
        None,
        "EndMuzzledStatus",
        "Removes the target's muzzled status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndMiracleEyeStatus = Symbol(
        [0x2AB10],
        [0x2307690],
        None,
        "EndMiracleEyeStatus",
        "Removes the target's miracle eye status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    EndMagnetRiseStatus = Symbol(
        [0x2AB7C],
        [0x23076FC],
        None,
        "EndMagnetRiseStatus",
        "Removes the target's magnet rise status due to the action of the user, and prints the event to the log.\n\nr0: pointer to user\nr1: pointer to target",
        None,
    )

    TransferNegativeBlinkerClassStatus = Symbol(
        [0x2B798],
        [0x2308318],
        None,
        "TransferNegativeBlinkerClassStatus",
        "Tries to transfer the negative blinker class status conditions from the user to\nthe target.\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: Whether or not the status could be transferred",
        None,
    )

    EndFrozenStatus = Symbol(
        [0x2BB24],
        [0x23086A4],
        None,
        "EndFrozenStatus",
        "Cures the target's freeze status due to the action of the user.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    EndProtectStatus = Symbol(
        [0x2BBC4],
        [0x2308744],
        None,
        "EndProtectStatus",
        "Ends the target's protect status due to the action of the user.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryRestoreRoostTyping = Symbol(
        [0x2BC00],
        [0x2308780],
        None,
        "TryRestoreRoostTyping",
        "Tries to restore the target's original typings before the Roost effect took place. Does nothing if the target\nis not affected by Roost.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryTriggerMonsterHouse = Symbol(
        [0x2BDF8],
        [0x2308978],
        None,
        "TryTriggerMonsterHouse",
        "Triggers a Monster House for an entity, if the right conditions are met.\n\nConditions: entity is valid and on the team, the tile is a Monster House tile, and the Monster House hasn't already been triggered.\n\nThis function sets the monster_house_triggered flag on the dungeon struct, spawns a bunch of enemies around the triggering entity (within a 4 tile radius), and handles the 'dropping down' animation for these enemies. If the allow outside enemies flag is set, the enemy spawns can be on any free tile (no monster) with open terrain, including in hallways. Otherwise, spawns are confined within the room boundaries.\n\nr0: entity for which the Monster House should be triggered\nr1: allow outside enemies flag (in practice this is always set to dungeon_generation_info::force_create_monster_house)",
        None,
    )

    ShouldMonsterFollowLeader = Symbol(
        [0x2C14C],
        [0x2308CCC],
        None,
        "ShouldMonsterFollowLeader",
        "Checks if the monster should follow the leader. Always returns false for enemy monsters.\nThis function may actually be should monster target leader position.\n\nr0: Pointer to monster\nreturn: bool",
        None,
    )

    RunMonsterAi = Symbol(
        [0x2C1EC],
        [0x2308D6C],
        None,
        "RunMonsterAi",
        "Runs the AI for a single monster to determine whether the monster can act and which action it should perform if so\n\nr0: Pointer to monster\nr1: ?",
        None,
    )

    ApplyDamageAndEffects = Symbol(
        [0x2C4E8],
        [0x2309068],
        None,
        "ApplyDamageAndEffects",
        "Calls ApplyDamage, then performs various 'post-damage' effects such as counter damage, statuses from abilities that activate on contact, and probably some other stuff.\n\nNote that this doesn't include the effect of Illuminate, which is specifically handled elsewhere.\n\nr0: attacker pointer\nr1: defender pointer\nr2: damage_data pointer\nr3: False Swipe flag (see ApplyDamage)\nstack[0]: experience flag (see ApplyDamage)\nstack[1]: Damage source (see HandleFaint)\nstack[2]: defender response flag. If true, the defender can respond to the attack with various effects. If false, the only post-damage effect that can happen is the Rage attack boost.",
        None,
    )

    ApplyDamage = Symbol(
        [0x2CE8C],
        [0x2309A0C],
        None,
        "ApplyDamage",
        "Applies damage to a monster. Displays the damage animation, lowers its health and handles reviving if applicable.\nThe EU version has some additional checks related to printing fainting messages under specific circumstances.\n\nr0: Attacker pointer\nr1: Defender pointer\nr2: Pointer to the damage_data struct that contains info about the damage to deal\nr3: False Swipe flag, causes the defender's HP to be set to 1 if it would otherwise have been 0\nstack[0]: experience flag, controls whether or not experience will be granted upon a monster fainting, and whether enemy evolution might be triggered\nstack[1]: Damage source (see HandleFaint)\nreturn: True if the target fainted (reviving does not count as fainting)",
        None,
    )

    AftermathCheck = Symbol(
        [0x2E900],
        [0x230B480],
        None,
        "AftermathCheck",
        "Checks if the defender has the Aftermath ability and tries to activate it if so (50% chance).\n\nThe ability won't trigger if the damage source is DAMAGE_SOURCE_EXPLOSION.\n\nr0: Attacker pointer\nr1: Defender pointer\nr2: Damage source\nreturn: True if Aftermath was activated, false if it wasn't",
        None,
    )

    GetTypeMatchupBothTypes = Symbol(
        [0x2E980],
        [0x230B500],
        None,
        "GetTypeMatchupBothTypes",
        "Gets the type matchup for a given combat interaction, accounting for both of the user's types.\n\nCalls GetTypeMatchup twice and combines the result.\n\nr0: attacker pointer\nr1: defender pointer\nr2: attack type\nreturn: enum type_matchup",
        None,
    )

    ScrappyShouldActivate = Symbol(
        [0x2EA4C],
        [0x230B5CC],
        None,
        "ScrappyShouldActivate",
        "Checks whether Scrappy should activate.\n\nScrappy activates when the ability is active on the attacker, the move type is Normal or Fighting, and the defender is a Ghost type.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move type ID\nreturn: bool",
        None,
    )

    IsTypeIneffectiveAgainstGhost = Symbol(
        [0x2EAE4],
        [0x230B664],
        None,
        "IsTypeIneffectiveAgainstGhost",
        "Checks whether a type is normally ineffective against Ghost, i.e., it's Normal or Fighting.\n\nr0: type ID\nreturn: bool",
        None,
    )

    GhostImmunityIsActive = Symbol(
        [0x2EAF8],
        [0x230B678],
        None,
        "GhostImmunityIsActive",
        "Checks whether the defender's typing would give it Ghost immunities.\n\nThis only checks one of the defender's types at a time. It checks whether the defender has the exposed status and whether the attacker has the Scrappy-like exclusive item effect, but does NOT check whether the attacker has the Scrappy ability.\n\nr0: attacker pointer\nr1: defender pointer\nr2: defender type index (0 the defender's first type, 1 for the defender's second type)\nreturn: bool",
        None,
    )

    GetTypeMatchup = Symbol(
        [0x2EB4C],
        [0x230B6CC],
        None,
        "GetTypeMatchup",
        "Gets the type matchup for a given combat interaction.\n\nNote that the actual monster's types on the attacker and defender pointers are not used; the pointers are only used to check conditions. The actual type matchup table lookup is done solely using the attack and target type parameters.\n\nThis factors in some conditional effects like exclusive items, statuses, etc. There's some weirdness with the Ghost type; see the comment for struct type_matchup_table.\n\nr0: attacker pointer\nr1: defender pointer\nr2: target type index (0 the target's first type, 1 for the target's second type)\nr3: attack type\nreturn: enum type_matchup",
        None,
    )

    CalcTypeBasedDamageEffects = Symbol(
        [0x2EBF8],
        [0x230B778],
        None,
        "CalcTypeBasedDamageEffects",
        "Calculates type-based effects on damage.\n\nLoosely, this includes type matchup effects (including modifications due to abilities, IQ skills, and exclusive items), STAB, pinch abilities like Overgrow, weather/floor condition effects on certain types, and miscellaneous effects like Charge.\n\nr0: [output] damage multiplier due to type effects.\nr1: attacker pointer\nr2: defender pointer\nr3: attack power\nstack[0]: attack type\nstack[1]: [output] struct containing info about the damage calculation (only the critical_hit, type_matchup, and field_0xF fields are modified)\nstack[2]: flag for whether Erratic Player and Technician effects should be excluded. CalcDamage only passes in true if the move is the regular attack or a projectile.\nreturn: whether or not the Type-Advantage Master IQ skill should activate if the attacker has it. In practice, this corresponds to when the attack is super-effective, but technically true is also returned when the defender is an invalid entity.",
        None,
    )

    CalcDamage = Symbol(
        [0x2FAA0],
        [0x230C620],
        None,
        "CalcDamage",
        "The damage calculation function.\n\nAt a high level, the damage formula is:\n  M * [(153/256)*(A + P) - 0.5*D + 50*ln(10*[L + (A - D)/8 + 50]) - 311]\nwhere:\n  - A is the offensive stat (attack or special attack) with relevant modifiers applied (stat stages, certain items, certain abilities, etc.)\n  - D is the defensive stat (defense or special defense) with relevant modifiers applied (stat stages, certain items, certain abilities, etc.)\n  - L is the attacker's level\n  - P is the move power with relevant modifiers applied\n  - M is an aggregate damage multiplier from a variety of things, such as type-effectiveness, STAB, critical hits (which are also rolled in this function), certain items, certain abilities, certain statuses, etc.\n\nThe calculations are done primarily with 64-bit fixed point arithmetic, and a bit of 32-bit fixed point arithmetic. There's also rounding/truncation/clamping at various steps in the process.\n\nr0: attacker pointer\nr1: defender pointer\nr2: attack type\nr3: attack power\nstack[0]: crit chance\nstack[1]: [output] struct containing info about the damage calculation\nstack[2]: damage multiplier (as a binary fixed-point number with 8 fraction bits)\nstack[3]: move ID\nstack[4]: flag to account for certain effects (Flash Fire, Reflect, Light Screen, aura bows, Def. Scarf, Zinc Band). Only ever set to false when computing recoil damage for Jump Kick/Hi Jump Kick missing, which is based on the damage that would have been done if the move didn't miss.",
        None,
    )

    ApplyDamageAndEffectsWrapper = Symbol(
        [0x31010],
        [0x230DB90],
        None,
        "ApplyDamageAndEffectsWrapper",
        "A wrapper for ApplyDamageAndEffects used for applying damage from sources such as statuses, traps, liquid ooze,\nhunger, and possibly more.\n\nr0: monster entity pointer\nr1: damage amount\nr2: damage message\nr3: damage source",
        None,
    )

    CalcRecoilDamageFixed = Symbol(
        [0x31080],
        [0x230DC00],
        None,
        "CalcRecoilDamageFixed",
        "Appears to calculate recoil damage to a monster.\n\nThis function wraps CalcDamageFixed using the monster as both the attacker and the defender, after doing some basic checks (like if the monster is already at 0 HP) and applying a boost from the Reckless ability if applicable.\n\nr0: entity pointer\nr1: fixed damage\nr2: ?\nr3: [output] struct containing info about the damage calculation\nstack[0]: move ID (interestingly, this doesn't seem to be used by the function)\nstack[1]: attack type\nstack[2]: damage source\nstack[3]: damage message\nothers: ?",
        None,
    )

    CalcDamageFixed = Symbol(
        [0x31134],
        [0x230DCB4],
        None,
        "CalcDamageFixed",
        "Appears to calculate damage from a fixed-damage effect.\n\nr0: attacker pointer\nr1: defender pointer\nr2: fixed damage\nr3: experience flag (see ApplyDamage)\nstack[0]: [output] struct containing info about the damage calculation\nstack[1]: attack type\nstack[2]: move category\nstack[3]: damage source\nstack[4]: damage message\nothers: ?",
        None,
    )

    CalcDamageFixedNoCategory = Symbol(
        [0x3129C],
        [0x230DE1C],
        None,
        "CalcDamageFixedNoCategory",
        "A wrapper around CalcDamageFixed with the move category set to none.\n\nr0: attacker pointer\nr1: defender pointer\nr2: fixed damage\nr3: experience flag (see ApplyDamage)\nstack[0]: [output] struct containing info about the damage calculation\nstack[1]: attack type\nstack[2]: damage source\nstack[3]: damage message\nothers: ?",
        None,
    )

    CalcDamageFixedWrapper = Symbol(
        [0x312E8],
        [0x230DE68],
        None,
        "CalcDamageFixedWrapper",
        "A wrapper around CalcDamageFixed.\n\nr0: attacker pointer\nr1: defender pointer\nr2: fixed damage\nr3: experience flag (see ApplyDamage)\nstack[0]: [output] struct containing info about the damage calculation\nstack[1]: attack type\nstack[2]: move category\nstack[3]: damage source\nstack[4]: damage message\nothers: ?",
        None,
    )

    UpdateShopkeeperModeAfterAttack = Symbol(
        [0x31334],
        [0x230DEB4],
        None,
        "UpdateShopkeeperModeAfterAttack",
        "Updates the shopkeeper mode of a monster in response to being struck by an attack.\n\nIf the defender is in normal shopkeeper mode (not aggressive), nothing happens. Otherwise, the mode is set to SHOPKEEPER_MODE_ATTACK_TEAM if the attacker is a team member, or SHOPKEEPER_MODE_ATTACK_ENEMIES otherwise.\n\nr0: attacker pointer\nr1: defender pointer",
        None,
    )

    UpdateShopkeeperModeAfterTrap = Symbol(
        [0x31370],
        [0x230DEF0],
        None,
        "UpdateShopkeeperModeAfterTrap",
        "Updates the shopkeeper mode of a monster in response to stepping on a trap.\n\nIf in the normal shopkeeper mode (not aggressive), nothing happens. Otherwise, the mode is set to SHOPKEEPER_MODE_ATTACK_TEAM if the trap is from a team member or SHOPKEEPER_MODE_ATTACK_ENEMIES otherwise.\n\nr0: shopkeeper pointer\nr1: bool non team member trap",
        None,
    )

    ResetDamageCalcDiagnostics = Symbol(
        [0x3141C],
        [0x230DF9C],
        None,
        "ResetDamageCalcDiagnostics",
        "Resets the damage calculation diagnostic info stored on the dungeon struct. Called unconditionally at the start of CalcDamage.\n\nNo params.",
        None,
    )

    SpecificRecruitCheck = Symbol(
        [0x31A08],
        [0x230E588],
        None,
        "SpecificRecruitCheck",
        "Checks if a specific monster can be recruited. Called by RecruitCheck.\n\nWill return false if dungeon::recruiting_enabled is false, if the monster is Mew and dungeon::dungeon_objective is OBJECTIVE_RESCUE or if the monster is any of the special Deoxys forms or any of the 3 regis.\nIf this function returns false, RecruitCheck will return false as well.\n\nr0: Monster ID\nreturn: True if the monster can be recruited",
        None,
    )

    RecruitCheck = Symbol(
        [0x31AC4],
        [0x230E644],
        None,
        "RecruitCheck",
        "Determines if a defeated enemy will attempt to join the team\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: True if the target will attempt to join the team",
        None,
    )

    TryRecruit = Symbol(
        [0x31F58],
        [0x230EAD8],
        None,
        "TryRecruit",
        "Asks the player if they would like to recruit the enemy that was just defeated and handles the recruitment if they accept.\n\nr0: user entity pointer\nr1: monster to recruit entity pointer\nreturn: True if the monster was recruited, false if it wasn't",
        None,
    )

    TrySpawnMonsterAndTickSpawnCounter = Symbol(
        [0x325B0],
        [0x230F130],
        None,
        "TrySpawnMonsterAndTickSpawnCounter",
        "First ticks up the spawn counter, and if it's equal or greater than the spawn cooldown, it will try to spawn an enemy if the number of enemies is below the spawn cap.\n\nIf the spawn counter is greater than 900, it will instead perform the special spawn caused by the ability Illuminate.\n\nNo params.",
        None,
    )

    AiDecideUseItem = Symbol(
        [0x32808],
        [0x230F388],
        None,
        "AiDecideUseItem",
        "Decides whether or not an AI should use its held item and updates its action_data fields accordingly.\n\nr0: Entity pointer",
        None,
    )

    GetPossibleAiThrownItemDirections = Symbol(
        [0x32CA4],
        [0x230F824],
        None,
        "GetPossibleAiThrownItemDirections",
        "If the entity can throw an item at a target in a certain direction,\nadds that direction to AI_THROWN_ITEM_DIRECTIONS and the probability of throwing it to AI_THROWN_ITEM_PROBABILITIES (if it is not already present).\nThe size of the arrays will be stored in AI_THROWN_ITEM_ACTION_CHOICE_COUNT.\nThe caller function will select the direction to throw the item by iterating through the array(s), rolling the probability, and then throwing in that direction if the roll succeeds.\nNothing will be thrown if all rolls fail.\n\nr0: Entity pointer\nr1: Integer in {1, 2}. If 1, target allies; if 2, target enemies.\nr2: Item struct pointer\nr3: If false, will call GetAiUseItemProbability to get the probability of throwing in a certain direction.\nIf true, the added probability will always be 100.",
        None,
    )

    GetPossibleAiArcItemTargets = Symbol(
        [0x32F20],
        [0x230FAA0],
        None,
        "GetPossibleAiArcItemTargets",
        "Gets the positions of all targets that an AI can hit with an item thrown in an arc, such as a Gravelerock.\nThe number of positions in the array will be stored in AI_THROWN_ITEM_ACTION_CHOICE_COUNT.\n\nr0: Entity pointer\nr1: Item struct pointer\nr2: [output] Array of size 20 for storing position structs\nr3: If false, will roll GetAiUseItemProbability every time a position is checked and not add it if it rolls false.",
        None,
    )

    TryNonLeaderItemPickUp = Symbol(
        [0x33058],
        [0x230FBD8],
        None,
        "TryNonLeaderItemPickUp",
        "Similar to TryLeaderItemPickUp, but for other monsters.\n\nUsed both for enemies and team members.\n\nr0: entity pointer",
        None,
    )

    GetExclusiveItemWithEffectFromBag = Symbol(
        [0x33548],
        [0x23100C8],
        None,
        "GetExclusiveItemWithEffectFromBag",
        "If an exclusive item with a certain effect is present in the bag and works for the entity, returns true and copies the item struct to the address at item. Otherwise, returns false.\n\nr0: Entity pointer\nr1: exclusive_item_effect_id enum\nr2: [output] Item pointer\nreturn: bool",
        None,
    )

    AuraBowIsActive = Symbol(
        [0x335BC],
        [0x231013C],
        None,
        "AuraBowIsActive",
        "Checks if a monster is holding an aura bow that isn't disabled by Klutz.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    ExclusiveItemOffenseBoost = Symbol(
        [0x3366C],
        [0x23101EC],
        None,
        "ExclusiveItemOffenseBoost",
        "Gets the exclusive item boost for attack/special attack for a monster\n\nr0: entity pointer\nr1: move category index (0 for physical, 1 for special)\nreturn: boost",
        None,
    )

    ExclusiveItemDefenseBoost = Symbol(
        [0x3367C],
        [0x23101FC],
        None,
        "ExclusiveItemDefenseBoost",
        "Gets the exclusive item boost for defense/special defense for a monster\n\nr0: entity pointer\nr1: move category index (0 for physical, 1 for special)\nreturn: boost",
        None,
    )

    TeamMemberHasItemActive = Symbol(
        [0x3368C],
        [0x231020C],
        None,
        "TeamMemberHasItemActive",
        "Checks if any team member is holding a certain item and puts them into the array given.\n\nr0: [output] pointer to array of monsters (expected to have space for at least 4 pointers)\nr1: item ID\nreturn: number of team members with the item active",
        None,
    )

    TeamMemberHasExclusiveItemEffectActive = Symbol(
        [0x33734],
        [0x23102B4],
        None,
        "TeamMemberHasExclusiveItemEffectActive",
        "Checks if any team member is under the effects of a certain exclusive item effect.\n\nr0: exclusive item effect ID\nreturn: bool",
        None,
    )

    TrySpawnEnemyItemDrop = Symbol(
        [0x338CC],
        [0x231044C],
        None,
        "TrySpawnEnemyItemDrop",
        "Determine what item a defeated enemy should drop, if any, then (probably?) spawn that item underneath them.\n\nThis function is called at the time when an enemy is defeated from ApplyDamage.\n\nr0: attacker entity (who defeated the enemy)\nr1: defender entity (who was defeated)",
        None,
    )

    TickNoSlipCap = Symbol(
        [0x33A84],
        [0x2310604],
        None,
        "TickNoSlipCap",
        "Checks if the entity is a team member and holds the No-Slip Cap, and if so attempts to make one item in the bag sticky.\n\nr0: pointer to entity",
        None,
    )

    TickStatusAndHealthRegen = Symbol(
        [0x34F68],
        [0x2311AE8],
        None,
        "TickStatusAndHealthRegen",
        "Applies the natural HP regen effect by taking modifiers into account (Poison Heal, Heal Ribbon, weather-related regen). Then it ticks down counters for volatile status effects, and heals them if the counter reached zero.\n\nr0: pointer to entity",
        None,
    )

    InflictSleepStatusSingle = Symbol(
        [0x35704],
        [0x2312284],
        None,
        "InflictSleepStatusSingle",
        "This is called by TryInflictSleepStatus.\n\nr0: entity pointer\nr1: number of turns",
        None,
    )

    TryInflictSleepStatus = Symbol(
        [0x357B8],
        [0x2312338],
        None,
        "TryInflictSleepStatus",
        "Inflicts the Sleep status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of turns\nr3: flag to log a message on failure",
        None,
    )

    IsProtectedFromSleepClassStatus = Symbol(
        [0x358C4],
        [0x2312444],
        None,
        "IsProtectedFromSleepClassStatus",
        "Checks if the monster is immune to sleep class status conditions.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: ignore safeguard\nr3: ignore other protections (exclusive items + leaf guard)\nstack[0]: flag to log a message on failure\nreturn: bool",
        None,
    )

    TryInflictNightmareStatus = Symbol(
        [0x35B2C],
        [0x23126AC],
        None,
        "TryInflictNightmareStatus",
        "Inflicts the Nightmare status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of turns",
        None,
    )

    TryInflictNappingStatus = Symbol(
        [0x35C40],
        [0x23127C0],
        None,
        "TryInflictNappingStatus",
        "Inflicts the Napping status condition (from Rest) on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of turns",
        None,
    )

    TryInflictYawningStatus = Symbol(
        [0x35D50],
        [0x23128D0],
        None,
        "TryInflictYawningStatus",
        "Inflicts the Yawning status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of turns",
        None,
    )

    TryInflictSleeplessStatus = Symbol(
        [0x35E60],
        [0x23129E0],
        None,
        "TryInflictSleeplessStatus",
        "Inflicts the Sleepless status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictPausedStatus = Symbol(
        [0x35F4C],
        [0x2312ACC],
        None,
        "TryInflictPausedStatus",
        "Inflicts the Paused status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: ?\nr3: number of turns\nstack[0]: flag to log a message on failure\nstack[1]: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictInfatuatedStatus = Symbol(
        [0x3608C],
        [0x2312C0C],
        None,
        "TryInflictInfatuatedStatus",
        "Inflicts the Infatuated status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictBurnStatus = Symbol(
        [0x36218],
        [0x2312D98],
        None,
        "TryInflictBurnStatus",
        "Inflicts the Burn status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to apply some special effect alongside the burn?\nr3: flag to log a message on failure\nstack[0]: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictBurnStatusWholeTeam = Symbol(
        [0x364F8],
        [0x2313078],
        None,
        "TryInflictBurnStatusWholeTeam",
        "Inflicts the Burn status condition on all team members if possible.\n\nNo params.",
        None,
    )

    TryInflictPoisonedStatus = Symbol(
        [0x36544],
        [0x23130C4],
        None,
        "TryInflictPoisonedStatus",
        "Inflicts the Poisoned status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictBadlyPoisonedStatus = Symbol(
        [0x3681C],
        [0x231339C],
        None,
        "TryInflictBadlyPoisonedStatus",
        "Inflicts the Badly Poisoned status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictFrozenStatus = Symbol(
        [0x36AD8],
        [0x2313658],
        None,
        "TryInflictFrozenStatus",
        "Inflicts the Frozen status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure",
        None,
    )

    TryInflictConstrictionStatus = Symbol(
        [0x36D00],
        [0x2313880],
        None,
        "TryInflictConstrictionStatus",
        "Inflicts the Constriction status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: animation ID\nr3: flag to log a message on failure",
        None,
    )

    TryInflictShadowHoldStatus = Symbol(
        [0x36E58],
        [0x23139D8],
        None,
        "TryInflictShadowHoldStatus",
        "Inflicts the Shadow Hold (AKA Immobilized) status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting",
        None,
    )

    TryInflictIngrainStatus = Symbol(
        [0x37010],
        [0x2313B90],
        None,
        "TryInflictIngrainStatus",
        "Inflicts the Ingrain status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictWrappedStatus = Symbol(
        [0x370D4],
        [0x2313C54],
        None,
        "TryInflictWrappedStatus",
        "Inflicts the Wrapped status condition on a target monster if possible.\n\nThis also gives the user the Wrap status (Wrapped around foe).\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    FreeOtherWrappedMonsters = Symbol(
        [0x372D0],
        [0x2313E50],
        None,
        "FreeOtherWrappedMonsters",
        "Frees from the wrap status all monsters which are wrapped by/around the monster passed as parameter.\n\nr0: pointer to entity",
        None,
    )

    TryInflictPetrifiedStatus = Symbol(
        [0x3734C],
        [0x2313ECC],
        None,
        "TryInflictPetrifiedStatus",
        "Inflicts the Petrified status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    LowerOffensiveStat = Symbol(
        [0x374DC],
        [0x231405C],
        None,
        "LowerOffensiveStat",
        "Lowers the specified offensive stat on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: number of stages\nstack[0]: flag to check for being protected from stat drops\nstack[1]: flag to log a message on failure for IsProtectedFromStatDrops",
        None,
    )

    LowerDefensiveStat = Symbol(
        [0x376F4],
        [0x2314274],
        None,
        "LowerDefensiveStat",
        "Lowers the specified defensive stat on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: number of stages\nstack[0]: flag to check for being protected from stat drops\nstack[1]: flag to log a message on failure for IsProtectedFromStatDrops",
        None,
    )

    BoostOffensiveStat = Symbol(
        [0x3787C],
        [0x23143FC],
        None,
        "BoostOffensiveStat",
        "Boosts the specified offensive stat on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: number of stages",
        None,
    )

    BoostDefensiveStat = Symbol(
        [0x379E8],
        [0x2314568],
        None,
        "BoostDefensiveStat",
        "Boosts the specified defensive stat on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: number of stages",
        None,
    )

    FlashFireShouldActivate = Symbol(
        [0x37B54],
        [0x23146D4],
        None,
        "FlashFireShouldActivate",
        "Checks whether Flash Fire should activate, assuming the defender is being hit by a Fire-type move.\n\nThis checks that the defender is valid and Flash Fire is active, and that Normalize isn't active on the attacker.\n\nr0: attacker pointer\nr1: defender pointer\nreturn: 2 if Flash Fire should activate and raise the defender's boost level, 1 if Flash Fire should activate but the defender's boost level is maxed out, 0 otherwise.",
        None,
    )

    ActivateFlashFire = Symbol(
        [0x37BC4],
        [0x2314744],
        None,
        "ActivateFlashFire",
        "Actually applies the Flash Fire boost with a message log and animation. Passes the same monster for attacker and\ndefender, but the attacker goes unused.\n\nr0: attacker pointer?\nr1: defender pointer",
        None,
    )

    ApplyOffensiveStatMultiplier = Symbol(
        [0x37C20],
        [0x23147A0],
        None,
        "ApplyOffensiveStatMultiplier",
        "Applies a multiplier to the specified offensive stat on the target monster.\n\nThis affects struct monster_stat_modifiers::offensive_multipliers, for moves like Charm and Memento.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: multiplier\nstack[0]: ?",
        None,
    )

    ApplyDefensiveStatMultiplier = Symbol(
        [0x37E44],
        [0x23149C4],
        None,
        "ApplyDefensiveStatMultiplier",
        "Applies a multiplier to the specified defensive stat on the target monster.\n\nThis affects struct monster_stat_modifiers::defensive_multipliers, for moves like Screech.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: multiplier\nstack[0]: ?",
        None,
    )

    BoostHitChanceStat = Symbol(
        [0x37FC4],
        [0x2314B44],
        None,
        "BoostHitChanceStat",
        "Boosts the specified hit chance stat (accuracy or evasion) on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index",
        None,
    )

    LowerHitChanceStat = Symbol(
        [0x3810C],
        [0x2314C8C],
        None,
        "LowerHitChanceStat",
        "Lowers the specified hit chance stat (accuracy or evasion) on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: ? (Irdkwia's notes say this is the number of stages, but I'm pretty sure that's incorrect)",
        None,
    )

    TryInflictCringeStatus = Symbol(
        [0x382C8],
        [0x2314E48],
        None,
        "TryInflictCringeStatus",
        "Inflicts the Cringe status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictParalysisStatus = Symbol(
        [0x38424],
        [0x2314FA4],
        None,
        "TryInflictParalysisStatus",
        "Inflicts the Paralysis status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    BoostSpeed = Symbol(
        [0x386F0],
        [0x2315270],
        None,
        "BoostSpeed",
        "Boosts the speed of the target monster.\n\nIf the number of turns specified is 0, a random turn count will be selected using the default SPEED_BOOST_TURN_RANGE.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of stages\nr3: number of turns\nstack[0]: flag to log a message on failure",
        None,
    )

    BoostSpeedOneStage = Symbol(
        [0x3881C],
        [0x231539C],
        None,
        "BoostSpeedOneStage",
        "A wrapper around BoostSpeed with the number of stages set to 1.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of turns\nr3: flag to log a message on failure",
        None,
    )

    LowerSpeed = Symbol(
        [0x38834],
        [0x23153B4],
        None,
        "LowerSpeed",
        "Lowers the speed of the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: number of stages\nr3: flag to log a message on failure",
        None,
    )

    TrySealMove = Symbol(
        [0x3899C],
        [0x231551C],
        None,
        "TrySealMove",
        "Seals one of the target monster's moves. The move to be sealed is randomly selected.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nreturn: Whether or not a move was sealed",
        None,
    )

    BoostOrLowerSpeed = Symbol(
        [0x38B0C],
        [0x231568C],
        None,
        "BoostOrLowerSpeed",
        "Randomly boosts or lowers the speed of the target monster by one stage with equal probability.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ResetHitChanceStat = Symbol(
        [0x38B6C],
        [0x23156EC],
        None,
        "ResetHitChanceStat",
        "Resets the specified hit chance stat (accuracy or evasion) back to normal on the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: stat index\nr3: ?",
        None,
    )

    ExclusiveItemEffectIsActiveWithLogging = Symbol(
        [0x38C20],
        [0x23157A0],
        None,
        "ExclusiveItemEffectIsActiveWithLogging",
        "Calls ExclusiveItemEffectIsActive, then logs the specified message if indicated.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: whether a message should be logged if the effect is active\nr3: message ID to be logged if the effect is active\nstack[0]: exclusive item effect ID\nreturn: bool, same as ExclusiveItemEffectIsActive",
        None,
    )

    TryActivateQuickFeet = Symbol(
        [0x38CFC],
        [0x231587C],
        None,
        "TryActivateQuickFeet",
        "Activate the Quick Feet ability on the defender, if the monster has it and it's active.\n\nr0: attacker pointer\nr1: defender pointer\nreturn: bool, whether or not the ability was activated",
        None,
    )

    TryInflictTerrifiedStatus = Symbol(
        [0x38D40],
        [0x23158C0],
        None,
        "TryInflictTerrifiedStatus",
        "Inflicts the Terrified status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictGrudgeStatus = Symbol(
        [0x38D98],
        [0x2315918],
        None,
        "TryInflictGrudgeStatus",
        "Inflicts the Grudge status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictConfusedStatus = Symbol(
        [0x38E18],
        [0x2315998],
        None,
        "TryInflictConfusedStatus",
        "Inflicts the Confused status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictCoweringStatus = Symbol(
        [0x3904C],
        [0x2315BCC],
        None,
        "TryInflictCoweringStatus",
        "Inflicts the Cowering status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryRestoreHp = Symbol(
        [0x3914C],
        [0x2315CCC],
        None,
        "TryRestoreHp",
        "Restore HP of the target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: HP to restore\nreturn: success flag",
        None,
    )

    TryIncreaseHp = Symbol(
        [0x391C4],
        [0x2315D44],
        None,
        "TryIncreaseHp",
        "Restore HP and possibly boost max HP of the target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: HP to restore\nr3: max HP boost\nstack[0]: flag to log a message on failure\nreturn: Success flag",
        None,
    )

    RevealItems = Symbol(
        [0x394F0],
        [0x2316070],
        None,
        "RevealItems",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    RevealStairs = Symbol(
        [0x39580],
        [0x2316100],
        None,
        "RevealStairs",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    RevealEnemies = Symbol(
        [0x3963C],
        [0x23161BC],
        None,
        "RevealEnemies",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictLeechSeedStatus = Symbol(
        [0x396CC],
        [0x231624C],
        None,
        "TryInflictLeechSeedStatus",
        "Inflicts the Leech Seed status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log a message on failure\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictDestinyBondStatus = Symbol(
        [0x39930],
        [0x23164B0],
        None,
        "TryInflictDestinyBondStatus",
        "Inflicts the Destiny Bond status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictSureShotStatus = Symbol(
        [0x39A50],
        [0x23165D0],
        None,
        "TryInflictSureShotStatus",
        "Inflicts the Sure Shot status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictWhifferStatus = Symbol(
        [0x39AE0],
        [0x2316660],
        None,
        "TryInflictWhifferStatus",
        "Inflicts the Whiffer status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictSetDamageStatus = Symbol(
        [0x39BC8],
        [0x2316748],
        None,
        "TryInflictSetDamageStatus",
        "Inflicts the Set Damage status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictFocusEnergyStatus = Symbol(
        [0x39C64],
        [0x23167E4],
        None,
        "TryInflictFocusEnergyStatus",
        "Inflicts the Focus Energy status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictDecoyStatus = Symbol(
        [0x39D04],
        [0x2316884],
        None,
        "TryInflictDecoyStatus",
        "Inflicts the Decoy status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictCurseStatus = Symbol(
        [0x39FBC],
        [0x2316B3C],
        None,
        "TryInflictCurseStatus",
        "Inflicts the Curse status condition on a target monster if possible and if the user is\na ghost type. Otherwise, just boost the user's defense and attack then lower the user's\nspeed.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictSnatchStatus = Symbol(
        [0x3A160],
        [0x2316CE0],
        None,
        "TryInflictSnatchStatus",
        "Inflicts the Snatch status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictTauntStatus = Symbol(
        [0x3A288],
        [0x2316E08],
        None,
        "TryInflictTauntStatus",
        "Inflicts the Taunt status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictStockpileStatus = Symbol(
        [0x3A3B8],
        [0x2316F38],
        None,
        "TryInflictStockpileStatus",
        "Inflicts the Stockpile condition on a target monster if possible. Won't boost the level\nof stockpiling above 3.\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: Whether or not the status could be inflicted or boosted",
        None,
    )

    TryInflictInvisibleStatus = Symbol(
        [0x3A45C],
        [0x2316FDC],
        None,
        "TryInflictInvisibleStatus",
        "Attempts to turn the target invisible.\n\nThe user pointer is only used when calling LogMessage functions.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictPerishSongStatus = Symbol(
        [0x3A50C],
        [0x231708C],
        None,
        "TryInflictPerishSongStatus",
        "Inflicts the Perish Song status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictEncoreStatus = Symbol(
        [0x3A600],
        [0x2317180],
        None,
        "TryInflictEncoreStatus",
        "Inflicts the Encore status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryDecreaseBelly = Symbol(
        [0x3A7B8],
        [0x2317338],
        None,
        "TryDecreaseBelly",
        "Tries to reduce the belly size of the target. Only when max belly shrink is 0, the\ncurrent belly is reduced by belly to lose. If both are non-zero, only the max belly\nshrink is applied.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: belly to lose\nr3: max belly shrink",
        None,
    )

    TryIncreaseBelly = Symbol(
        [0x3AA90],
        [0x2317610],
        None,
        "TryIncreaseBelly",
        "Restore belly and possibly boost max belly of the target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: belly to restore\nr3: max belly boost (if belly is full)\nstack[0]: flag to log a message",
        None,
    )

    TryInflictMuzzledStatus = Symbol(
        [0x3B004],
        [0x2317B84],
        None,
        "TryInflictMuzzledStatus",
        "Inflicts the Muzzled status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryTransform = Symbol(
        [0x3B0FC],
        [0x2317C7C],
        None,
        "TryTransform",
        "Attempts to transform the target into the species of a random monster contained in the list returned by MonsterSpawnListPartialCopy.\n\nThe user pointer is only used when calling LogMessage functions.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictMobileStatus = Symbol(
        [0x3B2EC],
        [0x2317E6C],
        None,
        "TryInflictMobileStatus",
        "Inflicts the Mobile status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictExposedStatus = Symbol(
        [0x3B3A8],
        [0x2317F28],
        None,
        "TryInflictExposedStatus",
        "Inflicts the Exposed status condition on a target monster if possible. Only applies to\nGhost types and monsters with raised evasion. If the animation effect ID is 0,\ndefaults to animation ID 0xE (this fallback animation likely can't be seen in normal\nplay).\n\nr0: user entity pointer\nr1: target entity pointer\nr2: animation effect ID\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryActivateIdentifyCondition = Symbol(
        [0x3B528],
        [0x23180A8],
        None,
        "TryActivateIdentifyCondition",
        "Sets the flag for the identify orb which causes monsters holding items to be shown with\na blue exclamation mark status icon.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictBlinkerStatus = Symbol(
        [0x3B5AC],
        [0x231812C],
        None,
        "TryInflictBlinkerStatus",
        "Inflicts the Blinker status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting\nr3: flag to log a message on failure\nreturn: Whether or not the status could be inflicted",
        None,
    )

    IsBlinded = Symbol(
        [0x3B6C4],
        [0x2318244],
        None,
        "IsBlinded",
        "Returns true if the monster has the blinded status (see statuses::blinded), or if it is not the leader and is holding Y-Ray Specs.\n\nr0: pointer to entity\nr1: flag for whether to check for the held item\nreturn: bool",
        None,
    )

    TryInflictCrossEyedStatus = Symbol(
        [0x3B724],
        [0x23182A4],
        None,
        "TryInflictCrossEyedStatus",
        "Inflicts the Cross-Eyed status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictEyedropStatus = Symbol(
        [0x3B83C],
        [0x23183BC],
        None,
        "TryInflictEyedropStatus",
        "Inflicts the Eyedrop status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictSlipStatus = Symbol(
        [0x3B8EC],
        [0x231846C],
        None,
        "TryInflictSlipStatus",
        "Inflicts the Slip status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictDropeyeStatus = Symbol(
        [0x3B9D4],
        [0x2318554],
        None,
        "TryInflictDropeyeStatus",
        "Inflicts the Dropeye status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nreturn: Whether or not the status could be inflicted",
        None,
    )

    RestoreAllMovePP = Symbol(
        [0x3BB00],
        [0x2318680],
        None,
        "RestoreAllMovePP",
        "Restores the PP of all the target's moves by the specified amount.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: PP to restore\nr3: flag to suppress message logging",
        None,
    )

    RestoreOneMovePP = Symbol(
        [0x3BC38],
        [0x23187B8],
        None,
        "RestoreOneMovePP",
        "Restores the PP the target's move in the specified move slot by the specified amount.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: move index\nr3: PP to restore\nstack[0]: flag to log message",
        None,
    )

    RestoreRandomMovePP = Symbol(
        [0x3BD68],
        [0x23188E8],
        None,
        "RestoreRandomMovePP",
        "Restores the PP of a random one of the target's moves by the specified amount.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: PP to restore\nr3: flag to log message",
        None,
    )

    ApplyProteinEffect = Symbol(
        [0x3BE30],
        [0x23189B0],
        None,
        "ApplyProteinEffect",
        "Tries to boost the target's attack stat.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: attack boost",
        None,
    )

    ApplyCalciumEffect = Symbol(
        [0x3BEC4],
        [0x2318A44],
        None,
        "ApplyCalciumEffect",
        "Tries to boost the target's special attack stat.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: special attack boost",
        None,
    )

    ApplyIronEffect = Symbol(
        [0x3BF58],
        [0x2318AD8],
        None,
        "ApplyIronEffect",
        "Tries to boost the target's defense stat.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: defense boost",
        None,
    )

    ApplyZincEffect = Symbol(
        [0x3BFEC],
        [0x2318B6C],
        None,
        "ApplyZincEffect",
        "Tries to boost the target's special defense stat.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: special defense boost",
        None,
    )

    TryInflictLongTossStatus = Symbol(
        [0x3C080],
        [0x2318C00],
        None,
        "TryInflictLongTossStatus",
        "Inflicts the Long Toss status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictPierceStatus = Symbol(
        [0x3C0F0],
        [0x2318C70],
        None,
        "TryInflictPierceStatus",
        "Inflicts the Pierce status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictGastroAcidStatus = Symbol(
        [0x3C15C],
        [0x2318CDC],
        None,
        "TryInflictGastroAcidStatus",
        "Inflicts the Gastro Acid status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log message\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    SetAquaRingHealingCountdownTo4 = Symbol(
        [0x3C2A0],
        [0x2318E20],
        None,
        "SetAquaRingHealingCountdownTo4",
        "Sets the countdown for Aqua Ring healing countdown to a global value (0x4).\n\nr0: pointer to entity",
        None,
    )

    ApplyAquaRingHealing = Symbol(
        [0x3C2C8],
        [0x2318E48],
        None,
        "ApplyAquaRingHealing",
        "Applies the passive healing gained from the Aqua Ring status.\n\nr0: pointer to entity",
        None,
    )

    TryInflictAquaRingStatus = Symbol(
        [0x3C33C],
        [0x2318EBC],
        None,
        "TryInflictAquaRingStatus",
        "Inflicts the Aqua Ring status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictLuckyChantStatus = Symbol(
        [0x3C3E8],
        [0x2318F68],
        None,
        "TryInflictLuckyChantStatus",
        "Inflicts the Lucky Chant status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictHealBlockStatus = Symbol(
        [0x3C488],
        [0x2319008],
        None,
        "TryInflictHealBlockStatus",
        "Inflicts the Heal Block status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log message\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    MonsterHasEmbargoStatus = Symbol(
        [0x3C5AC],
        [0x231912C],
        None,
        "MonsterHasEmbargoStatus",
        "Returns true if the monster has the Embargo status condition.\n\nr0: pointer to entity\nreturn: bool",
        None,
    )

    LogItemBlockedByEmbargo = Symbol(
        [0x3C5E0],
        [0x2319160],
        None,
        "LogItemBlockedByEmbargo",
        "Logs the error message when the usage of an item is blocked by Embargo.\n\nr0: pointer to entity",
        None,
    )

    TryInflictEmbargoStatus = Symbol(
        [0x3C60C],
        [0x231918C],
        None,
        "TryInflictEmbargoStatus",
        "Inflicts the Embargo status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to log message\nr3: flag to only perform the check for inflicting without actually inflicting\nreturn: Whether or not the status could be inflicted",
        None,
    )

    TryInflictMiracleEyeStatus = Symbol(
        [0x3C730],
        [0x23192B0],
        None,
        "TryInflictMiracleEyeStatus",
        "Inflicts the Miracle Eye status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: flag to only perform the check for inflicting without actually inflicting",
        None,
    )

    TryInflictMagnetRiseStatus = Symbol(
        [0x3C864],
        [0x23193E4],
        None,
        "TryInflictMagnetRiseStatus",
        "Inflicts the Magnet Rise status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    IsFloating = Symbol(
        [0x3C92C],
        [0x23194AC],
        None,
        "IsFloating",
        "Checks if a monster is currently floating for reasons other than its typing or ability.\n\nIn particular, this checks for Gravity and Magnet Rise.\n\nr0: entity pointer\nreturn: bool",
        None,
    )

    TryInflictSafeguardStatus = Symbol(
        [0x3CD50],
        [0x23198D0],
        None,
        "TryInflictSafeguardStatus",
        "Inflicts the Safeguard status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictMistStatus = Symbol(
        [0x3CDF0],
        [0x2319970],
        None,
        "TryInflictMistStatus",
        "Inflicts the Mist status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictWishStatus = Symbol(
        [0x3CE8C],
        [0x2319A0C],
        None,
        "TryInflictWishStatus",
        "Inflicts the Wish status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictMagicCoatStatus = Symbol(
        [0x3CF2C],
        [0x2319AAC],
        None,
        "TryInflictMagicCoatStatus",
        "Inflicts the Magic Coat status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictLightScreenStatus = Symbol(
        [0x3CFCC],
        [0x2319B4C],
        None,
        "TryInflictLightScreenStatus",
        "Inflicts the Light Screen status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictReflectStatus = Symbol(
        [0x3D06C],
        [0x2319BEC],
        None,
        "TryInflictReflectStatus",
        "Inflicts the Reflect status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictProtectStatus = Symbol(
        [0x3D10C],
        [0x2319C8C],
        None,
        "TryInflictProtectStatus",
        "Inflicts the Protect status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictMirrorCoatStatus = Symbol(
        [0x3D1BC],
        [0x2319D3C],
        None,
        "TryInflictMirrorCoatStatus",
        "Inflicts the Mirror Coat status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictEndureStatus = Symbol(
        [0x3D258],
        [0x2319DD8],
        None,
        "TryInflictEndureStatus",
        "Inflicts the Endure status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictMirrorMoveStatus = Symbol(
        [0x3D2F8],
        [0x2319E78],
        None,
        "TryInflictMirrorMoveStatus",
        "Inflicts the Mirror Move status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictConversion2Status = Symbol(
        [0x3D398],
        [0x2319F18],
        None,
        "TryInflictConversion2Status",
        "Inflicts the Conversion2 status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryInflictVitalThrowStatus = Symbol(
        [0x3D464],
        [0x2319FE4],
        None,
        "TryInflictVitalThrowStatus",
        "Inflicts the Vital Throw status condition on a target monster if possible.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    TryResetStatChanges = Symbol(
        [0x3D504],
        [0x231A084],
        None,
        "TryResetStatChanges",
        "Tries to reset the stat changes of the defender.\n\nr0: attacker entity pointer\nr1: defender entity pointer\nr3: bool to force animation",
        None,
    )

    MirrorMoveIsActive = Symbol(
        [0x3D628],
        [0x231A1A8],
        None,
        "MirrorMoveIsActive",
        "Checks if the monster is under the effect of Mirror Move.\n\nReturns 1 if the effects is a status, 2 if it comes from an exclusive item, 0 otherwise.\n\nr0: pointer to entity\nreturn: int",
        None,
    )

    MistIsActive = Symbol(
        [0x3D6AC],
        [0x231A22C],
        None,
        "MistIsActive",
        "Checks if the monster is under the effect of Mist.\n\nReturns 1 if the effects is a status, 2 if it comes from an exclusive item, 0 otherwise.\n\nr0: pointer to entity\nreturn: int",
        None,
    )

    Conversion2IsActive = Symbol(
        [0x3D6F4],
        [0x231A274],
        None,
        "Conversion2IsActive",
        "Checks if the monster is under the effect of Conversion 2 (its type was changed).\n\nReturns 1 if the effects is a status, 2 if it comes from an exclusive item, 0 otherwise.\n\nr0: pointer to entity\nreturn: int",
        None,
    )

    AiConsiderMove = Symbol(
        [0x3D760],
        [0x231A2E0],
        None,
        "AiConsiderMove",
        "The AI uses this function to check if a move has any potential targets, to calculate the list of potential targets and to calculate the move's special weight.\nThis weight will be higher if the pokémon has weak-type picker and the target is weak to the move (allies only, enemies always get a result of 1 even if the move is super effective). More things could affect the result.\nThis function also sets the flag can_be_used on the ai_possible_move struct if it makes sense to use it.\nMore research is needed. There's more documentation about this special weight. Does all the documented behavior happen in this function?\n\nr0: ai_possible_move struct for this move\nr1: Entity pointer\nr2: Move pointer\nreturn: Move's calculated special weight",
        None,
    )

    TryAddTargetToAiTargetList = Symbol(
        [0x3DE90],
        [0x231AA10],
        None,
        "TryAddTargetToAiTargetList",
        "Checks if the specified target is eligible to be targeted by the AI and if so adds it to the list of targets. This function also fills an array that seems to contain the directions in which the user should turn to look at each of the targets in the list, as well as a third unknown array.\n\nr0: Number of existing targets in the list\nr1: Move's AI range field\nr2: User entity pointer\nr3: Target entity pointer\nstack[0]: Move pointer\nstack[1]: check_all_conditions parameter to pass to IsAiTargetEligible\nreturn: New number of targets in the target list",
        None,
    )

    IsAiTargetEligible = Symbol(
        [0x3DF84],
        [0x231AB04],
        None,
        "IsAiTargetEligible",
        "Checks if a given target is eligible to be targeted by the AI with a certain move\n\nr0: Move's AI range field\nr1: User entity pointer\nr2: Target entity pointer\nr3: Move pointer\nstack[0]: True to check all the possible move_ai_condition values, false to only check for move_ai_condition::AI_CONDITION_RANDOM (if the move has a different ai condition, the result will be false).\nreturn: True if the target is eligible, false otherwise",
        None,
    )

    IsTargetInRange = Symbol(
        [0x3E574],
        [0x231B0F4],
        None,
        "IsTargetInRange",
        "Returns true if the target is within range of the user's move, false otherwise.\n\nIf the user does not have Course Checker, it simply checks if the distance between user and target is less or equal than the move range.\nOtherwise, it will iterate through all tiles in the direction specified, checking for walls or other monsters in the way, and return false if they are found.\n\nr0: user pointer\nr1: target pointer\nr2: direction ID\nr3: move range (in number of tiles)",
        None,
    )

    ShouldUsePp = Symbol(
        [0x3E680],
        [0x231B200],
        None,
        "ShouldUsePp",
        "Checks if a monster should use PP when using a move. It also displays the corresponding animation if PP Saver triggers and prints the required messages to the message log.\n\nr0: entity pointer\nreturn: True if the monster should not use PP, false if it should.",
        None,
    )

    GetEntityMoveTargetAndRange = Symbol(
        [0x3EB8C],
        [0x231B70C],
        None,
        "GetEntityMoveTargetAndRange",
        "Gets the move target-and-range field when used by a given entity. See struct move_target_and_range in the C headers.\n\nr0: entity pointer\nr1: move pointer\nr2: AI flag (same as GetMoveTargetAndRange)\nreturn: move target and range",
        None,
    )

    GetEntityNaturalGiftInfo = Symbol(
        [0x3ED70],
        [0x231B8F0],
        None,
        "GetEntityNaturalGiftInfo",
        "Gets the relevant entry in NATURAL_GIFT_ITEM_TABLE based on the entity's held item, if possible.\n\nr0: entity pointer\nreturn: pointer to a struct natural_gift_item_info, or null if none was found",
        None,
    )

    GetEntityWeatherBallType = Symbol(
        [0x3EDEC],
        [0x231B96C],
        None,
        "GetEntityWeatherBallType",
        "Gets the current Weather Ball type for the given entity, based on the apparent weather.\n\nr0: entity pointer\nreturn: type ID",
        None,
    )

    ActivateMotorDrive = Symbol(
        [0x3EF40],
        [0x231BAC0],
        None,
        "ActivateMotorDrive",
        "Displays the message and applies the speed boost for the ability Motor Drive.\n\nr0: monster pointer",
        None,
    )

    TryActivateFrisk = Symbol(
        [0x3EF84],
        [0x231BB04],
        None,
        "TryActivateFrisk",
        "Tries to activate the Frisk ability on the defender. The attacker has to be on the team and the defender has to be\nholding an item or be able to drop a treasure box.\n\nr0: attacker pointer\nr1: defender pointer",
        None,
    )

    TryActivateBadDreams = Symbol(
        [0x3F098],
        [0x231BC18],
        None,
        "TryActivateBadDreams",
        "Tries to apply the damage from Bad Dreams to all sleeping monsters in the room.\n\nr0: monster pointer",
        None,
    )

    ActivateStench = Symbol(
        [0x3F21C],
        [0x231BD9C],
        None,
        "ActivateStench",
        "Activate the Stench ability on the monster.\n\nr0: monster pointer",
        None,
    )

    TryActivateSteadfast = Symbol(
        [0x3F244],
        [0x231BDC4],
        None,
        "TryActivateSteadfast",
        "Activate the Steadfast ability on the defender, if the monster has it and it's active.\n\nr0: attacker pointer\nr1: defender pointer",
        None,
    )

    IsInSpawnList = Symbol(
        [0x3F2DC],
        [0x231BE5C],
        None,
        "IsInSpawnList",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: spawn_list_ptr\nr1: monster ID\nreturn: bool",
        None,
    )

    ChangeShayminForme = Symbol(
        [0x3F3CC],
        [0x231BF4C],
        None,
        "ChangeShayminForme",
        "forme:\n  1: change from Land to Sky\n  2: change from Sky to Land\nresult:\n  0: not Shaymin\n  1: not correct Forme\n  2: frozen\n  3: ok\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: Target\nr1: forme\nreturn: result",
        None,
    )

    ApplyItemEffect = Symbol(
        [0x3F56C],
        [0x231C0EC],
        None,
        "ApplyItemEffect",
        "Seems to apply an item's effect via a giant switch statement?\n\nr3: attacker pointer\nstack[0]: defender pointer\nstack[1]: thrown item pointer\nothers: ?",
        None,
    )

    ApplyCheriBerryEffect = Symbol(
        [0x40AD4],
        [0x231D654],
        None,
        "ApplyCheriBerryEffect",
        "Tries to heal the paralysis status condition. Prints a message on failure.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyPechaBerryEffect = Symbol(
        [0x40B00],
        [0x231D680],
        None,
        "ApplyPechaBerryEffect",
        "Tries to heal the poisoned and badly poisoned status condition. Prints a message on\nfailure.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyRawstBerryEffect = Symbol(
        [0x40B34],
        [0x231D6B4],
        None,
        "ApplyRawstBerryEffect",
        "Tries to heal the burn status condition. Prints a message on failure.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyHungerSeedEffect = Symbol(
        [0x40B7C],
        [0x231D6FC],
        None,
        "ApplyHungerSeedEffect",
        "Empties the targets belly to cause Hungry Pal status in non-leader monsters and\nFamished in the leader monster.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyVileSeedEffect = Symbol(
        [0x40C68],
        [0x231D7E8],
        None,
        "ApplyVileSeedEffect",
        "Reduces the targets defense and special defense stages to the lowest level.\n\nr0: attacker pointer\nr1: defender pointer",
        None,
    )

    ApplyViolentSeedEffect = Symbol(
        [0x40D04],
        [0x231D884],
        None,
        "ApplyViolentSeedEffect",
        "Boosts the target's offensive stats stages to the max.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyGinsengEffect = Symbol(
        [0x40D50],
        [0x231D8D0],
        None,
        "ApplyGinsengEffect",
        "Boosts the power of the move at the top of the target's Move List. Appears to have a\nleftover check to boost the power of a move by 3 instead of 1 that always fails because\nthe chance is 0.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyBlastSeedEffect = Symbol(
        [0x40E6C],
        [0x231D9EC],
        None,
        "ApplyBlastSeedEffect",
        "If thrown, unfreeze and deal fixed damage to the defender. If not thrown, try to find \na monster in front of the attacker. If a monster is found unfreeze and dedal fixed \ndamage to the defender. Appears to have a leftover check for if the current fixed room is a boss fight and loads a different pointer for the damage when used in a boss room.\nHowever, this isn't noticeable because both the normal and boss damage is the same.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: bool thrown",
        None,
    )

    ApplyGummiBoostsDungeonMode = Symbol(
        [0x40FA8],
        [0x231DB28],
        None,
        "ApplyGummiBoostsDungeonMode",
        "Applies the IQ and possible stat boosts from eating a Gummi to the target monster.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: Gummi type ID\nr3: Stat boost amount, if a random stat boost occurs",
        None,
    )

    CanMonsterUseItem = Symbol(
        [0x4138C],
        [0x231DF0C],
        None,
        "CanMonsterUseItem",
        "Checks whether a monster can use a certain item.\n\nReturns false if the item is sticky, or if the monster is under the STATUS_MUZZLED status and the item is edible.\nAlso prints failure messages if required.\n\nr0: Monster entity pointer\nr1: Item pointer\nreturn: True if the monster can use the item, false otherwise",
        None,
    )

    ApplyGrimyFoodEffect = Symbol(
        [0x4141C],
        [0x231DF9C],
        None,
        "ApplyGrimyFoodEffect",
        "Randomly inflicts poison, shadow hold, burn, paralysis, or an offensive stat debuff\nto the target. If the survivalist iq skill or gluttony ability is active, the target\nhas a 50% chance not to be affected.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyMixElixirEffect = Symbol(
        [0x41568],
        [0x231E0E8],
        None,
        "ApplyMixElixirEffect",
        "If the target monster is a Linoone, restores all the PP of all the target's moves.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyDoughSeedEffect = Symbol(
        [0x415C8],
        [0x231E148],
        None,
        "ApplyDoughSeedEffect",
        "If the target monster is a team member, set dough_seed_extra_poke_flag to true to \nmake extra poke spawn on the next floor. Otherwise, do nothing.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyViaSeedEffect = Symbol(
        [0x41634],
        [0x231E1B4],
        None,
        "ApplyViaSeedEffect",
        "Tries to randomly teleport the target with a message for eating the seed.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyGravelyrockEffect = Symbol(
        [0x416A8],
        [0x231E228],
        None,
        "ApplyGravelyrockEffect",
        "Restores 10 hunger to the target and will raise the target's IQ if they are a bonsly\nor sudowoodo.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyGonePebbleEffect = Symbol(
        [0x41720],
        [0x231E2A0],
        None,
        "ApplyGonePebbleEffect",
        "Causes a few visual effects, temporarily changes the dungeon music to the Goodnight\ntrack, and gives the target the enduring status.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    ApplyGracideaEffect = Symbol(
        [0x418A8],
        [0x231E428],
        None,
        "ApplyGracideaEffect",
        "If the target is Shaymin, attempt to change the target's form to Shaymin Sky Forme. Otherwise, do nothing.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    GetAiUseItemProbability = Symbol(
        [0x41F44],
        [0x231EAC4],
        None,
        "GetAiUseItemProbability",
        "Called to get the probability of an item being used or thrown by an AI on the current turn.\n\nr0: Pointer to either the user if it is an item used by the AI or the target if it is an item thrown by the AI\nr1: Pointer to item\nr2: Size-2 bitvector: if bit 0 is set, the AI is throwing the item. If bit 1 is set, it is targeting an ally with the item.\nreturn: Integer in range [0, 100]",
        None,
    )

    IsAdjacentToEnemy = Symbol(
        [0x427D8],
        [0x231F358],
        None,
        "IsAdjacentToEnemy",
        "Called to check if a hostile entity is present in any of the tiles adjacent to an entity.\n\nr0: Pointer to entity\nreturn: True if yes, false if no",
        None,
    )

    ShouldTryEatItem = Symbol(
        [0x42878],
        [0x231F3F8],
        None,
        "ShouldTryEatItem",
        "Checks if a given item should be eaten by the TryEatItem effect.\n\nReturns false if the ID is lower than 0x45, greater than 0x8A or if it's listed in the EAT_ITEM_EFFECT_IGNORE_LIST array.\n\nr0: Item ID\nreturn: True if the item should be eaten by TryEatItem.",
        None,
    )

    GetMaxPpWrapper = Symbol(
        [0x428D8],
        [0x231F458],
        None,
        "GetMaxPpWrapper",
        "Gets the maximum PP for a given move. A wrapper around the function in the ARM 9 binary.\n\nr0: move pointer\nreturn: max PP for the given move, capped at 99",
        None,
    )

    MoveIsNotPhysical = Symbol(
        [0x42900],
        [0x231F480],
        None,
        "MoveIsNotPhysical",
        "Checks if a move isn't a physical move.\n\nr0: move ID\nreturn: bool",
        None,
    )

    CategoryIsNotPhysical = Symbol(
        [0x42918],
        [0x231F498],
        None,
        "CategoryIsNotPhysical",
        "Checks that a move category is not CATEGORY_PHYSICAL.\n\nr0: move category ID\nreturn: bool",
        None,
    )

    TryDrought = Symbol(
        [0x4347C],
        [0x231FFFC],
        None,
        "TryDrought",
        "Attempts to drain all water from the current floor.\n\nFails if orbs are disabled on the floor or if the current tileset has the is_water_tileset flag set.\n\nr0: user pointer",
        None,
    )

    TryPounce = Symbol(
        [0x43B08],
        [0x2320688],
        None,
        "TryPounce",
        "Makes the target monster execute the Pounce action in a given direction if possible.\n\nIf the direction ID is 8, the target will pounce in the direction it's currently facing.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: direction ID",
        None,
    )

    TryBlowAway = Symbol(
        [0x43CC8],
        [0x2320848],
        None,
        "TryBlowAway",
        "Blows away the target monster in a given direction if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: direction ID",
        None,
    )

    TryExplosion = Symbol(
        [0x44330],
        [0x2320EB0],
        None,
        "TryExplosion",
        "Creates an explosion if possible.\n\nThe target monster is considered the source of the explosion.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: coordinates where the explosion should take place (center)\nr3: explosion radius (only works correctly with 1 and 2)\nstack[0]: damage type\nstack[1]: damage source",
        None,
    )

    TryAftermathExplosion = Symbol(
        [0x44670],
        [0x23211F0],
        None,
        "TryAftermathExplosion",
        "Creates the explosion for the ability aftermath if possible.\n\nThe target monster is considered the source of the explosion.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: coordinates where the explosion should take place (center)\nr3: explosion radius (only works correctly with 1 and 2)\nstack[0]: damage type\nstack[1]: damage source (normally DAMAGE_SOURCE_EXPLOSION)",
        None,
    )

    TryWarp = Symbol(
        [0x44BF0],
        [0x2321770],
        None,
        "TryWarp",
        "Makes the target monster warp if possible.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: warp type\nr3: position (if warp type is position-based)",
        None,
    )

    EnsureCanStandCurrentTile = Symbol(
        [0x44FEC],
        [0x2321B6C],
        None,
        "EnsureCanStandCurrentTile",
        "Checks that the given monster is standing on a tile it can stand on given its\nmovement type and warps it if not. If the monster is a non-leader ally, they\nwill be warped to the leader. Otherwise, the monster is warped randomly.\n\nr0: Entity pointer",
        None,
    )

    TryActivateNondamagingDefenderAbility = Symbol(
        [0x45960],
        [0x23224E0],
        None,
        "TryActivateNondamagingDefenderAbility",
        "Applies the effects of a defender's ability on an attacker. After a move is used,\nthis function is called to see if any of the bitflags for an ability were set and\napplies the corresponding effect. (The way leech seed removes certain statuses is\nalso handled here.)\n\nr0: entity pointer",
        None,
    )

    TryActivateNondamagingDefenderExclusiveItem = Symbol(
        [0x45BD8],
        [0x2322758],
        None,
        "TryActivateNondamagingDefenderExclusiveItem",
        "Applies the effects of a defender's item on an attacker. After a move is used,\nthis function is called to see if any of the bitflags for an item were set and\napplies the corresponding effect.\n\nr0: attacker entity pointer\nr1: defender entity pointer",
        None,
    )

    GetMoveRangeDistance = Symbol(
        [0x4618C],
        [0x2322D0C],
        None,
        "GetMoveRangeDistance",
        "Returns the maximum reach distance of a move, based on its AI range value.\n\nIf the move doesn't have an AI range value of RANGE_FRONT_10, RANGE_FRONT_WITH_CORNER_CUTTING or RANGE_FRONT_2_WITH_CORNER_CUTTING, returns 0.\nIf r2 is true, the move is a two-turn move and the user isn't charging said move, returns 0.\n\nr0: User entity pointer\nr1: Move pointer\nr2: True to perform the two-turn move check\nreturn: Maximum reach distance of the move, in tiles.",
        None,
    )

    MoveHitCheck = Symbol(
        [0x47B30],
        [0x23246B0],
        None,
        "MoveHitCheck",
        "Determines if a move used hits or misses the target. It gets called twice per target, once with r3 = false and a second time with r3 = true.\n\nr0: Attacker\nr1: Defender\nr2: Pointer to move data\nr3: False if the move's first accuracy (accuracy1) should be used, true if its second accuracy (accuracy2) should be used instead.\nstack[0]: If true, always hit if the attacker and defender are the same. Otherwise, moves can miss no matter what the attacker and defender are.\nreturns: True if the move hits, false if it misses.",
        None,
    )

    IsHyperBeamVariant = Symbol(
        [0x4841C],
        [0x2324F9C],
        None,
        "IsHyperBeamVariant",
        "Checks if a move is a Hyper Beam variant that requires a a turn to recharge.\n\nInclude moves: Frenzy Plant, Hydro Cannon, Hyper Beam, Blast Burn, Rock Wrecker, Giga Impact, Roar of Time\n\nr0: move\nreturn: bool",
        None,
    )

    IsChargingTwoTurnMove = Symbol(
        [0x4848C],
        [0x232500C],
        None,
        "IsChargingTwoTurnMove",
        "Checks if a monster is currently charging the specified two-turn move.\n\nr0: User entity pointer\nr1: Move pointer\nreturn: True if the user is charging the specified two-turn move, false otherwise.",
        None,
    )

    IsChargingAnyTwoTurnMove = Symbol(
        [0x48504],
        [0x2325084],
        None,
        "IsChargingAnyTwoTurnMove",
        "Returns a boolean indicating whether or not the given entity is charging any two-turn move.\n\nr0: Entity pointer\nr1: Unused boolean which was supposed to make function return true if the entity is under the effect of Charge (the Electric-type move).\n    However, the conditional which uses this boolean will never be activated, as the loop will always terminate before getting to it.\nreturn: bool",
        None,
    )

    HasMaxGinsengBoost99 = Symbol(
        [0x48680],
        [0x2325200],
        None,
        "HasMaxGinsengBoost99",
        "Checks if a move has a max Ginseng boost value of 99\n\nr0: Move\nreturn: True if the move's max Ginseng boost is 99, false otherwise.",
        None,
    )

    TwoTurnMoveForcedMiss = Symbol(
        [0x4873C],
        [0x23252BC],
        None,
        "TwoTurnMoveForcedMiss",
        "Checks if a move should miss a monster due to the monster being in the middle of Fly, Bounce, Dive, Dig, Shadow Force, or some other two-turn move that grants pseudo-invincibility.\n\nr0: entity pointer\nr1: move\nreturn: true if the move should miss",
        None,
    )

    DungeonRandOutcomeUserTargetInteraction = Symbol(
        [0x4881C],
        [0x232539C],
        None,
        "DungeonRandOutcomeUserTargetInteraction",
        "Like DungeonRandOutcome, but specifically for user-target interactions.\n\nThis modifies the underlying random process depending on factors like Serene Grace, and whether or not either entity has fainted.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: base success percentage (100*p). 0 is treated specially and guarantees success.\nreturns: True if the random check passed, false otherwise.",
        None,
    )

    DungeonRandOutcomeUserAction = Symbol(
        [0x48908],
        [0x2325488],
        None,
        "DungeonRandOutcomeUserAction",
        "Like DungeonRandOutcome, but specifically for user actions.\n\nThis modifies the underlying random process to factor in Serene Grace (and checks whether the user is a valid entity).\n\nr0: entity pointer\nr1: base success percentage (100*p). 0 is treated specially and guarantees success.\nreturns: True if the random check passed, false otherwise.",
        None,
    )

    CanAiUseMove = Symbol(
        [0x4895C],
        [0x23254DC],
        None,
        "CanAiUseMove",
        "Checks if an AI-controlled monster can use a move.\nWill return false if the any of the flags move::f_exists, move::f_subsequent_in_link_chain or move::f_disabled is true. The function does not check if the flag move::f_enabled_for_ai is set. This function also returns true if the call to CanMonsterUseMove is true.\nThe function contains a loop that is supposed to check other moves after the specified one, but the loop breaks after it finds a move that isn't linked, which is always true given the checks in place at the start of the function.\n\nr0: Entity pointer\nr1: Move index\nr2: extra_checks parameter when calling CanMonsterUseMove\nreturn: True if the AI can use the move (not accounting for move::f_enabled_for_ai)",
        None,
    )

    CanMonsterUseMove = Symbol(
        [0x48A0C],
        [0x232558C],
        None,
        "CanMonsterUseMove",
        "Checks if a monster can use the given move.\nWill always return true for the regular attack. Will return false if the move if the flag move::f_disabled is true, if the flag move::f_sealed is true. More things will be checked if the extra_checks parameter is true.\n\nr0: Entity pointer\nr1: Move pointer\nr2: True to check whether the move is out of PP, whether it can be used under the taunted status and whether the encore status prevents using the move\nreturn: True if the monster can use the move, false otherwise.",
        None,
    )

    UpdateMovePp = Symbol(
        [0x48C74],
        [0x23257F4],
        None,
        "UpdateMovePp",
        "Updates the PP of any moves that were used by a monster, if PP should be consumed.\n\nr0: entity pointer\nr1: flag for whether or not PP should be consumed",
        None,
    )

    GetDamageSourceWrapper = Symbol(
        [0x48D2C],
        [0x23258AC],
        None,
        "GetDamageSourceWrapper",
        "Wraps GetDamageSource (in arm9) for a move info struct rather than a move ID.\n\nr0: move info pointer\nr1: item ID\nreturn: damage source",
        None,
    )

    LowerSshort = Symbol(
        [0x48D4C],
        [0x23258CC],
        None,
        "LowerSshort",
        "Gets the lower 2 bytes of a 4-byte number and interprets it as a signed short.\n\nr0: 4-byte number x\nreturn: (short) x",
        None,
    )

    PlayMoveAnimation = Symbol(
        [0x4959C],
        [0x232611C],
        None,
        "PlayMoveAnimation",
        "Handles the process of getting and playing all the animations for a move. Waits\nuntil the animation has no more frames before returning.\n\nr0: Pointer to the entity that used the move\nr1: Pointer to the entity that is the target\nr2: Move pointer\nr3: position",
        None,
    )

    GetMoveAnimationId = Symbol(
        [0x499F8],
        [0x2326578],
        None,
        "GetMoveAnimationId",
        "Returns the move animation ID that should be played for a move.\nIt contains a check for weather ball. After that, if the parameter should_play_alternative_animation is false, the move ID is returned. If it's true, there's a bunch of manual ID checks that result on a certain hardcoded return value.\n\nr0: Move ID\nr1: Apparent weather for the monster who used the move\nr2: Result of ShouldMovePlayADifferentAnimation\nreturn: Move animation ID",
        None,
    )

    ShouldMovePlayAlternativeAnimation = Symbol(
        [0x49B60],
        [0x23266E0],
        None,
        "ShouldMovePlayAlternativeAnimation",
        "Checks whether a moved used by a monster should play its alternative animation. Includes checks for Curse, Snore, Sleep Talk, Solar Beam and 2-turn moves.\n\nr0: Pointer to the entity that used the move\nr1: Move pointer\nreturn: True if the move should play its alternative animation",
        None,
    )

    ExecuteMoveEffect = Symbol(
        [0x52724],
        [0x232F2A4],
        None,
        "ExecuteMoveEffect",
        "Handles the effects that happen after a move is used. Includes a loop that is run for each target, mutiple ability checks and the giant switch statement that executes the effect of the move used given its ID.\n\nr0: pointer to some struct\nr1: attacker pointer\nr2: pointer to move data\nr3: ?\nstack[0]: ?",
        None,
    )

    DoMoveDamageInlined = Symbol(
        [0x56930],
        [0x23334B0],
        None,
        "DoMoveDamageInlined",
        "Exactly the same as DoMoveDamage, except it appears DealDamage was inlined.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: item ID\nreturn: whether or not damage was dealt",
        None,
    )

    DealDamage = Symbol(
        [0x569E0],
        [0x2333560],
        None,
        "DealDamage",
        "Deals damage from a move or item used by an attacking monster on a defending monster.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: damage multiplier (as a binary fixed-point number with 8 fraction bits)\nstack[0]: item ID\nreturn: amount of damage dealt",
        None,
    )

    DealDamageWithTypeAndPowerBoost = Symbol(
        [0x56A78],
        [0x23335F8],
        None,
        "DealDamageWithTypeAndPowerBoost",
        "Same as DealDamage, except with an explicit move type and a base power boost.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move\nr3: damage multiplier (as a binary fixed-point number with 8 fraction bits)\nstack[0]: item ID\nstack[1]: move type\nstack[2]: base power boost\nreturn: amount of damage dealt",
        None,
    )

    DealDamageProjectile = Symbol(
        [0x56B0C],
        [0x233368C],
        None,
        "DealDamageProjectile",
        "Deals damage from a variable-damage projectile.\n\nr0: entity pointer 1?\nr1: entity pointer 2?\nr2: move pointer\nr3: move power\nstack[0]: damage multiplier (as a binary fixed-point number with 8 fraction bits)\nstack[1]: item ID of the projectile\nreturn: Calculated damage",
        None,
    )

    DealDamageWithType = Symbol(
        [0x56B9C],
        [0x233371C],
        None,
        "DealDamageWithType",
        "Same as DealDamage, except with an explicit move type.\n\nr0: attacker pointer\nr1: defender pointer\nr2: move type\nr3: move\nstack[0]: damage multiplier (as a binary fixed-point number with 8 fraction bits)\nstack[1]: item ID\nreturn: amount of damage dealt",
        None,
    )

    PerformDamageSequence = Symbol(
        [0x56C2C],
        [0x23337AC],
        None,
        "PerformDamageSequence",
        "Performs the 'damage sequence' given the results of the damage calculation. This includes running the accuracy roll with MoveHitCheck, calling ApplyDamageAndEffects, and some other miscellaneous bits of state bookkeeping (including handling the effects of Illuminate).\n\nThis is the last function called by DealDamage. The result of this call is the return value of DealDamage and its relatives.\n\nr0: Attacker pointer\nr1: Defender pointer\nr2: Move pointer\nr3: [output] struct containing info about the damage calculation\nstack[0]: Damage source\nreturn: Calculated damage",
        None,
    )

    CanHitWithRegularAttack = Symbol(
        [0x56E88],
        [0x2333A08],
        None,
        "CanHitWithRegularAttack",
        "Returns true if the defender is adjacent to the attacker and can hit them with a regular attack.\nNotably, this check is what prevents ranged moves, moves that cut corners, etc. from being reflected by Magic Coat and Mirror Move.\n\nr0: Entity pointer (attacker)\nr1: Entity pointer (defender)\nreturn: bool",
        None,
    )

    StatusCheckerCheck = Symbol(
        [0x56F34],
        [0x2333AB4],
        None,
        "StatusCheckerCheck",
        "Determines if using a given move against its intended targets would be redundant because all of them already have the effect caused by said move.\n\nr0: Pointer to the entity that is considering using the move\nr1: Move pointer\nreturn: True if it makes sense to use the move, false if it would be redundant given the effects it causes and the effects that all the targets already have.",
        None,
    )

    GetApparentWeather = Symbol(
        [0x58BC8],
        [0x2335748],
        None,
        "GetApparentWeather",
        "Get the weather, as experienced by a specific entity.\n\nr0: entity pointer\nreturn: weather ID",
        None,
    )

    TryWeatherFormChange = Symbol(
        [0x59030],
        [0x2335BB0],
        None,
        "TryWeatherFormChange",
        "Tries to change a monster into one of its weather-related alternative forms. Applies to Castform and Cherrim, and checks for their unique abilities.\n\nr0: pointer to entity",
        None,
    )

    ActivateSportCondition = Symbol(
        [0x5930C],
        [0x2335E8C],
        None,
        "ActivateSportCondition",
        "Activates the Mud Sport or Water Sport condition on the dungeon floor for some number of turns.\n\nr0: water sport flag (false for Mud Sport, true for Water Sport)",
        None,
    )

    TryActivateWeather = Symbol(
        [0x59384],
        [0x2335F04],
        None,
        "TryActivateWeather",
        "Tries to change the weather based upon the information for each weather type in the\ndungeon struct. Returns whether the weather was succesfully changed or not.\n\nr0: bool to log message and play animation?\nr1: bool to force weather change and animation?\nreturn: True if the weather changed",
        None,
    )

    DigitCount = Symbol(
        [0x59530],
        [0x23360B0],
        None,
        "DigitCount",
        "Counts the number of digits in a nonnegative integer.\n\nIf the number is negative, it is cast to a uint16_t before counting digits.\n\nr0: int\nreturn: number of digits in int",
        None,
    )

    LoadTextureUi = Symbol(
        [0x59580],
        [0x2336100],
        None,
        "LoadTextureUi",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    DisplayNumberTextureUi = Symbol(
        [0x5974C],
        [0x23362CC],
        None,
        "DisplayNumberTextureUi",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: x position\nr1: y position\nr2: number\nr3: ally_mode\nreturn: xsize",
        None,
    )

    DisplayCharTextureUi = Symbol(
        [0x59854],
        [0x23363D4],
        None,
        "DisplayCharTextureUi",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: render_3d_element_64\nr1: x position\nr2: y position\nr3: char_id\nstack[0]: ?\nreturn: ?",
        None,
    )

    DisplayUi = Symbol(
        [0x598DC],
        [0x233645C],
        None,
        "DisplayUi",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    GetTile = Symbol(
        [0x5A14C],
        [0x2336CCC],
        None,
        "GetTile",
        "Get the tile at some position. If the coordinates are out of bounds, returns a default tile.\n\nr0: x position\nr1: y position\nreturn: tile pointer",
        None,
    )

    GetTileSafe = Symbol(
        [0x5A1B4],
        [0x2336D34],
        None,
        "GetTileSafe",
        "Get the tile at some position. If the coordinates are out of bounds, returns a pointer to a copy of the default tile.\n\nr0: x position\nr1: y position\nreturn: tile pointer",
        None,
    )

    IsFullFloorFixedRoom = Symbol(
        [0x5A224],
        [0x2336DA4],
        None,
        "IsFullFloorFixedRoom",
        "Checks if the current fixed room on the dungeon generation info corresponds to a fixed, full-floor layout.\n\nThe first non-full-floor fixed room is 0xA5, which is for Sealed Chambers.\n\nreturn: bool",
        None,
    )

    IsCurrentTilesetBackground = Symbol(
        [0x5A254],
        [0x2336DD4],
        None,
        "IsCurrentTilesetBackground",
        "Calls IsBackgroundTileset with the current tileset ID\n\nreturn: True if the current dungeon tileset is a background, false if it's a regular tileset.",
        None,
    )

    TrySpawnGoldenChamber = Symbol(
        [0x5A274],
        [0x2336DF4],
        None,
        "TrySpawnGoldenChamber",
        "Changes the tileset and fixed room id of the floor for the Golden Chamber if the floor should be a\nGolden Chamber.\n\nNo params.",
        None,
    )

    CountItemsOnFloorForAcuteSniffer = Symbol(
        [0x5A2B0],
        [0x2336E30],
        None,
        "CountItemsOnFloorForAcuteSniffer",
        "Counts the number of items on the floor by checking every tile for an item and stores it into\ndungeon::item_sniffer_item_count\n\nNo params.",
        None,
    )

    GetStairsSpawnPosition = Symbol(
        [0x5A410],
        [0x2336F90],
        None,
        "GetStairsSpawnPosition",
        "Gets the spawn position for the stairs and stores it at the passed pointers.\n\nr0: [output] pointer to x coordinate\nr1: [output] pointer to y coordinate",
        None,
    )

    PositionIsOnStairs = Symbol(
        [0x5A43C],
        [0x2336FBC],
        None,
        "PositionIsOnStairs",
        "Checks if this location is on top of the staircase. In the game it is only used to check if an outlaw has reached\nthe staircase.\n\nr0: x coordinate\nr1: y coordinate\nreturn: bool",
        None,
    )

    GetStairsRoom = Symbol(
        [0x5A478],
        [0x2336FF8],
        None,
        "GetStairsRoom",
        "Returns the index of the room that contains the stairs\n\nreturn: Room index",
        None,
    )

    GetDefaultTileTextureId = Symbol(
        [0x5A4A0],
        [0x2337020],
        None,
        "GetDefaultTileTextureId",
        "Returns the texture_id of the default tile?\n\nreturn: texture_id",
        None,
    )

    DetermineAllTilesWalkableNeighbors = Symbol(
        [0x5AA9C],
        [0x233761C],
        None,
        "DetermineAllTilesWalkableNeighbors",
        "Evaluates the walkable_neighbor_flags for all tiles.\n\nNo params.",
        None,
    )

    DetermineTileWalkableNeighbors = Symbol(
        [0x5AAD4],
        [0x2337654],
        None,
        "DetermineTileWalkableNeighbors",
        "Evaluates the walkable_neighbor_flags for the this tile by checking the 8 adjacent tiles.\n\nr0: x coordinate\nr1: y coordinate",
        None,
    )

    UpdateTrapsVisibility = Symbol(
        [0x5AF9C],
        [0x2337B1C],
        None,
        "UpdateTrapsVisibility",
        "Exact purpose unknown. Gets called whenever a trap tile is shown or hidden.\n\nNo params.",
        None,
    )

    DrawTileGrid = Symbol(
        [0x5B478],
        [0x2337FF8],
        None,
        "DrawTileGrid",
        "Draws a grid on the nearby walkable tiles. Triggered by pressing Y.\n\nr0: Coordinates of the entity around which the grid will be drawn\nr1: ?\nr2: ?\nr3: ?",
        None,
    )

    HideTileGrid = Symbol(
        [0x5B7EC],
        [0x233836C],
        None,
        "HideTileGrid",
        "Hides the grid on the nearby walkable tiles. Triggered by releasing Y.\n\nNo params.",
        None,
    )

    DiscoverMinimap = Symbol(
        [0x5BA8C],
        [0x233860C],
        None,
        "DiscoverMinimap",
        "Discovers the tiles around the specified position on the minimap.\n\nThe discovery radius depends on the visibility range of the floor. If display_data::blinded is true, the function returns early without doing anything.\n\nr0: Position around which the map should be discovered",
        None,
    )

    PositionHasItem = Symbol(
        [0x5BB7C],
        [0x23386FC],
        None,
        "PositionHasItem",
        "Checks if the tile at the position has an item on it.\n\nr0: Position to check\nreturn: bool",
        None,
    )

    PositionHasMonster = Symbol(
        [0x5BBB8],
        [0x2338738],
        None,
        "PositionHasMonster",
        "Checks if the tile at the position has a monster on it.\n\nr0: Position to check\nreturn: bool",
        None,
    )

    TrySmashWall = Symbol(
        [0x5BBEC],
        [0x233876C],
        None,
        "TrySmashWall",
        "Checks if the tile at the position is a wall. If so, smash it (turn it into a floor tile), play an animation\n\nr0: Wall position to smash\nreturn: bool",
        None,
    )

    IsWaterTileset = Symbol(
        [0x5BEE4],
        [0x2338A64],
        None,
        "IsWaterTileset",
        "Returns flag tileset_property::is_water_tileset for the current tileset\n\nreturn: True if the current tileset is a water tileset",
        None,
    )

    GetRandomSpawnMonsterID = Symbol(
        [0x5BFE8],
        [0x2338B68],
        None,
        "GetRandomSpawnMonsterID",
        "Note: unverified, ported from Irdkwia's notes\n\nreturn: monster ID?",
        None,
    )

    NearbyAllyIqSkillIsEnabled = Symbol(
        [0x5C2D8],
        [0x2338E58],
        None,
        "NearbyAllyIqSkillIsEnabled",
        "Appears to check whether or not the given monster has any allies nearby (within 1 tile) that have the given IQ skill active.\n\nr0: entity pointer\nr1: IQ skill ID\nreturn: bool",
        None,
    )

    ResetGravity = Symbol(
        [0x5C3BC],
        [0x2338F3C],
        None,
        "ResetGravity",
        "Resets gravity (and the byte after it?) in the dungeon struct back to 0.\n\nNo params.",
        None,
    )

    GravityIsActive = Symbol(
        [0x5C3E0],
        [0x2338F60],
        None,
        "GravityIsActive",
        "Checks if gravity is active on the floor.\n\nreturn: bool",
        None,
    )

    TryActivateGravity = Symbol(
        [0x5C40C],
        [0x2338F8C],
        None,
        "TryActivateGravity",
        "Attempts to activate Gravity for this dungeon floor.\n\nreturn: whether or not gravity was activated",
        None,
    )

    ShouldBoostKecleonShopSpawnChance = Symbol(
        [0x5C510],
        [0x2339090],
        None,
        "ShouldBoostKecleonShopSpawnChance",
        "Gets the boost_kecleon_shop_spawn_chance field on the dungeon struct.\n\nreturn: bool",
        None,
    )

    SetShouldBoostKecleonShopSpawnChance = Symbol(
        [0x5C528],
        [0x23390A8],
        None,
        "SetShouldBoostKecleonShopSpawnChance",
        "Sets the boost_kecleon_shop_spawn_chance field on the dungeon struct to the given value.\n\nr0: bool to set the flag to",
        None,
    )

    UpdateShouldBoostKecleonShopSpawnChance = Symbol(
        [0x5C540],
        [0x23390C0],
        None,
        "UpdateShouldBoostKecleonShopSpawnChance",
        "Sets the boost_kecleon_shop_spawn_chance field on the dungeon struct depending on if a team member has the exclusive item effect for more kecleon shops.\n\nNo params.",
        None,
    )

    GetDoughSeedFlag = Symbol(
        [0x5C580],
        [0x2339100],
        None,
        "GetDoughSeedFlag",
        "Gets the dough_seed_extra_money_flag field on the dungeon struct.\n\nreturn: bool",
        None,
    )

    SetDoughSeedFlag = Symbol(
        [0x5C598],
        [0x2339118],
        None,
        "SetDoughSeedFlag",
        "Sets the dough_seed_extra_money_flag field on the dungeon struct to the given value.\n\nr0: bool to set the flag to",
        None,
    )

    TrySpawnDoughSeedPoke = Symbol(
        [0x5C5B0],
        [0x2339130],
        None,
        "TrySpawnDoughSeedPoke",
        "Checks the dough_seed_extra_money_flag field on the dungeon struct and tries to spawn\nextra poke if it is set.\n\nNo params.",
        None,
    )

    IsSecretBazaar = Symbol(
        [0x5C614],
        [0x2339194],
        None,
        "IsSecretBazaar",
        "Checks if the current floor is the Secret Bazaar.\n\nreturn: bool",
        None,
    )

    ShouldBoostHiddenStairsSpawnChance = Symbol(
        [0x5C63C],
        [0x23391BC],
        None,
        "ShouldBoostHiddenStairsSpawnChance",
        "Gets the boost_hidden_stairs_spawn_chance field on the dungeon struct.\n\nreturn: bool",
        None,
    )

    SetShouldBoostHiddenStairsSpawnChance = Symbol(
        [0x5C654],
        [0x23391D4],
        None,
        "SetShouldBoostHiddenStairsSpawnChance",
        "Sets the boost_hidden_stairs_spawn_chance field on the dungeon struct to the given value.\n\nr0: bool to set the flag to",
        None,
    )

    UpdateShouldBoostHiddenStairsSpawnChance = Symbol(
        [0x5C66C],
        [0x23391EC],
        None,
        "UpdateShouldBoostHiddenStairsSpawnChance",
        "Sets the boost_hidden_stairs_spawn_chance field on the dungeon struct depending on if a team member has the exclusive item effect for more hidden stairs.\n\nNo params.",
        None,
    )

    IsSecretRoom = Symbol(
        [0x5C6AC],
        [0x233922C],
        None,
        "IsSecretRoom",
        "Checks if the current floor is the Secret Room fixed floor (from hidden stairs).\n\nreturn: bool",
        None,
    )

    IsSecretFloor = Symbol(
        [0x5C6D4],
        [0x2339254],
        None,
        "IsSecretFloor",
        "Checks if the current floor is a secret bazaar or a secret room.\n\nreturn: bool",
        None,
    )

    GetCurrentHiddenStairsType = Symbol(
        [0x5C700],
        [0x2339280],
        None,
        "GetCurrentHiddenStairsType",
        "Checks if the current floor is a secret bazaar or a secret room and returns which one it is.\n\nreturn: enum hidden_stairs_type",
        None,
    )

    HiddenStairsPresent = Symbol(
        [0x5C728],
        [0x23392A8],
        None,
        "HiddenStairsPresent",
        "Checks if the hidden stairs are present on this floor.\n\nThe function checks that dungeon_generation_info::hidden_stairs_pos isn't (-1, -1)\n\nreturn: True if the hidden stairs are present on this floor, false otherwise.",
        None,
    )

    PositionIsOnHiddenStairs = Symbol(
        [0x5C758],
        [0x23392D8],
        None,
        "PositionIsOnHiddenStairs",
        "Checks if this location is on top of the hidden stairs.\n\nr0: position pointer\nreturn: bool",
        None,
    )

    HiddenStairsTrigger = Symbol(
        [0x5C7E4],
        [0x2339364],
        None,
        "HiddenStairsTrigger",
        "Called whenever the leader steps on the hidden stairs.\n\nIf the stairs hadn't been revealed yet, plays the corresponding animation.\n\nr0: True to display a message if the stairs are revealed, false to omit it.",
        None,
    )

    GetHiddenStairsField = Symbol(
        [0x5C8A0],
        [0x2339420],
        None,
        "GetHiddenStairsField",
        "Gets the hidden_stairs_type variable from dungeon::dungeon_generation_info.\n\nreturn: enum hidden_stairs_type",
        None,
    )

    SetHiddenStairsField = Symbol(
        [0x5C8B8],
        [0x2339438],
        None,
        "SetHiddenStairsField",
        "Sets the hidden_stairs_type variable from dungeon::dungeon_generation_info to a certain value.\n\nr0: New value",
        None,
    )

    GetHiddenFloorField = Symbol(
        [0x5C8D0],
        [0x2339450],
        None,
        "GetHiddenFloorField",
        "Gets the hidden_floor_type variable from dungeon::dungeon_generation_info.\n\nreturn: enum hidden_stairs_type",
        None,
    )

    SetHiddenFloorField = Symbol(
        [0x5C8E8],
        [0x2339468],
        None,
        "SetHiddenFloorField",
        "Sets the hidden_floor_type variable from dungeon::dungeon_generation_info to a certain value.\n\nr0: New value",
        None,
    )

    GetMinimapData = Symbol(
        [0x5D168],
        [0x2339CE8],
        None,
        "GetMinimapData",
        "Returns a pointer to the minimap_display_data struct in the dungeon struct.\n\nreturn: minimap_display_data*",
        None,
    )

    DrawMinimapTile = Symbol(
        [0x5D23C],
        [0x2339DBC],
        None,
        "DrawMinimapTile",
        "Draws a single tile on the minimap.\n\nr0: X position\nr1: Y position",
        None,
    )

    UpdateMinimap = Symbol(
        [0x5DD38],
        [0x233A8B8],
        None,
        "UpdateMinimap",
        "Graphically updates the minimap\n\nNo params.",
        None,
    )

    SetMinimapDataE447 = Symbol(
        [0x5E268],
        [0x233ADE8],
        None,
        "SetMinimapDataE447",
        "Sets minimap_display_data::field_0xE447 to the specified value\n\nr0: Value to set the field to",
        None,
    )

    GetMinimapDataE447 = Symbol(
        [0x5E280],
        [0x233AE00],
        None,
        "GetMinimapDataE447",
        "Exclusive to the EU ROM. Returns minimap_display_data::field_0xE447.\n\nreturn: minimap_display_data::field_0xE447",
        None,
    )

    SetMinimapDataE448 = Symbol(
        [0x5E294],
        [0x233AE14],
        None,
        "SetMinimapDataE448",
        "Sets minimap_display_data::field_0xE448 to the specified value\n\nr0: Value to set the field to",
        None,
    )

    InitWeirdMinimapMatrix = Symbol(
        [0x5E2F4],
        [0x233AE74],
        None,
        "InitWeirdMinimapMatrix",
        "Initializes the matrix at minimap_display_data+0xE000. Seems to overflow said matrix when doing so.\n\nNo params.",
        None,
    )

    InitMinimapDisplayTile = Symbol(
        [0x5E354],
        [0x233AED4],
        None,
        "InitMinimapDisplayTile",
        "Used to initialize an instance of struct minimap_display_tile\n\nr0: Pointer to struct to init\nr1: Seems to be a pointer to the file that stores minimap icons or something like that",
        None,
    )

    LoadFixedRoomDataVeneer = Symbol(
        [0x5E688],
        [0x233B208],
        None,
        "LoadFixedRoomDataVeneer",
        "Likely a linker-generated veneer for LoadFixedRoomData.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nNo params.",
        None,
    )

    UnloadFixedRoomData = Symbol(
        [0x5E694],
        [0x233B214],
        None,
        "UnloadFixedRoomData",
        "Unloads fixed room data from the buffer pointed to by FIXED_ROOM_DATA_PTR, then clears the pointer.\n\nAlso clears dungeon::unk_fixed_room_pointer.\n\nNo params.",
        None,
    )

    IsNormalFloor = Symbol(
        [0x5E6B8],
        [0x233B238],
        None,
        "IsNormalFloor",
        "Checks if the current floor is a normal layout.\n\n'Normal' means any layout that is NOT one of the following:\n- Hidden stairs floors\n- Golden Chamber\n- Challenge Request floor\n- Outlaw hideout\n- Treasure Memo floor\n- Full-room fixed floors (ID < 0xA5) [0xA5 == Sealed Chamber]\n\nreturn: bool",
        None,
    )

    GenerateFloor = Symbol(
        [0x5E73C],
        [0x233B2BC],
        None,
        "GenerateFloor",
        "This is the master function that generates the dungeon floor.\n\nVery loosely speaking, this function first tries to generate a valid floor layout. Then it tries to spawn entities in a valid configuration. Finally, it performs cleanup and post-processing depending on the dungeon.\n\nIf a spawn configuration is invalid, the entire floor layout is scrapped and regenerated. If the generated floor layout is invalid 10 times in a row, or a valid spawn configuration isn't generated within 10 attempts, the generation algorithm aborts and the default one-room Monster House floor is generated as a fallback.\n\nNo params.",
        None,
    )

    GetTileTerrain = Symbol(
        [0x5EEDC],
        [0x233BA5C],
        None,
        "GetTileTerrain",
        "Gets the terrain type of a tile.\n\nr0: tile pointer\nreturn: terrain ID",
        None,
    )

    DungeonRand100 = Symbol(
        [0x5EEE8],
        [0x233BA68],
        None,
        "DungeonRand100",
        "Compute a pseudorandom integer on the interval [0, 100) using the dungeon PRNG.\n\nreturn: pseudorandom integer",
        None,
    )

    ClearHiddenStairs = Symbol(
        [0x5EEF8],
        [0x233BA78],
        None,
        "ClearHiddenStairs",
        "Clears the tile (terrain and spawns) on which Hidden Stairs are spawned, if applicable.\n\nNo params.",
        None,
    )

    FlagHallwayJunctions = Symbol(
        [0x5EF70],
        [0x233BAF0],
        None,
        "FlagHallwayJunctions",
        "Sets the junction flag (bit 3 of the terrain flags) on any hallway junction tiles in some range [x0, x1), [y0, y1). This leaves tiles within rooms untouched.\n\nA hallway tile is considered a junction if it has at least 3 cardinal neighbors with open terrain.\n\nr0: x0\nr1: y0\nr2: x1\nr3: y1",
        None,
    )

    GenerateStandardFloor = Symbol(
        [0x5F08C],
        [0x233BC0C],
        None,
        "GenerateStandardFloor",
        "Generate a standard floor with the given parameters.\n\nBroadly speaking, a standard floor is generated as follows:\n1. Generating the grid\n2. Creating a room or hallway anchor in each grid cell\n3. Creating hallways between grid cells\n4. Generating special features (maze room, Kecleon shop, Monster House, extra hallways, room imperfections, secondary structures)\n\nr0: grid size x\nr1: grid size y\nr2: floor properties",
        None,
    )

    GenerateOuterRingFloor = Symbol(
        [0x5F1F4],
        [0x233BD74],
        None,
        "GenerateOuterRingFloor",
        "Generates a floor layout with a 4x2 grid of rooms, surrounded by an outer ring of hallways.\n\nr0: floor properties",
        None,
    )

    GenerateCrossroadsFloor = Symbol(
        [0x5F680],
        [0x233C200],
        None,
        "GenerateCrossroadsFloor",
        "Generates a floor layout with a mesh of hallways on the interior 3x2 grid, surrounded by a boundary of rooms protruding from the interior like spikes, excluding the corner cells.\n\nr0: floor properties",
        None,
    )

    GenerateLineFloor = Symbol(
        [0x5FAE0],
        [0x233C660],
        None,
        "GenerateLineFloor",
        "Generates a floor layout with 5 grid cells in a horizontal line.\n\nr0: floor properties",
        None,
    )

    GenerateCrossFloor = Symbol(
        [0x5FC40],
        [0x233C7C0],
        None,
        "GenerateCrossFloor",
        "Generates a floor layout with 5 rooms arranged in a cross ('plus sign') formation.\n\nr0: floor properties",
        None,
    )

    GenerateBeetleFloor = Symbol(
        [0x5FDD8],
        [0x233C958],
        None,
        "GenerateBeetleFloor",
        "Generates a floor layout in a 'beetle' formation, which is created by taking a 3x3 grid of rooms, connecting the rooms within each row, and merging the central column into one big room.\n\nr0: floor properties",
        None,
    )

    MergeRoomsVertically = Symbol(
        [0x5FF94],
        [0x233CB14],
        None,
        "MergeRoomsVertically",
        "Merges two vertically stacked rooms into one larger room.\n\nr0: x grid coordinate of the rooms to merge\nr1: y grid coordinate of the upper room\nr2: dy, where the lower room has a y grid coordinate of y+dy\nr3: grid to update",
        None,
    )

    GenerateOuterRoomsFloor = Symbol(
        [0x600E0],
        [0x233CC60],
        None,
        "GenerateOuterRoomsFloor",
        "Generates a floor layout with a ring of rooms on the grid boundary and nothing in the interior.\n\nNote that this function is bugged, and won't properly connect all the rooms together for grid_size_x < 4.\n\nr0: grid size x\nr1: grid size y\nr2: floor properties",
        None,
    )

    IsNotFullFloorFixedRoom = Symbol(
        [0x60374],
        [0x233CEF4],
        None,
        "IsNotFullFloorFixedRoom",
        "Checks if a fixed room ID does not correspond to a fixed, full-floor layout.\n\nThe first non-full-floor fixed room is 0xA5, which is for Sealed Chambers.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    GenerateFixedRoom = Symbol(
        [0x60390],
        [0x233CF10],
        None,
        "GenerateFixedRoom",
        "Handles fixed room generation if the floor contains a fixed room.\n\nr0: fixed room ID\nr1: floor properties\nreturn: bool",
        None,
    )

    GenerateOneRoomMonsterHouseFloor = Symbol(
        [0x607D8],
        [0x233D358],
        None,
        "GenerateOneRoomMonsterHouseFloor",
        "Generates a floor layout with just a large, one-room Monster House.\n\nThis is the default layout if dungeon generation fails.\n\nNo params.",
        None,
    )

    GenerateTwoRoomsWithMonsterHouseFloor = Symbol(
        [0x608A8],
        [0x233D428],
        None,
        "GenerateTwoRoomsWithMonsterHouseFloor",
        "Generate a floor layout with two rooms (left and right), one of which is a Monster House.\n\nNo params.",
        None,
    )

    GenerateExtraHallways = Symbol(
        [0x60A4C],
        [0x233D5CC],
        None,
        "GenerateExtraHallways",
        "Generate extra hallways on the floor via a series of random walks.\n\nEach random walk starts from a random tile in a random room, leaves the room in a random cardinal direction, and from there tunnels through obstacles through a series of random turns, leaving open terrain in its wake. The random walk stops when it reaches open terrain, goes out of bounds, or reaches an impassable obstruction.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: number of extra hallways to generate",
        None,
    )

    GetGridPositions = Symbol(
        [0x60FE8],
        [0x233DB68],
        None,
        "GetGridPositions",
        "Get the grid cell positions for a given set of floor grid dimensions.\n\nr0: [output] pointer to array of the starting x coordinates of each grid column\nr1: [output] pointer to array of the starting y coordinates of each grid row\nr2: grid size x\nr3: grid size y",
        None,
    )

    InitDungeonGrid = Symbol(
        [0x61068],
        [0x233DBE8],
        None,
        "InitDungeonGrid",
        "Initialize a dungeon grid with defaults.\n\nThe grid is an array of grid cells stored in column-major order (such that grid cells with the same x value are stored contiguously), with a fixed column size of 15. If the grid size in the y direction is less than this, the last (15 - grid_size_y) entries of each column will be uninitialized.\n\nNote that the grid size arguments define the maximum size of the grid from a programmatic standpoint. However, grid cells can be invalidated if they exceed the configured floor size in the dungeon generation status struct. Thus, the dimensions of the ACTIVE grid can be smaller.\n\nr0: [output] grid (expected to have space for at least (15*(grid_size_x-1) + grid_size_y) dungeon grid cells)\nr1: grid size x\nr2: grid size y",
        None,
    )

    AssignRooms = Symbol(
        [0x61168],
        [0x233DCE8],
        None,
        "AssignRooms",
        "Randomly selects a subset of grid cells to become rooms.\n\nThe given number of grid cells will become rooms. If any of the selected grid cells are invalid, fewer rooms will be generated. The number of rooms assigned will always be at least 2 and never exceed 36.\n\nCells not marked as rooms will become hallway anchors. A hallway anchor is a single tile in a non-room grid cell to which hallways will be connected later, thus 'anchoring' hallway generation.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: number of rooms; if positive, a random value between [n_rooms, n_rooms+2] will be used. If negative, |n_rooms| will be used exactly.",
        None,
    )

    CreateRoomsAndAnchors = Symbol(
        [0x6137C],
        [0x233DEFC],
        None,
        "CreateRoomsAndAnchors",
        "Creates rooms and hallway anchors in each grid cell as designated by AssignRooms.\n\nThis function creates a rectangle of open terrain for each room (with some margin relative to the grid cell border). A single open tile is created in hallway anchor cells, and a hallway anchor indicator is set for later reference.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: array of the starting x coordinates of each grid column\nstack[0]: array of the starting y coordinates of each grid row\nstack[1]: room bitflags; only uses bit 2 (mask: 0b100), which enables room imperfections",
        None,
    )

    GenerateSecondaryStructures = Symbol(
        [0x616D8],
        [0x233E258],
        None,
        "GenerateSecondaryStructures",
        "Try to generate secondary structures in flagged rooms.\n\nIf a valid room with no special features is flagged to have a secondary structure, try to generate a random one in the room, based on the result of a dice roll:\n  0: no secondary structure\n  1: maze, or a central water/lava 'plus sign' as fallback, or a single water/lava tile in the center as a second fallback\n  2: checkerboard pattern of water/lava\n  3: central pool of water/lava\n  4: central 'island' with items and a Warp Tile, surrounded by a 'moat' of water/lava\n  5: horizontal or vertical divider of water/lava splitting the room in two\n\nIf the room isn't the right shape, dimension, or otherwise doesn't support the selected secondary structure, it is left untouched.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y",
        None,
    )

    AssignGridCellConnections = Symbol(
        [0x620C0],
        [0x233EC40],
        None,
        "AssignGridCellConnections",
        "Randomly assigns connections between adjacent grid cells.\n\nConnections are created via a random walk with momentum, starting from the grid cell at (cursor x, cursor y). A connection is drawn in a random direction from the current cursor, and this process is repeated a certain number of times (the 'floor connectivity' specified in the floor properties). The direction of the random walk has 'momentum'; there's a 50% chance it will be the same as the previous step (or rotated counterclockwise if on the boundary). This helps to reduce the number of dead ends and forks in the road caused by the random walk 'doubling back' on itself.\n\nIf dead ends are disabled in the floor properties, there is an additional phase to remove dead end hallway anchors (only hallway anchors, not rooms) by drawing additional connections. Note that the actual implementation contains a bug: the grid cell validity checks use the wrong index, so connections may be drawn to invalid cells.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: cursor x\nstack[0]: cursor y\nstack[1]: floor properties",
        None,
    )

    CreateGridCellConnections = Symbol(
        [0x624A0],
        [0x233F020],
        None,
        "CreateGridCellConnections",
        "Create grid cell connections either by creating hallways or merging rooms.\n\nWhen creating a hallway connecting a hallway anchor, the exact anchor coordinates are used as the endpoint. When creating a hallway connecting a room, a random point on the room edge facing the hallway is used as the endpoint. The grid cell boundaries are used as the middle coordinates for kinks (see CreateHallway).\n\nIf room merging is enabled, there is a 9.75% chance that two connected rooms will be merged into a single larger room (9.75% comes from two 5% rolls, one for each of the two rooms being merged). A room can only participate in a merge once.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: array of the starting x coordinates of each grid column\nstack[0]: array of the starting y coordinates of each grid row\nstack[1]: disable room merging flag",
        None,
    )

    GenerateRoomImperfections = Symbol(
        [0x62D98],
        [0x233F918],
        None,
        "GenerateRoomImperfections",
        "Attempt to generate room imperfections for each room in the floor layout, if enabled.\n\nEach room has a 40% chance of having imperfections if its grid cell is flagged to allow room imperfections. Imperfections are generated by randomly growing the walls of the room inwards for a certain number of iterations, starting from the corners.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y",
        None,
    )

    CreateHallway = Symbol(
        [0x63184],
        [0x233FD04],
        None,
        "CreateHallway",
        "Create a hallway between two points.\n\nIf the two points share no coordinates in common (meaning the line connecting them is diagonal), a 'kinked' hallway is created, with the kink at a specified 'middle' coordinate (in practice the grid cell boundary). For example, with a kinked horizontal hallway, there are two horizontal lines extending out from the endpoints, connected by a vertical line on the middle x coordinate.\n\nIf a hallway would intersect with an existing open tile (like an existing hallway), the hallway will only be created up to the point where it intersects with the open tile.\n\nr0: x0\nr1: y0\nr2: x1\nr3: y1\nstack[0]: vertical flag (true for vertical hallway, false for horizontal)\nstack[1]: middle x coordinate for kinked horizontal hallways\nstack[2]: middle y coordinate for kinked vertical hallways",
        None,
    )

    EnsureConnectedGrid = Symbol(
        [0x63488],
        [0x2340008],
        None,
        "EnsureConnectedGrid",
        "Ensure the grid forms a connected graph (all valid cells are reachable) by adding hallways to unreachable grid cells.\n\nIf a grid cell cannot be connected for some reason, remove it entirely.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: array of the starting x coordinates of each grid column\nstack[0]: array of the starting y coordinates of each grid row",
        None,
    )

    SetTerrainObstacleChecked = Symbol(
        [0x63964],
        [0x23404E4],
        None,
        "SetTerrainObstacleChecked",
        "Set the terrain of a specific tile to be an obstacle (wall or secondary terrain).\n\nSecondary terrain (water/lava) can only be placed in the specified room. If the tile room index does not match, a wall will be placed instead.\n\nr0: tile pointer\nr1: use secondary terrain flag (true for water/lava, false for wall)\nr2: room index",
        None,
    )

    FinalizeJunctions = Symbol(
        [0x639A0],
        [0x2340520],
        None,
        "FinalizeJunctions",
        "Finalizes junction tiles by setting the junction flag (bit 3 of the terrain flags) and ensuring open terrain.\n\nNote that this implementation is slightly buggy. This function scans tiles left-to-right, top-to-bottom, and identifies junctions as any open, non-hallway tile (room_index != 0xFF) adjacent to an open, hallway tile (room_index == 0xFF). This interacts poorly with hallway anchors (room_index == 0xFE). This function sets the room index of any hallway anchors to 0xFF within the same loop, so a hallway anchor may or may not be identified as a junction depending on the orientation of connected hallways.\n\nFor example, in the following configuration, the 'o' tile would be marked as a junction because the neighboring hallway tile to its left comes earlier in iteration, while the 'o' tile still has the room index 0xFE, causing the algorithm to mistake it for a room tile:\n  xxxxx\n  ---ox\n  xxx|x\n  xxx|x\nHowever, in the following configuration, the 'o' tile would NOT be marked as a junction because it comes earlier in iteration than any of its neighboring hallway tiles, so its room index is set to 0xFF before it can be marked as a junction. This is actually the ONLY possible configuration where a hallway anchor will not be marked as a junction.\n  xxxxx\n  xo---\n  x|xxx\n  x|xxx\n\nNo params.",
        None,
    )

    GenerateKecleonShop = Symbol(
        [0x63C4C],
        [0x23407CC],
        None,
        "GenerateKecleonShop",
        "Possibly generate a Kecleon shop on the floor.\n\nA Kecleon shop will be generated with a probability determined by the Kecleon shop spawn chance parameter. A Kecleon shop will be generated in a random room that is valid, connected, has no other special features, and has dimensions of at least 5x4. Kecleon shops will occupy the entire room interior, leaving a one tile margin from the room walls.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: Kecleon shop spawn chance (percentage from 0-100)",
        None,
    )

    GenerateMonsterHouse = Symbol(
        [0x64000],
        [0x2340B80],
        None,
        "GenerateMonsterHouse",
        "Possibly generate a Monster House on the floor.\n\nA Monster House will be generated with a probability determined by the Monster House spawn chance parameter, and only if the current floor can support one (no non-Monster-House outlaw missions or special floor types). A Monster House will be generated in a random room that is valid, connected, and is not a merged or maze room.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: Monster House spawn chance (percentage from 0-100)",
        None,
    )

    GenerateMazeRoom = Symbol(
        [0x64288],
        [0x2340E08],
        None,
        "GenerateMazeRoom",
        "Possibly generate a maze room on the floor.\n\nA maze room will be generated with a probability determined by the maze room chance parameter. A maze will be generated in a random room that is valid, connected, has odd dimensions, and has no other features.\n\nr0: grid to update\nr1: grid size x\nr2: grid size y\nr3: maze room chance (percentage from 0-100)",
        None,
    )

    GenerateMaze = Symbol(
        [0x644BC],
        [0x234103C],
        None,
        "GenerateMaze",
        "Generate a maze room within a given grid cell.\n\nA 'maze' is generated within the room using a series of random walks to place obstacle terrain (walls or secondary terrain) in a maze-like arrangement. 'Maze lines' (see GenerateMazeLine) are generated using every other tile around the room's border, as well as every other interior tile, as a starting point. This ensures that there are stripes of walkable open terrain surrounded by stripes of obstacles (the maze walls).\n\nr0: grid cell pointer\nr1: use secondary terrain flag (true for water/lava, false for walls)",
        None,
    )

    GenerateMazeLine = Symbol(
        [0x64738],
        [0x23412B8],
        None,
        "GenerateMazeLine",
        "Generate a 'maze line' from a given starting point, within the given bounds.\n\nA 'maze line' is a random walk starting from (x0, y0). The random walk proceeds with a stride of 2 in a random direction, laying down obstacles as it goes. The random walk terminates when it gets trapped and there are no more neighboring tiles that are open and in-bounds.\n\nr0: x0\nr1: y0\nr2: xmin\nr3: ymin\nstack[0]: xmax\nstack[1]: ymax\nstack[2]: use secondary terrain flag (true for water/lava, false for walls)\nstack[3]: room index",
        None,
    )

    SetSpawnFlag5 = Symbol(
        [0x648E0],
        [0x2341460],
        None,
        "SetSpawnFlag5",
        "Set spawn flag 5 (0b100000 or 0x20) on all tiles in a room.\n\nr0: grid cell",
        None,
    )

    IsNextToHallway = Symbol(
        [0x64934],
        [0x23414B4],
        None,
        "IsNextToHallway",
        "Checks if a tile position is either in a hallway or next to one.\n\nr0: x\nr1: y\nreturn: bool",
        None,
    )

    ResolveInvalidSpawns = Symbol(
        [0x649D8],
        [0x2341558],
        None,
        "ResolveInvalidSpawns",
        "Resolve invalid spawn flags on tiles.\n\nSpawn flags can be invalid due to terrain. For example, traps can't spawn on obstacles. Spawn flags can also be invalid due to multiple being set on a single tile, in which case one will take precedence. For example, stair spawns trump trap spawns.\n\nNo params.",
        None,
    )

    ConvertSecondaryTerrainToChasms = Symbol(
        [0x64A70],
        [0x23415F0],
        None,
        "ConvertSecondaryTerrainToChasms",
        "Converts all secondary terrain tiles (water/lava) to chasms.\n\nNo params.",
        None,
    )

    EnsureImpassableTilesAreWalls = Symbol(
        [0x64ADC],
        [0x234165C],
        None,
        "EnsureImpassableTilesAreWalls",
        "Ensures all tiles with the impassable flag are walls.\n\nNo params.",
        None,
    )

    InitializeTile = Symbol(
        [0x64B38],
        [0x23416B8],
        None,
        "InitializeTile",
        "Initialize a tile struct.\n\nr0: tile pointer",
        None,
    )

    ResetFloor = Symbol(
        [0x64B70],
        [0x23416F0],
        None,
        "ResetFloor",
        "Resets the floor in preparation for a floor generation attempt.\n\nResets all tiles, resets the border to be impassable, and clears entity spawns.\n\nNo params.",
        None,
    )

    PosIsOutOfBounds = Symbol(
        [0x64D10],
        [0x2341890],
        None,
        "PosIsOutOfBounds",
        "Checks if a position (x, y) is out of bounds on the map: !((0 <= x <= 55) && (0 <= y <= 31)).\n\nr0: x\nr1: y\nreturn: bool",
        None,
    )

    ShuffleSpawnPositions = Symbol(
        [0x64D48],
        [0x23418C8],
        None,
        "ShuffleSpawnPositions",
        "Randomly shuffle an array of spawn positions.\n\nr0: spawn position array containing bytes {x1, y1, x2, y2, ...}\nr1: number of (x, y) pairs in the spawn position array",
        None,
    )

    MarkNonEnemySpawns = Symbol(
        [0x64DB0],
        [0x2341930],
        None,
        "MarkNonEnemySpawns",
        "Mark tiles for all non-enemy entities, which includes stairs, items, traps, and the player. Note that this only marks tiles; actual spawning is handled later.\n\nMost entities are spawned randomly on a subset of permissible tiles.\n\nStairs are spawned if they don't already exist on the floor, and hidden stairs of the specified type are also spawned if configured as long as there are at least 2 floors left in the dungeon. Stairs can spawn on any tile that has open terrain, is in a room, isn't in a Kecleon shop, doesn't already have an enemy spawn, isn't a hallway junction, and isn't a special tile like a Key door.\n\nItems are spawned both normally in rooms, as well as in walls and Monster Houses. Normal items can spawn on any tile that has open terrain, is in a room, isn't in a Kecleon shop or Monster House, isn't a hallway junction, and isn't a special tile like a Key door. Buried items can spawn on any wall tile. Monster House items can spawn on any Monster House tile that isn't in a Kecleon shop and isn't a hallway junction.\n\nTraps are similarly spawned both normally in rooms, as well as in Monster Houses. Normal traps can spawn on any tile that has open terrain, is in a room, isn't in a Kecleon shop, doesn't already have an item or enemy spawn, and isn't a special tile like a Key door. Monster House traps follow the same conditions as Monster House items.\n\nThe player can spawn on any tile that has open terrain, is in a room, isn't in a Kecleon shop, isn't a hallway junction, doesn't already have an item, enemy, or trap spawn, and isn't a special tile like a Key door.\n\nr0: floor properties\nr1: empty Monster House flag. An empty Monster House is one with no items or traps, and only a small number of enemies.",
        None,
    )

    MarkEnemySpawns = Symbol(
        [0x654D4],
        [0x2342054],
        None,
        "MarkEnemySpawns",
        "Mark tiles for all enemies, which includes normal enemies and those in Monster Houses. Note that this only marks tiles; actual spawning is handled later in SpawnInitialMonsters.\n\nNormal enemies can spawn on any tile that has open terrain, isn't in a Kecleon shop, doesn't already have another entity spawn, and isn't a special tile like a Key door.\n\nMonster House enemies can spawn on any Monster House tile that isn't in a Kecleon shop, isn't where the player spawns, and isn't a special tile like a Key door.\n\nr0: floor properties\nr1: empty Monster House flag. An empty Monster House is one with no items or traps, and only a small number of enemies.",
        None,
    )

    SetSecondaryTerrainOnWall = Symbol(
        [0x657D0],
        [0x2342350],
        None,
        "SetSecondaryTerrainOnWall",
        "Set a specific tile to have secondary terrain (water/lava), but only if it's a passable wall.\n\nr0: tile pointer",
        None,
    )

    GenerateSecondaryTerrainFormations = Symbol(
        [0x65810],
        [0x2342390],
        None,
        "GenerateSecondaryTerrainFormations",
        "Generate secondary terrain (water/lava) formations.\n\nThis includes 'rivers' that flow from top-to-bottom (or bottom-to-top), as well as 'lakes' both standalone and after rivers. Water/lava formations will never cut through rooms, but they can pass through rooms to the opposite side.\n\nRivers are generated by a top-down or bottom-up random walk that ends when existing secondary terrain is reached or the walk goes out of bounds. Some rivers also end prematurely in a lake. Lakes are a large collection of secondary terrain generated around a central point.\n\nr0: bit index to test in the floor properties room flag bitvector (formations are only generated if the bit is set)\nr1: floor properties",
        None,
    )

    StairsAlwaysReachable = Symbol(
        [0x65ED0],
        [0x2342A50],
        None,
        "StairsAlwaysReachable",
        "Checks that the stairs are reachable from every walkable tile on the floor.\n\nThis runs a graph traversal algorithm that is very similar to breadth-first search (the order in which nodes are visited is slightly different), starting from the stairs. If any tile is walkable but wasn't reached by the traversal algorithm, then the stairs must not be reachable from that tile.\n\nr0: x coordinate of the stairs\nr1: y coordinate of the stairs\nr2: flag to always return true, but set a special bit on all walkable tiles that aren't reachable from the stairs\nreturn: bool",
        None,
    )

    GetNextFixedRoomAction = Symbol(
        [0x66534],
        [0x23430B4],
        None,
        "GetNextFixedRoomAction",
        "Returns the next action that needs to be performed when spawning a fixed room tile.\n\nreturn: Next action ID",
        None,
    )

    ConvertWallsToChasms = Symbol(
        [0x665AC],
        [0x234312C],
        None,
        "ConvertWallsToChasms",
        "Converts all wall tiles to chasms.\n\nNo params.",
        None,
    )

    ResetInnerBoundaryTileRows = Symbol(
        [0x66BE0],
        [0x2343760],
        None,
        "ResetInnerBoundaryTileRows",
        "Reset the inner boundary tile rows (y == 1 and y == 30) to their initial state of all wall tiles, with impassable walls at the edges (x == 0 and x == 55).\n\nNo params.",
        None,
    )

    ResetImportantSpawnPositions = Symbol(
        [0x66CCC],
        [0x234384C],
        None,
        "ResetImportantSpawnPositions",
        "Resets important spawn positions (the player, stairs, and hidden stairs) back to their default values.\n\nr0: dungeon generation info pointer (a field on the dungeon struct)",
        None,
    )

    SpawnStairs = Symbol(
        [0x66CF0],
        [0x2343870],
        None,
        "SpawnStairs",
        "Spawn stairs at the given location.\n\nIf the hidden stairs type is something other than HIDDEN_STAIRS_NONE, hidden stairs of the specified type will be spawned instead of normal stairs.\n\nIf spawning normal stairs and the current floor is a rescue floor, the room containing the stairs will be converted into a Monster House.\n\nIf attempting to spawn hidden stairs but the spawn is blocked, the floor generation status's hidden stairs spawn position will be updated, but it won't be transferred to the dungeon generation info struct.\n\nr0: position (two-byte array for {x, y})\nr1: dungeon generation info pointer (a field on the dungeon struct)\nr2: hidden stairs type",
        None,
    )

    GetHiddenStairsType = Symbol(
        [0x66E00],
        [0x2343980],
        None,
        "GetHiddenStairsType",
        "Gets the hidden stairs type for a given floor.\n\nThis function reads the floor properties and resolves any randomness (such as HIDDEN_STAIRS_RANDOM_SECRET_BAZAAR_OR_SECRET_ROOM and the floor_properties::hidden_stairs_spawn_chance) into a concrete hidden stairs type.\n\nr0: dungeon generation info pointer\nr1: floor properties pointer\nreturn: enum hidden_stairs_type",
        None,
    )

    GetFinalKecleonShopSpawnChance = Symbol(
        [0x66F20],
        [0x2343AA0],
        None,
        "GetFinalKecleonShopSpawnChance",
        "Gets the kecleon shop spawn chance for the floor.\n\nWhen dungeon::boost_kecleon_shop_spawn_chance is false, returns the same value as the input. When it's true, returns the input (chance * 1.2).\n\nr0: base kecleon shop spawn chance, floor_properties::kecleon_shop_spawn_chance\nreturn: int",
        None,
    )

    ResetHiddenStairsSpawn = Symbol(
        [0x66F6C],
        [0x2343AEC],
        None,
        "ResetHiddenStairsSpawn",
        "Resets hidden stairs spawn information for the floor. This includes the position on the floor generation status as well as the flag indicating whether the spawn was blocked.\n\nNo params.",
        None,
    )

    PlaceFixedRoomTile = Symbol(
        [0x66F94],
        [0x2343B14],
        None,
        "PlaceFixedRoomTile",
        "Used to spawn a single tile when generating a fixed room. The tile might contain an item or a monster.\n\nr0: Pointer to the tile to spawn\nr1: Fixed room action to perform. Controls what exactly will be spawned. The action is actually 12 bits long, the highest 4 bits are used as a parameter that represents a direction (for example, when spawning a monster).\nr2: Tile X position\nr3: Tile Y position",
        None,
    )

    FixedRoomActionParamToDirection = Symbol(
        [0x679D0],
        [0x2344550],
        None,
        "FixedRoomActionParamToDirection",
        "Converts the parameter stored in a fixed room action value to a direction ID.\n\nThe conversion is performed by subtracting 1 to the value. If the parameter had a value of 0, DIR_NONE is returned.\n\nr0: Parameter value\nreturn: Direction",
        None,
    )

    ApplyKeyEffect = Symbol(
        [0x67D3C],
        [0x23448BC],
        None,
        "ApplyKeyEffect",
        "Attempts to open a locked door in front of the target if a locked door has not already\nbeen open on the floor.\n\nr0: user entity pointer\nr1: target entity pointer",
        None,
    )

    LoadFixedRoomData = Symbol(
        [0x67DF4],
        [0x2344974],
        None,
        "LoadFixedRoomData",
        "Loads fixed room data from BALANCE/fixed.bin into the buffer pointed to by FIXED_ROOM_DATA_PTR.\n\nNo params.",
        None,
    )

    LoadFixedRoom = Symbol(
        [0x67E84],
        [0x2344A04],
        None,
        "LoadFixedRoom",
        "Note: unverified, ported from Irdkwia's notes",
        None,
    )

    OpenFixedBin = Symbol(
        [0x680B8],
        [0x2344C38],
        None,
        "OpenFixedBin",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    CloseFixedBin = Symbol(
        [0x680EC],
        [0x2344C6C],
        None,
        "CloseFixedBin",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    AreOrbsAllowed = Symbol(
        [0x68110],
        [0x2344C90],
        None,
        "AreOrbsAllowed",
        "Checks if orbs are usable in the given fixed room.\n\nAlways true if not a full-floor fixed room.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    AreTileJumpsAllowed = Symbol(
        [0x68140],
        [0x2344CC0],
        None,
        "AreTileJumpsAllowed",
        "Checks if tile jumps (warping, being blown away, and leaping) are allowed in the given fixed room.\n\nAlways true if not a full-floor fixed room.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    AreTrawlOrbsAllowed = Symbol(
        [0x68170],
        [0x2344CF0],
        None,
        "AreTrawlOrbsAllowed",
        "Checks if Trawl Orbs work in the given fixed room.\n\nAlways true if not a full-floor fixed room.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    AreOrbsAllowedVeneer = Symbol(
        [0x681A0],
        [0x2344D20],
        None,
        "AreOrbsAllowedVeneer",
        "Likely a linker-generated veneer for InitMemAllocTable.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    AreLateGameTrapsEnabled = Symbol(
        [0x681AC],
        [0x2344D2C],
        None,
        "AreLateGameTrapsEnabled",
        "Check if late-game traps (Summon, Pitfall, and Pokémon traps) work in the given fixed room.\n\nOr disabled? This function, which Irdkwia's notes label as a disable check, check the struct field labeled in End's notes as an enable flag.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    AreMovesEnabled = Symbol(
        [0x681C4],
        [0x2344D44],
        None,
        "AreMovesEnabled",
        "Checks if moves (excluding the regular attack) are usable in the given fixed room.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    IsRoomIlluminated = Symbol(
        [0x681DC],
        [0x2344D5C],
        None,
        "IsRoomIlluminated",
        "Checks if the given fixed room is fully illuminated.\n\nr0: fixed room ID\nreturn: bool",
        None,
    )

    GetMatchingMonsterId = Symbol(
        [0x681F4],
        [0x2344D74],
        None,
        "GetMatchingMonsterId",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster ID\nr1: ?\nr2: ?\nreturn: monster ID",
        None,
    )

    GenerateItemExplicit = Symbol(
        [0x68418],
        [0x2344F98],
        None,
        "GenerateItemExplicit",
        "Initializes an item struct with the given information.\n\nThis calls InitStandardItem, then explicitly sets the quantity and stickiness. If quantity == 0 for Poké, GenerateCleanItem is used instead.\n\nr0: pointer to item to initialize\nr1: item ID\nr2: quantity\nr3: sticky flag",
        None,
    )

    GenerateAndSpawnItem = Symbol(
        [0x68494],
        [0x2345014],
        None,
        "GenerateAndSpawnItem",
        "A convenience function that generates an item with GenerateItemExplicit, then spawns it with SpawnItem.\n\nIf the check-in-bag flag is set and the player's bag already contains an item with the given ID, a Reviver Seed will be spawned instead.\n\nIt seems like this function is only ever called in one place, with an item ID of 0x49 (Reviver Seed).\n\nr0: item ID\nr1: x position\nr2: y position\nr3: quantity\nstack[0]: sticky flag\nstack[1]: check-in-bag flag",
        None,
    )

    IsHiddenStairsFloor = Symbol(
        [0x68570],
        [0x23450F0],
        None,
        "IsHiddenStairsFloor",
        "Checks if the current floor is either the Secret Bazaar or a Secret Room.\n\nreturn: bool",
        None,
    )

    IsSecretBazaarVeneer = Symbol(
        [0x6859C],
        [0x234511C],
        None,
        "IsSecretBazaarVeneer",
        "Likely a linker-generated veneer for IsSecretBazaar.\n\nSee https://developer.arm.com/documentation/dui0474/k/image-structure-and-generation/linker-generated-veneers/what-is-a-veneer-\n\nreturn: bool",
        None,
    )

    GenerateStandardItem = Symbol(
        [0x68C34],
        [0x23457B4],
        None,
        "GenerateStandardItem",
        "Wrapper around GenerateItem with quantity set to 0\n\nr0: pointer to item to initialize\nr1: item ID\nr2: stickiness type",
        None,
    )

    GenerateCleanItem = Symbol(
        [0x68C48],
        [0x23457C8],
        None,
        "GenerateCleanItem",
        "Wrapper around GenerateItem with quantity set to 0 and stickiness type set to SPAWN_STICKY_NEVER.\n\nr0: pointer to item to initialize\nr1: item ID",
        None,
    )

    TryLeaderItemPickUp = Symbol(
        [0x690C0],
        [0x2345C40],
        None,
        "TryLeaderItemPickUp",
        "Checks the tile at the specified position and determines if the leader should pick up an item.\n\nr0: position\nr1: flag for whether or not a message should be logged upon the leader failing to obtain the item",
        None,
    )

    SpawnItem = Symbol(
        [0x695A0],
        [0x2346120],
        None,
        "SpawnItem",
        "Spawns an item on the floor. Fails if there are more than 64 items already on the floor.\n\nThis calls SpawnItemEntity, fills in the item info struct, sets the entity to be visible, binds the entity to the tile it occupies, updates the n_items counter on the dungeon struct, and various other bits of bookkeeping.\n\nr0: position\nr1: item pointer\nr2: some flag?\nreturn: success flag",
        None,
    )

    RemoveGroundItem = Symbol(
        [0x69728],
        [0x23462A8],
        None,
        "RemoveGroundItem",
        "Removes an item lying on the ground.\n\nAlso updates dungeon::n_items.\n\nr0: Position where the item is located\nr1: If true, update dungeon::poke_buy_kecleon_shop and dungeon::poke_sold_kecleon_shop",
        None,
    )

    SpawnDroppedItemWrapper = Symbol(
        [0x69AA8],
        [0x2346628],
        None,
        "SpawnDroppedItemWrapper",
        "Wraps SpawnDroppedItem in a more convenient interface.\n\nr0: entity\nr1: position\nr2: item\nr3: ?",
        None,
    )

    SpawnDroppedItem = Symbol(
        [0x69B44],
        [0x23466C4],
        None,
        "SpawnDroppedItem",
        "Used to spawn an item that was thrown or dropped, with a log message.\n\nDetermines where exactly the item will land, if it bounces on a trap, etc.\nUsed for thrown items that hit a wall, for certain enemy drops (such as Unown stones or Treasure Boxes), for certain moves (like Pay Day and Knock Off), and possibly other things.\n\nr0: entity that dropped or threw the item\nr1: item entity. Contains the coordinates where the item should try to land first.\nr2: item info\nr3: ?\nstack[0]: pointer to int16_t[2] for x/y direction (corresponding to DIRECTIONS_XY)\nstack[1]: ?",
        None,
    )

    TryGenerateUnownStoneDrop = Symbol(
        [0x6A0CC],
        [0x2346C4C],
        None,
        "TryGenerateUnownStoneDrop",
        "Determine if a defeated monster should drop a Unown Stone, and generate the item if so.\n\nChecks that the current dungeon isn't a Marowak Dojo training maze, and that the monster is an Unown. If so, there's a 21% chance that an Unown Stone will be generated.\n\nr0: [output] item\nr1: monster ID\nreturn: whether or not an Unown Stone was generated",
        None,
    )

    HasHeldItem = Symbol(
        [0x6A850],
        [0x23473D0],
        None,
        "HasHeldItem",
        "Checks if a monster has a certain held item.\n\nr0: entity pointer\nr1: item ID\nreturn: bool",
        None,
    )

    GenerateMoneyQuantity = Symbol(
        [0x6A8A0],
        [0x2347420],
        None,
        "GenerateMoneyQuantity",
        "Set the quantity code on an item (assuming it's Poké), given some maximum acceptable money amount.\n\nr0: item pointer\nr1: max money amount (inclusive)",
        None,
    )

    CheckTeamItemsFlags = Symbol(
        [0x6AC4C],
        [0x23477CC],
        None,
        "CheckTeamItemsFlags",
        "Checks whether any of the items in the bag or any of the items carried by team members has any of the specified flags set in its flags field.\n\nr0: Flag(s) to check (0 = f_exists, 1 = f_in_shop, 2 = f_unpaid, etc.)\nreturn: True if any of the items of the team has the specified flags set, false otherwise.",
        None,
    )

    AddHeldItemToBag = Symbol(
        [0x6AF90],
        [0x2347B10],
        None,
        "AddHeldItemToBag",
        "Adds the monster's held item to the bag. This is only called on monsters on the exploration team.\nmonster::is_not_team_member should be checked to be false before calling.\n\nr0: monster pointer",
        None,
    )

    RemoveEmptyItemsInBagWrapper = Symbol(
        [0x6B0AC],
        [0x2347C2C],
        None,
        "RemoveEmptyItemsInBagWrapper",
        "Calls RemoveEmptyItemsInBag, then some other function that seems to update the minimap, the map surveyor flag, and other stuff.\n\nNo params.",
        None,
    )

    GenerateItem = Symbol(
        [0x6B344],
        [0x2347EC4],
        None,
        "GenerateItem",
        "Initializes an item struct with the given information.\n\nThis wraps InitItem, but with extra logic to resolve the item's stickiness. It also calls GenerateMoneyQuantity for Poké.\n\nr0: pointer to item to initialize\nr1: item ID\nr2: quantity\nr3: stickiness type (enum gen_item_stickiness)",
        None,
    )

    DoesProjectileHitTarget = Symbol(
        [0x6C0A0],
        [0x2348C20],
        None,
        "DoesProjectileHitTarget",
        "Determines if a hurled projectile will impact on a target or if the target will dodge it instead.\n\nContains a random chance using THROWN_ITEM_HIT_CHANCE, as well as some additional checks involving certain items (Whiff Specs, Lockon Specs and Dodge Scarf), exclusive item effects (EXCLUSIVE_EFF_THROWN_ITEM_PROTECTION) or pokémon (Kecleon, clients, secret bazaar NPCs).\n\nr0: Monster that throws the item\nr1: Target monster\nreturn: True if the item impacts on the target, false if the target dodges the item.",
        None,
    )

    DisplayFloorCard = Symbol(
        [0x6C354],
        [0x2348ED4],
        None,
        "DisplayFloorCard",
        "Dispatches the splash screen between floors showing the dungeon name and the current floor.\n\nFirst it checks whether the current floor is a secret bazaar or secret room, then it calls HandleFloorCard.\n\nr0: Duration in frames",
        None,
    )

    HandleFloorCard = Symbol(
        [0x6C38C],
        [0x2348F0C],
        None,
        "HandleFloorCard",
        "Handles the display of the splash screen between floors showing the dungeon name and the current floor.\n\nSeems to enter a loop where it calls AdvanceFrame until the desired number of frames is waited or A is pressed.\n\nr0: dungeon_id\nr1: floor\nr2: duration\nr3: enum hidden_stairs_type",
        None,
    )

    CheckActiveChallengeRequest = Symbol(
        [0x6D1CC],
        [0x2349D4C],
        None,
        "CheckActiveChallengeRequest",
        "Checks if there's an active challenge request on the current dungeon.\n\nreturn: True if there's an active challenge request on the current dungeon in the list of missions.",
        None,
    )

    GetMissionDestination = Symbol(
        [0x6D224],
        [0x2349DA4],
        None,
        "GetMissionDestination",
        "Returns the current mission destination on the dungeon struct.\n\nreturn: &dungeon::mission_destination",
        None,
    )

    IsOutlawOrChallengeRequestFloor = Symbol(
        [0x6D244],
        [0x2349DC4],
        None,
        "IsOutlawOrChallengeRequestFloor",
        "Checks if the current floor is an active mission destination of type MISSION_TAKE_ITEM_FROM_OUTLAW, MISSION_ARREST_OUTLAW or MISSION_CHALLENGE_REQUEST.\n\nreturn: bool",
        None,
    )

    IsDestinationFloor = Symbol(
        [0x6D288],
        [0x2349E08],
        None,
        "IsDestinationFloor",
        "Checks if the current floor is a mission destination floor.\n\nreturn: bool",
        None,
    )

    IsCurrentMissionType = Symbol(
        [0x6D29C],
        [0x2349E1C],
        None,
        "IsCurrentMissionType",
        "Checks if the current floor is an active mission destination of a given type (and any subtype).\n\nr0: mission type\nreturn: bool",
        None,
    )

    IsCurrentMissionTypeExact = Symbol(
        [0x6D2D0],
        [0x2349E50],
        None,
        "IsCurrentMissionTypeExact",
        "Checks if the current floor is an active mission destination of a given type and subtype.\n\nr0: mission type\nr1: mission subtype\nreturn: bool",
        None,
    )

    IsOutlawMonsterHouseFloor = Symbol(
        [0x6D30C],
        [0x2349E8C],
        None,
        "IsOutlawMonsterHouseFloor",
        "Checks if the current floor is a mission destination for a Monster House outlaw mission.\n\nreturn: bool",
        None,
    )

    IsGoldenChamber = Symbol(
        [0x6D330],
        [0x2349EB0],
        None,
        "IsGoldenChamber",
        "Checks if the current floor is a Golden Chamber floor.\n\nreturn: bool",
        None,
    )

    IsLegendaryChallengeFloor = Symbol(
        [0x6D354],
        [0x2349ED4],
        None,
        "IsLegendaryChallengeFloor",
        "Checks if the current floor is a boss floor for a Legendary Challenge Letter mission.\n\nreturn: bool",
        None,
    )

    IsJirachiChallengeFloor = Symbol(
        [0x6D394],
        [0x2349F14],
        None,
        "IsJirachiChallengeFloor",
        "Checks if the current floor is the boss floor in Star Cave Pit for Jirachi's Challenge Letter mission.\n\nreturn: bool",
        None,
    )

    IsDestinationFloorWithMonster = Symbol(
        [0x6D3CC],
        [0x2349F4C],
        None,
        "IsDestinationFloorWithMonster",
        "Checks if the current floor is a mission destination floor with a special monster.\n\nSee FloorHasMissionMonster for details.\n\nreturn: bool",
        None,
    )

    LoadMissionMonsterSprites = Symbol(
        [0x6D478],
        [0x2349FF8],
        None,
        "LoadMissionMonsterSprites",
        "Loads the sprites of monsters that appear on the current floor because of a mission, if applicable.\n\nThis includes monsters to be rescued, outlaws and its minions.\n\nNo params.",
        None,
    )

    MissionTargetEnemyIsDefeated = Symbol(
        [0x6D4F0],
        [0x234A070],
        None,
        "MissionTargetEnemyIsDefeated",
        "Checks if the target enemy of the mission on the current floor has been defeated.\n\nreturn: bool",
        None,
    )

    SetMissionTargetEnemyDefeated = Symbol(
        [0x6D510],
        [0x234A090],
        None,
        "SetMissionTargetEnemyDefeated",
        "Set the flag for whether or not the target enemy of the current mission has been defeated.\n\nr0: new flag value",
        None,
    )

    IsDestinationFloorWithFixedRoom = Symbol(
        [0x6D524],
        [0x234A0A4],
        None,
        "IsDestinationFloorWithFixedRoom",
        "Checks if the current floor is a mission destination floor with a fixed room.\n\nThe entire floor can be a fixed room layout, or it can just contain a Sealed Chamber.\n\nreturn: bool",
        None,
    )

    GetItemToRetrieve = Symbol(
        [0x6D54C],
        [0x234A0CC],
        None,
        "GetItemToRetrieve",
        "Get the ID of the item that needs to be retrieve on the current floor for a mission, if one exists.\n\nreturn: item ID",
        None,
    )

    GetItemToDeliver = Symbol(
        [0x6D570],
        [0x234A0F0],
        None,
        "GetItemToDeliver",
        "Get the ID of the item that needs to be delivered to a mission client on the current floor, if one exists.\n\nreturn: item ID",
        None,
    )

    GetSpecialTargetItem = Symbol(
        [0x6D59C],
        [0x234A11C],
        None,
        "GetSpecialTargetItem",
        "Get the ID of the special target item for a Sealed Chamber or Treasure Memo mission on the current floor.\n\nreturn: item ID",
        None,
    )

    IsDestinationFloorWithItem = Symbol(
        [0x6D5E4],
        [0x234A164],
        None,
        "IsDestinationFloorWithItem",
        "Checks if the current floor is a mission destination floor with a special item.\n\nThis excludes missions involving taking an item from an outlaw.\n\nreturn: bool",
        None,
    )

    IsDestinationFloorWithHiddenOutlaw = Symbol(
        [0x6D644],
        [0x234A1C4],
        None,
        "IsDestinationFloorWithHiddenOutlaw",
        "Checks if the current floor is a mission destination floor with a 'hidden outlaw' that behaves like a normal enemy.\n\nreturn: bool",
        None,
    )

    IsDestinationFloorWithFleeingOutlaw = Symbol(
        [0x6D668],
        [0x234A1E8],
        None,
        "IsDestinationFloorWithFleeingOutlaw",
        "Checks if the current floor is a mission destination floor with a 'fleeing outlaw' that runs away.\n\nreturn: bool",
        None,
    )

    GetMissionTargetEnemy = Symbol(
        [0x6D6A0],
        [0x234A220],
        None,
        "GetMissionTargetEnemy",
        "Get the monster ID of the target enemy to be defeated on the current floor for a mission, if one exists.\n\nreturn: monster ID",
        None,
    )

    GetMissionEnemyMinionGroup = Symbol(
        [0x6D6B8],
        [0x234A238],
        None,
        "GetMissionEnemyMinionGroup",
        "Get the monster ID of the specified minion group on the current floor for a mission, if it exists.\n\nNote that a single minion group can correspond to multiple actual minions of the same species. There can be up to 2 minion groups.\n\nr0: minion group index (0-indexed)\nreturn: monster ID",
        None,
    )

    SetTargetMonsterNotFoundFlag = Symbol(
        [0x6D744],
        [0x234A2C4],
        None,
        "SetTargetMonsterNotFoundFlag",
        "Sets dungeon::target_monster_not_found_flag to the specified value.\n\nr0: Value to set the flag to",
        None,
    )

    GetTargetMonsterNotFoundFlag = Symbol(
        [0x6D758],
        [0x234A2D8],
        None,
        "GetTargetMonsterNotFoundFlag",
        "Gets the value of dungeon::target_monster_not_found_flag.\n\nreturn: dungeon::target_monster_not_found_flag",
        None,
    )

    FloorHasMissionMonster = Symbol(
        [0x6D7C8],
        [0x234A348],
        None,
        "FloorHasMissionMonster",
        "Checks if a given floor is a mission destination with a special monster, either a target to rescue or an enemy to defeat.\n\nMission types with a monster on the destination floor:\n- Rescue client\n- Rescue target\n- Escort to target\n- Deliver item\n- Search for target\n- Take item from outlaw\n- Arrest outlaw\n- Challenge Request\n\nr0: mission destination info pointer\nreturn: bool",
        None,
    )

    GenerateMissionEggMonster = Symbol(
        [0x6D920],
        [0x234A4A0],
        None,
        "GenerateMissionEggMonster",
        "Generates the monster ID in the egg from the given mission. Uses the base form of the monster.\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: mission struct",
        None,
    )

    LogMessageByIdWithPopupCheckParticipants = Symbol(
        [0x6F2D0],
        [0x234BE50],
        None,
        "LogMessageByIdWithPopupCheckParticipants",
        "Logs the appropriate message based on the participating entites; this function calls LogMessageByIdWithPopupCheckUserTarget is both the user and target pointers are non-null, otherwise it calls LogMessageByIdWithPopupCheckUser if the user pointer is non-null, otherwise doesn't log anything.\n\nThis function also seems to set some global table entry to some value?\n\nr0: user entity pointer\nr1: target entity pointer\nr2: message ID\nr3: index into some table?\nstack[0]: value to set at the table index specified by r3?",
        None,
    )

    LogMessageByIdWithPopupCheckUser = Symbol(
        [0x6F324],
        [0x234BEA4],
        None,
        "LogMessageByIdWithPopupCheckUser",
        "Logs a message in the message log alongside a message popup, if the user hasn't fainted.\n\nr0: user entity pointer\nr1: message ID",
        None,
    )

    LogMessageWithPopupCheckUser = Symbol(
        [0x6F364],
        [0x234BEE4],
        None,
        "LogMessageWithPopupCheckUser",
        "Logs a message in the message log alongside a message popup, if the user hasn't fainted.\n\nr0: user entity pointer\nr1: message string",
        None,
    )

    LogMessageByIdQuiet = Symbol(
        [0x6F39C],
        [0x234BF1C],
        None,
        "LogMessageByIdQuiet",
        "Logs a message in the message log (but without a message popup).\n\nr0: user entity pointer\nr1: message ID",
        None,
    )

    LogMessageQuiet = Symbol(
        [0x6F3C0],
        [0x234BF40],
        None,
        "LogMessageQuiet",
        "Logs a message in the message log (but without a message popup).\n\nr0: user entity pointer\nr1: message string",
        None,
    )

    LogMessageByIdWithPopupCheckUserTarget = Symbol(
        [0x6F3D0],
        [0x234BF50],
        None,
        "LogMessageByIdWithPopupCheckUserTarget",
        "Logs a message in the message log alongside a message popup, if some user check passes and the target hasn't fainted.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: message ID",
        None,
    )

    LogMessageWithPopupCheckUserTarget = Symbol(
        [0x6F424],
        [0x234BFA4],
        None,
        "LogMessageWithPopupCheckUserTarget",
        "Logs a message in the message log alongside a message popup, if some user check passes and the target hasn't fainted.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: message string",
        None,
    )

    LogMessageByIdQuietCheckUserTarget = Symbol(
        [0x6F470],
        [0x234BFF0],
        None,
        "LogMessageByIdQuietCheckUserTarget",
        "Logs a message in the message log (but without a message popup), if some user check passes and the target hasn't fainted.\n\nr0: user entity pointer\nr1: target entity pointer\nr2: message ID",
        None,
    )

    LogMessageByIdWithPopupCheckUserUnknown = Symbol(
        [0x6F4C4],
        [0x234C044],
        None,
        "LogMessageByIdWithPopupCheckUserUnknown",
        "Logs a message in the message log alongside a message popup, if the user hasn't fainted and some other unknown check.\n\nr0: user entity pointer\nr1: ?\nr2: message ID",
        None,
    )

    LogMessageByIdWithPopup = Symbol(
        [0x6F518],
        [0x234C098],
        None,
        "LogMessageByIdWithPopup",
        "Logs a message in the message log alongside a message popup.\n\nr0: user entity pointer\nr1: message ID",
        None,
    )

    LogMessageWithPopup = Symbol(
        [0x6F53C],
        [0x234C0BC],
        None,
        "LogMessageWithPopup",
        "Logs a message in the message log alongside a message popup.\n\nr0: user entity pointer\nr1: message string",
        None,
    )

    LogMessage = Symbol(
        [0x6F588],
        [0x234C108],
        None,
        "LogMessage",
        "Logs a message in the message log.\n\nr0: user entity pointer\nr1: message string\nr2: bool, whether or not to present a message popup",
        None,
    )

    LogMessageById = Symbol(
        [0x6F794],
        [0x234C314],
        None,
        "LogMessageById",
        "Logs a message in the message log.\n\nr0: user entity pointer\nr1: message ID\nr2: bool, whether or not to present a message popup",
        None,
    )

    InitPortraitDungeon = Symbol(
        [0x6FB40],
        [0x234C6C0],
        None,
        "InitPortraitDungeon",
        "Initialize the portrait params structure for the given monster and expression\n\nr0: pointer the portrait params data structure to initialize\nr1: monster id\nr2: emotion id",
        None,
    )

    OpenMessageLog = Symbol(
        [0x6FBDC],
        [0x234C75C],
        None,
        "OpenMessageLog",
        "Opens the message log window.\n\nr0: ?\nr1: ?",
        None,
    )

    RunDungeonMode = Symbol(
        [0x6FFA8],
        [0x234CB28],
        None,
        "RunDungeonMode",
        "This appears to be the top-level function for running dungeon mode.\n\nIt gets called by MainGame right after doing the dungeon fade transition, and once it exits, the dungeon results are processed.\n\nThis function is presumably in charge of allocating the dungeon struct, setting it up, launching the dungeon engine, etc.",
        None,
    )

    StartFadeDungeon = Symbol(
        [0x70488],
        [0x234D008],
        None,
        "StartFadeDungeon",
        "Initiates a screen fade in dungeon mode.\n\nSets the fields of the dungeon_fade struct to appropriate values given in the args.\n\nr0: Dungeon fade struct\nr1: Change of brightness per frame\nr2: Fade type",
        None,
    )

    StartFadeDungeonWrapper = Symbol(
        [0x706E8],
        [0x234D268],
        None,
        "StartFadeDungeonWrapper",
        "Calls StartFadeDungeon to initiate a screen fade in dungeon mode.\n\nSets the status field in the dungeon_fades struct to the fade type, then uses a switch-case to create a mapping of the status enums to different ones for some reason. This mapped value is then used in the StartFadeDungeon call.\n\nr0: Fade type\nr1: Change of brightness per frame\nr2: Screen to fade",
        None,
    )

    HandleFadesDungeon = Symbol(
        [0x70854],
        [0x234D3D4],
        None,
        "HandleFadesDungeon",
        "Gets called every frame for both screens in dungeon mode. Handles the status of the screen fades.\n\nr0: enum screen",
        None,
    )

    HandleFadesDungeonBothScreens = Symbol(
        [0x70A64],
        [0x234D5E4],
        None,
        "HandleFadesDungeonBothScreens",
        "Calls HandleFadesDungeon for both screens.\n\nNo params.",
        None,
    )

    DisplayFloorTip = Symbol(
        [0x70C08],
        [0x234D788],
        None,
        "DisplayFloorTip",
        "Display the dungeon tip that displays on floor change, based on which tips have already been displayed.\n\nNo params.\n\nreturn: 1 if a tip has been displayed, 0 otherwise",
        None,
    )

    DisplayItemTip = Symbol(
        [0x70D34],
        [0x234D8B4],
        None,
        "DisplayItemTip",
        "Display the dungeon tip if not already displayed matching the (presumably newly acquired) item\n\nr0: item id\nreturn: 1 if a tip has been displayed, 0 otherwise",
        None,
    )

    DisplayDungeonTip = Symbol(
        [0x70F70],
        [0x234DAF0],
        None,
        "DisplayDungeonTip",
        "Checks if a given dungeon tip should be displayed at the start of a floor and if so, displays it. Called up to 4 times at the start of each new floor, with a different r0 parameter each time.\n\nr0: Pointer to the message_tip struct of the message that should be displayed\nr1: True to log the message in the message log\n\nreturn: 1 if the message has been displayed, 0 if it wasn’t",
        None,
    )

    SetBothScreensWindowColorToDefault = Symbol(
        [0x70FE0],
        [0x234DB60],
        None,
        "SetBothScreensWindowColorToDefault",
        "This changes the palettes of windows in both screens to an appropiate value depending on the playthrough\nIf you're in a special episode, they turn green , otherwise, they turn blue or pink depending on your character's sex\n\nNo params",
        None,
    )

    GetPersonalityIndex = Symbol(
        [0x7106C],
        [0x234DBEC],
        None,
        "GetPersonalityIndex",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: monster pointer\nreturn: ?",
        None,
    )

    DisplayMessage = Symbol(
        [0x712D8],
        [0x234DE58],
        None,
        "DisplayMessage",
        "Displays a message in a dialogue box that optionally waits for player input before closing.\n\nr0: pointer to the structure representing the desired state of the portrait\nr1: ID of the string to display\nr2: True to wait for player input before closing the dialogue box, false to close it automatically once all the characters get printed.",
        None,
    )

    DisplayMessage2 = Symbol(
        [0x7132C],
        [0x234DEAC],
        None,
        "DisplayMessage2",
        "Very similar to DisplayMessage",
        None,
    )

    YesNoMenu = Symbol(
        [0x71598],
        [0x234E118],
        None,
        "YesNoMenu",
        "Opens a menu where the user can choose 'Yes' or 'No' and waits for input before returning.\n\nr0: ?\nr1: ID of the string to display in the textbox\nr2: Option that the cursor will be on by default. 0 for 'Yes', 1 for 'No'\nr3: ?\nreturn: True if the user chooses 'Yes', false if the user chooses 'No'",
        None,
    )

    DisplayMessageInternal = Symbol(
        [0x71610],
        [0x234E190],
        None,
        "DisplayMessageInternal",
        "Called by DisplayMessage. Seems to be the function that handles the display of the dialogue box. It won't return until all the characters have been written and after the player manually closes the dialogue box (if the corresponding parameter was set).\n\nr0: ID of the string to display\nr1: True to wait for player input before closing the dialogue box, false to close it automatically once all the characters get printed.\nr2: pointer to the structure representing the desired state of the portrait\nr3: ?\nstack[0]: ?\nstack[1]: ?",
        None,
    )

    OpenMenu = Symbol(
        [0x71E74],
        [0x234E9F4],
        None,
        "OpenMenu",
        "Opens a menu. The menu to open depends on the specified parameter.\n\nIt looks like the function takes a parameter in r0, but doesn't use it. r1 doesn't even get set when this function is called.\n\nr0: (?) Unused by the function. Seems to be 1 byte long.\nr1: (?) Unused by the function. Seems to be 1 byte long.\nr2: True to open the bag menu, false to open the main dungeon menu",
        None,
    )

    OthersMenuLoop = Symbol(
        [0x7384C],
        [0x23503CC],
        None,
        "OthersMenuLoop",
        "Called on each frame while the in-dungeon 'others' menu is open.\n\nIt contains a switch to determine whether an option has been chosen or not and a second switch that determines what to do depending on which option was chosen.\n\nreturn: int (Actually, this is probably some sort of enum shared by all the MenuLoop functions)",
        None,
    )

    OthersMenu = Symbol(
        [0x73AB0],
        [0x2350630],
        None,
        "OthersMenu",
        "Called when the in-dungeon 'others' menu is open. Does not return until the menu is closed.\n\nreturn: Always 0",
        None,
    )


class EuOverlay29Data:

    DUNGEON_STRUCT_SIZE = Symbol(
        [0x2838, 0x286C],
        [0x22DF3B8, 0x22DF3EC],
        0x4,
        "DUNGEON_STRUCT_SIZE",
        "Size of the dungeon struct (0x2CB14)",
        "uint32_t",
    )

    MAX_HP_CAP = Symbol(
        [0x7C00, 0x356F4, 0x3C334],
        [0x22E4780, 0x2312274, 0x2318EB4],
        0x4,
        "MAX_HP_CAP",
        "The maximum amount of HP a monster can have (999).",
        "int32_t",
    )

    OFFSET_OF_DUNGEON_FLOOR_PROPERTIES = Symbol(
        [0xB828, 0x5EECC],
        [0x22E83A8, 0x233BA4C],
        0x4,
        "OFFSET_OF_DUNGEON_FLOOR_PROPERTIES",
        "Offset of the floor properties field in the dungeon struct (0x286B2)",
        "uint32_t",
    )

    SPAWN_RAND_MAX = Symbol(
        [0xBC80],
        [0x22E8800],
        0x4,
        "SPAWN_RAND_MAX",
        "Equal to 10,000 (0x2710). Used as parameter for DungeonRandInt to generate the random number which determines the entity to spawn.",
        "int32_t",
    )

    DUNGEON_PRNG_LCG_MULTIPLIER = Symbol(
        [0xE7F8, 0xE8BC],
        [0x22EB378, 0x22EB43C],
        0x4,
        "DUNGEON_PRNG_LCG_MULTIPLIER",
        "The multiplier shared by all of the dungeon PRNG's LCGs, 1566083941 (0x5D588B65).",
        "uint32_t",
    )

    DUNGEON_PRNG_LCG_INCREMENT_SECONDARY = Symbol(
        [0xE8C4],
        [0x22EB444],
        0x4,
        "DUNGEON_PRNG_LCG_INCREMENT_SECONDARY",
        "The increment for the dungeon PRNG's secondary LCGs, 2531011 (0x269EC3). This happens to be the same increment that the Microsoft Visual C++ runtime library uses in its implementation of the rand() function.",
        "uint32_t",
    )

    ATTACK_SPRITE_BUFFER_SIZE = Symbol(
        [0x1AD10],
        [0x22F7890],
        0x4,
        "ATTACK_SPRITE_BUFFER_SIZE",
        "Size of the buffer used to store the current attack sprite file.",
        "int32_t",
    )

    KECLEON_FEMALE_ID = Symbol(
        [0x1B23C],
        [0x22F7DBC],
        0x4,
        "KECLEON_FEMALE_ID",
        "0x3D7 (983). Used when spawning Kecleon on an even numbered floor.",
        "enum monster_id",
    )

    KECLEON_MALE_ID = Symbol(
        [0x1B240],
        [0x22F7DC0],
        0x4,
        "KECLEON_MALE_ID",
        "0x17F (383). Used when spawning Kecleon on an odd numbered floor.",
        "enum monster_id",
    )

    MSG_ID_SLOW_START = Symbol(
        [0x1D15C],
        [0x22F9CDC],
        0x4,
        "MSG_ID_SLOW_START",
        "ID of the message printed when a monster has the ability Slow Start at the beginning of the floor.",
        "int32_t",
    )

    EXPERIENCE_POINT_GAIN_CAP = Symbol(
        [0x26574],
        [0x23030F4],
        0x4,
        "EXPERIENCE_POINT_GAIN_CAP",
        "A cap on the experience that can be given to a monster in one call to AddExpSpecial",
        "int32_t",
    )

    JUDGMENT_MOVE_ID = Symbol(
        [0x3034C],
        [0x230CECC],
        0x4,
        "JUDGMENT_MOVE_ID",
        "Move ID for Judgment (0x1D3)\n\ntype: enum move_id",
        "enum move_id",
    )

    REGULAR_ATTACK_MOVE_ID = Symbol(
        [0x30350],
        [0x230CED0],
        0x4,
        "REGULAR_ATTACK_MOVE_ID",
        "Move ID for the regular attack (0x163)\n\ntype: enum move_id",
        "enum move_id",
    )

    DEOXYS_ATTACK_ID = Symbol(
        [0x30354],
        [0x230CED4],
        0x4,
        "DEOXYS_ATTACK_ID",
        "Monster ID for Deoxys in Attack Forme (0x1A3)\n\ntype: enum monster_id",
        "enum monster_id",
    )

    DEOXYS_SPEED_ID = Symbol(
        [0x30358],
        [0x230CED8],
        0x4,
        "DEOXYS_SPEED_ID",
        "Monster ID for Deoxys in Speed Forme (0x1A5)\n\ntype: enum monster_id",
        "enum monster_id",
    )

    GIRATINA_ALTERED_ID = Symbol(
        [0x3035C],
        [0x230CEDC],
        0x4,
        "GIRATINA_ALTERED_ID",
        "Monster ID for Giratina in Altered Forme (0x211)\n\ntype: enum monster_id",
        "enum monster_id",
    )

    PUNISHMENT_MOVE_ID = Symbol(
        [0x30360],
        [0x230CEE0],
        0x4,
        "PUNISHMENT_MOVE_ID",
        "Move ID for Punishment (0x1BD)\n\ntype: enum move_id",
        "enum move_id",
    )

    OFFENSE_STAT_MAX = Symbol(
        [0x30390],
        [0x230CF10],
        0x4,
        "OFFENSE_STAT_MAX",
        "Cap on an attacker's modified offense (attack or special attack) stat after boosts. Used during damage calculation.",
        "int32_t",
    )

    PROJECTILE_MOVE_ID = Symbol(
        [0x30F70, 0x405E0],
        [0x230DAF0, 0x231D160],
        0x4,
        "PROJECTILE_MOVE_ID",
        "The move ID of the special 'projectile' move (0x195)\n\ntype: enum move_id",
        "enum move_id",
    )

    BELLY_LOST_PER_TURN = Symbol(
        [0x34950],
        [0x23114D0],
        0x4,
        "BELLY_LOST_PER_TURN",
        "The base value by which belly is decreased every turn.\n\nIts raw value is 0x199A, which encodes a binary fixed-point number (16 fraction bits) with value (0x199A * 2^-16), and is the closest approximation to 0.1 representable in this number format.",
        "fx32_16",
    )

    MONSTER_HEAL_HP_MAX = Symbol(
        None,
        None,
        None,
        "MONSTER_HEAL_HP_MAX",
        "The maximum amount of HP a monster can have (999).",
        "int",
    )

    MOVE_TARGET_AND_RANGE_SPECIAL_USER_HEALING = Symbol(
        [0x3EC14],
        [0x231B794],
        0x4,
        "MOVE_TARGET_AND_RANGE_SPECIAL_USER_HEALING",
        "The move target and range code for special healing moves that target just the user (0x273).\n\ntype: struct move_target_and_range (+ padding)",
        "struct move_target_and_range",
    )

    PLAIN_SEED_STRING_ID = Symbol(
        [0x40628],
        [0x231D1A8],
        0x4,
        "PLAIN_SEED_STRING_ID",
        "The string ID for eating a Plain Seed (0xBE9).",
        "int32_t",
    )

    MAX_ELIXIR_PP_RESTORATION = Symbol(
        [0x4062C],
        [0x231D1AC],
        0x4,
        "MAX_ELIXIR_PP_RESTORATION",
        "The amount of PP restored per move by ingesting a Max Elixir (0x3E7).",
        "int32_t",
    )

    SLIP_SEED_FAIL_STRING_ID = Symbol(
        [0x40A94],
        [0x231D614],
        0x4,
        "SLIP_SEED_FAIL_STRING_ID",
        "The string ID for when eating the Slip Seed fails (0xC75).",
        "int32_t",
    )

    ROCK_WRECKER_MOVE_ID = Symbol(
        None,
        None,
        None,
        "ROCK_WRECKER_MOVE_ID",
        "The move ID for Rock Wrecker (453).",
        "enum move_id",
    )

    CASTFORM_NORMAL_FORM_MALE_ID = Symbol(
        [0x592F8],
        [0x2335E78],
        0x4,
        "CASTFORM_NORMAL_FORM_MALE_ID",
        "Castform's male normal form ID (0x17B)",
        "enum monster_id",
    )

    CASTFORM_NORMAL_FORM_FEMALE_ID = Symbol(
        [0x592FC],
        [0x2335E7C],
        0x4,
        "CASTFORM_NORMAL_FORM_FEMALE_ID",
        "Castform's female normal form ID (0x3D3)",
        "enum monster_id",
    )

    CHERRIM_SUNSHINE_FORM_MALE_ID = Symbol(
        [0x59300],
        [0x2335E80],
        0x4,
        "CHERRIM_SUNSHINE_FORM_MALE_ID",
        "Cherrim's male sunshine form ID (0x1CD)",
        "enum monster_id",
    )

    CHERRIM_OVERCAST_FORM_FEMALE_ID = Symbol(
        [0x59304],
        [0x2335E84],
        0x4,
        "CHERRIM_OVERCAST_FORM_FEMALE_ID",
        "Cherrim's female overcast form ID (0x424)",
        "enum monster_id",
    )

    CHERRIM_SUNSHINE_FORM_FEMALE_ID = Symbol(
        [0x59308],
        [0x2335E88],
        0x4,
        "CHERRIM_SUNSHINE_FORM_FEMALE_ID",
        "Cherrim's female sunshine form ID (0x425)",
        "enum monster_id",
    )

    FLOOR_GENERATION_STATUS_PTR = Symbol(
        [
            0x5EED0,
            0x5EF6C,
            0x5F1F0,
            0x5F67C,
            0x5FADC,
            0x5FC3C,
            0x5FDD4,
            0x5FF90,
            0x60370,
            0x607D0,
            0x60FE4,
            0x61164,
            0x61374,
            0x616D4,
            0x620BC,
            0x63FF4,
            0x64280,
            0x64734,
            0x654C0,
            0x657C8,
            0x661DC,
            0x66574,
            0x66844,
            0x66BD8,
            0x66CC8,
            0x66DFC,
            0x66F8C,
        ],
        [
            0x233BA50,
            0x233BAEC,
            0x233BD70,
            0x233C1FC,
            0x233C65C,
            0x233C7BC,
            0x233C954,
            0x233CB10,
            0x233CEF0,
            0x233D350,
            0x233DB64,
            0x233DCE4,
            0x233DEF4,
            0x233E254,
            0x233EC3C,
            0x2340B74,
            0x2340E00,
            0x23412B4,
            0x2342040,
            0x2342348,
            0x2342D5C,
            0x23430F4,
            0x23433C4,
            0x2343758,
            0x2343848,
            0x234397C,
            0x2343B0C,
        ],
        0x4,
        "FLOOR_GENERATION_STATUS_PTR",
        "Pointer to the global FLOOR_GENERATION_STATUS\n\ntype: struct floor_generation_status*",
        "struct floor_generation_status*",
    )

    OFFSET_OF_DUNGEON_N_NORMAL_ITEM_SPAWNS = Symbol(
        [0x5EED8, 0x654C8],
        [0x233BA58, 0x2342048],
        0x4,
        "OFFSET_OF_DUNGEON_N_NORMAL_ITEM_SPAWNS",
        "Offset of the (number of base items + 1) field on the dungeon struct (0x12AFA)",
        "uint32_t",
    )

    DUNGEON_GRID_COLUMN_BYTES = Symbol(
        [
            0x5F678,
            0x5FAD8,
            0x5FDD0,
            0x5FF8C,
            0x6036C,
            0x607D4,
            0x60A48,
            0x60FDC,
            0x61160,
            0x61378,
            0x616D0,
            0x620B8,
            0x6249C,
            0x62D94,
            0x63178,
            0x63960,
            0x63FF8,
            0x64284,
            0x644B8,
            0x66530,
        ],
        [
            0x233C1F8,
            0x233C658,
            0x233C950,
            0x233CB0C,
            0x233CEEC,
            0x233D354,
            0x233D5C8,
            0x233DB5C,
            0x233DCE0,
            0x233DEF8,
            0x233E250,
            0x233EC38,
            0x233F01C,
            0x233F914,
            0x233FCF8,
            0x23404E0,
            0x2340B78,
            0x2340E04,
            0x2341038,
            0x23430B0,
        ],
        0x4,
        "DUNGEON_GRID_COLUMN_BYTES",
        "The number of bytes in one column of the dungeon grid cell array, 450, which corresponds to a column of 15 grid cells.",
        "uint32_t",
    )

    DEFAULT_MAX_POSITION = Symbol(
        [0x63FFC],
        [0x2340B7C],
        0x4,
        "DEFAULT_MAX_POSITION",
        "A large number (9999) to use as a default position for keeping track of min/max position values",
        "int32_t",
    )

    OFFSET_OF_DUNGEON_GUARANTEED_ITEM_ID = Symbol(
        [0x654C4, 0x68EE4],
        [0x2342044, 0x2345A64],
        0x4,
        "OFFSET_OF_DUNGEON_GUARANTEED_ITEM_ID",
        "Offset of the guaranteed item ID field in the dungeon struct (0x2C9E8)",
        "uint32_t",
    )

    FIXED_ROOM_TILE_SPAWN_TABLE = Symbol(
        [0x73E5C],
        [0x23509DC],
        0x2C,
        "FIXED_ROOM_TILE_SPAWN_TABLE",
        "Table of tiles that can spawn in fixed rooms, pointed into by the FIXED_ROOM_TILE_SPAWN_TABLE.\n\nThis is an array of 11 4-byte entries containing info about one tile each. Info includes the trap ID if a trap, room ID, and flags.\n\ntype: struct fixed_room_tile_spawn_entry[11]",
        "struct fixed_room_tile_spawn_entry[11]",
    )

    TREASURE_BOX_1_ITEM_IDS = Symbol(
        [0x73E88],
        [0x2350A08],
        0x18,
        "TREASURE_BOX_1_ITEM_IDS",
        "Item IDs for variant 1 of each of the treasure box items (ITEM_*_BOX_1).\n\ntype: struct item_id_16[12]",
        "struct item_id_16[12]",
    )

    FIXED_ROOM_REVISIT_OVERRIDES = Symbol(
        [0x73EA0],
        [0x2350A20],
        0x100,
        "FIXED_ROOM_REVISIT_OVERRIDES",
        "Table of fixed room IDs, which if nonzero, overrides the normal fixed room ID for a floor (which is used to index the table) if the dungeon has already been cleared previously.\n\nOverrides are used to substitute different fixed room data for things like revisits to story dungeons.\n\ntype: struct fixed_room_id_8[256]",
        "struct fixed_room_id_8[256]",
    )

    FIXED_ROOM_MONSTER_SPAWN_TABLE = Symbol(
        [0x73FA0],
        [0x2350B20],
        0x1E0,
        "FIXED_ROOM_MONSTER_SPAWN_TABLE",
        "Table of monsters that can spawn in fixed rooms, pointed into by the FIXED_ROOM_ENTITY_SPAWN_TABLE.\n\nThis is an array of 120 4-byte entries containing info about one monster each. Info includes the monster ID, stats, and behavior type.\n\ntype: struct fixed_room_monster_spawn_entry[120]",
        "struct fixed_room_monster_spawn_entry[120]",
    )

    FIXED_ROOM_ITEM_SPAWN_TABLE = Symbol(
        [0x74180],
        [0x2350D00],
        0x1F8,
        "FIXED_ROOM_ITEM_SPAWN_TABLE",
        "Table of items that can spawn in fixed rooms, pointed into by the FIXED_ROOM_ENTITY_SPAWN_TABLE.\n\nThis is an array of 63 8-byte entries containing one item ID each.\n\ntype: struct fixed_room_item_spawn_entry[63]",
        "struct fixed_room_item_spawn_entry[63]",
    )

    FIXED_ROOM_ENTITY_SPAWN_TABLE = Symbol(
        [0x74378],
        [0x2350EF8],
        0xC9C,
        "FIXED_ROOM_ENTITY_SPAWN_TABLE",
        "Table of entities (items, monsters, tiles) that can spawn in fixed rooms, which is indexed into by the main data structure for each fixed room.\n\nThis is an array of 269 entries. Each entry contains 3 pointers (one into FIXED_ROOM_ITEM_SPAWN_TABLE, one into FIXED_ROOM_MONSTER_SPAWN_TABLE, and one into FIXED_ROOM_TILE_SPAWN_TABLE), and represents the entities that can spawn on one specific tile in a fixed room.\n\ntype: struct fixed_room_entity_spawn_entry[269]",
        "struct fixed_room_entity_spawn_entry[269]",
    )

    STATUS_ICON_ARRAY_MUZZLED = Symbol(
        [0x75248],
        [0x2351DC8],
        0x10,
        "STATUS_ICON_ARRAY_MUZZLED",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::muzzled * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[2]",
    )

    STATUS_ICON_ARRAY_MAGNET_RISE = Symbol(
        [0x75258],
        [0x2351DD8],
        0x10,
        "STATUS_ICON_ARRAY_MAGNET_RISE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::magnet_rise * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[2]",
    )

    STATUS_ICON_ARRAY_MIRACLE_EYE = Symbol(
        [0x75278],
        [0x2351DF8],
        0x18,
        "STATUS_ICON_ARRAY_MIRACLE_EYE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::miracle_eye * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[3]",
    )

    STATUS_ICON_ARRAY_LEECH_SEED = Symbol(
        [0x75288],
        [0x2351E08],
        0x18,
        "STATUS_ICON_ARRAY_LEECH_SEED",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::leech_seed * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[3]",
    )

    STATUS_ICON_ARRAY_LONG_TOSS = Symbol(
        [0x752A0],
        [0x2351E20],
        0x18,
        "STATUS_ICON_ARRAY_LONG_TOSS",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::long_toss * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[3]",
    )

    STATUS_ICON_ARRAY_BLINDED = Symbol(
        [0x752F8],
        [0x2351E78],
        0x28,
        "STATUS_ICON_ARRAY_BLINDED",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::blinded * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[5]",
    )

    STATUS_ICON_ARRAY_BURN = Symbol(
        [0x75320],
        [0x2351EA0],
        0x28,
        "STATUS_ICON_ARRAY_BURN",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::burn * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[5]",
    )

    STATUS_ICON_ARRAY_SURE_SHOT = Symbol(
        [0x75348],
        [0x2351EC8],
        0x28,
        "STATUS_ICON_ARRAY_SURE_SHOT",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::sure_shot * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[5]",
    )

    STATUS_ICON_ARRAY_INVISIBLE = Symbol(
        [0x75370],
        [0x2351EF0],
        0x28,
        "STATUS_ICON_ARRAY_INVISIBLE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::invisible * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[5]",
    )

    STATUS_ICON_ARRAY_SLEEP = Symbol(
        [0x75398],
        [0x2351F18],
        0x40,
        "STATUS_ICON_ARRAY_SLEEP",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::sleep * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[8]",
    )

    STATUS_ICON_ARRAY_CURSE = Symbol(
        [0x753C8],
        [0x2351F48],
        0x38,
        "STATUS_ICON_ARRAY_CURSE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::curse * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[7]",
    )

    STATUS_ICON_ARRAY_FREEZE = Symbol(
        [0x75400],
        [0x2351F80],
        0x40,
        "STATUS_ICON_ARRAY_FREEZE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::freeze * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[8]",
    )

    STATUS_ICON_ARRAY_CRINGE = Symbol(
        [0x75440],
        [0x2351FC0],
        0x40,
        "STATUS_ICON_ARRAY_CRINGE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::cringe * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[8]",
    )

    STATUS_ICON_ARRAY_BIDE = Symbol(
        [0x75480],
        [0x2352000],
        0x70,
        "STATUS_ICON_ARRAY_BIDE",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::bide * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[14]",
    )

    STATUS_ICON_ARRAY_REFLECT = Symbol(
        [0x75580],
        [0x2352100],
        0x90,
        "STATUS_ICON_ARRAY_REFLECT",
        "Array of bit masks used to set monster::status_icon. Indexed by monster::statuses::reflect * 8. See UpdateStatusIconFlags for details.",
        "struct status_icon_flags[18]",
    )

    DIRECTIONS_XY = Symbol(
        [0x757A8],
        [0x2352328],
        0x20,
        "DIRECTIONS_XY",
        "An array mapping each direction index to its x and y displacements.\n\nDirections start with 0=down and proceed counterclockwise (see enum direction_id). Displacements for x and y are interleaved and encoded as 2-byte signed integers. For example, the first two integers are [0, 1], which correspond to the x and y displacements for the 'down' direction (positive y means down).",
        "int16_t[8][2]",
    )

    DISPLACEMENTS_WITHIN_2_LARGEST_FIRST = Symbol(
        [0x75868],
        [0x23523E8],
        None,
        "DISPLACEMENTS_WITHIN_2_LARGEST_FIRST",
        "An array of displacement vectors with max norm <= 2, ordered in descending order by norm.\n\nThe last element, (99, 99), is invalid and used as an end marker.\n\ntype: position[26]",
        "struct position[26]",
    )

    DISPLACEMENTS_WITHIN_2_SMALLEST_FIRST = Symbol(
        [0x758D0],
        [0x2352450],
        None,
        "DISPLACEMENTS_WITHIN_2_SMALLEST_FIRST",
        "An array of displacement vectors with max norm <= 2, ordered in ascending order by norm.\n\nThe last element, (99, 99), is invalid and used as an end marker.\n\ntype: position[26]",
        "struct position[26]",
    )

    DISPLACEMENTS_WITHIN_3 = Symbol(
        [0x75938],
        [0x23524B8],
        None,
        "DISPLACEMENTS_WITHIN_3",
        "An array of displacement vectors with max norm <= 3. The elements are vaguely in ascending order by norm, but not exactly.\n\nThe last element, (99, 99), is invalid and used as an end marker.\n\ntype: position[50]",
        "struct position[50]",
    )

    ITEM_CATEGORY_ACTIONS = Symbol(
        [0x7609C],
        [0x2352C1C],
        0x20,
        "ITEM_CATEGORY_ACTIONS",
        "Action ID associated with each item category. Used by GetItemAction.\n\nEach entry is 2 bytes long.",
        "struct action_16[16]",
    )

    FRACTIONAL_TURN_SEQUENCE = Symbol(
        [0x76310],
        [0x2352E90],
        0xFA,
        "FRACTIONAL_TURN_SEQUENCE",
        "Read by certain functions that are called by RunFractionalTurn to see if they should be executed.\n\nArray is accessed via a pointer added to some multiple of fractional_turn, so that if the resulting memory location is zero, the function returns.",
        "int16_t[125]",
    )

    BELLY_DRAIN_IN_WALLS_INT = Symbol(
        [0x767F4],
        [0x2353374],
        0x2,
        "BELLY_DRAIN_IN_WALLS_INT",
        "The additional amount by which belly is decreased every turn when inside walls (integer part)",
        "uint16_t",
    )

    BELLY_DRAIN_IN_WALLS_THOUSANDTHS = Symbol(
        [0x767F6],
        [0x2353376],
        0x2,
        "BELLY_DRAIN_IN_WALLS_THOUSANDTHS",
        "The additional amount by which belly is decreased every turn when inside walls (fractional thousandths)",
        "uint16_t",
    )

    DAMAGE_MULTIPLIER_0_5 = Symbol(
        [0x768C8],
        [0x2353448],
        None,
        "DAMAGE_MULTIPLIER_0_5",
        "A generic damage multiplier of 0.5 used in various places, as a 64-bit fixed-point number with 16 fraction bits.",
        "struct fx64_16",
    )

    DAMAGE_MULTIPLIER_1_5 = Symbol(
        [0x768D0],
        [0x2353450],
        None,
        "DAMAGE_MULTIPLIER_1_5",
        "A generic damage multiplier of 1.5 used in various places, as a 64-bit fixed-point number with 16 fraction bits.",
        "struct fx64_16",
    )

    DAMAGE_MULTIPLIER_2 = Symbol(
        [0x768D8],
        [0x2353458],
        None,
        "DAMAGE_MULTIPLIER_2",
        "A generic damage multiplier of 2 used in various places, as a 64-bit fixed-point number with 16 fraction bits.",
        "struct fx64_16",
    )

    CLOUDY_DAMAGE_MULTIPLIER = Symbol(
        [0x768E8],
        [0x2353468],
        None,
        "CLOUDY_DAMAGE_MULTIPLIER",
        "The extra damage multiplier for non-Normal-type moves when the weather is Cloudy, as a 64-bit fixed-point number with 16 fraction bits (0.75).",
        "struct fx64_16",
    )

    SOLID_ROCK_MULTIPLIER = Symbol(
        [0x768F0],
        [0x2353470],
        None,
        "SOLID_ROCK_MULTIPLIER",
        "The extra damage multiplier for super-effective moves when Solid Rock or Filter is active, as a 64-bit fixed-point number with 16 fraction bits (0.75).",
        "struct fx64_16",
    )

    DAMAGE_FORMULA_MAX_BASE = Symbol(
        [0x768F8],
        [0x2353478],
        None,
        "DAMAGE_FORMULA_MAX_BASE",
        "The maximum value of the base damage formula (after DAMAGE_FORMULA_NON_TEAM_MEMBER_MODIFIER application, if relevant), as a 64-bit binary fixed-point number with 16 fraction bits (999).",
        "struct fx64_16",
    )

    WONDER_GUARD_MULTIPLIER = Symbol(
        None,
        None,
        None,
        "WONDER_GUARD_MULTIPLIER",
        "The damage multiplier for moves affected by Wonder Guard, as a 64-bit fixed-point number with 16 fraction bits (0).",
        "struct fx64_16",
    )

    DAMAGE_FORMULA_MIN_BASE = Symbol(
        [0x76908],
        [0x2353488],
        None,
        "DAMAGE_FORMULA_MIN_BASE",
        "The minimum value of the base damage formula (after DAMAGE_FORMULA_NON_TEAM_MEMBER_MODIFIER application, if relevant), as a 64-bit binary fixed-point number with 16 fraction bits (1).",
        "struct fx64_16",
    )

    TYPE_DAMAGE_NEGATING_EXCLUSIVE_ITEM_EFFECTS = Symbol(
        [0x76930],
        [0x23534B0],
        None,
        "TYPE_DAMAGE_NEGATING_EXCLUSIVE_ITEM_EFFECTS",
        "List of exclusive item effects that negate damage of a certain type, terminated by a TYPE_NEUTRAL entry.\n\ntype: struct damage_negating_exclusive_eff_entry[28]",
        "struct damage_negating_exclusive_eff_entry[28]",
    )

    TWO_TURN_MOVES_AND_STATUSES = Symbol(
        [0x76B38],
        [0x23536B8],
        0x2C,
        "TWO_TURN_MOVES_AND_STATUSES",
        "List that matches two-turn move IDs to their corresponding status ID. The last entry is null.",
        "struct two_turn_move_and_status[22]",
    )

    SPATK_STAT_IDX = Symbol(
        [0x76B74],
        [0x23536F4],
        0x4,
        "SPATK_STAT_IDX",
        "The index (1) of the special attack entry in internal stat structs, such as the stat modifier array for a monster.",
        "int32_t",
    )

    ATK_STAT_IDX = Symbol(
        [0x76B78],
        [0x23536F8],
        0x4,
        "ATK_STAT_IDX",
        "The index (0) of the attack entry in internal stat structs, such as the stat modifier array for a monster.",
        "int32_t",
    )

    ROLLOUT_DAMAGE_MULT_TABLE = Symbol(
        [0x76B7C],
        [0x23536FC],
        None,
        "ROLLOUT_DAMAGE_MULT_TABLE",
        "A table of damage multipliers for each successive hit of Rollout/Ice Ball. Each entry is a binary fixed-point number with 8 fraction bits.\n\ntype: int32_t[10]",
        "fx32_8[10]",
    )

    MAP_COLOR_TABLE = Symbol(
        [0x7705C],
        [0x2353BDC],
        None,
        "MAP_COLOR_TABLE",
        "In order: white, black, red, green, blue, magenta, dark pink, chartreuse, light orange\n\nNote: unverified, ported from Irdkwia's notes\n\ntype: struct rgba[9]",
        "struct rgba[9]",
    )

    CORNER_CARDINAL_NEIGHBOR_IS_OPEN = Symbol(
        [0x770A4],
        [0x2353C24],
        0x20,
        "CORNER_CARDINAL_NEIGHBOR_IS_OPEN",
        "An array mapping each (corner index, neighbor direction index) to whether or not that neighbor is expected to be open floor.\n\nCorners start with 0=top-left and proceed clockwise. Directions are enumerated as with DIRECTIONS_XY. The array is indexed by i=(corner_index * N_DIRECTIONS + direction). An element of 1 (0) means that starting from the specified corner of a room, moving in the specified direction should lead to an open floor tile (non-open terrain like a wall).\n\nNote that this array is only used for the cardinal directions. The elements at odd indexes are unused and unconditionally set to 0.\n\nThis array is used by the dungeon generation algorithm when generating room imperfections. See GenerateRoomImperfections.",
        "bool[4][8]",
    )

    GUMMI_LIKE_STRING_IDS = Symbol(
        [0x77360],
        [0x2353EE0],
        0x8,
        "GUMMI_LIKE_STRING_IDS",
        "List that holds the string IDs for how much a monster liked a gummi in decreasing order.",
        "int16_t[4]",
    )

    GUMMI_IQ_STRING_IDS = Symbol(
        [0x773BC],
        [0x2353F3C],
        0xA,
        "GUMMI_IQ_STRING_IDS",
        "List that holds the string IDs for how much a monster's IQ was raised by in decreasing order.",
        "int16_t[5]",
    )

    DAMAGE_STRING_IDS = Symbol(
        [0x773C8],
        [0x2353F48],
        None,
        "DAMAGE_STRING_IDS",
        "List that matches the damage_message ID to their corresponding string ID. The null entry at 0xE in the middle is for hunger. The last entry is null.",
        "int16_t[27]",
    )

    DUNGEON_PTR = Symbol(
        [0x775B8],
        [0x2354138],
        0x4,
        "DUNGEON_PTR",
        "[Runtime] Pointer to the dungeon struct in dungeon mode.\n\nThis is a 'working copy' of DUNGEON_PTR_MASTER. The main dungeon engine uses this pointer (or rather pointers to this pointer) when actually running dungeon mode.\n\ntype: struct dungeon*",
        "struct dungeon*",
    )

    DUNGEON_PTR_MASTER = Symbol(
        [0x775BC],
        [0x235413C],
        0x4,
        "DUNGEON_PTR_MASTER",
        "[Runtime] Pointer to the dungeon struct in dungeon mode.\n\nThis is a 'master copy' of the dungeon pointer. The game uses this pointer when doing low-level memory work (allocation, freeing, zeroing). The normal DUNGEON_PTR is used for most other dungeon mode work.\n\ntype: struct dungeon*",
        "struct dungeon*",
    )

    TOP_SCREEN_STATUS_PTR = Symbol(
        [0x775D4],
        [0x2354154],
        0x4,
        "TOP_SCREEN_STATUS_PTR",
        "[Runtime] Pointer for struct for handling the status of the top screen in dungeon mode.\n\ntype: struct top_screen_status",
        "struct top_screen_status*",
    )

    LEADER_PTR = Symbol(
        [0x775DC],
        [0x235415C],
        0x4,
        "LEADER_PTR",
        "[Runtime] Pointer to the current leader of the team.\n\ntype: struct entity*",
        "struct entity*",
    )

    DUNGEON_PRNG_STATE = Symbol(
        [0x775F0],
        [0x2354170],
        0x14,
        "DUNGEON_PRNG_STATE",
        "[Runtime] The global PRNG state for dungeon mode, not including the current values in the secondary sequences.\n\nThis struct holds state for the primary LCG, as well as the current configuration controlling which LCG to use when generating random numbers. See DungeonRand16Bit for more information on how the dungeon PRNG works.\n\ntype: struct prng_state",
        "struct prng_state",
    )

    DUNGEON_PRNG_STATE_SECONDARY_VALUES = Symbol(
        [0x77604],
        [0x2354184],
        0x14,
        "DUNGEON_PRNG_STATE_SECONDARY_VALUES",
        "[Runtime] An array of 5 integers corresponding to the last value generated for each secondary LCG sequence.\n\nBased on the assembly, this appears to be its own global array, separate from DUNGEON_PRNG_STATE.",
        "uint32_t[5]",
    )

    LOADED_ATTACK_SPRITE_FILE_INDEX = Symbol(
        [0x7762C],
        [0x23541AC],
        0x2,
        "LOADED_ATTACK_SPRITE_FILE_INDEX",
        "[Runtime] The file index of the currently loaded attack sprite.\n\ntype: uint16_t",
        "uint16_t",
    )

    LOADED_ATTACK_SPRITE_PACK_ID = Symbol(
        [0x7762E],
        [0x23541AE],
        0x2,
        "LOADED_ATTACK_SPRITE_PACK_ID",
        "[Runtime] The pack id of the currently loaded attack sprite. Should correspond to the id of m_attack.bin\n\ntype: enum pack_file_id",
        "enum pack_file_id",
    )

    EXCL_ITEM_EFFECTS_WEATHER_ATK_SPEED_BOOST = Symbol(
        [0x77630],
        [0x23541B0],
        0x8,
        "EXCL_ITEM_EFFECTS_WEATHER_ATK_SPEED_BOOST",
        "Array of IDs for exclusive item effects that increase attack speed with certain weather conditions.",
        "struct exclusive_item_effect_id_8[8]",
    )

    EXCL_ITEM_EFFECTS_WEATHER_MOVE_SPEED_BOOST = Symbol(
        [0x77638],
        [0x23541B8],
        0x8,
        "EXCL_ITEM_EFFECTS_WEATHER_MOVE_SPEED_BOOST",
        "Array of IDs for exclusive item effects that increase movement speed with certain weather conditions.",
        "struct exclusive_item_effect_id_8[8]",
    )

    EXCL_ITEM_EFFECTS_WEATHER_NO_STATUS = Symbol(
        [0x77640],
        [0x23541C0],
        0x8,
        "EXCL_ITEM_EFFECTS_WEATHER_NO_STATUS",
        "Array of IDs for exclusive item effects that grant status immunity with certain weather conditions.",
        "struct exclusive_item_effect_id_8[8]",
    )

    AI_THROWN_ITEM_ACTION_CHOICE_COUNT = Symbol(
        [0x7777C],
        [0x23542FC],
        0x4,
        "AI_THROWN_ITEM_ACTION_CHOICE_COUNT",
        "[Runtime] Used to store the number of positions output by GetPossibleAiArcItemTargets and the number of directions/probabilities output by GetPossibleAiThrownItemDirections.",
        "uint32_t",
    )

    EXCL_ITEM_EFFECTS_EVASION_BOOST = Symbol(
        [0x77790],
        [0x2354310],
        0x8,
        "EXCL_ITEM_EFFECTS_EVASION_BOOST",
        "Array of IDs for exclusive item effects that grant an evasion boost with certain weather conditions.",
        "struct exclusive_item_effect_id_8[8]",
    )

    DEFAULT_TILE = Symbol(
        [0x777BC],
        [0x235433C],
        0x14,
        "DEFAULT_TILE",
        "The default tile struct.\n\nThis is just a struct full of zeroes, but is used as a fallback in various places where a 'default' tile is needed, such as when a grid index is out of range.\n\ntype: struct tile",
        "struct tile",
    )

    HIDDEN_STAIRS_SPAWN_BLOCKED = Symbol(
        [0x77824],
        [0x23543A4],
        0x1,
        "HIDDEN_STAIRS_SPAWN_BLOCKED",
        "[Runtime] A flag for when Hidden Stairs could normally have spawned on the floor but didn't.\n\nThis is set either when the Hidden Stairs just happen not to spawn by chance, or when the current floor is a rescue or mission destination floor.\n\nThis appears to be part of a larger (8-byte?) struct. It seems like this value is at least followed by 3 bytes of padding and a 4-byte integer field.",
        "bool",
    )

    FIXED_ROOM_DATA_PTR = Symbol(
        [0x7782C],
        [0x23543AC],
        0x4,
        "FIXED_ROOM_DATA_PTR",
        "[Runtime] Pointer to decoded fixed room data loaded from the BALANCE/fixed.bin file.",
        "void*",
    )

    DUNGEON_FADES_PTR = Symbol(
        [0x77878],
        [0x23543F8],
        0x4,
        "DUNGEON_FADES_PTR",
        "[Runtime] Pointer to the dungeon fades struct that maintains the status of screen fades in dungeon mode.",
        "struct dungeon_fades*",
    )

    NECTAR_IQ_BOOST = Symbol(
        [0x40264],
        [0x231CDE4],
        None,
        "NECTAR_IQ_BOOST",
        "IQ boost from ingesting Nectar.",
        "struct data_processing_instruction",
    )

    COMPRESSED_SPRITE_BUFFER_SIZE = Symbol(
        [0x6FFEC],
        [0x234CB6C],
        None,
        "COMPRESSED_SPRITE_BUFFER_SIZE",
        "Size of the buffer to store the current sprite to decompress.",
        "struct data_processing_instruction",
    )


class EuOverlay29Section:
    name = "overlay29"
    description = "The dungeon engine.\n\nThis is the 'main' overlay of dungeon mode. It controls most things that happen in a Mystery Dungeon, such as dungeon layout generation, dungeon menus, enemy AI, and generally just running each turn while within a dungeon."
    loadaddress = 0x22DCB80
    length = 0x77900
    functions = EuOverlay29Functions
    data = EuOverlay29Data


class EuOverlay3Functions:

    pass


class EuOverlay3Data:

    pass


class EuOverlay3Section:
    name = "overlay3"
    description = "Controls the Friend Rescue submenu within the top menu."
    loadaddress = 0x233D200
    length = 0xA160
    functions = EuOverlay3Functions
    data = EuOverlay3Data


class EuOverlay30Functions:

    WriteQuicksaveData = Symbol(
        [0x448],
        [0x2383868],
        None,
        "WriteQuicksaveData",
        "Function responsible for writing dungeon data when quicksaving.\n\nAmong other things, it contains a loop that goes through all the monsters in the current dungeon, copying their data to the buffer. The data is not copied as-is though, the game uses a reduced version of the monster struct containing only the minimum required data to resume the game later.\n\nr0: Pointer to buffer where data should be written\nr1: Buffer size. Seems to be 0x5800 (22 KB) when the function is called.",
        None,
    )


class EuOverlay30Data:

    OVERLAY30_JP_STRING_1 = Symbol(
        [0x3864], [0x2386C84], 0xC, "OVERLAY30_JP_STRING_1", "みさき様", ""
    )

    OVERLAY30_JP_STRING_2 = Symbol(
        [0x3870], [0x2386C90], 0xC, "OVERLAY30_JP_STRING_2", "やよい様", ""
    )


class EuOverlay30Section:
    name = "overlay30"
    description = "Controls quicksaving in dungeons."
    loadaddress = 0x2383420
    length = 0x38A0
    functions = EuOverlay30Functions
    data = EuOverlay30Data


class EuOverlay31Functions:

    EntryOverlay31 = Symbol(
        [0x0],
        [0x2383420],
        None,
        "EntryOverlay31",
        "Note: unverified, ported from Irdkwia's notes\n\nNo params.",
        None,
    )

    DrawDungeonMenuStatusWindow = Symbol(
        [0x44],
        [0x2383464],
        None,
        "DrawDungeonMenuStatusWindow",
        "Draws the contents shown in the main dungeon menu status window showing the player's belly, money, play time, etc.\n\nr0: int",
        None,
    )

    DungeonMenuSwitch = Symbol(
        [0x2A0],
        [0x23836C0],
        None,
        "DungeonMenuSwitch",
        "Note: unverified, ported from Irdkwia's notes\n\nr0: appears to be an index of some sort, probably the menu index based on the function name?",
        None,
    )

    CreateStairsMenuState = Symbol(
        [0x6B4],
        [0x2383AD4],
        None,
        "CreateStairsMenuState",
        "Called when the leader steps on any stairs tile (regular, warp zone, rescue point, hidden stairs).\n\nAllocates a stairs_menu struct on the heap with information for HandleStairsMenu, which will be pointed to by STAIRS_MENU_PTR.\n\nr0: Entity pointer (in practice, always the leader)",
        None,
    )

    StairsSubheadingCallback = Symbol(
        [0x748],
        [0x2383B68],
        None,
        "StairsSubheadingCallback",
        "Callback function passed to CreateAdvancedTextBox for creating the subheading for the stairs menu.\n\nr0: window_id",
        None,
    )

    HandleStairsMenu = Symbol(
        [0x79C],
        [0x2383BBC],
        None,
        "HandleStairsMenu",
        "Handles displaying the stairs menu and is called on each frame while it is open, also updating the leader's action fields.\n\nUses a switch statement based on the state field in stairs_menu to determine what actions to take.\n\nreturn: int",
        None,
    )

    MovesMenu = Symbol(
        [0x29A0],
        [0x2385DC0],
        None,
        "MovesMenu",
        "Displays a menu showing the moves of a monster. Does not return until the menu is closed.\n\nThis function does not get called when opening the leader's move menu.\n\nr0: Pointer to an action struct containing the index of the monster whose moves will be checked in the action_use_idx field.",
        None,
    )

    HandleMovesMenuWrapper0 = Symbol(
        [0x2B9C],
        [0x2385FBC],
        None,
        "HandleMovesMenuWrapper0",
        "Sets some field on a struct to 0 and calls HandleMovesMenu.\n\nr0: struct pointer, see HandleMovesMenu\nr1: See HandleMovesMenu\nr2: See HandleMovesMenu\nr3: monster index, see HandleMovesMenu\nreturn: bool, see HandleMovesMenu",
        None,
    )

    HandleMovesMenuWrapper1 = Symbol(
        [0x2BC0],
        [0x2385FE0],
        None,
        "HandleMovesMenuWrapper1",
        "Sets some field on a struct to 1 and calls HandleMovesMenu.\n\nr0: struct pointer, see HandleMovesMenu\nr1: See HandleMovesMenu\nr2: See HandleMovesMenu\nr3: monster index, see HandleMovesMenu\nreturn: bool, see HandleMovesMenu",
        None,
    )

    HandleMovesMenu = Symbol(
        [0x2BE4],
        [0x2386004],
        None,
        "HandleMovesMenu",
        "Handles the different options on the moves menu. Does not return until the menu is closed.\n\nThis function also takes care of updating the fields in the action_data struct it receives when a menu option is chosen.\n\nr0: Pointer to some struct that was created by a previous function. Contains a pointer to the monster whose moves are being displayed at offset 0x0.\nr1: ?\nr2: ?\nr3: Index of the monster whose moves are going to be displayed on the menu. Unused.\nreturn: True if the menu was closed without selecting anything, false if an option was chosen.",
        None,
    )

    TeamMenu = Symbol(
        [0x4850],
        [0x2387C70],
        None,
        "TeamMenu",
        "Called when the in-dungeon 'team' menu is open. Does not return until the menu is closed.\n\nNote that selecting certain options in this menu (such as viewing the details or the moves of a pokémon) counts as switching to a different menu, which causes the function to return.\n\nr0: Pointer to the leader's entity struct\nreturn: ?",
        None,
    )

    RestMenu = Symbol(
        [0x5F90],
        [0x23893B0],
        None,
        "RestMenu",
        "Called when the in-dungeon 'rest' menu is open. Does not return until the menu is closed.\n\nNo params.",
        None,
    )

    RecruitmentSearchMenuLoop = Symbol(
        [0x6408],
        [0x2389828],
        None,
        "RecruitmentSearchMenuLoop",
        "Called on each frame while the in-dungeon 'recruitment search' menu is open.\n\nreturn: int (Actually, this is probably some sort of enum shared by all the MenuLoop functions)",
        None,
    )

    HelpMenuLoop = Symbol(
        [0x6A00],
        [0x2389E20],
        None,
        "HelpMenuLoop",
        "Called on each frame while the in-dungeon 'help' menu is open.\n\nThe menu is still considered open while one of the help pages is being viewed, so this function keeps being called even after choosing an option.\n\nreturn: int (Actually, this is probably some sort of enum shared by all the MenuLoop functions)",
        None,
    )


class EuOverlay31Data:

    DUNGEON_WINDOW_PARAMS_1 = Symbol(
        [0x7598],
        [0x238A9B8],
        0x10,
        "DUNGEON_WINDOW_PARAMS_1",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_2 = Symbol(
        [0x75A8],
        [0x238A9C8],
        0x10,
        "DUNGEON_WINDOW_PARAMS_2",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_3 = Symbol(
        [0x75B8],
        [0x238A9D8],
        0x10,
        "DUNGEON_WINDOW_PARAMS_3",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_4 = Symbol(
        [0x75C8],
        [0x238A9E8],
        0x10,
        "DUNGEON_WINDOW_PARAMS_4",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_MAIN_MENU_ITEMS = Symbol(
        [0x75D8],
        [0x238A9F8],
        0x40,
        "DUNGEON_MAIN_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[8]",
    )

    DUNGEON_MENU_SWITCH_STR1 = Symbol(
        [0x7618], [0x238AA38], 0xC, "DUNGEON_MENU_SWITCH_STR1", "", "char[12]"
    )

    OVERLAY31_UNKNOWN_STRING_IDS = Symbol(
        [0x7624],
        [0x238AA44],
        None,
        "OVERLAY31_UNKNOWN_STRING_IDS",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_STRUCT__NA_2389E30 = Symbol(
        [0x7634],
        [0x238AA54],
        None,
        "OVERLAY31_UNKNOWN_STRUCT__NA_2389E30",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DUNGEON_WINDOW_PARAMS_5 = Symbol(
        [0x7644],
        [0x238AA64],
        0x10,
        "DUNGEON_WINDOW_PARAMS_5",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_6 = Symbol(
        [0x7654],
        [0x238AA74],
        0x10,
        "DUNGEON_WINDOW_PARAMS_6",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_7 = Symbol(
        [0x7664],
        [0x238AA84],
        0x10,
        "DUNGEON_WINDOW_PARAMS_7",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_SUBMENU_ITEMS_1 = Symbol(
        [0x7674],
        [0x238AA94],
        0x20,
        "DUNGEON_SUBMENU_ITEMS_1",
        "",
        "struct simple_menu_id_item[4]",
    )

    DUNGEON_SUBMENU_ITEMS_2 = Symbol(
        [0x7694],
        [0x238AAB4],
        0x20,
        "DUNGEON_SUBMENU_ITEMS_2",
        "",
        "struct simple_menu_id_item[4]",
    )

    DUNGEON_SUBMENU_ITEMS_3 = Symbol(
        [0x76B4],
        [0x238AAD4],
        0x20,
        "DUNGEON_SUBMENU_ITEMS_3",
        "",
        "struct simple_menu_id_item[4]",
    )

    DUNGEON_SUBMENU_ITEMS_4 = Symbol(
        [0x76D4],
        [0x238AAF4],
        0x20,
        "DUNGEON_SUBMENU_ITEMS_4",
        "",
        "struct simple_menu_id_item[4]",
    )

    OVERLAY31_UNKNOWN_STRUCT__NA_2389EF0 = Symbol(
        [0x76F4],
        [0x238AB14],
        None,
        "OVERLAY31_UNKNOWN_STRUCT__NA_2389EF0",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DUNGEON_WINDOW_PARAMS_8 = Symbol(
        [0x7700],
        [0x238AB20],
        0x10,
        "DUNGEON_WINDOW_PARAMS_8",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_9 = Symbol(
        [0x7710],
        [0x238AB30],
        0x10,
        "DUNGEON_WINDOW_PARAMS_9",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_10 = Symbol(
        [0x7720],
        [0x238AB40],
        0x10,
        "DUNGEON_WINDOW_PARAMS_10",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_11 = Symbol(
        [0x7730],
        [0x238AB50],
        0x10,
        "DUNGEON_WINDOW_PARAMS_11",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_12 = Symbol(
        [0x7740],
        [0x238AB60],
        0x10,
        "DUNGEON_WINDOW_PARAMS_12",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_13 = Symbol(
        [0x7750],
        [0x238AB70],
        0x10,
        "DUNGEON_WINDOW_PARAMS_13",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY31_JP_STRING = Symbol(
        [0x7768],
        [0x238AB88],
        None,
        "OVERLAY31_JP_STRING",
        "\n\n----　 初期ポジション=%d　----- \n",
        "",
    )

    DUNGEON_WINDOW_PARAMS_14 = Symbol(
        [0x778C],
        [0x238ABAC],
        0x10,
        "DUNGEON_WINDOW_PARAMS_14",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_15 = Symbol(
        [0x779C],
        [0x238ABBC],
        0x10,
        "DUNGEON_WINDOW_PARAMS_15",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_16 = Symbol(
        [0x77AC],
        [0x238ABCC],
        0x10,
        "DUNGEON_WINDOW_PARAMS_16",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_17 = Symbol(
        [0x77BC],
        [0x238ABDC],
        0x10,
        "DUNGEON_WINDOW_PARAMS_17",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_18 = Symbol(
        [0x77CC],
        [0x238ABEC],
        0x10,
        "DUNGEON_WINDOW_PARAMS_18",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_19 = Symbol(
        [0x77DC],
        [0x238ABFC],
        0x10,
        "DUNGEON_WINDOW_PARAMS_19",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY31_UNKNOWN_STRUCT__NA_2389FE8 = Symbol(
        [0x77EC],
        [0x238AC0C],
        None,
        "OVERLAY31_UNKNOWN_STRUCT__NA_2389FE8",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DUNGEON_WINDOW_PARAMS_20 = Symbol(
        [0x77F8],
        [0x238AC18],
        0x10,
        "DUNGEON_WINDOW_PARAMS_20",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_21 = Symbol(
        [0x7808],
        [0x238AC28],
        0x10,
        "DUNGEON_WINDOW_PARAMS_21",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_22 = Symbol(
        [0x7818],
        [0x238AC38],
        0x10,
        "DUNGEON_WINDOW_PARAMS_22",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_23 = Symbol(
        [0x7828],
        [0x238AC48],
        0x10,
        "DUNGEON_WINDOW_PARAMS_23",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_24 = Symbol(
        [0x7838],
        [0x238AC58],
        0x10,
        "DUNGEON_WINDOW_PARAMS_24",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_25 = Symbol(
        [0x7910],
        [0x238AD30],
        0x10,
        "DUNGEON_WINDOW_PARAMS_25",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_SUBMENU_ITEMS_5 = Symbol(
        [0x7920],
        [0x238AD40],
        0x18,
        "DUNGEON_SUBMENU_ITEMS_5",
        "",
        "struct simple_menu_id_item[3]",
    )

    DUNGEON_WINDOW_PARAMS_26 = Symbol(
        [0x7938],
        [0x238AD58],
        0x10,
        "DUNGEON_WINDOW_PARAMS_26",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY31_UNKNOWN_STRUCT__NA_238A144 = Symbol(
        [0x7948],
        [0x238AD68],
        None,
        "OVERLAY31_UNKNOWN_STRUCT__NA_238A144",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DUNGEON_WINDOW_PARAMS_27 = Symbol(
        [0x7974],
        [0x238AD94],
        0x10,
        "DUNGEON_WINDOW_PARAMS_27",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_28 = Symbol(
        [0x7984],
        [0x238ADA4],
        0x10,
        "DUNGEON_WINDOW_PARAMS_28",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY31_UNKNOWN_STRUCT__NA_238A190 = Symbol(
        [0x7994],
        [0x238ADB4],
        None,
        "OVERLAY31_UNKNOWN_STRUCT__NA_238A190",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    DUNGEON_SUBMENU_ITEMS_6 = Symbol(
        [0x79A4],
        [0x238ADC4],
        0x48,
        "DUNGEON_SUBMENU_ITEMS_6",
        "",
        "struct simple_menu_id_item[9]",
    )

    DUNGEON_WINDOW_PARAMS_29 = Symbol(
        [0x79EC],
        [0x238AE0C],
        0x10,
        "DUNGEON_WINDOW_PARAMS_29",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_30 = Symbol(
        [0x79FC],
        [0x238AE1C],
        0x10,
        "DUNGEON_WINDOW_PARAMS_30",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_31 = Symbol(
        [0x7A0C],
        [0x238AE2C],
        0x10,
        "DUNGEON_WINDOW_PARAMS_31",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    DUNGEON_WINDOW_PARAMS_32 = Symbol(
        [0x7A1C],
        [0x238AE3C],
        0x10,
        "DUNGEON_WINDOW_PARAMS_32",
        "Note: unverified, ported from Irdkwia's notes",
        "struct window_params",
    )

    OVERLAY31_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY31_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A260 = Symbol(
        [0x7A60],
        [0x238AE80],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A260",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_VALUE__NA_238A264 = Symbol(
        None,
        None,
        None,
        "OVERLAY31_UNKNOWN_VALUE__NA_238A264",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A268 = Symbol(
        [0x7A68],
        [0x238AE88],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A268",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A26C = Symbol(
        [0x7A6C],
        [0x238AE8C],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A26C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A270 = Symbol(
        [0x7A70],
        [0x238AE90],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A270",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A274 = Symbol(
        None,
        None,
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A274",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A278 = Symbol(
        None,
        None,
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A278",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A27C = Symbol(
        [0x7A7C],
        [0x238AE9C],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A27C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A280 = Symbol(
        [0x7A80],
        [0x238AEA0],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A280",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A284 = Symbol(
        [0x7A84],
        [0x238AEA4],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A284",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A288 = Symbol(
        [0x7A88],
        [0x238AEA8],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A288",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY31_UNKNOWN_POINTER__NA_238A28C = Symbol(
        [0x7A8C],
        [0x238AEAC],
        None,
        "OVERLAY31_UNKNOWN_POINTER__NA_238A28C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay31Section:
    name = "overlay31"
    description = "Controls the dungeon menu (during dungeon mode)."
    loadaddress = 0x2383420
    length = 0x7AA0
    functions = EuOverlay31Functions
    data = EuOverlay31Data


class EuOverlay32Functions:

    pass


class EuOverlay32Data:

    pass


class EuOverlay32Section:
    name = "overlay32"
    description = "Unused; all zeroes."
    loadaddress = 0x2383420
    length = 0x20
    functions = EuOverlay32Functions
    data = EuOverlay32Data


class EuOverlay33Functions:

    pass


class EuOverlay33Data:

    pass


class EuOverlay33Section:
    name = "overlay33"
    description = "Unused; all zeroes."
    loadaddress = 0x2383420
    length = 0x20
    functions = EuOverlay33Functions
    data = EuOverlay33Data


class EuOverlay34Functions:

    ExplorersOfSkyMain = Symbol(
        [0x0],
        [0x22DCB80],
        None,
        "ExplorersOfSkyMain",
        "The main function for Explorers of Sky.\n\nNote: unverified, ported from Irdkwia's notes\n\nr0: probably a game mode ID?\nreturn: probably a return code?",
        None,
    )


class EuOverlay34Data:

    OVERLAY34_UNKNOWN_STRUCT__NA_22DD014 = Symbol(
        [0xD3C],
        [0x22DD8BC],
        None,
        "OVERLAY34_UNKNOWN_STRUCT__NA_22DD014",
        "1*0x4 + 3*0x4\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    START_MENU_ITEMS_CONFIRM = Symbol(
        [0xD4C],
        [0x22DD8CC],
        0x18,
        "START_MENU_ITEMS_CONFIRM",
        "",
        "struct simple_menu_id_item[3]",
    )

    OVERLAY34_UNKNOWN_STRUCT__NA_22DD03C = Symbol(
        [0xD64],
        [0x22DD8E4],
        None,
        "OVERLAY34_UNKNOWN_STRUCT__NA_22DD03C",
        "1*0x4 + 3*0x4\n\nNote: unverified, ported from Irdkwia's notes",
        "",
    )

    DUNGEON_DEBUG_MENU_ITEMS = Symbol(
        [0xD74],
        [0x22DD8F4],
        0x28,
        "DUNGEON_DEBUG_MENU_ITEMS",
        "",
        "struct simple_menu_id_item[5]",
    )

    OVERLAY34_RESERVED_SPACE = Symbol(
        None,
        None,
        None,
        "OVERLAY34_RESERVED_SPACE",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY34_UNKNOWN_POINTER__NA_22DD080 = Symbol(
        [0xDA0],
        [0x22DD920],
        None,
        "OVERLAY34_UNKNOWN_POINTER__NA_22DD080",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY34_UNKNOWN_POINTER__NA_22DD084 = Symbol(
        [0xDA4],
        [0x22DD924],
        None,
        "OVERLAY34_UNKNOWN_POINTER__NA_22DD084",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY34_UNKNOWN_POINTER__NA_22DD088 = Symbol(
        None,
        None,
        None,
        "OVERLAY34_UNKNOWN_POINTER__NA_22DD088",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY34_UNKNOWN_POINTER__NA_22DD08C = Symbol(
        [0xDAC],
        [0x22DD92C],
        None,
        "OVERLAY34_UNKNOWN_POINTER__NA_22DD08C",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )

    OVERLAY34_UNKNOWN_POINTER__NA_22DD090 = Symbol(
        None,
        None,
        None,
        "OVERLAY34_UNKNOWN_POINTER__NA_22DD090",
        "Note: unverified, ported from Irdkwia's notes",
        "",
    )


class EuOverlay34Section:
    name = "overlay34"
    description = "Related to launching the game.\n\nThere are mention in the strings of logos like the ESRB logo. This only seems to be loaded during the ESRB rating splash screen, so this is likely the sole purpose of this overlay."
    loadaddress = 0x22DCB80
    length = 0xDC0
    functions = EuOverlay34Functions
    data = EuOverlay34Data


class EuOverlay35Functions:

    pass


class EuOverlay35Data:

    pass


class EuOverlay35Section:
    name = "overlay35"
    description = "Unused; all zeroes."
    loadaddress = 0x22BD3C0
    length = 0x20
    functions = EuOverlay35Functions
    data = EuOverlay35Data


class EuOverlay4Functions:

    pass


class EuOverlay4Data:

    pass


class EuOverlay4Section:
    name = "overlay4"
    description = "Controls the Trade Items submenu within the top menu."
    loadaddress = 0x233D200
    length = 0x2BE0
    functions = EuOverlay4Functions
    data = EuOverlay4Data


class EuOverlay5Functions:

    pass


class EuOverlay5Data:

    pass


class EuOverlay5Section:
    name = "overlay5"
    description = "Controls the Trade Team submenu within the top menu."
    loadaddress = 0x233D200
    length = 0x3240
    functions = EuOverlay5Functions
    data = EuOverlay5Data


class EuOverlay6Functions:

    pass


class EuOverlay6Data:

    pass


class EuOverlay6Section:
    name = "overlay6"
    description = "Controls the Wonder Mail S submenu within the top menu."
    loadaddress = 0x233D200
    length = 0x2460
    functions = EuOverlay6Functions
    data = EuOverlay6Data


class EuOverlay7Functions:

    pass


class EuOverlay7Data:

    pass


class EuOverlay7Section:
    name = "overlay7"
    description = (
        "Controls the Nintendo WFC submenu within the top menu (under 'Other')."
    )
    loadaddress = 0x233D200
    length = 0x3300
    functions = EuOverlay7Functions
    data = EuOverlay7Data


class EuOverlay8Functions:

    pass


class EuOverlay8Data:

    pass


class EuOverlay8Section:
    name = "overlay8"
    description = (
        "Controls the Send Demo Dungeon submenu within the top menu (under 'Other')."
    )
    loadaddress = 0x233D200
    length = 0x2620
    functions = EuOverlay8Functions
    data = EuOverlay8Data


class EuOverlay9Functions:

    CreateJukeboxTrackMenu = Symbol(
        [0x15B0],
        [0x233E7B0],
        None,
        "CreateJukeboxTrackMenu",
        "Creates a window containing the track selection menu for the Sky Jukebox. Also see struct jukebox_track_menu.\n\nIf window_params is NULL, JUKEBOX_TRACK_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: simple_menu_id_item struct array, terminated with an item with string_id 0\nstack[0]: number of menu items\nreturn: window_id",
        None,
    )

    CloseJukeboxTrackMenu = Symbol(
        [0x18CC],
        [0x233EACC],
        None,
        "CloseJukeboxTrackMenu",
        "Closes a window created with CreateJukeboxTrackMenu.\n\nr0: window_id",
        None,
    )

    IsJukeboxTrackMenuActive = Symbol(
        [0x1904],
        [0x233EB04],
        None,
        "IsJukeboxTrackMenuActive",
        "This is a guess.\n\nChecks if the state of a jukebox track menu is something other than 7 or 8.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateJukeboxTrackMenu = Symbol(
        [0x195C],
        [0x233EB5C],
        None,
        "UpdateJukeboxTrackMenu",
        "Window update function for jukebox track menus.\n\nr0: window pointer",
        None,
    )

    CreatePlaybackControlsMenu = Symbol(
        [0x1E98],
        [0x233F098],
        None,
        "CreatePlaybackControlsMenu",
        "Creates a window containing the playback controls menu for a selected song. Also see struct playback_controls_menu.\n\nIf window_params is NULL, PLAYBACK_CONTROLS_MENU_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::width and/or window_params::height are 0, they will be computed based on the contained text.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: ?\nstack[0]: simple_menu_id_item struct array 1, terminated with an item with string_id 0\nstack[1]: simple_menu_id_item struct array 2, terminated with an item with string_id 0\nreturn: window_id",
        None,
    )

    ClosePlaybackControlsMenu = Symbol(
        [0x21D8],
        [0x233F3D8],
        None,
        "ClosePlaybackControlsMenu",
        "Closes a window created with CreatePlaybackControlsMenu.\n\nr0: window_id",
        None,
    )

    IsPlaybackControlsMenuActive = Symbol(
        [0x227C],
        [0x233F47C],
        None,
        "IsPlaybackControlsMenuActive",
        "This is a guess.\n\nChecks if the state of a playback controls menu is something other than 7 or 8.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdatePlaybackControlsMenu = Symbol(
        [0x2304],
        [0x233F504],
        None,
        "UpdatePlaybackControlsMenu",
        "Window update function for playback controls menus.\n\nr0: window pointer",
        None,
    )

    CreateInputLockBox = Symbol(
        [0x2790],
        [0x233F990],
        None,
        "CreateInputLockBox",
        "Creates a window containing the 'Locked' text when inputs are locked while a song is playing. Also see struct input_lock_box.\n\nIf window_params is NULL, INPUT_LOCK_BOX_DEFAULT_WINDOW_PARAMS will be used. Otherwise, it will be copied onto the window, ignoring the update and contents fields. If window_params::height is 0, it will default to 2.\n\nIf window_extra_info is non-NULL, it will be copied onto the window. Note that window_extra_info can only be NULL if there are no window_flags set that require extra info.\n\nr0: window_params\nr1: window_flags\nr2: window_extra_info pointer\nr3: ?\nstack[0]: string ID\nreturn: window_id",
        None,
    )

    CloseInputLockBox = Symbol(
        [0x2940],
        [0x233FB40],
        None,
        "CloseInputLockBox",
        "Closes a window created with InputLockBox.\n\nr0: window_id",
        None,
    )

    IsInputLockBoxActive = Symbol(
        [0x295C],
        [0x233FB5C],
        None,
        "IsInputLockBoxActive",
        "This is a guess.\n\nChecks if the state of an input lock box is not 4.\n\nr0: window_id\nreturn: bool",
        None,
    )

    UpdateInputLockBox = Symbol(
        [0x297C],
        [0x233FB7C],
        None,
        "UpdateInputLockBox",
        "Window update function for input lock boxes.\n\nr0: window pointer",
        None,
    )


class EuOverlay9Data:

    JUKEBOX_TRACK_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x2D1C],
        [0x233FF1C],
        None,
        "JUKEBOX_TRACK_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a jukebox_track_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreateJukeboxTrackMenu.\n\nAdditionally, width and height are 0, and will be computed in CreateJukeboxTrackMenu.",
        "struct window_params",
    )

    PLAYBACK_CONTROLS_MENU_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x2D2C],
        [0x233FF2C],
        None,
        "PLAYBACK_CONTROLS_MENU_DEFAULT_WINDOW_PARAMS",
        "Default window_params for a playback_controls_menu.\n\nNote that x_offset and y_offset refer to the right and bottom edges, since they will be paired with the x_offset_end and y_offset_end window flags in CreatePlaybackControlsMenu.\n\nAdditionally, width and height are 0, and will be computed in CreatePlaybackControlsMenu.",
        "struct window_params",
    )

    INPUT_LOCK_BOX_DEFAULT_WINDOW_PARAMS = Symbol(
        [0x2D3C],
        [0x233FF3C],
        None,
        "INPUT_LOCK_BOX_DEFAULT_WINDOW_PARAMS",
        "Default window_params for an input_lock_box.",
        "struct window_params",
    )

    TOP_MENU_RETURN_MUSIC_ID = Symbol(
        [0xE80],
        [0x233E080],
        None,
        "TOP_MENU_RETURN_MUSIC_ID",
        "Song playing in the main menu when returning from the Sky Jukebox.",
        "struct data_processing_instruction",
    )


class EuOverlay9Section:
    name = "overlay9"
    description = "Controls the Sky Jukebox."
    loadaddress = 0x233D200
    length = 0x2D80
    functions = EuOverlay9Functions
    data = EuOverlay9Data


class EuRamFunctions:

    pass


class EuRamData:

    DEFAULT_MEMORY_ARENA_MEMORY = Symbol(
        None,
        None,
        None,
        "DEFAULT_MEMORY_ARENA_MEMORY",
        "The memory region for the default memory arena.\n\nThe length is defined by DEFAULT_MEMORY_ARENA_SIZE.\n\nOne mode that uses this region for heap allocations is dungeon mode.",
        "uint8_t[1991680]",
    )

    GROUND_MEMORY_ARENA_2 = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_2",
        "This is a memory subarena under DEFAULT_MEMORY_ARENA used for some things in ground mode.\n\nIt's used for user_flags 14.\n\nIncluding the allocator metadata, this arena occupies 0xB0000 bytes of space.\n\ntype: struct mem_arena",
        "struct mem_arena",
    )

    GROUND_MEMORY_ARENA_2_BLOCKS = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_2_BLOCKS",
        "The block array for GROUND_MEMORY_ARENA_2.\n\ntype: struct mem_block[32]",
        "struct mem_block[32]",
    )

    GROUND_MEMORY_ARENA_2_MEMORY = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_2_MEMORY",
        "The memory region for GROUND_MEMORY_ARENA_2.",
        "uint8_t[720100]",
    )

    DUNGEON_COLORMAP_PTR = Symbol(
        [0x1BA634],
        [0x21BA634],
        0x4,
        "DUNGEON_COLORMAP_PTR",
        "Pointer to a colormap used to render colors in a dungeon.\n\nThe colormap is a list of 4-byte RGB colors of the form {R, G, B, padding}, which the game indexes into when rendering colors. Some weather conditions modify the colormap, which is how the color scheme changes when it's, e.g., raining.",
        "struct rgba*",
    )

    DUNGEON_STRUCT = Symbol(
        [0x1BA674],
        [0x21BA674],
        0x2CB14,
        "DUNGEON_STRUCT",
        "The dungeon context struct used for tons of stuff in dungeon mode. See struct dungeon in the C headers.\n\nThis struct never seems to be referenced directly, and is instead usually accessed via DUNGEON_PTR in overlay 29.\n\ntype: struct dungeon",
        "struct dungeon",
    )

    MOVE_DATA_TABLE = Symbol(
        [0x211D0C],
        [0x2211D0C],
        0x38C6,
        "MOVE_DATA_TABLE",
        "The move data table loaded directly from /BALANCE/waza_p.bin. See struct move_data_table in the C headers.\n\nPointed to by MOVE_DATA_TABLE_PTR in the ARM 9 binary.\n\ntype: struct move_data_table",
        "struct move_data_table",
    )

    SOUND_MEMORY_ARENA = Symbol(
        None,
        None,
        None,
        "SOUND_MEMORY_ARENA",
        "This is a memory subarena under DEFAULT_MEMORY_ARENA that seems to be used exclusively for sound data.\n\nIncluding allocator metadata, this subarena occupies 0x3C000 bytes of space within the default arena.\n\nIt's referenced by various sound functions like LoadDseFile, PlaySeLoad, and PlayBgm when allocating memory.\n\ntype: struct mem_arena",
        "struct mem_arena",
    )

    SOUND_MEMORY_ARENA_BLOCKS = Symbol(
        None,
        None,
        None,
        "SOUND_MEMORY_ARENA_BLOCKS",
        "The block array for SOUND_MEMORY_ARENA.\n\ntype: struct mem_block[20]",
        "struct mem_block[20]",
    )

    SOUND_MEMORY_ARENA_MEMORY = Symbol(
        None,
        None,
        None,
        "SOUND_MEMORY_ARENA_MEMORY",
        "The memory region for SOUND_MEMORY_ARENA.\n\nThis region appears to be used for sound-related heap allocations, like when loading sound files into memory.",
        "uint8_t[245252]",
    )

    FRAMES_SINCE_LAUNCH = Symbol(
        [0x2A3E8C, 0x2A3EDC],
        [0x22A3E8C, 0x22A3EDC],
        0x4,
        "FRAMES_SINCE_LAUNCH",
        "Starts at 0 when the game is first launched, and continuously ticks up once per frame while the game is running.",
        "uint32_t",
    )

    TOUCHSCREEN_STATUS = Symbol(
        [0x2A3F1C],
        [0x22A3F1C],
        0x104,
        "TOUCHSCREEN_STATUS",
        "Status of the touchscreen, including the coordinates of the currently pressed position in pixels.",
        "struct touchscreen_status",
    )

    BAG_ITEMS = Symbol(
        [0x2A4164],
        [0x22A4164],
        0x12C,
        "BAG_ITEMS",
        "Array of item structs within the player's bag.\n\nWhile the game only allows a maximum of 48 items during normal play, it seems to read up to 50 item slots if filled.\n\ntype: struct item[50]",
        "struct item[50]",
    )

    BAG_ITEMS_PTR = Symbol(
        [0x2A44E8],
        [0x22A44E8],
        0x4,
        "BAG_ITEMS_PTR",
        "Pointer to BAG_ITEMS.",
        "struct item*",
    )

    STORAGE_ITEMS = Symbol(
        [0x2A44EE],
        [0x22A44EE],
        0x7D0,
        "STORAGE_ITEMS",
        "Array of item IDs in the player's item storage.\n\nFor stackable items, the quantities are stored elsewhere, in STORAGE_ITEM_QUANTITIES.\n\ntype: struct item_id_16[1000]",
        "struct item_id_16[1000]",
    )

    STORAGE_ITEM_QUANTITIES = Symbol(
        [0x2A4CBE],
        [0x22A4CBE],
        0x7D0,
        "STORAGE_ITEM_QUANTITIES",
        "Array of 1000 2-byte (unsigned) quantities corresponding to the item IDs in STORAGE_ITEMS.\n\nIf the corresponding item ID is not a stackable item, the entry in this array is unused, and will be 0.",
        "uint16_t[1000]",
    )

    KECLEON_SHOP_ITEMS_PTR = Symbol(
        [0x2A5490],
        [0x22A5490],
        0x4,
        "KECLEON_SHOP_ITEMS_PTR",
        "Pointer to KECLEON_SHOP_ITEMS.",
        "struct bulk_item*",
    )

    KECLEON_SHOP_ITEMS = Symbol(
        [0x2A5494],
        [0x22A5494],
        0x20,
        "KECLEON_SHOP_ITEMS",
        "Array of up to 8 items in the Kecleon Shop.\n\nIf there are fewer than 8 items, the array is expected to be null-terminated.\n\ntype: struct bulk_item[8]",
        "struct bulk_item[8]",
    )

    UNUSED_KECLEON_SHOP_ITEMS = Symbol(
        [0x2A54B4],
        [0x22A54B4],
        0x20,
        "UNUSED_KECLEON_SHOP_ITEMS",
        "Seems to be another array like KECLEON_SHOP_ITEMS, but don't actually appear to be used by the Kecleon Shop.",
        "struct bulk_item[8]",
    )

    KECLEON_WARES_ITEMS_PTR = Symbol(
        [0x2A54D4],
        [0x22A54D4],
        0x4,
        "KECLEON_WARES_ITEMS_PTR",
        "Pointer to KECLEON_WARES_ITEMS.",
        "struct bulk_item*",
    )

    KECLEON_WARES_ITEMS = Symbol(
        [0x2A54D8],
        [0x22A54D8],
        0x10,
        "KECLEON_WARES_ITEMS",
        "Array of up to 4 items in Kecleon Wares.\n\nIf there are fewer than 4 items, the array is expected to be null-terminated.\n\ntype: struct bulk_item[4]",
        "struct bulk_item[4]",
    )

    UNUSED_KECLEON_WARES_ITEMS = Symbol(
        [0x2A54E8],
        [0x22A54E8],
        0x10,
        "UNUSED_KECLEON_WARES_ITEMS",
        "Seems to be another array like KECLEON_WARES_ITEMS, but don't actually appear to be used by Kecleon Wares.",
        "struct bulk_item[4]",
    )

    MONEY_CARRIED = Symbol(
        [0x2A54F8],
        [0x22A54F8],
        0x4,
        "MONEY_CARRIED",
        "The amount of money the player is currently carrying.",
        "int32_t",
    )

    MONEY_STORED = Symbol(
        [0x2A5504],
        [0x22A5504],
        0x4,
        "MONEY_STORED",
        "The amount of money the player currently has stored in the Duskull Bank.",
        "int32_t",
    )

    AUDIO_COMMANDS_BUFFER = Symbol(
        [0x2A5599],
        [0x22A5599],
        0x200,
        "AUDIO_COMMANDS_BUFFER",
        "Buffer used to store audio commands. 16 entries in total. Seems like entries are removed at some point (maybe after the commands are read or after they finish executing).",
        "struct audio_command[16]",
    )

    CURSOR_16_SPRITE_ID = Symbol(
        [0x2AB5A4],
        [0x22AB5A4],
        0x2,
        "CURSOR_16_SPRITE_ID",
        "Id of the 'FONT/cursor_16.wan' sprite loaded in WAN_TABLE",
        "uint16_t",
    )

    CURSOR_SPRITE_ID = Symbol(
        [0x2AB5A6],
        [0x22AB5A6],
        0x2,
        "CURSOR_SPRITE_ID",
        "Id of the 'FONT/cursor.wan' sprite loaded in WAN_TABLE",
        "uint16_t",
    )

    CURSOR_ANIMATION_CONTROL = Symbol(
        [0x2AB5C0],
        [0x22AB5C0],
        0x7C,
        "CURSOR_ANIMATION_CONTROL",
        "animation_control of 'FONT/cursor.wan'",
        "struct animation_control*",
    )

    CURSOR_16_ANIMATION_CONTROL = Symbol(
        [0x2AB63C],
        [0x22AB63C],
        0x7C,
        "CURSOR_16_ANIMATION_CONTROL",
        "animation_control of 'FONT/cursor_16.wan'",
        "struct animation_control*",
    )

    ALERT_SPRITE_ID = Symbol(
        [0x2AB6B8],
        [0x22AB6B8],
        0x2,
        "ALERT_SPRITE_ID",
        "Id of the 'FONT/alert.wan' sprite loaded in WAN_TABLE",
        "uint16_t",
    )

    ALERT_ANIMATION_CONTROL = Symbol(
        [0x2AB6BC],
        [0x22AB6BC],
        0x7C,
        "ALERT_ANIMATION_CONTROL",
        "animation_control of 'FONT/alter.wan'",
        "struct animation_control*",
    )

    SOUND_MEMORY_ARENA_PTR = Symbol(
        None,
        None,
        None,
        "SOUND_MEMORY_ARENA_PTR",
        "Pointer to SOUND_MEMORY_ARENA.",
        "struct mem_arena*",
    )

    WINDOW_LIST = Symbol(
        None,
        None,
        None,
        "WINDOW_LIST",
        "Array of all window structs. Newly created window structs are taken from slots in this array.\n\nNote that this array isn't strictly ordered in any way. A newly created window will occupy the first available slot. If a window in an early slot is destroyed, windows that are still active in later slots won't be shifted back unless destroyed and recreated.\n\ntype: struct window_list",
        "struct window_list",
    )

    LAST_NEW_MOVE = Symbol(
        [0x2AB78C],
        [0x22AB78C],
        0x8,
        "LAST_NEW_MOVE",
        "Move struct of the last new move introduced when learning a new move. Persists even after the move selection is made in the menu.\n\ntype: struct move",
        "struct move",
    )

    SCRIPT_VARS_VALUES = Symbol(
        [0x2AB9EC],
        [0x22AB9EC],
        0x400,
        "SCRIPT_VARS_VALUES",
        "The table of game variable values. Its structure is determined by SCRIPT_VARS.\n\nNote that with the script variable list defined in SCRIPT_VARS, the used length of this table is actually only 0x2B4. However, the real length of this table is 0x400 based on the game code.\n\ntype: struct script_var_value_table",
        "struct script_var_value_table",
    )

    BAG_LEVEL = Symbol(
        [0x2ABA9C],
        [0x22ABA9C],
        0x1,
        "BAG_LEVEL",
        "The player's bag level, which determines the bag capacity. This indexes directly into the BAG_CAPACITY_TABLE in the ARM9 binary.",
        "uint8_t",
    )

    DEBUG_SPECIAL_EPISODE_NUMBER = Symbol(
        [0x2ABDEC],
        [0x22ABDEC],
        0x1,
        "DEBUG_SPECIAL_EPISODE_NUMBER",
        "The number of the special episode currently being played.\n\nThis backs the EXECUTE_SPECIAL_EPISODE_TYPE script variable.\n\ntype: struct special_episode_type_8",
        "struct special_episode_type_8",
    )

    KAOMADO_STREAM = Symbol(
        None,
        None,
        None,
        "KAOMADO_STREAM",
        "The file stream utilized for all Kaomado portrait loads.\n\ntype: struct file_stream",
        "struct file_stream",
    )

    PENDING_DUNGEON_ID = Symbol(
        [0x2ABE3C],
        [0x22ABE3C],
        0x1,
        "PENDING_DUNGEON_ID",
        "The ID of the selected dungeon when setting off from the overworld.\n\nControls the text and map location during the 'map cutscene' just before entering a dungeon, as well as the actual dungeon loaded afterwards.\n\nThis field is actually part of a larger struct that also contains PENDING_STARTING_FLOOR.\n\ntype: struct dungeon_id_8",
        "struct dungeon_id_8",
    )

    PENDING_STARTING_FLOOR = Symbol(
        [0x2ABE3D],
        [0x22ABE3D],
        0x1,
        "PENDING_STARTING_FLOOR",
        "The floor number to start from in the dungeon specified by PENDING_DUNGEON_ID.",
        "uint8_t",
    )

    PLAY_TIME_SECONDS = Symbol(
        [0x2ABFD4],
        [0x22ABFD4],
        0x4,
        "PLAY_TIME_SECONDS",
        "The player's total play time in seconds.",
        "uint32_t",
    )

    PLAY_TIME_FRAME_COUNTER = Symbol(
        [0x2ABFD8],
        [0x22ABFD8],
        0x1,
        "PLAY_TIME_FRAME_COUNTER",
        "Counts from 0-59 in a loop, with the play time being incremented by 1 second with each rollover.",
        "uint8_t",
    )

    TEAM_NAME = Symbol(
        [0x2AC258],
        [0x22AC258],
        0xC,
        "TEAM_NAME",
        "The team name.\n\nA null-terminated string, with a maximum length of 10. Presumably encoded with the ANSI/Shift JIS encoding the game typically uses.\n\nThis is presumably part of a larger struct, together with other nearby data.",
        "char[10]",
    )

    LEVEL_UP_DATA_MONSTER_ID = Symbol(
        [0x2AC26C],
        [0x22AC26C],
        0x2,
        "LEVEL_UP_DATA_MONSTER_ID",
        "ID of the monster whose level-up data is currently stored in LEVEL_UP_DATA_DECOMPRESS_BUFFER.",
        "struct monster_id_16",
    )

    LEVEL_UP_DATA_DECOMPRESS_BUFFER = Symbol(
        [0x2AC270],
        [0x22AC270],
        0x4B0,
        "LEVEL_UP_DATA_DECOMPRESS_BUFFER",
        "Buffer used to stored a monster's decompressed level up data. Used by GetLvlUpEntry.\n\nExact size is a guess (100 levels * 12 bytes per entry = 1200 = 0x4B0).",
        "struct level_up_entry[100]",
    )

    TEAM_MEMBER_TABLE = Symbol(
        [0x2AC720],
        [0x22AC720],
        0x99A8,
        "TEAM_MEMBER_TABLE",
        "Table with all team members, persistent information about them, and information about which ones are currently active.\n\nSee the comments on struct team_member_table for more information.\n\ntype: struct team_member_table",
        "struct team_member_table",
    )

    DRIVER_WORK = Symbol([0x2B7C70], [0x22B7C70], None, "DRIVER_WORK", "", "")

    DISP_MODE = Symbol([0x2B9EC8], [0x22B9EC8], 0x2, "DISP_MODE", "", "uint16_t")

    GXI_VRAM_LOCK_ID = Symbol(
        [0x2B9ECA], [0x22B9ECA], 0x2, "GXI_VRAM_LOCK_ID", "", "uint16_t"
    )

    ENABLED_VRAM_BANKS = Symbol(
        [0x2B9ECC],
        [0x22B9ECC],
        0x2,
        "ENABLED_VRAM_BANKS",
        "Bitset of enabled VRAM banks\n\ntype: vram_banks_set",
        "struct vram_banks_set",
    )

    SUB_BG_EXT_PLTT = Symbol(
        [0x2B9EE8], [0x22B9EE8], 0x4, "SUB_BG_EXT_PLTT", "", "undefined4"
    )

    CLR_IMG = Symbol([0x2B9F04], [0x22B9F04], 0x4, "CLR_IMG", "", "undefined4")

    THREAD_INFO_STRUCT = Symbol(
        [0x2B9F88],
        [0x22B9F88],
        None,
        "THREAD_INFO_STRUCT",
        "thread_info struct that contains global state about threads",
        "struct thread_info",
    )

    FRAMES_SINCE_LAUNCH_TIMES_THREE = Symbol(
        [0x2BA304],
        [0x22BA304],
        0x4,
        "FRAMES_SINCE_LAUNCH_TIMES_THREE",
        "Starts at 0 when the game is first launched, and ticks up by 3 per frame while the game is running.",
        "uint32_t",
    )

    GROUND_MEMORY_ARENA_1_PTR = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_1_PTR",
        "Pointer to GROUND_MEMORY_ARENA_1.",
        "struct mem_arena*",
    )

    GROUND_MEMORY_ARENA_2_PTR = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_2_PTR",
        "Pointer to GROUND_MEMORY_ARENA_2.",
        "struct mem_arena*",
    )

    LOCK_NOTIFY_ARRAY = Symbol(
        [0x3259F4],
        [0x23259F4],
        0x14,
        "LOCK_NOTIFY_ARRAY",
        "Used to notify scripts waiting for a certain lock to unlock so they can resume their execution.\n\n1 byte per lock. Exact size isn't confirmed, it could potentially be longer.",
        "bool[20]",
    )

    GROUND_MEMORY_ARENA_1 = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_1",
        "This is a top-level memory arena used for some things in ground mode.\n\nIt's used for user_flags 8, 15, and 16.\n\nIncluding the allocator metadata, this arena occupies 0x64000 bytes of space.\n\ntype: struct mem_arena",
        "struct mem_arena",
    )

    GROUND_MEMORY_ARENA_1_BLOCKS = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_1_BLOCKS",
        "The block array for GROUND_MEMORY_ARENA_1.\n\ntype: struct mem_block[52]",
        "struct mem_block[52]",
    )

    GROUND_MEMORY_ARENA_1_MEMORY = Symbol(
        None,
        None,
        None,
        "GROUND_MEMORY_ARENA_1_MEMORY",
        "The memory region for GROUND_MEMORY_ARENA_1.",
        "uint8_t[408324]",
    )

    SENTRY_DUTY_STRUCT = Symbol(
        None, None, None, "SENTRY_DUTY_STRUCT", "", "struct sentry_duty"
    )

    TURNING_ON_THE_SPOT_FLAG = Symbol(
        [0x37D5A6],
        [0x237D5A6],
        0x1,
        "TURNING_ON_THE_SPOT_FLAG",
        "[Runtime] Flag for whether the player is turning on the spot (pressing Y).",
        "bool",
    )

    LOADED_ATTACK_SPRITE_DATA = Symbol(
        [0x37D5AC],
        [0x237D5AC],
        0x4,
        "LOADED_ATTACK_SPRITE_DATA",
        "[Runtime] Pointer to the dynamically allocated structure relating to the currently loaded attack sprite, in dungeon mode.\n\ntype: struct loaded_attack_sprite_data*",
        "struct loaded_attack_sprite_data*",
    )

    AI_THROWN_ITEM_DIRECTION_IS_USED = Symbol(
        [0x37D5D0],
        [0x237D5D0],
        0x8,
        "AI_THROWN_ITEM_DIRECTION_IS_USED",
        "[Runtime] Used in GetPossibleAiThrownItemDirections to indicate whether a certain direction enum value is already being used or not.",
        "bool[8]",
    )

    AI_THROWN_ITEM_DIRECTIONS = Symbol(
        [0x37D5D8],
        [0x237D5D8],
        0x20,
        "AI_THROWN_ITEM_DIRECTIONS",
        "[Runtime] Used to store the directions output by GetPossibleAiThrownItemDirections.",
        "uint32_t[8]",
    )

    AI_THROWN_ITEM_PROBABILITIES = Symbol(
        [0x37D5F8],
        [0x237D5F8],
        0x20,
        "AI_THROWN_ITEM_PROBABILITIES",
        "[Runtime] Used to store the probabilities matching the directions in THROWN_ITEM_DIRECTIONS.",
        "uint32_t[8]",
    )

    ROLLOUT_ICE_BALL_MISSED = Symbol(
        None,
        None,
        None,
        "ROLLOUT_ICE_BALL_MISSED",
        "[Runtime] Appears to be set to true whenever a hit from Rollout or Ice Ball fails to deal damage.",
        "bool",
    )

    MULTIHIT_FATIGUE_MOVE_USED = Symbol(
        None,
        None,
        None,
        "MULTIHIT_FATIGUE_MOVE_USED",
        "[Runtime] Appears to be set to true whenever a multihit fatigue move deals damage.",
        "bool",
    )

    TWINEEDLE_HIT_TRACKER = Symbol(
        [0x37D66B],
        [0x237D66B],
        None,
        "TWINEEDLE_HIT_TRACKER",
        "[Runtime] Appears to be set to true whenever Twineedle hits and deals damage. So that even if the second attack misses, it will still try to poison the target.",
        "bool",
    )

    RAPID_SPIN_BINDING_REMOVAL = Symbol(
        [0x37D66D],
        [0x237D66D],
        None,
        "RAPID_SPIN_BINDING_REMOVAL",
        "[Runtime] Appears to be set to true when using Rapid Spin to later remove any binding effects and Leech Seed.",
        "bool",
    )

    ROLLOUT_ICE_BALL_SUCCESSIVE_HITS = Symbol(
        None,
        None,
        None,
        "ROLLOUT_ICE_BALL_SUCCESSIVE_HITS",
        "[Runtime] Seems to count the number of successive hits by Rollout or Ice Ball.",
        "int",
    )

    MULTIHIT_MOVE_SUCCESSIVE_HITS = Symbol(
        [0x37D678],
        [0x237D678],
        None,
        "MULTIHIT_MOVE_SUCCESSIVE_HITS",
        "[Runtime] Seems to count the number of successive hits for multihit moves. This is used by Twineedle to check to attempt to apply Poison after the second attack.",
        "int",
    )

    TRIPLE_KICK_SUCCESSIVE_HITS = Symbol(
        [0x37D67C],
        [0x237D67C],
        None,
        "TRIPLE_KICK_SUCCESSIVE_HITS",
        "[Runtime] Seems to count the number of successive hits by Triple Kick.",
        "int",
    )

    METRONOME_NEXT_INDEX = Symbol(
        None,
        None,
        None,
        "METRONOME_NEXT_INDEX",
        "[Runtime] The index into METRONOME_TABLE for the next usage of Metronome.",
        "int",
    )

    FLOOR_GENERATION_STATUS = Symbol(
        [0x37DBBC],
        [0x237DBBC],
        0x40,
        "FLOOR_GENERATION_STATUS",
        "[Runtime] Status data related to generation of the current floor in a dungeon.\n\nThis data is populated as the dungeon floor is generated.\n\ntype: struct floor_generation_status",
        "struct floor_generation_status",
    )

    STAIRS_MENU_PTR = Symbol(
        [0x38AEC4],
        [0x238AEC4],
        0x4,
        "STAIRS_MENU_PTR",
        "Pointer to the stairs_menu struct.",
        "struct stairs_menu*",
    )


class EuRamSection:
    name = "ram"
    description = "Main memory.\nData in this file aren't located in the ROM itself, and are instead constructs loaded at runtime.\n\nMore specifically, this file is a dumping ground for addresses that are useful to know about, but don't fall in the address ranges of any of the other files. Dynamically loaded constructs that do fall within the address range of a relevant binary should be listed in the corresponding YAML file of that binary, since it still has direct utility when reverse-engineering that particular binary."
    loadaddress = 0x2000000
    length = 0x400000
    functions = EuRamFunctions
    data = EuRamData


class EuSections:

    arm7 = EuArm7Section

    arm9 = EuArm9Section

    itcm = EuItcmSection

    libs = EuLibsSection

    move_effects = EuMove_effectsSection

    overlay0 = EuOverlay0Section

    overlay1 = EuOverlay1Section

    overlay10 = EuOverlay10Section

    overlay11 = EuOverlay11Section

    overlay12 = EuOverlay12Section

    overlay13 = EuOverlay13Section

    overlay14 = EuOverlay14Section

    overlay15 = EuOverlay15Section

    overlay16 = EuOverlay16Section

    overlay17 = EuOverlay17Section

    overlay18 = EuOverlay18Section

    overlay19 = EuOverlay19Section

    overlay2 = EuOverlay2Section

    overlay20 = EuOverlay20Section

    overlay21 = EuOverlay21Section

    overlay22 = EuOverlay22Section

    overlay23 = EuOverlay23Section

    overlay24 = EuOverlay24Section

    overlay25 = EuOverlay25Section

    overlay26 = EuOverlay26Section

    overlay27 = EuOverlay27Section

    overlay28 = EuOverlay28Section

    overlay29 = EuOverlay29Section

    overlay3 = EuOverlay3Section

    overlay30 = EuOverlay30Section

    overlay31 = EuOverlay31Section

    overlay32 = EuOverlay32Section

    overlay33 = EuOverlay33Section

    overlay34 = EuOverlay34Section

    overlay35 = EuOverlay35Section

    overlay4 = EuOverlay4Section

    overlay5 = EuOverlay5Section

    overlay6 = EuOverlay6Section

    overlay7 = EuOverlay7Section

    overlay8 = EuOverlay8Section

    overlay9 = EuOverlay9Section

    ram = EuRamSection
